'use strict';

var configState = require('./config-state-Dz9bnWHg.js');
var utils = require('./utils-DqlrBltg.js');

const Api = () => {
    async function getAuthorizationHeader(authToken) {
        if (!authToken) {
            return {
                'Content-Type': 'application/json',
            };
        }
        return {
            Authorization: `Bearer ${authToken}`,
            'Idempotency-Key': utils.generateId(),
            'Content-Type': 'application/json',
        };
    }
    async function makeRequest(props) {
        const { authToken, endpoint, method, params, body, signal, headers } = props;
        await configState.waitForConfig();
        const apiOrigin = configState.configState.apiOrigin;
        const url = `${apiOrigin}/v1/${endpoint}`;
        const requestUrl = params ? `${url}?${new URLSearchParams(params)}` : url;
        const defaultHeaders = await getAuthorizationHeader(authToken);
        const mergedHeaders = Object.assign(Object.assign({}, defaultHeaders), headers);
        const response = await fetch(requestUrl, {
            method: method,
            headers: mergedHeaders,
            body: body,
            signal: signal,
        });
        if (response) {
            return response.status === 204 ? {} : response.json();
        }
        handleError(requestUrl);
    }
    async function get(props) {
        const { authToken, endpoint, params, signal, headers } = props;
        return makeRequest({ authToken, endpoint, method: 'GET', params, signal, headers });
    }
    async function post(props) {
        const { authToken, endpoint, body, params, signal, headers } = props;
        return makeRequest({
            authToken,
            endpoint,
            method: 'POST',
            params,
            body: JSON.stringify(body),
            signal,
            headers,
        });
    }
    async function put(props) {
        const { authToken, endpoint, body, params, signal } = props;
        return makeRequest({
            authToken,
            endpoint,
            method: 'PUT',
            params,
            body: JSON.stringify(body),
            signal,
        });
    }
    async function patch(props) {
        const { authToken, endpoint, body, params, signal } = props;
        return makeRequest({
            authToken,
            endpoint,
            method: 'PATCH',
            params,
            body: JSON.stringify(body),
            signal,
        });
    }
    async function destroy(props) {
        const { authToken, endpoint, params, signal } = props;
        return makeRequest({ authToken, endpoint, method: 'DELETE', params, signal });
    }
    return { get, post, put, patch, destroy };
};
function handleError(requestUrl) {
    console.error(`Error fetching from ${requestUrl}`);
}

exports.Api = Api;
