'use strict';

var index_esm = require('./index.esm-CVuJLXJZ.js');
var schemaValidations = require('./schema-validations-BSeMee-o.js');

const businessCoreInfoSchema = (allowOptionalFields) => {
    const schema = index_esm.create$3({
        legal_name: schemaValidations.businessNameValidation.required('Enter legal name'),
        website_url: schemaValidations.websiteUrlValidation.required('Enter business website url'),
        email: schemaValidations.emailValidation.required('Enter business email'),
        phone: schemaValidations.phoneValidation.required('Enter phone number'),
        doing_business_as: schemaValidations.doingBusinessAsValidation.nullable(),
        classification: schemaValidations.businessClassificationValidation.required('Select business classification'),
        industry: schemaValidations.industryValidation.required('Enter a business industry'),
        tax_id: schemaValidations.taxIdValidation.required('Enter valid tax ID (SSN or EIN) without dashes'),
        date_of_incorporation: schemaValidations.dateOfIncorporationValidation.required('Enter date of incorporation'),
    });
    const easySchema = index_esm.create$3({
        legal_name: schemaValidations.businessNameValidation.required('Enter legal name'),
        website_url: schemaValidations.websiteUrlValidation.nullable(),
        email: schemaValidations.emailValidation.nullable(),
        phone: schemaValidations.phoneValidation.nullable(),
        doing_business_as: schemaValidations.doingBusinessAsValidation.nullable(),
        classification: schemaValidations.businessClassificationValidation.nullable(),
        industry: schemaValidations.industryValidation.nullable(),
        tax_id: schemaValidations.taxIdValidation.nullable(),
        date_of_incorporation: schemaValidations.dateOfIncorporationValidation.nullable(),
    });
    return allowOptionalFields ? easySchema : schema;
};

const additionalQuestionsSchema = (allowOptionalFields) => {
    const schema = index_esm.create$3({
        business_revenue: schemaValidations.revenueValidation.required('Enter business revenue'),
        business_payment_volume: schemaValidations.paymentVolumeValidation.required('Enter business payment volume'),
        business_when_service_received: schemaValidations.whenServiceReceivedValidation.required('Select when service is received'),
        business_recurring_payments: schemaValidations.recurringPaymentsValidation.required('Select recurring payments'),
        business_recurring_payments_percentage: schemaValidations.recurringPaymentsPercentageValidation,
        business_seasonal: schemaValidations.seasonalBusinessValidation.required('Select business seasonal'),
        business_other_payment_details: schemaValidations.otherPaymentDetailsValidation.nullable(),
    });
    const easySchema = index_esm.create$3({
        business_revenue: schemaValidations.revenueValidation.nullable(),
        business_payment_volume: schemaValidations.paymentVolumeValidation.nullable(),
        business_when_service_received: schemaValidations.whenServiceReceivedValidation.nullable(),
        business_recurring_payments: schemaValidations.recurringPaymentsValidation.nullable(),
        business_recurring_payments_percentage: schemaValidations.recurringPaymentsPercentageValidation,
        business_seasonal: schemaValidations.seasonalBusinessValidation.nullable(),
        business_other_payment_details: schemaValidations.otherPaymentDetailsValidation.nullable(),
    });
    return allowOptionalFields ? easySchema : schema;
};

exports.additionalQuestionsSchema = additionalQuestionsSchema;
exports.businessCoreInfoSchema = businessCoreInfoSchema;
