'use strict';

var index_esm = require('./index.esm-CVuJLXJZ.js');
var schemaValidations = require('./schema-validations-BSeMee-o.js');

const addressSchema = (allowOptionalFields) => {
    const schema = index_esm.create$3({
        line1: schemaValidations.lineOneValidation.required('Enter street address'),
        line2: schemaValidations.lineTwoValidation.nullable(),
        city: schemaValidations.cityValidation.required('Enter city'),
        state: schemaValidations.stateValidation.required('Select state'),
        postal_code: schemaValidations.postalValidation.required('Enter postal code'),
        country: index_esm.create$6().required('Select country')
    });
    const easySchema = index_esm.create$3({
        line1: schemaValidations.lineOneValidation.nullable(),
        line2: schemaValidations.lineTwoValidation.nullable(),
        city: schemaValidations.cityValidation.nullable(),
        state: schemaValidations.stateValidation.nullable(),
        postal_code: schemaValidations.postalValidation.nullable(),
        country: index_esm.create$6().required('Select country')
    });
    return allowOptionalFields ? easySchema : schema;
};

const identitySchema = (role, allowOptionalFields) => {
    const schema = index_esm.create$3({
        name: schemaValidations.identityNameValidation.required(`Enter ${role} name`),
        title: schemaValidations.identityTitleValidation.required(`Enter ${role} title`),
        email: schemaValidations.emailValidation.required(`Enter ${role} email`),
        phone: schemaValidations.phoneValidation.required('Enter phone number'),
        dob_full: schemaValidations.dobValidation(role).required('Enter date of birth'),
        ssn_last4: index_esm.create$6().nullable(),
        identification_number: schemaValidations.ssnValidation,
        address: addressSchema(allowOptionalFields),
    });
    const easySchema = index_esm.create$3({
        name: schemaValidations.identityNameValidation.required(`Enter ${role} name`),
        title: schemaValidations.identityTitleValidation.nullable(),
        email: schemaValidations.emailValidation.nullable(),
        phone: schemaValidations.phoneValidation.nullable(),
        dob_full: schemaValidations.dobValidation(role).nullable(),
        ssn_last4: index_esm.create$6().nullable(),
        identification_number: schemaValidations.ssnValidation.nullable(),
        address: addressSchema(allowOptionalFields),
    });
    return allowOptionalFields ? easySchema : schema;
};

exports.addressSchema = addressSchema;
exports.identitySchema = identitySchema;
