'use strict';

var index = require('./index-D5bL1DOi.js');
require('./config-state-Dz9bnWHg.js');
require('./dinero-J-SRFKIR.js');
require('./ComponentError-CEv9ltwy.js');
require('./Refund-08OcZkXX.js');
var Pagination = require('./Pagination-Dediz133.js');
require('./Business-DCRzZf0w.js');
require('./Dispute-CruQTF6_.js');
var table = require('./table-CxvETNS1.js');
var eventTypes = require('./event-types-YOY5TKUN.js');
var checkoutsTable = require('./checkouts-table-Cp7rNkNd.js');
var checkoutsListParamsState = require('./checkouts-list-params-state-DZUKBmLC.js');
require('./index-BCtVWU61.js');
require('./_commonjsHelpers-BJu3ubxk.js');
require('./utils-DqlrBltg.js');
require('./helpers-B5OCqlIM.js');
require('./state-options-CIT9xdTz.js');
require('./parts-9jMf1erK.js');
require('./spinner-CIZFX7bz.js');
require('./badge-DDksduwk.js');

const CheckoutsListCore = class {
    constructor(hostRef) {
        index.registerInstance(this, hostRef);
        this.clickEvent = index.createEvent(this, "click-event");
        this.errorEvent = index.createEvent(this, "error-event");
        this.checkouts = [];
        this.subAccounts = [];
        this.loading = true;
        this.paging = Pagination.pagingDefaults;
        this.pagingParams = {};
        this.handleClickPrevious = (beforeCursor) => {
            this.pagingParams = { before_cursor: beforeCursor };
            this.clickEvent.emit({ name: eventTypes.TableClickActions.previous });
        };
        this.handleClickNext = (afterCursor) => {
            this.pagingParams = { after_cursor: afterCursor };
            this.clickEvent.emit({ name: eventTypes.TableClickActions.next });
        };
        this.rowClickHandler = (e) => {
            const clickedCheckoutID = e.target.closest('tr').dataset.rowEntityId;
            if (!clickedCheckoutID)
                return;
            const checkoutData = this.checkouts.find((checkout) => checkout.id === clickedCheckoutID);
            this.clickEvent.emit({ name: eventTypes.TableClickActions.row, data: checkoutData });
        };
    }
    updateOnPropChange() {
        this.fetchData();
    }
    componentWillLoad() {
        this.checkoutsTable = new table.Table(this.checkouts, this.columns, checkoutsTable.checkoutTableColumns, checkoutsTable.checkoutTableCells);
        if (this.getCheckouts && this.getSubAccounts) {
            this.fetchData();
        }
        checkoutsListParamsState.onQueryParamsChange('set', () => {
            this.pagingParams = {};
        });
        checkoutsListParamsState.onQueryParamsChange('reset', () => {
            this.pagingParams = {};
            this.errorMessage = '';
        });
    }
    fetchData() {
        this.loading = true;
        this.getCheckouts({
            params: this.checkoutParams,
            onSuccess: async ({ checkouts, pagingInfo }) => {
                this.checkouts = checkouts;
                this.paging = pagingInfo;
                this.checkoutsTable.collectionData = this.checkouts;
                const shouldFetchSubAccounts = this.checkoutsTable.columnKeys.includes('sub_account_name');
                if (shouldFetchSubAccounts) {
                    await this.fetchSubAccounts();
                }
                else {
                    this.loading = false;
                }
            },
            onError: ({ error, code, severity }) => {
                this.errorMessage = error;
                this.errorEvent.emit({
                    errorCode: code,
                    message: error,
                    severity,
                });
                this.loading = false;
            },
        });
    }
    async fetchSubAccounts() {
        this.getSubAccounts({
            params: this.subAccountParams,
            onSuccess: ({ subAccounts }) => {
                this.subAccounts = subAccounts;
                this.checkouts = this.checkouts.map((checkout) => {
                    var _a;
                    checkout.sub_account_name = (_a = this.subAccounts.find((subAccount) => subAccount.id === checkout.account_id)) === null || _a === void 0 ? void 0 : _a.name;
                    return checkout;
                });
                this.loading = false;
            },
            onError: ({ error, code, severity }) => {
                this.errorMessage = error;
                this.errorEvent.emit({
                    errorCode: code,
                    message: error,
                    severity,
                });
                this.loading = false;
            },
        });
    }
    get checkoutParams() {
        const requestParams = checkoutsListParamsState.getRequestParams();
        const params = Object.assign(Object.assign({}, requestParams), this.pagingParams);
        return params;
    }
    get subAccountParams() {
        let accountIdNumbers = this.checkouts.map((checkout) => checkout.account_id);
        let uniqueAccountIds = [...new Set(accountIdNumbers)];
        let accountIdString = uniqueAccountIds.join(',');
        return { sub_account_id: accountIdString };
    }
    get entityId() {
        return this.checkouts.map((checkout) => checkout.id);
    }
    get showEmptyState() {
        return !this.loading && !this.errorMessage && this.checkoutsTable.rowData.length < 1;
    }
    get showErrorState() {
        return !this.loading && !!this.errorMessage;
    }
    get showRowData() {
        return !this.showEmptyState && !this.showErrorState && !this.loading;
    }
    render() {
        return (index.h(table.TableWrapper, { key: 'ac27fa8b086e64e53a287f96be1d1212a7c23fc3' }, index.h(table.TableComponent, { key: '965b9e4761f686a254297a753b638952181d9758' }, index.h(table.TableHead, { key: '41502bb86d87acd8f730f22705d82a2bb4c3787c' }, index.h(table.TableHeadRow, { key: '9aa770a8bbb3c9623fde336580dcecda0ee6909e' }, this.checkoutsTable.columnData.map((column) => column))), index.h(table.TableBody, { key: 'ad20f6287a2eefd0aa659925cf4be8a03766c1c2' }, index.h(table.TableLoadingState, { key: 'bdd7d89bed12c4451199b59e2793cc3d4dbc24a8', columnSpan: this.checkoutsTable.columnKeys.length, isLoading: this.loading }), index.h(table.TableEmptyState, { key: '8b89063a5cc78beb42a52375c431e834583ef12a', isEmpty: this.showEmptyState, columnSpan: this.checkoutsTable.columnKeys.length }), index.h(table.TableErrorState, { key: 'a557b0a68af21a5501139433f980a6c083536d71', columnSpan: this.checkoutsTable.columnKeys.length, errorMessage: this.errorMessage }), this.showRowData && this.checkoutsTable.rowData.map((data, index$1) => (index.h(table.TableRow, { "data-test-id": "table-row", "data-row-entity-id": this.entityId[index$1], onClick: this.rowClickHandler }, data)))), this.paging && (index.h(table.TableFoot, { key: '0ba995e692b70214b1f63f3fbb7e05e76f229304' }, index.h(table.TableFootRow, { key: '25703345e36b46ce3a4cd9d09893c744b6db4d86' }, index.h(table.TableFootCell, { key: '07f5df6019322cb80053e4c061a2b5cb6ba7187e', colSpan: this.checkoutsTable.columnData.length }, index.h("pagination-menu", { key: 'daf2dd74a5f24192c9052a2906459a6d2b53544d', paging: Object.assign(Object.assign({}, this.paging), { handleClickPrevious: this.handleClickPrevious, handleClickNext: this.handleClickNext }) }))))))));
    }
    static get watchers() { return {
        "pagingParams": ["updateOnPropChange"],
        "getCheckouts": ["updateOnPropChange"],
        "getSubAccounts": ["updateOnPropChange"],
        "columns": ["updateOnPropChange"]
    }; }
};

exports.checkouts_list_core = CheckoutsListCore;
