'use strict';

var index = require('./index-D5bL1DOi.js');
var utils = require('./utils-DqlrBltg.js');
var badge = require('./badge-DDksduwk.js');
var parts = require('./parts-9jMf1erK.js');

const MapCheckoutStatusToBadge = (status) => {
    const statusToBadgeProps = {
        created: {
            variant: badge.BadgeVariant.PRIMARY,
            title: 'The checkout has been created',
            text: 'Created',
        },
        completed: {
            variant: badge.BadgeVariant.SUCCESS,
            title: 'The checkout has been completed',
            text: 'Completed',
        },
        attempted: {
            variant: badge.BadgeVariant.SECONDARY,
            title: 'The checkout has been attempted',
            text: 'Attempted',
        },
        expired: {
            variant: badge.BadgeVariant.DANGER,
            title: 'The checkout has expired',
            text: 'Expired',
        },
    };
    const badgeProps = statusToBadgeProps[status];
    return index.h(badge.Badge, Object.assign({}, badgeProps));
};

const defaultColumnsKeys = 'created_at,payment_amount,payment_description,payment_mode,status';
const checkoutTableColumns = {
    created_at: () => (index.h("th", { part: parts.tableHeadCell, scope: "col", title: "The date each checkout occurred" }, "Processed On")),
    payment_amount: () => (index.h("th", { part: parts.tableHeadCell, scope: "col", title: "The dollar amount of each checkout" }, "Payment Amount")),
    payment_description: () => (index.h("th", { part: parts.tableHeadCell, scope: "col", title: "The description of each checkout" }, "Payment Description")),
    sub_account_name: () => (index.h("th", { part: parts.tableHeadCell, scope: "col", title: "The sub account associated with the checkout" }, "Sub Account")),
    payment_mode: () => (index.h("th", { part: parts.tableHeadCell, scope: "col", title: "The payment mode of each checkout" }, "Payment Mode")),
    status: () => (index.h("th", { part: parts.tableHeadCell, scope: "col", title: "The current status of each checkout" }, "Status")),
};
const checkoutTableCells = {
    created_at: (checkout, index$1) => (index.h("td", { part: parts.getAlternateTableCellPart(index$1) },
        index.h("div", { class: "fw-bold" }, utils.formatDate(checkout.created_at)),
        index.h("div", { class: "fw-bold" }, utils.formatTime(checkout.created_at)))),
    payment_amount: (checkout, index$1) => (index.h("td", { part: parts.getAlternateTableCellPart(index$1) }, checkout.formattedPaymentAmount(checkout.payment_amount))),
    payment_description: (checkout, index$1) => (index.h("td", { part: parts.getAlternateTableCellPart(index$1) }, checkout.payment_description)),
    sub_account_name: (checkout, index$1) => (index.h("td", { part: parts.getAlternateTableCellPart(index$1) }, checkout.sub_account_name)),
    payment_mode: (checkout, index$1) => (index.h("td", { part: parts.getAlternateTableCellPart(index$1) }, checkout.payment_mode)),
    status: (checkout, index$1) => (index.h("td", { part: parts.getAlternateTableCellPart(index$1) }, MapCheckoutStatusToBadge(checkout.status))),
};

exports.checkoutTableCells = checkoutTableCells;
exports.checkoutTableColumns = checkoutTableColumns;
exports.defaultColumnsKeys = defaultColumnsKeys;
