'use strict';

var index = require('./index-D5bL1DOi.js');
var index$1 = require('./index-1MT3Z4XI.js');
var parts = require('./parts-9jMf1erK.js');
var formControlErrorText = require('./form-control-error-text-CVPYL0lE.js');
require('./event-types-YOY5TKUN.js');
var stateOptions = require('./state-options-CIT9xdTz.js');
var utils = require('./utils-DAyWinG2.js');

const NumberInputMasked = class {
    constructor(hostRef) {
        index.registerInstance(this, hostRef);
        this.formControlInput = index.createEvent(this, "formControlInput");
        this.formControlBlur = index.createEvent(this, "formControlBlur");
        this.imask = null;
        this.isFocused = false;
        this.initializeIMask = () => {
            if (!this.textInput)
                return;
            this.imask = index$1.IMask(this.textInput, {
                mask: this.mask,
            });
            this.imask.on('accept', () => {
                var _a;
                const rawValue = (_a = this.imask) === null || _a === void 0 ? void 0 : _a.unmaskedValue;
                if (rawValue !== undefined) {
                    this.inputHandler(this.name, rawValue);
                }
            });
            this.textInput.addEventListener('blur', () => this.formControlBlur.emit());
        };
        this.handleFormControlInput = (event) => {
            const target = event.target;
            const name = target.getAttribute('name');
            this.formControlInput.emit({ name: name, value: target.value });
        };
        this.updateInput = (newValue) => {
            if (this.imask && newValue) {
                this.imask.value = String(newValue);
            }
        };
    }
    handleDefaultValueChange(newValue) {
        this.initializeIMask();
        this.updateInput(newValue);
    }
    disconnectedCallback() {
        var _a;
        (_a = this.imask) === null || _a === void 0 ? void 0 : _a.destroy();
    }
    componentDidLoad() {
        if (this.textInput) {
            this.initializeIMask();
            this.updateInput(this.defaultValue);
        }
    }
    get part() {
        if (this.errorText) {
            return parts.inputInvalid;
        }
        if (this.disabled) {
            return parts.inputDisabled;
        }
        if (this.isFocused) {
            return parts.inputFocused;
        }
        return parts.input;
    }
    render() {
        return (index.h(index.Host, { key: '6cae1871670deff0c71ea486c0e152f3e2fde29b' }, index.h("div", { key: 'd19b5550c44f287f8a209b8e5494f8dfa684c83c', class: "form-group d-flex flex-column" }, index.h("div", { key: 'b47d25e856e615073680ca7138659fb5a744482b', class: "d-flex align-items-start gap-2" }, index.h("label", { key: 'a8487b47e04941ff3f03f4cf50cc8e6a3487a83d', part: parts.label, class: "form-label", htmlFor: this.name }, this.label), index.h("form-control-tooltip", { key: 'c1742daada4cc36cabee18a31d64320b039c8b7c', helpText: this.helpText })), index.h("input", { key: 'f0502f8af26a5a1dede6e8ea3645119b7c29086e', ref: el => (this.textInput = el), id: this.name, name: this.name, onFocus: () => (this.isFocused = true), onBlur: () => {
                this.isFocused = false;
                this.formControlBlur.emit();
            }, onInput: this.handleFormControlInput, part: this.part, class: this.errorText ? 'form-control is-invalid' : 'form-control', type: "text", disabled: this.disabled }), index.h(formControlErrorText.FormControlErrorText, { key: 'f718537088c8b1fdb0b55a60fec35606e1d5e113', errorText: this.errorText, name: this.name }))));
    }
    static get watchers() { return {
        "defaultValue": ["handleDefaultValueChange"]
    }; }
};

const IdentityAddressForm = class {
    constructor(hostRef) {
        index.registerInstance(this, hostRef);
        this.address = {};
        this.inputHandler = (name, value) => {
            this.address[name] = value;
            this.address = Object.assign({}, this.address);
        };
    }
    handleAddressChange(newValues) {
        this.handleFormUpdate(newValues);
    }
    render() {
        var _a, _b, _c, _d, _e, _f, _g, _h, _j, _k, _l, _m;
        return (index.h(index.Host, { key: '136f90a2d2e8634c003a5f47af20d422b7cc59be' }, index.h("div", { key: 'e7441c2a0410381be43f8d0735fdf4e390f664f2', class: "row gy-3" }, index.h("div", { key: '93f23a3ba51716a88bf90628f395dbb3bc456cdc', class: "col-12 col-md-8" }, index.h("form-control-text", { key: 'f4801f6eb05d3a169142daa6b0d123ef84864de8', name: "line1", label: "Street Address", defaultValue: (_a = this.defaultValues) === null || _a === void 0 ? void 0 : _a.line1, errorText: (_b = this.errors) === null || _b === void 0 ? void 0 : _b.line1, inputHandler: this.inputHandler, helpText: "\u200B\u200BEnter your address exactly as stated on your driver's license. No PO Boxes." })), index.h("div", { key: 'e8ce49dcd4d3c6df3327d2c011ec1c0a080fb4f2', class: "col-12 col-md-4" }, index.h("form-control-text", { key: '8cbe92c156c4d410b712b2fc95c7bfe55be4e337', name: "line2", label: "Apartment, Suite, etc. (optional)", defaultValue: (_c = this.defaultValues) === null || _c === void 0 ? void 0 : _c.line2, errorText: (_d = this.errors) === null || _d === void 0 ? void 0 : _d.line2, inputHandler: this.inputHandler })), index.h("div", { key: '4cfcfc24268fd92ccaac110a8293e95bc9998af8', class: "col-12" }, index.h("form-control-text", { key: 'b2739b7fd7838ee73c9127fd8e9b0dd6dcd12210', name: "city", label: "City", defaultValue: (_e = this.defaultValues) === null || _e === void 0 ? void 0 : _e.city, errorText: (_f = this.errors) === null || _f === void 0 ? void 0 : _f.city, inputHandler: this.inputHandler })), index.h("div", { key: 'ce9e4974dcdab596dfcefef362d045ee2fea3648', class: "col-12 col-md-6" }, index.h("form-control-select", { key: 'c001d0a3d3b402768ec428c0e5760cf0e88c318d', name: "state", label: "State", defaultValue: (_g = this.defaultValues) === null || _g === void 0 ? void 0 : _g.state, options: stateOptions.StateOptions, errorText: (_h = this.errors) === null || _h === void 0 ? void 0 : _h.state, inputHandler: this.inputHandler })), index.h("div", { key: '7b73598a2b207db9ec2480ed37d163aa45128e6d', class: "col-12 col-md-6" }, index.h("form-control-text", { key: 'a070edca32110dc4ec238c486ae96852733ae924', name: "postal_code", label: "Postal Code", defaultValue: (_j = this.defaultValues) === null || _j === void 0 ? void 0 : _j.postal_code, errorText: (_k = this.errors) === null || _k === void 0 ? void 0 : _k.postal_code, maxLength: 5, keyDownHandler: utils.numberOnlyHandler, inputHandler: this.inputHandler })), index.h("div", { key: '57b01955142ed533a65058b63cfd20598e8387c2', class: "col-12" }, index.h("form-control-select", { key: '8f07809025c039b4c39a452ddf2948f973a82d9a', name: "country", label: "Country", options: [{ label: 'United States', value: 'USA' }], inputHandler: this.inputHandler, defaultValue: (_l = this.defaultValues) === null || _l === void 0 ? void 0 : _l.country, errorText: (_m = this.errors) === null || _m === void 0 ? void 0 : _m.country,
            // just for now so we skip handling country specificities
            disabled: true })))));
    }
    static get watchers() { return {
        "address": ["handleAddressChange"]
    }; }
};

exports.form_control_number_masked = NumberInputMasked;
exports.justifi_identity_address_form = IdentityAddressForm;
