'use strict';

var index = require('./index-D5bL1DOi.js');
var styledHost = require('./styled-host-DXNHOiqW.js');
require('./event-types-YOY5TKUN.js');
var skeleton = require('./skeleton-CbZBGO47.js');
var checkPkgVersion = require('./check-pkg-version-DBocF2eE.js');
var configState = require('./config-state-Dz9bnWHg.js');
var index_esm = require('./index.esm-CVuJLXJZ.js');
var schemaValidations = require('./schema-validations-BSeMee-o.js');
var parts = require('./parts-9jMf1erK.js');
var utils = require('./utils-DAyWinG2.js');
var stateOptions = require('./state-options-CIT9xdTz.js');
var checkout_store = require('./checkout.store--pVCO0L1.js');
var button = require('./button-0HYMPryx.js');
var header1 = require('./header-1-M-mc3bsa.js');
var header2 = require('./header-2-BXQLJn1q.js');
require('./package-BM2FCIB8.js');
require('./Api-eP0XeJLd.js');
require('./utils-DqlrBltg.js');
require('./dinero-J-SRFKIR.js');
require('./_commonjsHelpers-BJu3ubxk.js');
require('./ComponentError-CEv9ltwy.js');
require('./Refund-08OcZkXX.js');
require('./Dispute-CruQTF6_.js');
require('./Pagination-Dediz133.js');
require('./Business-DCRzZf0w.js');
require('./helpers-B5OCqlIM.js');
require('./index-BCtVWU61.js');
require('./business-form-options-CMII7nIK.js');

const Header3 = (props) => {
    return index.h("h3", { class: `header-3 ${props === null || props === void 0 ? void 0 : props.class}`, part: parts.heading3 }, props.text);
};

const BankAccountFormSkeleton = (props) => {
    const { isReady } = props;
    if (isReady) {
        return null;
    }
    return (index.h("div", { class: "container-fluid p-0" },
        index.h("div", { class: "row mb-3" },
            index.h("div", { class: "col-12 align-content-end" },
                index.h(skeleton.Skeleton, { height: "18px", width: "120px" }),
                index.h(skeleton.Skeleton, { height: "36px" }))),
        index.h("div", { class: "row" },
            index.h("div", { class: "col-12 align-content-end" },
                index.h(skeleton.Skeleton, { height: "18px", width: "110px" }),
                index.h(skeleton.Skeleton, { height: "36px" })))));
};

const BankAccountForm = class {
    constructor(hostRef) {
        index.registerInstance(this, hostRef);
        this.isReady = false;
    }
    async componentWillLoad() {
        await configState.waitForConfig();
        this.iframeOrigin = configState.configState.iframeOrigin;
        checkPkgVersion.checkPkgVersion();
        this.analytics = new checkPkgVersion.JustifiAnalytics(this);
    }
    componentDidRender() {
        const elements = [
            this.accountNumberIframeElement,
            this.routingNumberIframeElement,
        ];
        Promise.all(elements.map((element) => {
            return new Promise((resolve) => {
                element.addEventListener('iframeLoaded', () => { resolve(); });
            });
        })).then(() => {
            this.isReady = true;
        });
    }
    disconnectedCallback() {
        var _a;
        (_a = this.analytics) === null || _a === void 0 ? void 0 : _a.cleanup();
    }
    async validate() {
        const accountNumberIsValid = await this.accountNumberIframeElement.validate();
        const routingNumberIsValid = await this.routingNumberIframeElement.validate();
        return accountNumberIsValid && routingNumberIsValid;
    }
    async tokenize({ clientId, paymentMethodMetadata, account }) {
        return this.accountNumberIframeElement.tokenize(clientId, paymentMethodMetadata, account);
    }
    render() {
        return (index.h(styledHost.StyledHost, { key: '62431aba939585a8a341942d9847e8d491b0a658' }, index.h(BankAccountFormSkeleton, { key: '2da8452c73e52a6fc67d80e483c40a2d0dd276f9', isReady: this.isReady }), index.h("hidden-input", { key: 'c34bc48ee7e1925ae272b5fe60fd362ddf2433eb' }), index.h("div", { key: '3fefe63e9f9c98d7e08e0ceac5df0f8008303aec', class: "container-fluid p-0", style: {
                opacity: this.isReady ? '1' : '0',
                height: this.isReady ? 'auto' : '0',
            } }, index.h("div", { key: '6c19ea238eb0bff6b245f2f39028d651438c55d0', class: "row mb-3" }, index.h("iframe-input", { key: 'b5588dc21d24ec873fecedd91fbcb0344fbe324c', inputId: "accountNumber", ref: (el) => (this.accountNumberIframeElement = el), label: "Account Number", iframeOrigin: `${this.iframeOrigin}/v2/accountNumber` })), index.h("div", { key: '910f130a307449a3d60ef76eee6cc27fc86c3fe0', class: "row" }, index.h("iframe-input", { key: '72756b92912c3031cc472dee5bbf945f06c38920', inputId: "routingNumber", ref: (el) => (this.routingNumberIframeElement = el), label: "Routing Number", iframeOrigin: `${this.iframeOrigin}/v2/routingNumber` })))));
    }
};

const billingFormSchema = (postalOnly) => {
    const fullBillingForm = index_esm.create$3({
        name: schemaValidations.identityNameValidation.required('Enter full name'),
        address_line1: schemaValidations.lineOneValidation.required('Enter street address'),
        address_line2: schemaValidations.lineTwoValidation.nullable(),
        address_city: schemaValidations.cityValidation.required('Enter city'),
        address_state: schemaValidations.stateValidation.required('Select state'),
        address_postal_code: schemaValidations.postalValidation.required('Enter postal code'),
    });
    const postalForm = index_esm.create$3({
        name: schemaValidations.identityNameValidation.nullable(),
        address_line1: schemaValidations.lineOneValidation.nullable(),
        address_line2: schemaValidations.lineTwoValidation.nullable(),
        address_city: schemaValidations.cityValidation.nullable(),
        address_state: schemaValidations.stateValidation.nullable(),
        address_postal_code: schemaValidations.postalValidation.required('Enter postal code'),
    });
    return postalOnly ? postalForm : fullBillingForm;
};

const BillingInformationForm = class {
    constructor(hostRef) {
        index.registerInstance(this, hostRef);
        this.errors = {};
        this.inputHandler = (name, value) => {
            this.formController.setValues(Object.assign(Object.assign({}, this.formController.values.getValue()), { [name]: value }));
        };
    }
    connectedCallback() {
        this.unsubscribe = checkout_store.onChange('billingFormFields', (newValue) => {
            this.formController.setInitialValues(newValue);
        });
    }
    disconnectedCallback() {
        var _a;
        (_a = this.unsubscribe) === null || _a === void 0 ? void 0 : _a.call(this);
    }
    componentWillLoad() {
        this.formController = new index_esm.FormController(billingFormSchema());
    }
    componentDidLoad() {
        this.formController.values.subscribe(values => this.billingInfo = Object.assign({}, values));
        this.formController.errors.subscribe(errors => {
            this.errors = Object.assign({}, errors);
        });
    }
    async fill(values) {
        this.formController.setInitialValues(values);
        return this.formController.values.getValue();
    }
    async getValues() {
        return this.formController.values.getValue();
    }
    async validate() {
        const isValid = await this.formController.validate();
        const errors = this.formController.errors.getValue();
        return { isValid, errors };
    }
    render() {
        const billingFormDefaultValue = this.formController.getInitialValues();
        return (index.h(styledHost.StyledHost, { key: 'a88e767bb2e49c21e9ce48c44895f592a3a38aad' }, index.h("div", { key: '7f7766669fefa6096c9967a36d007d87a2487805', part: parts.billingForm }, index.h("form", { key: '32d6f2128425b41e67a01f295d4f41c3dd452dd6' }, index.h("fieldset", { key: 'b42d5fb584bb4e8a6d75ae31adab81162094d605' }, index.h("div", { key: 'b50049072ff30b9d49e2fb101cdd25a4ce3d69d4', class: "row gy-3" }, index.h("div", { key: '77daf407dbfaa961bbb05f2293a926bf71e3465c', class: "col-12" }, index.h("form-control-text", { key: 'f865d1247e0d07e3f55d58cc8f5e5c54bd3b8756', name: 'name', label: 'Full Name', defaultValue: billingFormDefaultValue.name, errorText: this.errors.name, inputHandler: this.inputHandler })), index.h("div", { key: '3260e35526ec7293aaf177d2a052ddb170df5934', class: "col-12" }, index.h("form-control-text", { key: '7e4d3e8f2d19d5f83b173a7f852ca7f7dabafec4', name: 'address_line1', label: 'Street Address', defaultValue: billingFormDefaultValue.address_line1, errorText: this.errors.address_line1, inputHandler: this.inputHandler })), index.h("div", { key: 'ed66dd692aa1f6542866a66bf962c751c95e6b9e', class: "col-12" }, index.h("form-control-text", { key: '4d092e34e70455ff890e68c94db4a150bb468df3', name: 'address_line2', label: "Apartment, Suite, etc. (optional)", defaultValue: billingFormDefaultValue.address_line2, errorText: this.errors.address_line2, inputHandler: this.inputHandler })), index.h("div", { key: '14eb1dda040024dd1fadde8c12b4421ae6691d93', class: "col-12" }, index.h("form-control-text", { key: 'e5cc48df0a79438605d601cc31423ce7ae410a7e', name: 'address_city', label: "City", defaultValue: billingFormDefaultValue.address_city, errorText: this.errors.address_city, inputHandler: this.inputHandler })), index.h("div", { key: '15699e13436a9742afd72ff3a799af11839609ae', class: "col-12" }, index.h("form-control-select", { key: '82bf4f8cbec206f8c942e2b2c3a4896b769683c3', name: 'address_state', label: 'State', options: stateOptions.StateOptions, defaultValue: billingFormDefaultValue.address_state, errorText: this.errors.address_state, inputHandler: this.inputHandler })), index.h("div", { key: '6f341fd1f9580830d460cbc2ef1f96bf4a6c87da', class: "col-12" }, index.h("form-control-text", { key: '2ff9907c1e36c01360f601a895d34fffbd3476a7', name: 'address_postal_code', label: "ZIP", defaultValue: billingFormDefaultValue.address_postal_code, errorText: this.errors.address_postal_code, inputHandler: this.inputHandler, maxLength: 5, keyDownHandler: utils.numberOnlyHandler }))))))));
    }
};

const JustifiButton = class {
    constructor(hostRef) {
        index.registerInstance(this, hostRef);
        this.variant = 'primary';
        this.type = 'button';
    }
    render() {
        return (index.h(styledHost.StyledHost, { key: '9058c69dafff70a5c678ab1c3bcf23912334fdb0' }, index.h(button.Button, { key: 'e338ce5761834c0a971970bb1d2085ec9f88eb65', variant: this.variant, isLoading: this.isLoading, clickHandler: this.clickHandler, class: this.class, type: this.type, disabled: this.disabled, style: this.customStyle }, this.text)));
    }
};

const CardFormSkeleton = (props) => {
    const { isReady } = props;
    if (isReady) {
        return null;
    }
    return (index.h("div", { class: "container-fluid p-0" },
        index.h("div", { class: "mb-3" },
            index.h(skeleton.Skeleton, { height: "18px", width: "100px" }),
            index.h(skeleton.Skeleton, { height: "36px" })),
        index.h("div", { class: "row" },
            index.h("div", { class: "col-4 align-content-end" },
                index.h(skeleton.Skeleton, { height: "18px", width: "80px" }),
                index.h(skeleton.Skeleton, { height: "36px" })),
            index.h("div", { class: "col-4 align-content-end" },
                index.h(skeleton.Skeleton, { height: "36px" })),
            index.h("div", { class: "col-4 align-content-end" },
                index.h(skeleton.Skeleton, { height: "18px", width: "30px" }),
                index.h(skeleton.Skeleton, { height: "36px" })))));
};

const JustifiCardForm = class {
    constructor(hostRef) {
        index.registerInstance(this, hostRef);
        this.isReady = false;
    }
    async componentWillLoad() {
        await configState.waitForConfig();
        this.iframeOrigin = configState.configState.iframeOrigin;
        checkPkgVersion.checkPkgVersion();
        this.analytics = new checkPkgVersion.JustifiAnalytics(this);
    }
    componentDidRender() {
        const elements = [
            this.cardNumberIframeElement,
            this.expirationMonthIframeElement,
            this.expirationYearIframeElement,
            this.cvvIframeElement,
        ];
        Promise.all(elements.map((element) => {
            return new Promise((resolve) => {
                element.addEventListener('iframeLoaded', () => { resolve(); });
            });
        })).then(() => {
            this.isReady = true;
        });
    }
    disconnectedCallback() {
        var _a;
        (_a = this.analytics) === null || _a === void 0 ? void 0 : _a.cleanup();
    }
    async validate() {
        const cardNumberIsValid = await this.cardNumberIframeElement.validate();
        const expirationMonthIsValid = await this.expirationMonthIframeElement.validate();
        const expirationYearIsValid = await this.expirationYearIframeElement.validate();
        const cvvIsValid = await this.cvvIframeElement.validate();
        return cardNumberIsValid && expirationMonthIsValid && expirationYearIsValid && cvvIsValid;
    }
    async tokenize({ clientId, paymentMethodMetadata, account, }) {
        return this.cardNumberIframeElement.tokenize(clientId, paymentMethodMetadata, account);
    }
    render() {
        return (index.h(styledHost.StyledHost, { key: 'c6a8109b35d9ef920747aadf75bea99bbba4ae21' }, index.h(CardFormSkeleton, { key: 'c1868489482ccb4125ffb47f981638a2c6016ffe', isReady: this.isReady }), index.h("hidden-input", { key: 'f21158c4fe6e63b8ffebbb084830e0331af5979a' }), index.h("div", { key: '8a4852e0a2e2db75672af221a0c9ca9822602da2', class: "container-fluid p-0", style: {
                opacity: this.isReady ? '1' : '0',
                height: this.isReady ? 'auto' : '0',
            } }, index.h("div", { key: '437a1e6d5d1dd7517fa87d876f017f28fb4f8c15', class: "mb-3" }, index.h("iframe-input", { key: '0d8582e8b9eb4fdd9a3c4e1c86eda90fa9eadf13', inputId: "cardNumber", ref: (el) => (this.cardNumberIframeElement = el), label: "Card Number", iframeOrigin: `${this.iframeOrigin}/v2/cardNumber` })), index.h("div", { key: '8311f0aac3f3826802d2fec0fd7de9ceae6af06c', class: "row" }, index.h("div", { key: '50c24e8cd76931f3ea19ffc3d4e52607f4bed78c', class: "col-4 align-content-end" }, index.h("iframe-input", { key: '82e610abedf2d4f42eb67e05a4de3a349fe0ff59', inputId: "expirationMonth", ref: (el) => (this.expirationMonthIframeElement = el), label: "Expiration", iframeOrigin: `${this.iframeOrigin}/v2/expirationMonth` })), index.h("div", { key: 'fa13540819346d3caf09d863a7bb6d2a2ea47cb0', class: "col-4 align-content-end" }, index.h("iframe-input", { key: '5292e69953eb0fbd3b36871fe7bd433e791f60f9', inputId: "expirationYear", ref: (el) => (this.expirationYearIframeElement = el), label: "", iframeOrigin: `${this.iframeOrigin}/v2/expirationYear` })), index.h("div", { key: 'd6ddb4af11e44ed0f1de6273c0d3fd0ba19522ad', class: "col-4 align-content-end" }, index.h("iframe-input", { key: '7491af49747367001b8eee954cd18464d929431b', inputId: "CVV", ref: (el) => (this.cvvIframeElement = el), label: "CVV", iframeOrigin: `${this.iframeOrigin}/v2/CVV` }))))));
    }
};

const Header = class {
    constructor(hostRef) {
        index.registerInstance(this, hostRef);
        this.levels = {
            h1: header1.Header1,
            h2: header2.Header2,
            h3: Header3,
        };
        this.level = 'h1';
    }
    render() {
        const HeaderComponent = this.levels[this.level];
        return (index.h(styledHost.StyledHost, { key: '91910c2913cd5085875d33d79e33136bcf78cb14' }, index.h(HeaderComponent, { key: 'd915085a734fa1abb5dc03d722c954139794ace3', text: this.text, class: this.class })));
    }
};

const PostalCodeForm = class {
    constructor(hostRef) {
        index.registerInstance(this, hostRef);
        this.errors = {};
        this.inputHandler = (name, value) => {
            this.formController.setValues(Object.assign(Object.assign({}, this.formController.values.getValue()), { [name]: value }));
        };
    }
    connectedCallback() {
        this.unsubscribe = checkout_store.onChange('billingFormFields', (newValue) => {
            this.formController.setInitialValues(newValue);
        });
    }
    disconnectedCallback() {
        var _a;
        (_a = this.unsubscribe) === null || _a === void 0 ? void 0 : _a.call(this);
    }
    componentWillLoad() {
        this.formController = new index_esm.FormController(billingFormSchema(true));
    }
    componentDidLoad() {
        this.formController.values.subscribe(values => this.billingInfo = Object.assign({}, values));
        this.formController.errors.subscribe(errors => {
            this.errors = Object.assign({}, errors);
        });
    }
    async getValues() {
        return this.formController.values.getValue();
    }
    async fill(fields) {
        this.formController.setInitialValues(fields);
    }
    async validate() {
        let isValid = await this.formController.validate();
        const errors = this.formController.errors.getValue();
        return { isValid, errors };
    }
    render() {
        const billingFormDefaultValue = this.formController.getInitialValues();
        return (index.h(styledHost.StyledHost, { key: '881138113d82dd87a364cbadef1947f34d3cdf4f' }, index.h("form", { key: '647945d6264d0611fcc7970eded8ce22ac2b4db7' }, index.h("form-control-text", { key: '2308fdcc1634fa8b39ce0735ab3431a406bc7398', name: 'address_postal_code', label: "ZIP", defaultValue: billingFormDefaultValue.address_postal_code, errorText: this.errors.address_postal_code, inputHandler: this.inputHandler, maxLength: 5, keyDownHandler: utils.numberOnlyHandler }))));
    }
};

const SaveNewPaymentMethod = class {
    constructor(hostRef) {
        index.registerInstance(this, hostRef);
        this.checkboxChanged = index.createEvent(this, "checkboxChanged");
        this.isChecked = false;
    }
    handleCheckboxChange(_name, value) {
        this.isChecked = value;
        this.checkboxChanged.emit(this.isChecked);
    }
    render() {
        return (index.h(styledHost.StyledHost, { key: 'd1d049867d908af91cc7bcd1b841345082344263' }, index.h("div", { key: '4159e5a8608f123f18542874e6589fdad133ffac', class: "mt-4 form-check" }, index.h("form-control-checkbox", { key: '2c202be08024fe72c0b1ee9894b392a8084f23e1', label: "Save new payment method", name: "saveNewPaymentMethod", checked: this.isChecked, inputHandler: this.handleCheckboxChange.bind(this) }))));
    }
};

exports.justifi_bank_account_form = BankAccountForm;
exports.justifi_billing_information_form = BillingInformationForm;
exports.justifi_button = JustifiButton;
exports.justifi_card_form = JustifiCardForm;
exports.justifi_header = Header;
exports.justifi_postal_code_form = PostalCodeForm;
exports.justifi_save_new_payment_method = SaveNewPaymentMethod;
