'use strict';

var index = require('./index-D5bL1DOi.js');
var checkPkgVersion = require('./check-pkg-version-DBocF2eE.js');
var checkout_store = require('./checkout.store--pVCO0L1.js');
var parts = require('./parts-9jMf1erK.js');
var Refund = require('./Refund-08OcZkXX.js');
var styledHost = require('./styled-host-DXNHOiqW.js');
require('./event-types-YOY5TKUN.js');
require('./package-BM2FCIB8.js');
require('./Api-eP0XeJLd.js');
require('./config-state-Dz9bnWHg.js');
require('./index-BCtVWU61.js');
require('./utils-DqlrBltg.js');
require('./dinero-J-SRFKIR.js');
require('./_commonjsHelpers-BJu3ubxk.js');
require('./ComponentError-CEv9ltwy.js');
require('./Pagination-Dediz133.js');
require('./Business-DCRzZf0w.js');
require('./helpers-B5OCqlIM.js');
require('./state-options-CIT9xdTz.js');
require('./Dispute-CruQTF6_.js');

const PaymentMethodTypeLabels = {
    bankAccount: 'New bank account',
    card: 'New credit or debit card',
};
const Checkout = class {
    constructor(hostRef) {
        index.registerInstance(this, hostRef);
        this.errorEvent = index.createEvent(this, "error-event");
        this.loadedEvent = index.createEvent(this, "loaded");
        this.submitEvent = index.createEvent(this, "submit-event");
        this.errorMessage = '';
        this.insuranceToggled = false;
        this.isSubmitting = false; // This is used to prevent multiple submissions and is different from loading state
        this.paymentMethodOptions = [];
        this.savePaymentMethod = false;
        this.disableBankAccount = false;
        this.disableBnpl = false;
        this.disableCreditCard = false;
        this.disablePaymentMethodGroup = false;
        this.hideBankAccountBillingForm = false;
        this.hideCardBillingForm = false;
    }
    propChanged() {
        this.updateStore();
    }
    connectedCallback() {
        if (this.authToken && this.checkoutId) {
            this.updateStore();
        }
    }
    componentWillLoad() {
        checkPkgVersion.checkPkgVersion();
        this.analytics = new checkPkgVersion.JustifiAnalytics(this);
    }
    disconnectedCallback() {
        var _a;
        (_a = this.analytics) === null || _a === void 0 ? void 0 : _a.cleanup();
    }
    savePaymentMethodChanged(event) {
        this.savePaymentMethod = event.detail;
    }
    checkoutComplete(_event) {
        this.isSubmitting = false;
    }
    checkoutError(event) {
        this.isSubmitting = false;
        console.error('checkout error', event.detail);
    }
    paymentMethodOptionSelected(event) {
        checkout_store.checkoutStore.selectedPaymentMethod = event.detail.id;
    }
    async fillBillingForm(fields) {
        checkout_store.checkoutStore.billingFormFields = fields;
    }
    async validate() {
        var _a;
        return { isValid: await ((_a = this.modularCheckoutRef) === null || _a === void 0 ? void 0 : _a.validate()) };
    }
    updateStore() {
        checkout_store.checkoutStore.checkoutId = this.checkoutId;
        checkout_store.checkoutStore.authToken = this.authToken;
        checkout_store.checkoutStore.disableCreditCard = this.disableCreditCard;
        checkout_store.checkoutStore.disableBankAccount = this.disableBankAccount;
        checkout_store.checkoutStore.disableBnpl = this.disableBnpl;
        checkout_store.checkoutStore.disablePaymentMethodGroup = this.disablePaymentMethodGroup;
    }
    async submit(_event) {
        this.isSubmitting = true;
        this.modularCheckoutRef.submitCheckout(checkout_store.checkoutStore.billingFormFields);
    }
    get canSavePaymentMethod() {
        return checkout_store.checkoutStore.selectedPaymentMethod === Refund.PaymentMethodTypes.card || checkout_store.checkoutStore.selectedPaymentMethod === Refund.PaymentMethodTypes.bankAccount;
    }
    get showBillingForm() {
        return (checkout_store.checkoutStore.selectedPaymentMethod === Refund.PaymentMethodTypes.card && !this.hideCardBillingForm)
            || (checkout_store.checkoutStore.selectedPaymentMethod === Refund.PaymentMethodTypes.bankAccount && !this.hideBankAccountBillingForm);
    }
    get showBillingFormSection() {
        return checkout_store.checkoutStore.selectedPaymentMethod === Refund.PaymentMethodTypes.card || checkout_store.checkoutStore.selectedPaymentMethod === Refund.PaymentMethodTypes.bankAccount;
    }
    get showPaymentTypeHeader() {
        return !this.disableCreditCard && !this.disableBankAccount;
    }
    get showPostalCodeForm() {
        return checkout_store.checkoutStore.selectedPaymentMethod === Refund.PaymentMethodTypes.card && this.hideCardBillingForm;
    }
    render() {
        return (index.h(styledHost.StyledHost, { key: '66b064eb09a9d14357b5f67ed6cb06a315e28cd3' }, index.h("justifi-modular-checkout", { key: '0c175af8ee77ba66a6c9e6e338f8e148485e1a44', ref: (el) => (this.modularCheckoutRef = el), authToken: this.authToken, checkoutId: this.checkoutId, savePaymentMethod: this.canSavePaymentMethod && this.savePaymentMethod }, index.h("div", { key: '27a831604928bae01d8a4f056065cf4bb22ed078', class: "row gy-3 jfi-checkout-core" }, index.h("div", { key: '42f396148f51c83fcfb6af8385bfeaa0809c80b4', class: "col-12", part: parts.checkoutSummary }, index.h("justifi-header", { key: '4fdee03c9f6c2d8cb125cf00e7774486f748024b', text: "Summary", level: "h2", class: "fs-5 fw-bold pb-3" }), index.h("section", { key: '9dd9f8f49c714d915d33f4767196cb31912fe2d4' }, index.h("justifi-checkout-summary", { key: 'ab3a241477367ace71894a89cdb8df6b02b6a475' }))), index.h("div", { key: '2fcfa4852da6ab570999e00c900a38ce3f7b22d6', class: "col-12 mt-4" }, index.h("slot", { key: '0d8990a3c78a59cfad5b31de02d885dd85bdff3b', name: "insurance" })), index.h("div", { key: '02bcacf6467c99b50b61cd46c4393d2f21ac7f30', class: "col-12 mt-4" }, index.h("justifi-header", { key: 'f6c88155bcd68d4c76dd1c6d812cb3bf96556454', text: "Payment", level: "h2", class: "fs-5 fw-bold pb-3" }), this.showPaymentTypeHeader && (index.h("justifi-header", { key: 'dfc55a62398f0baeb3eef4d934644f68cc8483b9', text: "Select payment type", level: "h3", class: "fs-6 fw-bold lh-lg" })), index.h("div", { key: '3bfdf78062b252b9fc53f63e3248966cd4bd6513', class: "d-flex flex-column" }, index.h("section", { key: '5f51a590d33ae9074314df4a5808fa4355c3711f' }, index.h("div", { key: '048568eb658167dcb267a406d11e9672539e5454' }, index.h("justifi-saved-payment-methods", { key: '150ba48b60bd5818a6fd2004ed1d3b0571050221' }), index.h("justifi-sezzle-payment-method", { key: 'c959ccbba4683f37706daa889eaa60d0a371d682' }), !this.disableCreditCard && (index.h("div", { key: '412255d8cf36a0e3669680e09ca77d5efedf7969' }, index.h("payment-method-option", { key: '9aaaecfd5880a7de93e6f3c986e12f2e63407674', paymentMethodOptionId: Refund.PaymentMethodTypes.card, isSelected: checkout_store.checkoutStore.selectedPaymentMethod === Refund.PaymentMethodTypes.card, clickHandler: () => { checkout_store.checkoutStore.selectedPaymentMethod = Refund.PaymentMethodTypes.card; }, radioButtonHidden: this.disableCreditCard, label: PaymentMethodTypeLabels[Refund.PaymentMethodTypes.card] }), checkout_store.checkoutStore.selectedPaymentMethod === Refund.PaymentMethodTypes.card && (index.h("div", { key: '4fefd1eb74d9c6ba17a1d01fe59ab3334bf8bdac', class: "mt-4 mb-4" }, index.h("justifi-card-form", { key: '6c78f67bce200b47201220a528fb289861761727' }))))), !this.disableBankAccount && (index.h("div", { key: 'c5b97b68abaf8fa754b9f12e08a1b68c85b4c852' }, index.h("payment-method-option", { key: '24c013b3e317d26c9c7b961c0b0a87f2f94949f2', paymentMethodOptionId: Refund.PaymentMethodTypes.bankAccount, isSelected: checkout_store.checkoutStore.selectedPaymentMethod === Refund.PaymentMethodTypes.bankAccount, clickHandler: () => { checkout_store.checkoutStore.selectedPaymentMethod = Refund.PaymentMethodTypes.bankAccount; }, radioButtonHidden: this.disableBankAccount, label: PaymentMethodTypeLabels[Refund.PaymentMethodTypes.bankAccount] }), checkout_store.checkoutStore.selectedPaymentMethod === Refund.PaymentMethodTypes.bankAccount && (index.h("div", { key: 'b61b75f7e449b1217357bdaddfbfcf37d863612f', class: "mt-4 mb-4" }, index.h("justifi-bank-account-form", { key: 'e6d182d60e1b308f76b4364c9a757c7ca59debf2' }))))))))), this.showBillingFormSection && (index.h("div", { key: '71ea650fdb37ff7227b4f8027a54f74c8bf8a575', class: "col-12 mt-4" }, this.showBillingForm && (index.h("justifi-header", { key: 'f36db4e0d6d008d924ada83a83899377e46ece90', text: "Billing Address", level: "h2", class: "fs-5 fw-bold pb-3" })), this.showPostalCodeForm && (index.h("justifi-postal-code-form", { key: '19005f53df4bd597ccf6484d662d7d230a8a7b83' })), this.showBillingForm && (index.h("justifi-billing-information-form", { key: 'e5f501833f7aef3c603d18b29b21c39f990e8ef1' })))), index.h("div", { key: '828ba958634f58c641a5f6e3a848993d03e4aba0', class: "col-12" }, this.canSavePaymentMethod && (index.h("justifi-save-new-payment-method", { key: 'e94caf3d77e0299008e6a0bbf6852347eaa02ebf' }))), index.h("div", { key: '8436468192642a3f20f82b390e5ec53c4dc951bf', class: "mt-4" }, index.h("justifi-button", { key: '981448c550a72eb1aa936d785912729a1d788cac', text: "Pay", type: "submit", variant: "primary", clickHandler: (e) => this.submit(e), disabled: this.isSubmitting, isLoading: this.isSubmitting, customStyle: { width: '100%', textAlign: "center" } }))))));
    }
    static get watchers() { return {
        "authToken": ["propChanged"],
        "checkoutId": ["propChanged"],
        "disableCreditCard": ["propChanged"],
        "disableBankAccount": ["propChanged"],
        "disableBnpl": ["propChanged"],
        "disablePaymentMethodGroup": ["propChanged"]
    }; }
};

exports.justifi_checkout = Checkout;
