'use strict';

var index = require('./index-D5bL1DOi.js');
var ComponentError = require('./ComponentError-CEv9ltwy.js');
var checkPkgVersion = require('./check-pkg-version-DBocF2eE.js');
var Dispute = require('./Dispute-CruQTF6_.js');
var utils = require('./utils-IGCnjtqc.js');
var dispute_service = require('./dispute.service-Chptj-DX.js');
require('./package-BM2FCIB8.js');
require('./Api-eP0XeJLd.js');
require('./config-state-Dz9bnWHg.js');
require('./index-BCtVWU61.js');
require('./utils-DqlrBltg.js');
require('./dinero-J-SRFKIR.js');
require('./_commonjsHelpers-BJu3ubxk.js');
require('./Refund-08OcZkXX.js');
require('./Pagination-Dediz133.js');
require('./Business-DCRzZf0w.js');
require('./helpers-B5OCqlIM.js');
require('./state-options-CIT9xdTz.js');

const makeGetDispute = ({ id, authToken, service }) => async ({ onSuccess, onError }) => {
    var _a;
    try {
        const response = await service.fetchDispute(id, authToken);
        if (!response.error) {
            const pagingInfo = Object.assign({}, response.page_info);
            const dispute = new Dispute.Dispute(response.data);
            onSuccess({ dispute, pagingInfo });
        }
        else {
            const responseError = utils.getErrorMessage(response.error);
            const code = utils.getErrorCode((_a = response.error) === null || _a === void 0 ? void 0 : _a.code);
            return onError({
                error: responseError,
                code,
                severity: ComponentError.ComponentErrorSeverity.ERROR,
            });
        }
    }
    catch (error) {
        const code = utils.getErrorCode(error === null || error === void 0 ? void 0 : error.code);
        return onError({
            error: error.message || error,
            code,
            severity: ComponentError.ComponentErrorSeverity.ERROR,
        });
    }
};

const DisputeManagement = class {
    constructor(hostRef) {
        index.registerInstance(this, hostRef);
        this.errorEvent = index.createEvent(this, "error-event");
        this.errorMessage = null;
        this.handleErrorEvent = event => {
            this.errorMessage = event.detail.message;
            this.errorEvent.emit(event.detail);
        };
    }
    componentWillLoad() {
        checkPkgVersion.checkPkgVersion();
        this.analytics = new checkPkgVersion.JustifiAnalytics(this);
        this.initializeGetDispute();
    }
    disconnectedCallback() {
        var _a;
        (_a = this.analytics) === null || _a === void 0 ? void 0 : _a.cleanup();
    }
    ;
    propChanged() {
        this.initializeGetDispute();
    }
    initializeGetDispute() {
        if (this.disputeId && this.authToken) {
            this.getDispute = makeGetDispute({
                id: this.disputeId,
                authToken: this.authToken,
                service: new dispute_service.DisputeService()
            });
        }
        else {
            this.errorMessage = 'Dispute ID and Auth Token are required';
            this.errorEvent.emit({
                message: this.errorMessage,
                errorCode: ComponentError.ComponentErrorCodes.MISSING_PROPS,
                severity: ComponentError.ComponentErrorSeverity.ERROR,
            });
        }
    }
    render() {
        return (index.h("justifi-dispute-management-core", { key: '8c800827aaa9d549a734ea05698763685e160a98', getDispute: this.getDispute, disputeId: this.disputeId, authToken: this.authToken, "onError-event": this.handleErrorEvent }));
    }
    static get watchers() { return {
        "disputeId": ["propChanged"],
        "authToken": ["propChanged"]
    }; }
};

exports.justifi_dispute_management = DisputeManagement;
