'use strict';

var index = require('./index-D5bL1DOi.js');
var paymentProvisioningActions = require('./payment-provisioning-actions-SNMCdsyF.js');
var business_service = require('./business.service-CZrK48lv.js');
var index_esm = require('./index.esm-CVuJLXJZ.js');
var Business = require('./Business-DCRzZf0w.js');
var businessIdentitySchema = require('./business-identity-schema-Diqj_WVQ.js');
var button = require('./button-0HYMPryx.js');
var parts = require('./parts-9jMf1erK.js');
require('./event-types-YOY5TKUN.js');
var eventTypes = require('./event-types-DNOUef41.js');
var formInputMasks = require('./form-input-masks-DgXd0f4V.js');
var inputHandlers = require('./input-handlers-DYl_0IwC.js');
require('./ComponentError-CEv9ltwy.js');
require('./utils-IGCnjtqc.js');
require('./Api-eP0XeJLd.js');
require('./config-state-Dz9bnWHg.js');
require('./index-BCtVWU61.js');
require('./utils-DqlrBltg.js');
require('./dinero-J-SRFKIR.js');
require('./_commonjsHelpers-BJu3ubxk.js');
require('./Refund-08OcZkXX.js');
require('./Dispute-CruQTF6_.js');
require('./Pagination-Dediz133.js');
require('./helpers-B5OCqlIM.js');
require('./state-options-CIT9xdTz.js');
require('./schema-validations-BSeMee-o.js');
require('./business-form-options-CMII7nIK.js');

const BusinessOwnerForm = class {
    constructor(hostRef) {
        index.registerInstance(this, hostRef);
        this.errorEvent = index.createEvent(this, "error-event");
    }
    async validate() {
        return this.coreComponent.validate();
    }
    async submit() {
        return this.coreComponent.submit();
    }
    async validateAndSubmit({ onSuccess }) {
        this.coreComponent.validateAndSubmit({ onSuccess });
    }
    componentWillLoad() {
        this.initializeApi();
    }
    initializeApi() {
        if (!this.authToken) {
            return;
        }
        this.getOwner = paymentProvisioningActions.makeGetIdentity({
            authToken: this.authToken,
            identityId: this.ownerId,
            service: new business_service.IdentityService()
        });
        this.patchOwner = paymentProvisioningActions.makePatchIdentity({
            authToken: this.authToken,
            identityId: this.ownerId,
            service: new business_service.IdentityService()
        });
        this.postOwner = paymentProvisioningActions.makePostIdentity({
            authToken: this.authToken,
            service: new business_service.IdentityService()
        });
    }
    render() {
        return (index.h("owner-form-core", { key: '07ad7cd2bb38442dc591c9e3421223294690ee8c', ownerId: this.ownerId, businessId: this.businessId, getOwner: this.getOwner, patchOwner: this.patchOwner, postOwner: this.postOwner, allowOptionalFields: this.allowOptionalFields, removeOwner: this.removeOwner, newFormOpen: this.newFormOpen, ownersLength: this.ownersLength, ref: ref => this.coreComponent = ref }));
    }
};

const BusinessOwnerFormCore = class {
    loadingWatcher() {
        this.formLoading.emit(this.isLoading);
    }
    constructor(hostRef) {
        index.registerInstance(this, hostRef);
        this.clickEvent = index.createEvent(this, "click-event");
        this.errorEvent = index.createEvent(this, "error-event");
        this.formLoading = index.createEvent(this, "formLoading");
        this.ownerSubmitted = index.createEvent(this, "ownerSubmitted");
        this.isLoading = false;
        this.errors = {};
        this.owner = {};
        this.getData = () => {
            this.isLoading = true;
            this.getOwner({
                onSuccess: (response) => {
                    this.instantiateOwner(response.data);
                },
                onError: ({ error, code, severity }) => {
                    this.errorEvent.emit({
                        message: error,
                        errorCode: code,
                        severity: severity
                    });
                },
                final: () => this.isLoading = false
            });
        };
        this.sendData = () => {
            this.isLoading = true;
            return new Promise((resolve) => {
                if (this.ownerId) {
                    this.patchOwner({
                        payload: this.payload,
                        onSuccess: (response) => {
                            this.ownerSubmitted.emit({ id: response.data.id });
                            this.instantiateOwner(response.data);
                            resolve(true);
                        },
                        onError: ({ error, code, severity }) => {
                            this.errorEvent.emit({
                                message: error,
                                errorCode: code,
                                severity: severity
                            });
                            resolve(false);
                        },
                        final: () => this.isLoading = false
                    });
                }
                else {
                    this.postOwner({
                        payload: this.payload,
                        onSuccess: (response) => {
                            this.ownerSubmitted.emit({ id: response.data.id });
                            this.instantiateOwner(response.data);
                            resolve(true);
                        },
                        onError: ({ error, code, severity }) => {
                            this.errorEvent.emit({
                                message: error,
                                errorCode: code,
                                severity: severity
                            });
                            resolve(false);
                        },
                        final: () => this.isLoading = false
                    });
                }
            });
        };
        this.instantiateOwner = async (data) => {
            this.owner = Object.assign({}, new Business.Owner(data));
            await this.formController.setInitialValues(this.owner);
        };
        this.handleAddOwner = () => {
            const eventName = this.ownerId ? eventTypes.BusinessFormClickActions.updateOwner : eventTypes.BusinessFormClickActions.addOwner;
            this.clickEvent.emit({ name: eventName });
        };
        this.handleRemoveOwner = () => {
            this.removeOwner(this.ownerId);
            this.clickEvent.emit({ name: eventTypes.BusinessFormClickActions.removeOwner });
        };
        this.validate = this.validate.bind(this);
        this.submit = this.submit.bind(this);
        this.validateAndSubmit = this.validateAndSubmit.bind(this);
    }
    async returnOwnerData() {
        return this.ownerId;
    }
    async validate() {
        return this.formController.validate();
    }
    async submit() {
        const isValid = await this.validate();
        if (isValid) {
            return this.sendData();
        }
    }
    async validateAndSubmit(event) {
        event.preventDefault();
        const isValid = await this.validate();
        if (isValid) {
            this.submit();
        }
    }
    get payload() {
        let formValues = new Business.Owner(this.formController.values.getValue()).payload;
        if (this.ownerId) {
            return formValues;
        }
        else {
            return Object.assign(Object.assign({}, formValues), { business_id: this.businessId });
        }
    }
    get formTitle() {
        return this.ownerId ? 'Edit Business Owner' : 'Add Business Owner';
    }
    get submitButtonText() {
        return this.ownerId ? 'Update' : 'Add';
    }
    get showRemoveButton() {
        const blankForm = !this.ownerId && this.newFormOpen;
        if (this.ownersLength <= 1) {
            return false;
        }
        else {
            if (blankForm) {
                return true;
            }
            else if (this.ownerId && !this.newFormOpen) {
                return true;
            }
        }
    }
    componentWillLoad() {
        this.formController = new index_esm.FormController(businessIdentitySchema.identitySchema('owner', this.allowOptionalFields));
        this.ownerId ? this.getData() : this.instantiateOwner({});
    }
    componentDidLoad() {
        this.formController.errors.subscribe(errors => (this.errors = Object.assign({}, errors)));
    }
    render() {
        return (index.h("form", { key: '570c20c1fdf79268e6c8193a393515c8602a3a44', onSubmit: this.validateAndSubmit }, index.h("fieldset", { key: 'f4f75a735438baef254d4578b779ca16e5080a41' }, index.h("legend", { key: 'dc0c83a7ada9f908afec56d7560f7d9d116baa40', class: "fw-semibold fs-5", part: parts.heading3 }, this.formTitle), index.h("br", { key: '5d97c0b38073618aef80ff9576cd57ab0e70d44e' }), index.h("div", { key: 'b15a207a4c4afc1249ce3b8a381e7b57ceb32e7a', class: "row gy-3" }, index.h("owner-form-inputs", { key: '21bd3e9b00580e7293338ad746c189d19ac3d98e', ownerDefaultValue: this.formController.getInitialValues(), errors: this.errors, formController: this.formController }), index.h("div", { key: 'b4653d9b78094b15bfba61e3a18ea3703dc53162', class: "d-flex gap-2 justify-content-start" }, index.h(button.Button, { key: '0328aa7af6e3c2f7ed8aa16724dedcb576bb9870', variant: "secondary", type: "button", onClick: this.handleRemoveOwner, hidden: !this.showRemoveButton }, "Remove"), index.h(button.Button, { key: 'e42671667156149d5424243eef1d6675a3bd6506', variant: "primary", type: "submit", onClick: this.handleAddOwner, disabled: this.isLoading }, this.submitButtonText))), index.h("hr", { key: 'ee7bf4cdb63cdc31df8b307ffb1772e5c0f0348c' }))));
    }
    static get watchers() { return {
        "isLoading": ["loadingWatcher"]
    }; }
};

const BusinessOwnerFormInputs = class {
    constructor(hostRef) {
        index.registerInstance(this, hostRef);
        this.inputHandler = (name, value) => {
            inputHandlers.updateFormValues(this.formController, { [name]: value });
        };
        this.onAddressFormUpdate = (values) => {
            inputHandlers.updateAddressFormValues(this.formController, Object.assign(Object.assign({}, this.formController.values.getValue().address), values));
        };
    }
    render() {
        return (index.h("div", { key: '86abe1713fdfd297e88c1fc1734fadb2c9eab966', class: "row gy-3" }, index.h("div", { key: '63a03271f2a777d4cede3b0790e11c7f4108797f', class: "col-12 col-md-8" }, index.h("form-control-text", { key: 'b86dd9184dbf50e00e047a733ff708526e32d6dc', name: "name", label: "Full Name", defaultValue: this.ownerDefaultValue.name, errorText: this.errors.name, inputHandler: this.inputHandler })), index.h("div", { key: 'c3850b7425ca0d8a118a6b78933f3a2fbe343124', class: "col-12 col-md-4" }, index.h("form-control-text", { key: 'f1f6e801eb36bcae5f2e51f8cd4ea9b7ed6a34a8', name: "title", label: "Title", defaultValue: this.ownerDefaultValue.title, errorText: this.errors.title, inputHandler: this.inputHandler, helpText: "Role at your business, e.g. President, CEO, Treasurer." })), index.h("div", { key: 'b07a8a86dbdef296c9438953ef311ccae3aed23c', class: "col-12 col-md-6" }, index.h("form-control-text", { key: '714ca04b0bf0e5ed1b116b8f4963ba12f7fd6b77', name: "email", label: "Email Address", defaultValue: this.ownerDefaultValue.email, errorText: this.errors.email, inputHandler: this.inputHandler })), index.h("div", { key: '46c11c80bb58d0190ff05f1e87ba962443b07c59', class: "col-12 col-md-6" }, index.h("form-control-number-masked", { key: '6da40db9fb8b3e4f3a744cd0426f4e6436350594', name: "phone", label: "Phone Number", defaultValue: this.ownerDefaultValue.phone, errorText: this.errors.phone, inputHandler: this.inputHandler, mask: formInputMasks.PHONE_MASKS.US })), index.h("div", { key: '0960ea2fb399d0098caeabf45347a89c74066f57', class: "col-12 col-md-4" }, index.h("form-control-date", { key: 'fe0891a3f42c093d70db1dd1d1a7e121ba3091c1', name: "dob_full", label: "Birth Date", defaultValue: this.ownerDefaultValue.dob_full, errorText: this.errors.dob_full, inputHandler: this.inputHandler, onFormControlInput: (e) => inputHandlers.updateDateOfBirthFormValues(e, this.formController), helpText: "Must be 18 or older." })), index.h("div", { key: 'e7cbc519fa6f4fa5b03a0d0b69c7d7f1c42185ff', class: "col-12 col-md-8" }, index.h("form-control-number-masked", { key: 'cf2b280c1560bd1a9f80cf81c1543d41bd807233', name: "identification_number", label: "SSN", defaultValue: this.ownerDefaultValue.identification_number, errorText: this.errors.identification_number, inputHandler: this.inputHandler, mask: formInputMasks.SSN_MASK, helpText: "Enter your full Social Security Number. It is required for Federal OFAC check." })), index.h("div", { key: '1755c849992bfd9f459b65b4cf7e967039fdbe27', class: "col-12" }, index.h("justifi-identity-address-form", { key: 'ac5372d4a9fad8ee3cfe2af20c11868e8753cc35', errors: this.errors.address, defaultValues: this.ownerDefaultValue.address, handleFormUpdate: this.onAddressFormUpdate }))));
    }
    ;
};

exports.justifi_owner_form = BusinessOwnerForm;
exports.owner_form_core = BusinessOwnerFormCore;
exports.owner_form_inputs = BusinessOwnerFormInputs;
