'use strict';

var index = require('./index-D5bL1DOi.js');
var ComponentError = require('./ComponentError-CEv9ltwy.js');
var helpers = require('./helpers-B5OCqlIM.js');
var parts = require('./parts-9jMf1erK.js');
var styledHost = require('./styled-host-DXNHOiqW.js');
var header1 = require('./header-1-M-mc3bsa.js');
require('./event-types-YOY5TKUN.js');
var eventTypes = require('./event-types-DNOUef41.js');
require('./state-options-CIT9xdTz.js');

const PaymentProvisioningCore = class {
    constructor(hostRef) {
        index.registerInstance(this, hostRef);
        this.clickEvent = index.createEvent(this, "click-event");
        this.errorEvent = index.createEvent(this, "error-event");
        this.submitEvent = index.createEvent(this, "submit-event");
        this.loading = false;
        this.businessProvisioned = false;
        this.currentStep = 0;
        this.allowOptionalFields = false;
        this.setBusinessProvisioned = () => {
            this.getBusiness({
                onSuccess: (response) => {
                    this.businessProvisioned = helpers.checkProvisioningStatus(response.data);
                    if (this.businessProvisioned) {
                        this.errorEvent.emit({
                            message: 'A request to provision payments for this business has already been submitted.',
                            errorCode: ComponentError.ComponentErrorCodes.PROVISIONING_REQUESTED,
                            severity: ComponentError.ComponentErrorSeverity.INFO,
                        });
                    }
                },
                onError: ({ error, code, severity }) => {
                    this.errorEvent.emit({
                        message: error,
                        errorCode: code,
                        severity: severity
                    });
                }
            });
        };
        this.postProvisioningData = () => {
            this.postProvisioning({
                onSuccess: (response) => {
                    this.submitEvent.emit({ response: response });
                },
                onError: ({ error, code, severity }) => {
                    this.submitEvent.emit({ response: { error } });
                    this.errorEvent.emit({
                        message: error,
                        errorCode: code,
                        severity: severity
                    });
                }
            });
        };
        this.refs = [];
        this.incrementSteps = () => {
            if (this.currentStep < this.totalSteps) {
                return this.currentStep++;
            }
        };
        this.decrementSteps = () => { return this.currentStep--; };
        this.previousStepButtonOnClick = () => {
            this.clickEvent.emit({ name: eventTypes.BusinessFormClickActions.previousStep });
            this.decrementSteps();
        };
        this.nextStepButtonOnClick = (e, clickEventName) => {
            e.preventDefault();
            this.clickEvent.emit({ name: clickEventName });
            const currentStep = this.refs[this.currentStep];
            currentStep.validateAndSubmit({ onSuccess: this.incrementSteps });
        };
    }
    handleFormCompleted() {
        this.postProvisioningData();
    }
    componentWillLoad() {
        this.getBusiness && this.setBusinessProvisioned();
        this.refs = [this.coreInfoRef, this.legalAddressRef, this.additionalQuestionsRef, this.representativeRef, this.ownersRef, this.bankAccountRef, this.termsRef];
    }
    get businessEndpoint() {
        return `entities/business/${this.businessId}`;
    }
    get formDisabled() {
        return this.loading || this.businessProvisioned;
    }
    get totalSteps() {
        return this.refs.length - 1;
    }
    get stepCounter() {
        return `${this.currentStep + 1} of ${this.totalSteps + 1}`;
    }
    handleFormLoading(event) {
        this.loading = event.detail;
    }
    render() {
        return (index.h(styledHost.StyledHost, { key: '621b616a3b9d5be0fcc1180dcdb0db6a89ec5aa2' }, index.h("div", { key: 'b51c6814bb81a6cdc6cd0c5ede4d485582f154ee', class: 'row gap-3' }, index.h(header1.Header1, { key: '7c03561b4c2b0cfc237d6b933aeffe532f35b626', text: this.formTitle }), index.h("justifi-payment-provisioning-form-steps", { key: 'b616b52cc9a0057f27ddbae1356710cee05c60fa', businessId: this.businessId, authToken: this.authToken, refs: this.refs, currentStep: this.currentStep, allowOptionalFields: this.allowOptionalFields, handleFormLoading: this.handleFormLoading }), index.h("div", { key: '2447bad174b5d32d253e821e76ebb32fb9ec50e3', class: 'd-flex justify-content-between align-items-center' }, index.h("div", { key: 'd746b5275ae0866a8619f67fe00217916153ea0a', class: 'd-flex align-items-center', part: parts.text }, this.stepCounter), index.h("justifi-payment-provisioning-form-buttons", { key: 'add808398005b6076d91788cc220ab6620f3ddfc', currentStep: this.currentStep, totalSteps: this.totalSteps, formLoading: this.loading, formDisabled: this.formDisabled, previousStepButtonOnClick: this.previousStepButtonOnClick, nextStepButtonOnClick: this.nextStepButtonOnClick })))));
    }
};

exports.justifi_payment_provisioning_core = PaymentProvisioningCore;
