'use strict';

var index = require('./index-D5bL1DOi.js');
require('./config-state-Dz9bnWHg.js');
require('./dinero-J-SRFKIR.js');
var ComponentError = require('./ComponentError-CEv9ltwy.js');
var Refund = require('./Refund-08OcZkXX.js');
var Pagination = require('./Pagination-Dediz133.js');
require('./Business-DCRzZf0w.js');
require('./Dispute-CruQTF6_.js');
var checkPkgVersion = require('./check-pkg-version-DBocF2eE.js');
var utils = require('./utils-IGCnjtqc.js');
var payment_service = require('./payment.service-C6kdaQYS.js');
var table = require('./table-CxvETNS1.js');
var styledHost = require('./styled-host-DXNHOiqW.js');
var eventTypes = require('./event-types-YOY5TKUN.js');
var utils$1 = require('./utils-DqlrBltg.js');
var parts = require('./parts-9jMf1erK.js');
require('./index-BCtVWU61.js');
require('./_commonjsHelpers-BJu3ubxk.js');
require('./helpers-B5OCqlIM.js');
require('./state-options-CIT9xdTz.js');
require('./package-BM2FCIB8.js');
require('./Api-eP0XeJLd.js');
require('./spinner-CIZFX7bz.js');

const makeGetPaymentTransactions = ({ id, authToken, service }) => async ({ params, onSuccess, onError, final }) => {
    var _a;
    try {
        const response = await service.fetchPaymentTransactions(id, authToken, params);
        if (!response.error) {
            const balanceTransactions = response.data.map((dataItem) => new Refund.PaymentBalanceTransaction(dataItem));
            const pagingInfo = Object.assign({}, response.page_info);
            onSuccess({ balanceTransactions, pagingInfo });
        }
        else {
            const responseError = utils.getErrorMessage(response.error);
            const code = utils.getErrorCode((_a = response.error) === null || _a === void 0 ? void 0 : _a.code);
            onError({
                error: responseError,
                code,
                severity: ComponentError.ComponentErrorSeverity.ERROR,
            });
        }
    }
    catch (error) {
        const code = utils.getErrorCode(error === null || error === void 0 ? void 0 : error.code);
        onError({
            error: utils.getErrorMessage(error),
            code,
            severity: ComponentError.ComponentErrorSeverity.ERROR,
        });
    }
    finally {
        final();
    }
};

const defaultColumnsKeys = 'created_at,type,id,amount,balance';
const paymentTransactionTableColumns = {
    created_at: () => (index.h("th", { part: parts.tableHeadCell, scope: "col", title: "The date and time each transaction was made" }, "Processed On")),
    type: () => (index.h("th", { part: parts.tableHeadCell, scope: "col", title: "The type of each transaction" }, "Type")),
    id: () => (index.h("th", { part: parts.tableHeadCell, scope: "col", title: "The unique identifier of each transaction" }, "ID")),
    amount: () => (index.h("th", { part: parts.tableHeadCell, scope: "col", title: "The dollar amount of each transaction", class: "text-end" }, "Amount")),
    balance: () => (index.h("th", { part: parts.tableHeadCell, scope: "col", title: "The running total amount of this payment that belongs to you", class: "text-end" }, "Balance")),
    currency: () => (index.h("th", { part: parts.tableHeadCell, scope: "col", title: "The currency of each transaction" }, "Currency")),
    financial_transaction_id: () => (index.h("th", { part: parts.tableHeadCell, scope: "col", title: "The unique identifier of the financial transaction associated with the payment balance transaction" }, "Financial Transaction ID")),
    payment_id: () => (index.h("th", { part: parts.tableHeadCell, scope: "col", title: "The unique identifier of the payment associated with the payment balance transaction" }, "Payment ID")),
    payment_balance_txn_type: () => (index.h("th", { part: parts.tableHeadCell, scope: "col", title: "The type of the payment balance transaction" }, "Transaction Type")),
    source_id: () => (index.h("th", { part: parts.tableHeadCell, scope: "col", title: "The unique identifier of the source object associated with the payment balance transaction" }, "Source ID")),
    source_type: () => (index.h("th", { part: parts.tableHeadCell, scope: "col", title: "The type of the source object associated with the payment balance transaction" }, "Source Type")),
};
const paymentTransactionTypes = {
    ach_return: "ACH Return",
    ach_return_fee: "ACH Return Fee",
    dispute: "Dispute",
    dispute_fee: "Dispute Fee",
    dispute_fee_refund: "Dispute Fee Refund",
    dispute_refund: "Dispute Refund",
    payment: "Payment",
    payment_fee: "Fee",
    refund: "Refund",
    fee_refund: "Fee Refund",
    application_fee_returned: "Application Fee Returned",
    refund_failure: "Refund Failure",
    void: "Void",
};
const paymentTransactionTableCells = {
    created_at: (balanceTransaction, index$1) => (index.h("td", { part: parts.getAlternateTableCellPart(index$1) },
        index.h("div", { class: "fw-bold" }, utils$1.convertToLocal(balanceTransaction.created_at, { showDisplayDate: true })),
        index.h("div", { class: "fw-bold" }, utils$1.convertToLocal(balanceTransaction.created_at, { showTime: true })))),
    type: (balanceTransaction, index$1) => (index.h("td", { part: parts.getAlternateTableCellPart(index$1) }, paymentTransactionTypes[balanceTransaction.payment_balance_txn_type])),
    id: (balanceTransaction, index$1) => (index.h("td", { part: parts.getAlternateTableCellPart(index$1) }, balanceTransaction.id)),
    amount: (balanceTransaction, index$1) => (index.h("td", { part: parts.getAlternateTableCellPart(index$1), class: "text-end" }, balanceTransaction.formattedPaymentAmount(balanceTransaction.amount))),
    balance: (balanceTransaction, index$1) => (index.h("td", { part: parts.getAlternateTableCellPart(index$1), class: "text-end" }, balanceTransaction.formattedPaymentAmount(balanceTransaction.balance))),
    currency: (balanceTransaction, index$1) => (index.h("td", { part: parts.getAlternateTableCellPart(index$1) }, balanceTransaction.currency)),
    financial_transaction_id: (balanceTransaction, index$1) => (index.h("td", { part: parts.getAlternateTableCellPart(index$1) }, balanceTransaction.financial_transaction_id)),
    payment_id: (balanceTransaction, index$1) => (index.h("td", { part: parts.getAlternateTableCellPart(index$1) }, balanceTransaction.payment_id)),
    payment_balance_txn_type: (balanceTransaction, index$1) => (index.h("td", { part: parts.getAlternateTableCellPart(index$1) }, balanceTransaction.payment_balance_txn_type)),
    source_id: (balanceTransaction, index$1) => (index.h("td", { part: parts.getAlternateTableCellPart(index$1) }, balanceTransaction.source_id)),
    source_type: (balanceTransaction, index$1) => (index.h("td", { part: parts.getAlternateTableCellPart(index$1) }, balanceTransaction.source_type)),
};

const PaymentTransactionsList = class {
    constructor(hostRef) {
        index.registerInstance(this, hostRef);
        this.clickEvent = index.createEvent(this, "click-event");
        this.errorEvent = index.createEvent(this, "error-event");
        this.balanceTransactions = [];
        this.isLoading = true;
        this.errorMessage = null;
        this.paging = Pagination.pagingDefaults;
        this.pagingParams = {};
        this.columns = defaultColumnsKeys;
        this.handleClickPrevious = (beforeCursor) => {
            this.pagingParams = { before_cursor: beforeCursor };
            this.clickEvent.emit({ name: eventTypes.TableClickActions.previous });
        };
        this.handleClickNext = (afterCursor) => {
            this.pagingParams = { after_cursor: afterCursor };
            this.clickEvent.emit({ name: eventTypes.TableClickActions.next });
        };
        this.rowClickHandler = (e) => {
            const clickedPaymentID = e.target.closest('tr').dataset.rowEntityId;
            if (!clickedPaymentID)
                return;
            const transactionData = this.balanceTransactions.find((payment) => payment.id === clickedPaymentID);
            this.clickEvent.emit({ name: eventTypes.TableClickActions.row, data: transactionData });
        };
    }
    componentWillLoad() {
        this.transactionsTable = new table.Table(this.balanceTransactions, this.columns, paymentTransactionTableColumns, paymentTransactionTableCells);
        checkPkgVersion.checkPkgVersion();
        this.analytics = new checkPkgVersion.JustifiAnalytics(this);
        this.initializeApi();
    }
    disconnectedCallback() {
        var _a;
        (_a = this.analytics) === null || _a === void 0 ? void 0 : _a.cleanup();
    }
    ;
    propChanged() {
        this.initializeApi();
    }
    handleError(code, errorMessage, severity) {
        this.isLoading = false;
        this.errorEvent.emit({ errorCode: code, message: errorMessage, severity });
    }
    initializeApi() {
        if (this.paymentId && this.authToken) {
            const getPaymentTransactions = makeGetPaymentTransactions({
                id: this.paymentId,
                authToken: this.authToken,
                service: new payment_service.PaymentService()
            });
            getPaymentTransactions({
                params: this.pagingParams,
                onSuccess: ({ balanceTransactions, pagingInfo }) => {
                    this.balanceTransactions = balanceTransactions;
                    this.paging = pagingInfo;
                    this.transactionsTable.collectionData = this.balanceTransactions;
                },
                onError: ({ error, code, severity }) => {
                    this.errorMessage = error.message;
                    this.handleError(error, code, severity);
                },
                final: () => {
                    this.isLoading = false;
                }
            });
        }
        else {
            this.errorMessage = 'payment-id and auth-token props are required';
            this.handleError(ComponentError.ComponentErrorCodes.MISSING_PROPS, this.errorMessage, ComponentError.ComponentErrorSeverity.ERROR);
        }
    }
    get entityId() {
        return this.balanceTransactions.map((transaction) => transaction.id);
    }
    get showEmptyState() {
        return !this.isLoading && !this.errorMessage && this.transactionsTable.rowData.length < 1;
    }
    get showErrorState() {
        return !this.isLoading && !!this.errorMessage;
    }
    get showRowData() {
        return !this.showEmptyState && !this.showErrorState && !this.isLoading;
    }
    render() {
        return (index.h(styledHost.StyledHost, { key: '664aa30267863d37af14dcced80f9a73ba43064f' }, index.h(table.TableWrapper, { key: 'eac72c7a0ed98734500e3e25d7d3f1ea6f07a73e' }, index.h(table.TableComponent, { key: 'c5d22e34a2d56d7b892cfd20aa495489b81efbc2' }, index.h(table.TableHead, { key: '79a87ca5015a964a5668388079179e3154e18d86' }, index.h(table.TableHeadRow, { key: 'deb2b85351c535fa535a68cc420e648ae2f2ff6c' }, this.transactionsTable.columnData.map((column) => column))), index.h(table.TableBody, { key: '73ee49890b3f3a2a827a73d59dd23b559092c8e4' }, index.h(table.TableLoadingState, { key: '1aee61900026ad4f668d5908180b28f5a507d6e2', columnSpan: this.transactionsTable.columnKeys.length, isLoading: this.isLoading }), index.h(table.TableEmptyState, { key: '4363869c2b1ee5444dda836115ba4770e3d198b1', isEmpty: this.showEmptyState, columnSpan: this.transactionsTable.columnKeys.length }), index.h(table.TableErrorState, { key: '5d77147db6ff290c487dd71b0b80f7a4e0513069', columnSpan: this.transactionsTable.columnKeys.length, errorMessage: this.errorMessage }), this.showRowData && this.transactionsTable.rowData.map((data, index$1) => (index.h(table.TableRow, { "data-test-id": "table-row", "data-row-entity-id": this.entityId[index$1], onClick: this.rowClickHandler }, data)))), this.paging && (index.h(table.TableFoot, { key: 'a3b1aacaacbc430121ae1f39095f3df7cb280e14' }, index.h(table.TableFootRow, { key: '07746bb99d2a5fed2d129864c3062ecd011a6063' }, index.h(table.TableFootCell, { key: '991930e0f18211617d94b37701ddcb80a66d71f8', colSpan: this.transactionsTable.columnData.length }, index.h("pagination-menu", { key: '6d5f299334a406e7c286e60a0c895f3490ea4a3d', paging: Object.assign(Object.assign({}, this.paging), { handleClickPrevious: this.handleClickPrevious, handleClickNext: this.handleClickNext }) })))))))));
    }
    static get watchers() { return {
        "pagingParams": ["propChanged"],
        "paymentId": ["propChanged"],
        "authToken": ["propChanged"]
    }; }
};

exports.justifi_payment_transactions_list = PaymentTransactionsList;
