'use strict';

var index = require('./index-D5bL1DOi.js');
var payment_service = require('./payment.service-C6kdaQYS.js');
require('./config-state-Dz9bnWHg.js');
require('./dinero-J-SRFKIR.js');
var ComponentError = require('./ComponentError-CEv9ltwy.js');
var Refund = require('./Refund-08OcZkXX.js');
require('./Pagination-Dediz133.js');
require('./Business-DCRzZf0w.js');
require('./Dispute-CruQTF6_.js');
var utils = require('./utils-IGCnjtqc.js');
var checkPkgVersion = require('./check-pkg-version-DBocF2eE.js');
var styledHost = require('./styled-host-DXNHOiqW.js');
require('./event-types-YOY5TKUN.js');
var paymentsTable = require('./payments-table-DaW6SvdL.js');
require('./Api-eP0XeJLd.js');
require('./utils-DqlrBltg.js');
require('./index-BCtVWU61.js');
require('./_commonjsHelpers-BJu3ubxk.js');
require('./helpers-B5OCqlIM.js');
require('./state-options-CIT9xdTz.js');
require('./package-BM2FCIB8.js');
require('./payments-status-DG50GuXR.js');
require('./badge-DDksduwk.js');
require('./parts-9jMf1erK.js');

const makeGetPayments = ({ id, authToken, service }) => async ({ params, onSuccess, onError, final }) => {
    var _a, _b;
    try {
        const response = await service.fetchPayments(id, authToken, params);
        if (!response.error) {
            const pagingInfo = Object.assign({}, response.page_info);
            const payments = ((_a = response.data) === null || _a === void 0 ? void 0 : _a.map((dataItem) => new Refund.Payment(dataItem))) || [];
            onSuccess({ payments, pagingInfo });
        }
        else {
            const responseError = utils.getErrorMessage(response.error);
            const code = utils.getErrorCode((_b = response.error) === null || _b === void 0 ? void 0 : _b.code);
            return onError({
                error: responseError,
                code,
                severity: ComponentError.ComponentErrorSeverity.ERROR,
            });
        }
    }
    catch (error) {
        const code = utils.getErrorCode(error === null || error === void 0 ? void 0 : error.code);
        return onError({
            error: error.message || error,
            code,
            severity: ComponentError.ComponentErrorSeverity.ERROR,
        });
    }
    finally {
        return final();
    }
};

const PaymentsList = class {
    constructor(hostRef) {
        index.registerInstance(this, hostRef);
        this.errorEvent = index.createEvent(this, "error-event");
        this.errorMessage = null;
        this.columns = paymentsTable.defaultColumnsKeys;
        this.handleErrorEvent = (event) => {
            this.errorMessage = event.detail.message;
            this.errorEvent.emit(event.detail);
        };
    }
    componentWillLoad() {
        checkPkgVersion.checkPkgVersion();
        this.analytics = new checkPkgVersion.JustifiAnalytics(this);
        this.initializeGetPayments();
    }
    disconnectedCallback() {
        var _a;
        (_a = this.analytics) === null || _a === void 0 ? void 0 : _a.cleanup();
    }
    ;
    propChanged() {
        this.initializeGetPayments();
    }
    initializeGetPayments() {
        if (this.accountId && this.authToken) {
            this.getPayments = makeGetPayments({
                id: this.accountId,
                authToken: this.authToken,
                service: new payment_service.PaymentService()
            });
        }
        else {
            this.errorMessage = 'Account ID and Auth Token are required';
            this.errorEvent.emit({
                errorCode: ComponentError.ComponentErrorCodes.MISSING_PROPS,
                message: this.errorMessage,
                severity: ComponentError.ComponentErrorSeverity.ERROR,
            });
        }
    }
    render() {
        return (index.h(styledHost.StyledHost, { key: '9d29383ee2084a5498f6dadc2a710748f5c81c13' }, index.h("payments-list-core", { key: '1a9255d13b6b1c5b8def24c70eff364ab44957f0', getPayments: this.getPayments, "onError-event": this.handleErrorEvent, columns: this.columns })));
    }
    static get watchers() { return {
        "accountId": ["propChanged"],
        "authToken": ["propChanged"]
    }; }
};

exports.justifi_payments_list = PaymentsList;
