'use strict';

var index = require('./index-D5bL1DOi.js');
var configState = require('./config-state-Dz9bnWHg.js');
require('./dinero-J-SRFKIR.js');
var ComponentError = require('./ComponentError-CEv9ltwy.js');
var Refund = require('./Refund-08OcZkXX.js');
var Pagination = require('./Pagination-Dediz133.js');
require('./Business-DCRzZf0w.js');
require('./Dispute-CruQTF6_.js');
var checkPkgVersion = require('./check-pkg-version-DBocF2eE.js');
var utils = require('./utils-IGCnjtqc.js');
var payout_service = require('./payout.service-CLnAr59x.js');
var table = require('./table-CxvETNS1.js');
var styledHost = require('./styled-host-DXNHOiqW.js');
var eventTypes = require('./event-types-YOY5TKUN.js');
var utils$1 = require('./utils-DqlrBltg.js');
var parts = require('./parts-9jMf1erK.js');
require('./index-BCtVWU61.js');
require('./_commonjsHelpers-BJu3ubxk.js');
require('./helpers-B5OCqlIM.js');
require('./state-options-CIT9xdTz.js');
require('./package-BM2FCIB8.js');
require('./Api-eP0XeJLd.js');
require('./spinner-CIZFX7bz.js');

const makeGetPayoutTransactions = ({ accountId, authToken, service }) => async ({ params, onSuccess, onError, final }) => {
    var _a;
    try {
        const response = await service.fetchPayoutTransactions(accountId, authToken, params);
        if (!response.error) {
            const balanceTransactions = response.data.map((dataItem) => new Refund.PayoutBalanceTransaction(dataItem));
            const pagingInfo = Object.assign({}, response.page_info);
            onSuccess({ balanceTransactions, pagingInfo });
        }
        else {
            const responseError = utils.getErrorMessage(response.error);
            const code = utils.getErrorCode((_a = response.error) === null || _a === void 0 ? void 0 : _a.code);
            onError({
                error: responseError,
                code,
                severity: ComponentError.ComponentErrorSeverity.ERROR,
            });
        }
    }
    catch (error) {
        const code = utils.getErrorCode(error === null || error === void 0 ? void 0 : error.code);
        onError({
            error: utils.getErrorMessage(error),
            code,
            severity: ComponentError.ComponentErrorSeverity.ERROR,
        });
    }
    finally {
        final();
    }
};

const defaultColumnsKeys = 'created_at,txn_type,description,amount,fee,net';
const payoutTransactionTableColumns = {
    id: () => (index.h("th", { part: parts.tableHeadCell, scope: "col", title: "The unique identifier of each transaction" }, "ID")),
    account_id: () => (index.h("th", { part: parts.tableHeadCell, scope: "col", title: "The unique identifier of the account associated with each transaction" }, "Account ID")),
    payout_id: () => (index.h("th", { part: parts.tableHeadCell, scope: "col", title: "The unique identifier of the payout associated with each transaction" }, "Payout ID")),
    financial_transaction_id: () => (index.h("th", { part: parts.tableHeadCell, scope: "col", title: "The unique identifier of the financial transaction associated with the payment balance transaction" }, "Financial Transaction ID")),
    amount: () => (index.h("th", { part: parts.tableHeadCell, scope: "col", title: "The dollar amount of each transaction" }, "Amount")),
    fee: () => (index.h("th", { part: parts.tableHeadCell, scope: "col", title: "The fee associated with each transaction" }, "Fee")),
    net: () => (index.h("th", { part: parts.tableHeadCell, scope: "col", title: "The net amount of each transaction" }, "Net")),
    currency: () => (index.h("th", { part: parts.tableHeadCell, scope: "col", title: "The currency of each transaction" }, "Currency")),
    description: () => (index.h("th", { part: parts.tableHeadCell, scope: "col", title: "The description of each transaction" }, "Description")),
    source_id: () => (index.h("th", { part: parts.tableHeadCell, scope: "col", title: "The unique identifier of the source object associated with the payment balance transaction" }, "Source ID")),
    txn_type: () => (index.h("th", { part: parts.tableHeadCell, scope: "col", title: "The type of each transaction" }, "Type")),
    created_at: () => (index.h("th", { part: parts.tableHeadCell, scope: "col", title: "The date and time each transaction was made" }, "Processed On")),
    available_on: () => (index.h("th", { part: parts.tableHeadCell, scope: "col", title: "The date and time each transaction will be available" }, "Available On")),
    updated_at: () => (index.h("th", { part: parts.tableHeadCell, scope: "col", title: "The date and time each transaction was last updated" }, "Updated On")),
};
const payoutTransactionTypes = {
    fee: "Fee",
    payment: "Payment",
    payout: "Payout",
    seller_payment_refund: "Seller Payment Refund",
    dispute_amount_collected: "Dispute Amount Collected",
    dispute_fee_collected: "Dispute Fee Collected",
    seller_payment: "Seller Payment",
    transfer: "Transfer",
    partner_platform_proceeds_credit: "Partner Platform Proceeds Credit"
};
const payoutTransactionTableCells = {
    id: (transaction) => (index.h("td", { part: parts.getAlternateTableCellPart(transaction.id) }, transaction.id)),
    account_id: (transaction) => (index.h("td", { part: parts.getAlternateTableCellPart(transaction.account_id) }, transaction.account_id)),
    payout_id: (transaction) => (index.h("td", { part: parts.getAlternateTableCellPart(transaction.payout_id) }, transaction.payout_id)),
    financial_transaction_id: (transaction) => (index.h("td", { part: parts.getAlternateTableCellPart(transaction.financial_transaction_id) }, transaction.financial_transaction_id)),
    amount: (transaction) => (index.h("td", { part: parts.getAlternateTableCellPart(transaction.amount) }, transaction.formattedPaymentAmount(transaction.amount))),
    fee: (transaction) => (index.h("td", { part: parts.getAlternateTableCellPart(transaction.fee) }, transaction.formattedPaymentAmount(transaction.fee))),
    net: (transaction) => (index.h("td", { part: parts.getAlternateTableCellPart(transaction.net) }, transaction.formattedPaymentAmount(transaction.net))),
    currency: (transaction) => (index.h("td", { part: parts.getAlternateTableCellPart(transaction.currency) }, transaction.currency)),
    description: (transaction) => (index.h("td", { part: parts.getAlternateTableCellPart(transaction.description) }, transaction.description)),
    source_id: (transaction) => (index.h("td", { part: parts.getAlternateTableCellPart(transaction.source_id) }, transaction.source_id)),
    txn_type: (transaction) => (index.h("td", { part: parts.getAlternateTableCellPart(transaction.txn_type) }, payoutTransactionTypes[transaction.txn_type])),
    created_at: (transaction) => (index.h("td", { part: parts.getAlternateTableCellPart(transaction.created_at) },
        index.h("div", { class: "fw-bold" }, utils$1.convertToLocal(transaction.created_at, { showDisplayDate: true })),
        index.h("div", { class: "fw-bold" }, utils$1.convertToLocal(transaction.created_at, { showTime: true })))),
    available_on: (transaction) => (index.h("td", { part: parts.getAlternateTableCellPart(transaction.available_on) },
        index.h("div", { class: "fw-bold" }, utils$1.convertToLocal(transaction.available_on, { showDisplayDate: true })),
        index.h("div", { class: "fw-bold" }, utils$1.convertToLocal(transaction.available_on, { showTime: true })))),
    updated_at: (transaction) => (index.h("td", { part: parts.getAlternateTableCellPart(transaction.updated_at) },
        index.h("div", { class: "fw-bold" }, utils$1.convertToLocal(transaction.updated_at, { showDisplayDate: true })),
        index.h("div", { class: "fw-bold" }, utils$1.convertToLocal(transaction.updated_at, { showTime: true })))),
};

const PayoutTransactionsList = class {
    constructor(hostRef) {
        index.registerInstance(this, hostRef);
        this.clickEvent = index.createEvent(this, "click-event");
        this.errorEvent = index.createEvent(this, "error-event");
        this.balanceTransactions = [];
        this.isLoading = true;
        this.errorMessage = null;
        this.paging = Pagination.pagingDefaults;
        this.pagingParams = {};
        this.columns = defaultColumnsKeys;
        this.handleClickPrevious = (beforeCursor) => {
            this.pagingParams = { before_cursor: beforeCursor };
            this.clickEvent.emit({ name: eventTypes.TableClickActions.previous });
        };
        this.handleClickNext = (afterCursor) => {
            this.pagingParams = { after_cursor: afterCursor };
            this.clickEvent.emit({ name: eventTypes.TableClickActions.next });
        };
        this.rowClickHandler = (e) => {
            const clickedPayoutId = e.target.closest('tr').dataset.rowEntityId;
            if (!clickedPayoutId)
                return;
            const transactionData = this.balanceTransactions.find((payout) => payout.id === clickedPayoutId);
            this.clickEvent.emit({ name: eventTypes.TableClickActions.row, data: transactionData });
        };
    }
    componentWillLoad() {
        this.transactionsTable = new table.Table(this.balanceTransactions, this.columns, payoutTransactionTableColumns, payoutTransactionTableCells);
        checkPkgVersion.checkPkgVersion();
        this.analytics = new checkPkgVersion.JustifiAnalytics(this);
        this.initializeApi();
    }
    disconnectedCallback() {
        var _a;
        (_a = this.analytics) === null || _a === void 0 ? void 0 : _a.cleanup();
    }
    ;
    propChanged() {
        this.initializeApi();
    }
    handleError(code, errorMessage, severity) {
        this.isLoading = false;
        this.errorEvent.emit({ errorCode: code, message: errorMessage, severity });
    }
    initializeApi() {
        if (this.payoutId && this.authToken) {
            const getPayoutTransactions = makeGetPayoutTransactions({
                accountId: configState.configState.accountId,
                authToken: this.authToken,
                service: new payout_service.PayoutService()
            });
            getPayoutTransactions({
                params: this.requestParams,
                onSuccess: ({ balanceTransactions, pagingInfo }) => {
                    this.balanceTransactions = balanceTransactions;
                    this.paging = pagingInfo;
                    this.transactionsTable.collectionData = this.balanceTransactions;
                },
                onError: ({ error, code, severity }) => {
                    this.errorMessage = error.message;
                    this.handleError(error, code, severity);
                },
                final: () => {
                    this.isLoading = false;
                }
            });
        }
        else {
            this.errorMessage = 'payout-id and auth-token props are required';
            this.handleError(ComponentError.ComponentErrorCodes.MISSING_PROPS, this.errorMessage, ComponentError.ComponentErrorSeverity.ERROR);
        }
    }
    get entityId() {
        return this.balanceTransactions.map((transaction) => transaction.id);
    }
    get showEmptyState() {
        return !this.isLoading && !this.errorMessage && this.transactionsTable.rowData.length < 1;
    }
    get showErrorState() {
        return !this.isLoading && !!this.errorMessage;
    }
    get showRowData() {
        return !this.showEmptyState && !this.showErrorState && !this.isLoading;
    }
    get requestParams() {
        return Object.assign({ payout_id: this.payoutId, limit: '15' }, this.pagingParams);
    }
    render() {
        return (index.h(styledHost.StyledHost, { key: 'ed5653473a599f6d6d80aa68730ed999398b0c76' }, index.h(table.TableWrapper, { key: 'b3d1d97363d8c5e798583604c7979ba1f9fa2752' }, index.h(table.TableComponent, { key: '477d9ff10b92d35b506ef8b78279bb04e4030549' }, index.h(table.TableHead, { key: 'c374d061a751b00ec3d7c95e8280653874fabe47' }, index.h(table.TableHeadRow, { key: '694753bbfdaaade6c5107100d7f99a4728a59c62' }, this.transactionsTable.columnData.map((column) => column))), index.h(table.TableBody, { key: '3e071619a0035b1aec9635ca2476eb279158cb59' }, index.h(table.TableLoadingState, { key: '16708244edda538a30bd63af865f9265c3850847', columnSpan: this.transactionsTable.columnKeys.length, isLoading: this.isLoading }), index.h(table.TableEmptyState, { key: '150b6e2956f73767d31321fee04d6151818337ce', isEmpty: this.showEmptyState, columnSpan: this.transactionsTable.columnKeys.length }), index.h(table.TableErrorState, { key: 'cd5d9464b97567378e07ffd9be1083738d940dc8', columnSpan: this.transactionsTable.columnKeys.length, errorMessage: this.errorMessage }), this.showRowData && this.transactionsTable.rowData.map((data, index$1) => (index.h(table.TableRow, { "data-test-id": "table-row", "data-row-entity-id": this.entityId[index$1], onClick: this.rowClickHandler }, data)))), this.paging && (index.h(table.TableFoot, { key: '83ed7fc0b0c6511de830a3a6880b1c1476a09306' }, index.h(table.TableFootRow, { key: '8d636efc57fee42f65165c6aefddab535d30e771' }, index.h(table.TableFootCell, { key: '2bed98f16b5b2769c6eb1c5ec8e65c90e1c6fc53', colSpan: this.transactionsTable.columnData.length }, index.h("pagination-menu", { key: '1ddeac174bc996e08af5e5e060bf8c3303d4c0dd', paging: Object.assign(Object.assign({}, this.paging), { handleClickPrevious: this.handleClickPrevious, handleClickNext: this.handleClickNext }) })))))))));
    }
    static get watchers() { return {
        "pagingParams": ["propChanged"],
        "payoutId": ["propChanged"],
        "authToken": ["propChanged"]
    }; }
};

exports.justifi_payout_transactions_list = PayoutTransactionsList;
