'use strict';

var index = require('./index-D5bL1DOi.js');
var ComponentError = require('./ComponentError-CEv9ltwy.js');
var checkPkgVersion = require('./check-pkg-version-DBocF2eE.js');
var payout_service = require('./payout.service-CLnAr59x.js');
require('./config-state-Dz9bnWHg.js');
require('./dinero-J-SRFKIR.js');
var Refund = require('./Refund-08OcZkXX.js');
require('./Pagination-Dediz133.js');
require('./Business-DCRzZf0w.js');
require('./Dispute-CruQTF6_.js');
var utils = require('./utils-IGCnjtqc.js');
var getPayoutCsv = require('./get-payout-csv-CdNRRH0t.js');
var getSubaccounts = require('./get-subaccounts-DKyvT-ZF.js');
var styledHost = require('./styled-host-DXNHOiqW.js');
require('./event-types-YOY5TKUN.js');
var payoutsTable = require('./payouts-table-D5hMHcaY.js');
require('./package-BM2FCIB8.js');
require('./Api-eP0XeJLd.js');
require('./utils-DqlrBltg.js');
require('./index-BCtVWU61.js');
require('./_commonjsHelpers-BJu3ubxk.js');
require('./helpers-B5OCqlIM.js');
require('./state-options-CIT9xdTz.js');
require('./payouts-status-meuI7eBr.js');
require('./badge-DDksduwk.js');
require('./parts-9jMf1erK.js');

const makeGetPayouts = ({ id, authToken, service }) => async ({ params, onSuccess, onError }) => {
    var _a, _b;
    try {
        const response = await service.fetchPayouts(id, authToken, params);
        if (!response.error) {
            const pagingInfo = Object.assign({}, response.page_info);
            const payouts = ((_a = response.data) === null || _a === void 0 ? void 0 : _a.map((dataItem) => new Refund.Payout(dataItem))) || [];
            onSuccess({ payouts, pagingInfo });
        }
        else {
            const error = utils.getErrorMessage(response.error);
            const code = utils.getErrorCode((_b = response.error) === null || _b === void 0 ? void 0 : _b.code);
            return onError({
                error,
                code,
                severity: ComponentError.ComponentErrorSeverity.ERROR,
            });
        }
    }
    catch (error) {
        const code = utils.getErrorCode(error === null || error === void 0 ? void 0 : error.code);
        return onError({
            error: error.message || error,
            code,
            severity: ComponentError.ComponentErrorSeverity.ERROR,
        });
    }
};

const PayoutsList = class {
    constructor(hostRef) {
        index.registerInstance(this, hostRef);
        this.errorEvent = index.createEvent(this, "error-event");
        this.errorMessage = null;
        this.columns = payoutsTable.defaultColumnsKeys;
        this.handleOnError = (event) => {
            this.errorMessage = event.detail.message;
            this.errorEvent.emit(event.detail);
        };
    }
    componentWillLoad() {
        checkPkgVersion.checkPkgVersion();
        this.analytics = new checkPkgVersion.JustifiAnalytics(this);
        this.initializeGetData();
    }
    disconnectedCallback() {
        var _a;
        (_a = this.analytics) === null || _a === void 0 ? void 0 : _a.cleanup();
    }
    ;
    propChanged() {
        this.initializeGetData();
    }
    initializeGetData() {
        this.initializePayoutsServices();
        this.initializeGetSubAccounts();
    }
    initializePayoutsServices() {
        if (this.accountId && this.authToken) {
            const serviceParams = {
                id: this.accountId,
                authToken: this.authToken,
                service: new payout_service.PayoutService()
            };
            this.getPayouts = makeGetPayouts(serviceParams);
            this.getPayoutCSV = getPayoutCsv.makeGetPayoutCSV(serviceParams);
        }
        else {
            this.errorMessage = 'Account ID and Auth Token are required';
            this.errorEvent.emit({
                errorCode: ComponentError.ComponentErrorCodes.MISSING_PROPS,
                message: this.errorMessage,
                severity: ComponentError.ComponentErrorSeverity.ERROR,
            });
        }
    }
    initializeGetSubAccounts() {
        if (this.accountId && this.authToken) {
            this.getSubAccounts = getSubaccounts.makeGetSubAccounts({
                accountId: this.accountId,
                authToken: this.authToken,
                service: new getSubaccounts.SubAccountService()
            });
        }
    }
    render() {
        return (index.h(styledHost.StyledHost, { key: 'b01ebbd64e4f09083663f01429c3d19ca9790c4d' }, index.h("payouts-list-core", { key: 'ee137e4322ef9ccf567b4172b0b8831dc18b38eb', getPayouts: this.getPayouts, getPayoutCSV: this.getPayoutCSV, getSubAccounts: this.getSubAccounts, "onError-event": this.handleOnError, columns: this.columns })));
    }
    static get watchers() { return {
        "accountId": ["propChanged"],
        "authToken": ["propChanged"]
    }; }
};

exports.justifi_payouts_list = PayoutsList;
