'use strict';

var index = require('./index-D5bL1DOi.js');
var Api = require('./Api-eP0XeJLd.js');
var ComponentError = require('./ComponentError-CEv9ltwy.js');
require('./Refund-08OcZkXX.js');
require('./Pagination-Dediz133.js');
require('./Business-DCRzZf0w.js');
require('./Dispute-CruQTF6_.js');
var utils = require('./utils-IGCnjtqc.js');
var checkPkgVersion = require('./check-pkg-version-DBocF2eE.js');
var checkout_store = require('./checkout.store--pVCO0L1.js');
require('./config-state-Dz9bnWHg.js');
require('./index-BCtVWU61.js');
require('./utils-DqlrBltg.js');
require('./dinero-J-SRFKIR.js');
require('./_commonjsHelpers-BJu3ubxk.js');
require('./helpers-B5OCqlIM.js');
require('./state-options-CIT9xdTz.js');
require('./package-BM2FCIB8.js');

const api = Api.Api();
class InsuranceService {
    async fetchQuote(authToken, payload) {
        const endpoint = 'insurance/quotes';
        const body = payload;
        return api.post({ endpoint, body, authToken });
    }
    async toggleCoverage(authToken, quoteId, payload) {
        const endpoint = `insurance/quotes/${quoteId}/toggle`;
        const body = payload;
        return api.post({ endpoint, body, authToken });
    }
}

const makeGetQuote = ({ authToken, service }) => async ({ payload, onSuccess, onError }) => {
    var _a;
    try {
        const response = await service.fetchQuote(authToken, payload);
        if (!response.error) {
            const quote = response.data;
            onSuccess({ quote });
        }
        else {
            const responseError = utils.getErrorMessage(response.error);
            const code = utils.getErrorCode((_a = response.error) === null || _a === void 0 ? void 0 : _a.code);
            return onError({
                error: responseError,
                code,
                severity: ComponentError.ComponentErrorSeverity.ERROR,
            });
        }
    }
    catch (error) {
        const code = utils.getErrorCode(error === null || error === void 0 ? void 0 : error.code);
        return onError({
            error: error.message || error,
            code,
            severity: ComponentError.ComponentErrorSeverity.ERROR,
        });
    }
};
const makeToggleCoverage = ({ authToken, service }) => async ({ quoteId, payload, onSuccess, onError }) => {
    var _a;
    try {
        const response = await service.toggleCoverage(authToken, quoteId, payload);
        if (!response.error) {
            const quote = response.data;
            onSuccess({ quote });
        }
        else {
            const responseError = utils.getErrorMessage(response.error);
            const code = utils.getErrorCode((_a = response.error) === null || _a === void 0 ? void 0 : _a.code);
            return onError({
                error: responseError,
                code,
                severity: ComponentError.ComponentErrorSeverity.ERROR,
            });
        }
    }
    catch (error) {
        const code = utils.getErrorCode(error === null || error === void 0 ? void 0 : error.code);
        return onError({
            error: error.message || error,
            code,
            severity: ComponentError.ComponentErrorSeverity.ERROR,
        });
    }
};

const SeasonInterruptionInsurance = class {
    constructor(hostRef) {
        index.registerInstance(this, hostRef);
        this.errorEvent = index.createEvent(this, "error-event");
    }
    async validate() {
        return this.seasonInterruptionCoreRef.validate();
    }
    componentWillLoad() {
        checkPkgVersion.checkPkgVersion();
        this.analytics = new checkPkgVersion.JustifiAnalytics(this);
        this.initializeServiceMethods();
    }
    disconnectedCallback() {
        var _a;
        (_a = this.analytics) === null || _a === void 0 ? void 0 : _a.cleanup();
    }
    initializeServiceMethods() {
        const authToken = this.authToken || checkout_store.checkoutStore.authToken;
        if (!authToken) {
            this.errorEvent.emit({
                errorCode: ComponentError.ComponentErrorCodes.MISSING_PROPS,
                message: 'Missing authToken',
                severity: ComponentError.ComponentErrorSeverity.ERROR,
            });
            return;
        }
        const service = new InsuranceService();
        const config = { authToken, service };
        this.getQuote = makeGetQuote(config);
        this.toggleCoverage = makeToggleCoverage(config);
    }
    render() {
        return (index.h("justifi-season-interruption-insurance-core", { key: '394fc5030f618621fe87b8760b9d0847fa3a496c', ref: (el) => (this.seasonInterruptionCoreRef = el), "checkout-id": this.checkoutId || checkout_store.checkoutStore.checkoutId, getQuote: this.getQuote, toggleCoverage: this.toggleCoverage, "primary-identity-first-name": this.primaryIdentityFirstName, "primary-identity-last-name": this.primaryIdentityLastName, "primary-identity-state": this.primaryIdentityState, "primary-identity-postal-code": this.primaryIdentityPostalCode, "primary-identity-country": this.primaryIdentityCountry, "primary-identity-email-address": this.primaryIdentityEmailAddress, "policy-attributes-insurable-amount": this.policyAttributesInsurableAmount, "policy-attributes-start-date": this.policyAttributesStartDate, "policy-attributes-end-date": this.policyAttributesEndDate, "covered-identity-first-name": this.coveredIdentityFirstName, "covered-identity-last-name": this.coveredIdentityLastName }));
    }
};

exports.justifi_season_interruption_insurance = SeasonInterruptionInsurance;
