'use strict';

var index = require('./index-D5bL1DOi.js');
var styledHost = require('./styled-host-DXNHOiqW.js');
require('./event-types-YOY5TKUN.js');
var checkPkgVersion = require('./check-pkg-version-DBocF2eE.js');
var terminalOrdersTable = require('./terminal-orders-table-DTZUpjkG.js');
require('./config-state-Dz9bnWHg.js');
require('./dinero-J-SRFKIR.js');
var ComponentError = require('./ComponentError-CEv9ltwy.js');
var Refund = require('./Refund-08OcZkXX.js');
require('./Pagination-Dediz133.js');
require('./Business-DCRzZf0w.js');
require('./Dispute-CruQTF6_.js');
var utils = require('./utils-IGCnjtqc.js');
var Api = require('./Api-eP0XeJLd.js');
require('./package-BM2FCIB8.js');
require('./parts-9jMf1erK.js');
require('./utils-DqlrBltg.js');
require('./badge-DDksduwk.js');
require('./index-BCtVWU61.js');
require('./_commonjsHelpers-BJu3ubxk.js');
require('./helpers-B5OCqlIM.js');
require('./state-options-CIT9xdTz.js');

const makeGetTerminalOrders = ({ id, authToken, service }) => async ({ params, onSuccess, onError, final }) => {
    var _a, _b;
    try {
        const response = await service.fetchTerminalOrders(id, authToken, params);
        if (!response.error) {
            const pagingInfo = Object.assign({}, response.page_info);
            const terminalOrders = ((_a = response.data) === null || _a === void 0 ? void 0 : _a.map((dataItem) => new Refund.TerminalOrder(dataItem))) || [];
            onSuccess({ terminalOrders, pagingInfo });
        }
        else {
            const responseError = utils.getErrorMessage(response.error);
            const code = utils.getErrorCode((_b = response.error) === null || _b === void 0 ? void 0 : _b.code);
            return onError({
                error: responseError,
                code,
                severity: ComponentError.ComponentErrorSeverity.ERROR,
            });
        }
    }
    catch (error) {
        const code = utils.getErrorCode(error === null || error === void 0 ? void 0 : error.code);
        return onError({
            error: error.message || error,
            code,
            severity: ComponentError.ComponentErrorSeverity.ERROR,
        });
    }
    finally {
        return final();
    }
};

const api = Api.Api();
class TerminalOrderService {
    async fetchTerminalOrders(accountId, authToken, params) {
        const endpoint = 'terminals/orders';
        const headers = { account: accountId };
        return api.get({ endpoint, params, headers, authToken });
    }
}

const TerminalOrdersList = class {
    constructor(hostRef) {
        index.registerInstance(this, hostRef);
        this.errorEvent = index.createEvent(this, "error-event");
        this.errorMessage = null;
        this.columns = terminalOrdersTable.defaultColumnsKeys;
        this.handleErrorEvent = (event) => {
            this.errorMessage = event.detail.message;
            this.errorEvent.emit(event.detail);
        };
    }
    componentWillLoad() {
        checkPkgVersion.checkPkgVersion();
        this.analytics = new checkPkgVersion.JustifiAnalytics(this);
        this.initializeGetData();
    }
    disconnectedCallback() {
        var _a;
        (_a = this.analytics) === null || _a === void 0 ? void 0 : _a.cleanup();
    }
    ;
    initializeGetData() {
        if (this.accountId && this.authToken) {
            this.getTerminalOrders = makeGetTerminalOrders({
                id: this.accountId,
                authToken: this.authToken,
                service: new TerminalOrderService()
            });
        }
        else {
            this.errorMessage = 'Account ID and Auth Token are required';
            this.errorEvent.emit({
                errorCode: ComponentError.ComponentErrorCodes.MISSING_PROPS,
                message: this.errorMessage,
                severity: ComponentError.ComponentErrorSeverity.ERROR,
            });
        }
    }
    render() {
        return (index.h(styledHost.StyledHost, { key: 'e0fcbc2ccb76acdbcd7a18772d509995c81b1ae1' }, index.h("terminal-orders-list-core", { key: '21b108f554caa4343ecbd3bffa404c01442ef938', getTerminalOrders: this.getTerminalOrders, "onError-event": this.handleErrorEvent, columns: this.columns })));
    }
};

exports.justifi_terminal_orders_list = TerminalOrdersList;
