'use strict';

var index = require('./index-D5bL1DOi.js');
var ComponentError = require('./ComponentError-CEv9ltwy.js');
var checkPkgVersion = require('./check-pkg-version-DBocF2eE.js');
var terminal_service = require('./terminal.service-CcBCXxNm.js');
require('./config-state-Dz9bnWHg.js');
require('./dinero-J-SRFKIR.js');
var Refund = require('./Refund-08OcZkXX.js');
require('./Pagination-Dediz133.js');
require('./Business-DCRzZf0w.js');
require('./Dispute-CruQTF6_.js');
var utils = require('./utils-IGCnjtqc.js');
var getSubaccounts = require('./get-subaccounts-DKyvT-ZF.js');
var styledHost = require('./styled-host-DXNHOiqW.js');
require('./event-types-YOY5TKUN.js');
var terminalsTable = require('./terminals-table-DOqVeHM1.js');
require('./package-BM2FCIB8.js');
require('./Api-eP0XeJLd.js');
require('./utils-DqlrBltg.js');
require('./index-BCtVWU61.js');
require('./_commonjsHelpers-BJu3ubxk.js');
require('./helpers-B5OCqlIM.js');
require('./state-options-CIT9xdTz.js');
require('./badge-DDksduwk.js');
require('./parts-9jMf1erK.js');

const makeGetTerminals = ({ id, authToken, service }) => async ({ params, onSuccess, onError }) => {
    var _a, _b;
    try {
        const response = await service.fetchTerminals(id, authToken, params);
        if (!response.error) {
            const pagingInfo = Object.assign({}, response.page_info);
            const terminals = ((_a = response.data) === null || _a === void 0 ? void 0 : _a.map((dataItem) => new Refund.Terminal(dataItem))) || [];
            onSuccess({ terminals, pagingInfo });
        }
        else {
            const responseError = utils.getErrorMessage(response.error);
            const code = utils.getErrorCode((_b = response.error) === null || _b === void 0 ? void 0 : _b.code);
            return onError({
                error: responseError,
                code,
                severity: ComponentError.ComponentErrorSeverity.ERROR,
            });
        }
    }
    catch (error) {
        const code = utils.getErrorCode(error === null || error === void 0 ? void 0 : error.code);
        return onError({
            error: error.message || error,
            code,
            severity: ComponentError.ComponentErrorSeverity.ERROR,
        });
    }
};

const TerminalsList = class {
    constructor(hostRef) {
        index.registerInstance(this, hostRef);
        this.errorEvent = index.createEvent(this, "error-event");
        this.errorMessage = null;
        this.columns = terminalsTable.defaultColumnsKeys;
        this.handleErrorEvent = (event) => {
            this.errorMessage = event.detail.message;
            this.errorEvent.emit(event.detail);
        };
    }
    componentWillLoad() {
        checkPkgVersion.checkPkgVersion();
        this.analytics = new checkPkgVersion.JustifiAnalytics(this);
        this.initializeGetData();
    }
    disconnectedCallback() {
        var _a;
        (_a = this.analytics) === null || _a === void 0 ? void 0 : _a.cleanup();
    }
    ;
    propChanged() {
        this.initializeGetData();
    }
    initializeGetData() {
        this.initializeGetTerminals();
        this.initializeGetSubAccounts();
    }
    initializeGetTerminals() {
        if (this.accountId && this.authToken) {
            this.getTerminals = makeGetTerminals({
                id: this.accountId,
                authToken: this.authToken,
                service: new terminal_service.TerminalService()
            });
        }
        else {
            this.errorMessage = 'Account ID and Auth Token are required';
            this.errorEvent.emit({
                errorCode: ComponentError.ComponentErrorCodes.MISSING_PROPS,
                message: this.errorMessage,
                severity: ComponentError.ComponentErrorSeverity.ERROR,
            });
        }
    }
    initializeGetSubAccounts() {
        if (this.accountId && this.authToken) {
            this.getSubAccounts = getSubaccounts.makeGetSubAccounts({
                accountId: this.accountId,
                authToken: this.authToken,
                service: new getSubaccounts.SubAccountService()
            });
        }
    }
    render() {
        return (index.h(styledHost.StyledHost, { key: '57a9be57de845dc3f905260445e245cf30458af8' }, index.h("terminals-list-core", { key: '00f79218e216fffc12ecfc3b158cd299ad054349', getTerminals: this.getTerminals, getSubAccounts: this.getSubAccounts, "onError-event": this.handleErrorEvent, columns: this.columns })));
    }
    static get watchers() { return {
        "accountId": ["propChanged"],
        "authToken": ["propChanged"]
    }; }
};

exports.justifi_terminals_list = TerminalsList;
