'use strict';

var index = require('./index-D5bL1DOi.js');
var styledHost = require('./styled-host-DXNHOiqW.js');
require('./event-types-YOY5TKUN.js');
var checkPkgVersion = require('./check-pkg-version-DBocF2eE.js');
var Refund = require('./Refund-08OcZkXX.js');
require('./config-state-Dz9bnWHg.js');
require('./dinero-J-SRFKIR.js');
var ComponentError = require('./ComponentError-CEv9ltwy.js');
require('./Pagination-Dediz133.js');
require('./Business-DCRzZf0w.js');
require('./Dispute-CruQTF6_.js');
var checkout_store = require('./checkout.store--pVCO0L1.js');
require('./package-BM2FCIB8.js');
require('./Api-eP0XeJLd.js');
require('./utils-DqlrBltg.js');
require('./index-BCtVWU61.js');
require('./_commonjsHelpers-BJu3ubxk.js');
require('./helpers-B5OCqlIM.js');
require('./state-options-CIT9xdTz.js');

// Constants
const PAYMENT_METHOD_TYPE_LABELS = {
    [Refund.PaymentMethodTypes.bankAccount]: 'New bank account',
    [Refund.PaymentMethodTypes.card]: 'New credit or debit card',
};
const ERROR_MESSAGES = {
    AUTH_TOKEN_REQUIRED: 'Auth token is required when using the tokenize-payment-method component not slotted in justifi-modular-checkout',
    ACCOUNT_ID_REQUIRED: 'Account ID is required when using the tokenize-payment-method component not slotted in justifi-modular-checkout',
    FORM_NOT_READY: 'Payment form not ready',
    VALIDATION_ERROR: 'Validation error',
};
const TokenizePaymentMethod = class {
    constructor(hostRef) {
        index.registerInstance(this, hostRef);
        this.errorEvent = index.createEvent(this, "error-event");
        this.submitEvent = index.createEvent(this, "submit-event");
        this.isLoading = false;
        this.saveNewPaymentMethodChecked = false;
        this.submitButtonText = 'Submit';
    }
    componentWillLoad() {
        checkPkgVersion.checkPkgVersion();
        this.analytics = new checkPkgVersion.JustifiAnalytics(this);
        this.validateRequiredProps();
    }
    connectedCallback() {
        this.setDefaultSelectedPaymentMethod();
    }
    disconnectedCallback() {
        var _a;
        (_a = this.analytics) === null || _a === void 0 ? void 0 : _a.cleanup();
    }
    paymentMethodsChanged() {
        this.setDefaultSelectedPaymentMethod();
    }
    handleRadioClick(event) {
        this.selectedPaymentMethodId = event.detail;
    }
    handleCheckboxChanged(event) {
        this.saveNewPaymentMethodChecked = event.detail;
    }
    async fillBillingForm(fields) {
        var _a;
        (_a = this.billingFormRef) === null || _a === void 0 ? void 0 : _a.fill(fields);
    }
    async tokenizePaymentMethod(event) {
        event === null || event === void 0 ? void 0 : event.preventDefault();
        this.isLoading = true;
        try {
            const validation = await this.validate();
            if (!validation.isValid) {
                this.errorEvent.emit({
                    errorCode: ComponentError.ComponentErrorCodes.TOKENIZE_ERROR,
                    message: ERROR_MESSAGES.VALIDATION_ERROR,
                });
                this.isLoading = false;
                return;
            }
            const tokenizeResponse = await this.resolvePaymentMethod({ isValid: true });
            if (tokenizeResponse.error) {
                this.emitError({
                    errorCode: tokenizeResponse.error.code,
                    message: tokenizeResponse.error.message,
                });
            }
            this.submitEvent.emit({ response: tokenizeResponse });
            return tokenizeResponse;
        }
        catch (error) {
            const errorResponse = this.createErrorResponse(ComponentError.ComponentErrorCodes.TOKENIZE_ERROR, error.message);
            this.emitError({
                errorCode: ComponentError.ComponentErrorCodes.TOKENIZE_ERROR,
                message: error.message,
            });
            this.submitEvent.emit({ response: errorResponse });
            return errorResponse;
        }
        finally {
            this.isLoading = false;
        }
    }
    async validate() {
        if (!this.areFormsReady()) {
            return { isValid: false, errors: { general: ERROR_MESSAGES.FORM_NOT_READY } };
        }
        const [billingValidation, paymentMethodValidation] = await Promise.all([
            this.billingFormRef.validate(),
            this.paymentMethodFormRef.validate(),
        ]);
        return {
            isValid: billingValidation.isValid && paymentMethodValidation.isValid,
            errors: Object.assign(Object.assign({}, billingValidation.errors), paymentMethodValidation.errors),
        };
    }
    validateRequiredProps() {
        if (!this.authToken && !checkout_store.checkoutStore.authToken) {
            this.emitError({
                errorCode: ComponentError.ComponentErrorCodes.TOKENIZE_ERROR,
                message: ERROR_MESSAGES.AUTH_TOKEN_REQUIRED,
            });
        }
        if (!this.accountId && !checkout_store.checkoutStore.accountId) {
            this.emitError({
                errorCode: ComponentError.ComponentErrorCodes.TOKENIZE_ERROR,
                message: ERROR_MESSAGES.ACCOUNT_ID_REQUIRED,
            });
        }
    }
    setDefaultSelectedPaymentMethod() {
        if (!this.selectedPaymentMethodId) {
            if (!this.disableCreditCard) {
                this.selectedPaymentMethodId = Refund.PaymentMethodTypes.card;
            }
            else if (!this.disableBankAccount) {
                this.selectedPaymentMethodId = Refund.PaymentMethodTypes.bankAccount;
            }
        }
    }
    get availablePaymentMethods() {
        const methods = [];
        if (!this.disableCreditCard) {
            methods.push(Refund.PaymentMethodTypes.card);
        }
        if (!this.disableBankAccount) {
            methods.push(Refund.PaymentMethodTypes.bankAccount);
        }
        return methods;
    }
    areFormsReady() {
        return !!(this.billingFormRef && this.paymentMethodFormRef);
    }
    emitError(errorData) {
        this.errorEvent.emit(Object.assign(Object.assign({}, errorData), { severity: ComponentError.ComponentErrorSeverity.ERROR }));
    }
    createErrorResponse(code, message) {
        return {
            error: {
                code: code,
                message,
                decline_code: undefined,
            },
        };
    }
    async resolvePaymentMethod(insuranceValidation) {
        if (!this.areFormsReady()) {
            return this.createErrorResponse('form_not_ready', ERROR_MESSAGES.FORM_NOT_READY);
        }
        try {
            const validation = await this.validate();
            if (!validation.isValid || !insuranceValidation.isValid) {
                const errorMessage = Object.values(validation.errors)[0] || ERROR_MESSAGES.VALIDATION_ERROR;
                return {
                    validationError: true,
                    error: {
                        code: 'validation_error',
                        message: String(errorMessage),
                        decline_code: undefined,
                    },
                };
            }
            return await this.performTokenization();
        }
        catch (error) {
            return { error };
        }
    }
    async performTokenization() {
        var _a, _b;
        const tokenizeResponse = await this.tokenize();
        if (tokenizeResponse.error) {
            return { error: tokenizeResponse.error };
        }
        const tokenizeResponseData = tokenizeResponse.data;
        return {
            token: ((_a = tokenizeResponseData.card) === null || _a === void 0 ? void 0 : _a.token) || ((_b = tokenizeResponseData.bank_account) === null || _b === void 0 ? void 0 : _b.token),
            data: tokenizeResponseData,
        };
    }
    async tokenize() {
        try {
            const billingFormFieldValues = await this.billingFormRef.getValues();
            const config = {
                clientId: this.authToken || checkout_store.checkoutStore.authToken,
                account: this.accountId || checkout_store.checkoutStore.accountId,
                paymentMethodMetadata: this.buildPaymentMethodMetadata(billingFormFieldValues),
            };
            return await this.paymentMethodFormRef.tokenize(config);
        }
        catch (error) {
            return error;
        }
    }
    buildPaymentMethodMetadata(billingFormFieldValues) {
        return this.saveNewPaymentMethodChecked
            ? Object.assign(Object.assign({}, billingFormFieldValues), { payment_method_group_id: this.paymentMethodGroupId }) : Object.assign({}, billingFormFieldValues);
    }
    get shouldHideRadioInput() {
        const showCard = !this.disableCreditCard;
        const showAch = !this.disableBankAccount;
        return !showAch || !showCard;
    }
    renderPaymentMethodOption(paymentMethodType) {
        const isSelected = this.selectedPaymentMethodId === paymentMethodType;
        return (index.h("div", { class: "payment-method" }, index.h("justifi-radio-list-item", { name: "paymentMethodType", value: paymentMethodType, checked: isSelected, label: PAYMENT_METHOD_TYPE_LABELS[paymentMethodType], hidden: this.shouldHideRadioInput }), isSelected && this.renderSelectedPaymentMethodForm(paymentMethodType)));
    }
    renderSelectedPaymentMethodForm(paymentMethodId) {
        return (index.h("div", { class: "mt-4 pb-4" }, this.renderPaymentMethodForm(paymentMethodId), index.h("justifi-billing-form", { ref: (el) => (this.billingFormRef = el), hideCardBillingForm: this.hideCardBillingForm, hideBankAccountBillingForm: this.hideBankAccountBillingForm, paymentMethodType: paymentMethodId }), index.h("justifi-save-new-payment-method", { hidden: !this.paymentMethodGroupId })));
    }
    renderPaymentMethodForm(paymentMethodId) {
        return paymentMethodId === Refund.PaymentMethodTypes.card ? (index.h("justifi-card-form", { ref: (el) => (this.paymentMethodFormRef = el) })) : (index.h("justifi-bank-account-form", { ref: (el) => (this.paymentMethodFormRef = el) }));
    }
    render() {
        return (index.h(styledHost.StyledHost, { key: 'c3c12d1c58540f7fe794bc999e8cc8f47e9e1f8c' }, index.h("form", { key: 'aeb7843431a96feb79da49f1c28e0de6dc2d65c4' }, index.h("fieldset", { key: 'e890fbe8bb05bb6d74f8cabc9f4eb4feee4284ee' }, index.h("div", { key: '5abfab85b050239deea655dc777ff026b6627b8b', class: "row gy-3" }, index.h("div", { key: '9bb9dd865d6b2162d19a773ca232934da71bd792', class: "col-12" }, this.availablePaymentMethods.map((method) => this.renderPaymentMethodOption(method))), index.h("div", { key: 'aac644f69aa0e68632b850fc0f5c1442e26979e4', class: "col-12" }, index.h("justifi-button", { key: 'd2a35bd402b0d45dbcb48fefd44a624d4ab27a64', text: this.submitButtonText, variant: "primary", type: "submit", clickHandler: (e) => this.tokenizePaymentMethod(e), isLoading: this.isLoading, "data-testid": "submit-button", hidden: this.hideSubmitButton })))))));
    }
    static get watchers() { return {
        "disableCreditCard": ["paymentMethodsChanged"],
        "disableBankAccount": ["paymentMethodsChanged"]
    }; }
};

exports.justifi_tokenize_payment_method = TokenizePaymentMethod;
