'use strict';

var index = require('./index-D5bL1DOi.js');
require('./config-state-Dz9bnWHg.js');
require('./dinero-J-SRFKIR.js');
require('./ComponentError-CEv9ltwy.js');
require('./Refund-08OcZkXX.js');
var Pagination = require('./Pagination-Dediz133.js');
require('./Business-DCRzZf0w.js');
require('./Dispute-CruQTF6_.js');
var table = require('./table-CxvETNS1.js');
var eventTypes = require('./event-types-YOY5TKUN.js');
var paymentsTable = require('./payments-table-DaW6SvdL.js');
var paymentsListParamsState = require('./payments-list-params-state-DZUKBmLC.js');
require('./index-BCtVWU61.js');
require('./_commonjsHelpers-BJu3ubxk.js');
require('./utils-DqlrBltg.js');
require('./helpers-B5OCqlIM.js');
require('./state-options-CIT9xdTz.js');
require('./parts-9jMf1erK.js');
require('./spinner-CIZFX7bz.js');
require('./payments-status-DG50GuXR.js');
require('./badge-DDksduwk.js');

const PaymentsListCore = class {
    constructor(hostRef) {
        index.registerInstance(this, hostRef);
        this.clickEvent = index.createEvent(this, "click-event");
        this.errorEvent = index.createEvent(this, "error-event");
        this.payments = [];
        this.loading = true;
        this.paging = Pagination.pagingDefaults;
        this.pagingParams = {};
        this.handleClickPrevious = (beforeCursor) => {
            this.pagingParams = { before_cursor: beforeCursor };
            this.clickEvent.emit({ name: eventTypes.TableClickActions.previous });
        };
        this.handleClickNext = (afterCursor) => {
            this.pagingParams = { after_cursor: afterCursor };
            this.clickEvent.emit({ name: eventTypes.TableClickActions.next });
        };
        this.rowClickHandler = (e) => {
            const clickedPaymentID = e.target.closest('tr').dataset.rowEntityId;
            if (!clickedPaymentID)
                return;
            const paymentData = this.payments.find((payment) => payment.id === clickedPaymentID);
            this.clickEvent.emit({ name: eventTypes.TableClickActions.row, data: paymentData });
        };
    }
    updateOnPropChange() {
        this.fetchData();
    }
    componentWillLoad() {
        this.paymentsTable = new table.Table(this.payments, this.columns, paymentsTable.paymentTableColumns, paymentsTable.paymentTableCells);
        if (this.getPayments) {
            this.fetchData();
        }
        paymentsListParamsState.onQueryParamsChange('set', () => {
            this.pagingParams = {};
        });
        paymentsListParamsState.onQueryParamsChange('reset', () => {
            this.pagingParams = {};
            this.errorMessage = '';
        });
    }
    fetchData() {
        this.loading = true;
        this.getPayments({
            params: this.paymentParams,
            onSuccess: ({ payments, pagingInfo }) => {
                this.payments = payments;
                this.paging = pagingInfo;
                this.paymentsTable.collectionData = this.payments;
            },
            onError: ({ error, code, severity }) => {
                this.errorMessage = error;
                this.errorEvent.emit({
                    errorCode: code,
                    message: error,
                    severity,
                });
            },
            final: () => {
                this.loading = false;
            }
        });
    }
    get paymentParams() {
        const requestParams = paymentsListParamsState.getRequestParams();
        const params = Object.assign(Object.assign({}, requestParams), this.pagingParams);
        return params;
    }
    get entityId() {
        return this.payments.map((payment) => payment.id);
    }
    get showEmptyState() {
        return !this.loading && !this.errorMessage && this.paymentsTable.rowData.length < 1;
    }
    get showErrorState() {
        return !this.loading && !!this.errorMessage;
    }
    get showRowData() {
        return !this.showEmptyState && !this.showErrorState && !this.loading;
    }
    render() {
        return (index.h(table.TableWrapper, { key: '8717c3554e0d5c8a2cd20b3a5510691c57d9f89a' }, index.h(table.TableComponent, { key: 'f23e5222c49c9d2f74c47ee0ded1c79319bd662c' }, index.h(table.TableHead, { key: '1cc4cf3bb057247bb0f26efc8414f574685ea134' }, index.h(table.TableHeadRow, { key: 'cfb828ecbe828cdd096e1e00710443627c00e72a' }, this.paymentsTable.columnData.map((column) => column))), index.h(table.TableBody, { key: 'da5eff4f32f2c47e700665a417f3d71605a287c3' }, index.h(table.TableLoadingState, { key: 'f5214c8760d679e47d50d1ac6883176abfd8aa91', columnSpan: this.paymentsTable.columnData.length, isLoading: this.loading }), index.h(table.TableEmptyState, { key: 'cbc72d572081b54b42d5adcb4e86937bf6c10fde', isEmpty: this.showEmptyState, columnSpan: this.paymentsTable.columnData.length }), index.h(table.TableErrorState, { key: 'ce954f66d360840e0c00d7acc77e8e8d43d93dd6', columnSpan: this.paymentsTable.columnData.length, errorMessage: this.errorMessage }), this.showRowData && this.paymentsTable.rowData.map((data, index$1) => (index.h(table.TableRow, { "data-test-id": "table-row", "data-row-entity-id": this.entityId[index$1], onClick: this.rowClickHandler }, data)))), this.paging && (index.h(table.TableFoot, { key: 'b6794bb85eb48d3ca9fd284a538eecba052b4e41' }, index.h(table.TableFootRow, { key: '923942c6cc9e110a93e0ea63dc4a99296ed10d63' }, index.h(table.TableFootCell, { key: 'ad259631ffc9d9a567375c7d28f48d449ac40990', colSpan: this.paymentsTable.columnData.length }, index.h("pagination-menu", { key: 'c06a9e46d23c851a9271bf893889cb3360475070', paging: Object.assign(Object.assign({}, this.paging), { handleClickPrevious: this.handleClickPrevious, handleClickNext: this.handleClickNext }) }))))))));
    }
    static get watchers() { return {
        "pagingParams": ["updateOnPropChange"],
        "getPayments": ["updateOnPropChange"],
        "columns": ["updateOnPropChange"]
    }; }
};

exports.payments_list_core = PaymentsListCore;
