'use strict';

var index = require('./index-D5bL1DOi.js');
require('./config-state-Dz9bnWHg.js');
require('./dinero-J-SRFKIR.js');
var ComponentError = require('./ComponentError-CEv9ltwy.js');
require('./Refund-08OcZkXX.js');
var Pagination = require('./Pagination-Dediz133.js');
require('./Business-DCRzZf0w.js');
require('./Dispute-CruQTF6_.js');
var table = require('./table-CxvETNS1.js');
var eventTypes = require('./event-types-YOY5TKUN.js');
var payoutsTable = require('./payouts-table-D5hMHcaY.js');
var payoutsListParamsState = require('./payouts-list-params-state-DZUKBmLC.js');
require('./index-BCtVWU61.js');
require('./_commonjsHelpers-BJu3ubxk.js');
require('./utils-DqlrBltg.js');
require('./helpers-B5OCqlIM.js');
require('./state-options-CIT9xdTz.js');
require('./parts-9jMf1erK.js');
require('./spinner-CIZFX7bz.js');
require('./payouts-status-meuI7eBr.js');
require('./badge-DDksduwk.js');

const PayoutsListCore = class {
    constructor(hostRef) {
        index.registerInstance(this, hostRef);
        this.clickEvent = index.createEvent(this, "click-event");
        this.errorEvent = index.createEvent(this, "error-event");
        this.payouts = [];
        this.subAccounts = [];
        this.loading = true;
        this.paging = Pagination.pagingDefaults;
        this.pagingParams = {};
        this.downloadCSV = (payoutId) => {
            this.getPayoutCSV({
                payoutId,
                onError: () => {
                    this.errorEvent.emit({
                        errorCode: ComponentError.ComponentErrorCodes.FETCH_ERROR,
                        message: 'Failed to download CSV',
                        severity: ComponentError.ComponentErrorSeverity.ERROR,
                    });
                },
            });
        };
        this.handleClickPrevious = (beforeCursor) => {
            this.pagingParams = { before_cursor: beforeCursor };
            this.clickEvent.emit({ name: eventTypes.TableClickActions.previous });
        };
        this.handleClickNext = (afterCursor) => {
            this.pagingParams = { after_cursor: afterCursor };
            this.clickEvent.emit({ name: eventTypes.TableClickActions.next });
        };
        this.rowClickHandler = (e) => {
            const clickedRow = e.target.closest('tr');
            const clickedPayoutID = clickedRow.dataset.rowEntityId;
            if (!clickedPayoutID)
                return;
            const clickedCSV = clickedRow.querySelector('a');
            if (clickedCSV === e.target)
                return;
            const payoutData = this.payouts.find((payout) => payout.id === clickedPayoutID);
            this.clickEvent.emit({ name: eventTypes.TableClickActions.row, data: payoutData });
        };
    }
    updateOnPropChange() {
        this.fetchData();
    }
    componentWillLoad() {
        this.payoutsTable = new table.Table(this.payouts, this.columns, payoutsTable.payoutTableColumns, payoutsTable.payoutTableCells(this.downloadCSV));
        if (this.getPayouts && this.getSubAccounts) {
            this.fetchData();
        }
        payoutsListParamsState.onQueryParamsChange('set', () => {
            this.pagingParams = {};
        });
        payoutsListParamsState.onQueryParamsChange('reset', () => {
            this.pagingParams = {};
            this.errorMessage = '';
        });
    }
    fetchData() {
        this.loading = true;
        this.getPayouts({
            params: this.payoutParams,
            onSuccess: ({ payouts, pagingInfo }) => {
                this.payouts = payouts;
                this.paging = pagingInfo;
                this.payoutsTable.collectionData = this.payouts;
                const shouldFetchSubAccounts = this.payoutsTable.columnKeys.includes('sub_account_name');
                if (shouldFetchSubAccounts) {
                    this.fetchSubAccounts();
                }
                else {
                    this.loading = false;
                }
            },
            onError: ({ error, code, severity }) => {
                this.errorMessage = error;
                this.errorEvent.emit({
                    errorCode: code,
                    message: error,
                    severity,
                });
                this.loading = false;
            },
        });
    }
    async fetchSubAccounts() {
        this.getSubAccounts({
            params: this.subAccountParams,
            onSuccess: ({ subAccounts }) => {
                this.subAccounts = subAccounts;
                this.payouts = this.payouts.map((payout) => {
                    var _a;
                    payout.sub_account_name = (_a = this.subAccounts.find((subAccount) => subAccount.id === payout.account_id)) === null || _a === void 0 ? void 0 : _a.name;
                    return payout;
                });
                this.loading = false;
            },
            onError: ({ error, code, severity }) => {
                this.errorMessage = error;
                this.errorEvent.emit({
                    errorCode: code,
                    message: error,
                    severity,
                });
                this.loading = false;
            },
        });
    }
    get payoutParams() {
        const requestParams = payoutsListParamsState.getRequestParams();
        const params = Object.assign(Object.assign({}, requestParams), this.pagingParams);
        return params;
    }
    get subAccountParams() {
        let accountIdNumbers = this.payouts.map((payout) => payout.account_id);
        let uniqueAccountIds = [...new Set(accountIdNumbers)];
        let accountIdString = uniqueAccountIds.join(',');
        return { sub_account_id: accountIdString };
    }
    get entityId() {
        return this.payouts.map((payout) => payout.id);
    }
    get showEmptyState() {
        return !this.loading && !this.errorMessage && this.payoutsTable.rowData.length < 1;
    }
    get showErrorState() {
        return !this.loading && !!this.errorMessage;
    }
    get showRowData() {
        return !this.showEmptyState && !this.showErrorState && !this.loading;
    }
    render() {
        return (index.h(table.TableWrapper, { key: '14a73ad4e8a841a731667d77a5be88d81a32a4e4' }, index.h(table.TableComponent, { key: 'aeb950f72b44547884da8d825604e36fd0d10945' }, index.h(table.TableHead, { key: 'e938550e08cc10f9f9bcf332c1ac187761849344' }, index.h(table.TableHeadRow, { key: '08e692828490e85cb7764a14a95a499d113136a1' }, this.payoutsTable.columnData.map((column) => column))), index.h(table.TableBody, { key: '9127ceac1604c85476cd4803a7e7ad2646bc5bf0' }, index.h(table.TableLoadingState, { key: 'd0e58b5ec8b8aad83922f8863fa7c0ba7136aca3', columnSpan: this.payoutsTable.columnKeys.length, isLoading: this.loading }), index.h(table.TableEmptyState, { key: '6e0b794a28b8067ba88330b96090362f0454c894', isEmpty: this.showEmptyState, columnSpan: this.payoutsTable.columnKeys.length }), index.h(table.TableErrorState, { key: 'c858aa45775a92fc0b9e76326cbd23d8054f5342', columnSpan: this.payoutsTable.columnKeys.length, errorMessage: this.errorMessage }), this.showRowData && this.payoutsTable.rowData.map((data, index$1) => (index.h(table.TableRow, { "data-test-id": "table-row", "data-row-entity-id": this.entityId[index$1], onClick: this.rowClickHandler }, data)))), this.paging && (index.h(table.TableFoot, { key: '98bf326a59c4b32d06c6738f086a660116576aa8' }, index.h(table.TableFootRow, { key: '36a2b0e17a94f5e361d12d6bc0e9fd9aaebf41e8' }, index.h(table.TableFootCell, { key: '54daa1d4c6e86128d74a75142b13184d3ec74502', colSpan: this.payoutsTable.columnData.length }, index.h("pagination-menu", { key: '7199ea8e69d351cc07d014770c8b48f6d01d04e3', paging: Object.assign(Object.assign({}, this.paging), { handleClickPrevious: this.handleClickPrevious, handleClickNext: this.handleClickNext }) }))))))));
    }
    static get watchers() { return {
        "pagingParams": ["updateOnPropChange"],
        "getPayouts": ["updateOnPropChange"],
        "getSubAccounts": ["updateOnPropChange"]
    }; }
};

exports.payouts_list_core = PayoutsListCore;
