'use strict';

var index = require('./index-D5bL1DOi.js');
var parts = require('./parts-9jMf1erK.js');
var utils = require('./utils-DqlrBltg.js');
require('./config-state-Dz9bnWHg.js');
require('./ComponentError-CEv9ltwy.js');
var Refund = require('./Refund-08OcZkXX.js');
require('./Pagination-Dediz133.js');
require('./Business-DCRzZf0w.js');
require('./Dispute-CruQTF6_.js');
var badge = require('./badge-DDksduwk.js');

const MapTerminalOrderStatusToBadge = (status) => {
    const statusToBadgeProps = {
        submitted: {
            variant: badge.BadgeVariant.PRIMARY,
            title: 'This order is submitted',
            text: 'Submitted',
        },
        completed: {
            variant: badge.BadgeVariant.SUCCESS,
            title: 'This order has been completed',
            text: 'Completed',
        },
        created: {
            variant: badge.BadgeVariant.SECONDARY,
            title: 'This order is created',
            text: 'Created',
        },
        in_progress: {
            variant: badge.BadgeVariant.PRIMARY,
            title: 'This order is in progress',
            text: 'In Progress',
        },
        on_hold: {
            variant: badge.BadgeVariant.WARNING,
            title: 'This order is on hold',
            text: 'On Hold',
        },
        canceled: {
            variant: badge.BadgeVariant.DANGER,
            title: 'This order is canceled',
            text: 'Canceled',
        }
    };
    const badgeProps = statusToBadgeProps[status];
    return index.h(badge.Badge, Object.assign({}, badgeProps));
};

const defaultColumnsKeys = 'created_at,updated_at,order_status,quantity';
const terminalOrdersTableColumns = {
    created_at: () => (index.h("th", { part: parts.tableHeadCell, scope: "col", title: "The date and time the order was created" }, "Created At")),
    updated_at: () => (index.h("th", { part: parts.tableHeadCell, scope: "col", title: "The date and time the order was last updated" }, "Updated At")),
    order_status: () => (index.h("th", { part: parts.tableHeadCell, scope: "col", title: "The current status of the order" }, "Order Status")),
    business_id: () => (index.h("th", { part: parts.tableHeadCell, scope: "col", title: "The business ID associated with the order" }, "Business ID")),
    company_name: () => (index.h("th", { part: parts.tableHeadCell, scope: "col", title: "The business name associated with the order" }, "Business Name")),
    provider: () => (index.h("th", { part: parts.tableHeadCell, scope: "col", title: "The provider associated with the order" }, "Provider")),
    order_type: () => (index.h("th", { part: parts.tableHeadCell, scope: "col", title: "The type of order" }, "Order Type")),
    quantity: () => (index.h("th", { part: parts.tableHeadCell, scope: "col", title: "The number of terminals associated with the order" }, "Order Quantity")),
};
const terminalOrdersTableCells = {
    created_at: (terminalOrder, index$1) => (index.h("td", { part: parts.getAlternateTableCellPart(index$1) },
        index.h("div", { class: "fw-bold" }, utils.convertToLocal(terminalOrder.created_at, { showDisplayDate: true })),
        index.h("div", { class: "fw-bold" }, utils.convertToLocal(terminalOrder.created_at, { showTime: true })))),
    updated_at: (terminalOrder, index$1) => (index.h("td", { part: parts.getAlternateTableCellPart(index$1) },
        index.h("div", { class: "fw-bold" }, utils.convertToLocal(terminalOrder.updated_at, { showDisplayDate: true })),
        index.h("div", { class: "fw-bold" }, utils.convertToLocal(terminalOrder.updated_at, { showTime: true })))),
    order_status: (terminalOrder, index$1) => (index.h("td", { part: parts.getAlternateTableCellPart(index$1) }, MapTerminalOrderStatusToBadge(terminalOrder.order_status))),
    business_id: (terminalOrder, index$1) => (index.h("td", { part: parts.getAlternateTableCellPart(index$1) }, terminalOrder.business_id)),
    company_name: (terminalOrder, index$1) => (index.h("td", { part: parts.getAlternateTableCellPart(index$1) }, terminalOrder.company_name)),
    provider: (terminalOrder, index$1) => (index.h("td", { part: parts.getAlternateTableCellPart(index$1) }, terminalOrder.provider)),
    order_type: (terminalOrder, index$1) => {
        let orderType;
        if (terminalOrder.order_type === Refund.TerminalOrderType.boardingOnly) {
            orderType = 'Boarding Only';
        }
        else if (terminalOrder.order_type === Refund.TerminalOrderType.boardingShipping) {
            orderType = 'Boarding & Shipping';
        }
        return (index.h("td", { part: parts.getAlternateTableCellPart(index$1) }, orderType));
    },
    quantity: (terminalOrder, index$1) => (index.h("td", { part: parts.getAlternateTableCellPart(index$1) }, terminalOrder.terminals.length)),
};

exports.defaultColumnsKeys = defaultColumnsKeys;
exports.terminalOrdersTableCells = terminalOrdersTableCells;
exports.terminalOrdersTableColumns = terminalOrdersTableColumns;
