'use strict';

var index = require('./index-D5bL1DOi.js');
require('./config-state-Dz9bnWHg.js');
require('./dinero-J-SRFKIR.js');
require('./ComponentError-CEv9ltwy.js');
require('./Refund-08OcZkXX.js');
var Pagination = require('./Pagination-Dediz133.js');
require('./Business-DCRzZf0w.js');
require('./Dispute-CruQTF6_.js');
var table = require('./table-CxvETNS1.js');
var eventTypes = require('./event-types-YOY5TKUN.js');
var terminalsTable = require('./terminals-table-DOqVeHM1.js');
var terminalsListParamsState = require('./terminals-list-params-state-DZUKBmLC.js');
require('./index-BCtVWU61.js');
require('./_commonjsHelpers-BJu3ubxk.js');
require('./utils-DqlrBltg.js');
require('./helpers-B5OCqlIM.js');
require('./state-options-CIT9xdTz.js');
require('./parts-9jMf1erK.js');
require('./spinner-CIZFX7bz.js');
require('./badge-DDksduwk.js');

const TerminalsListCore = class {
    constructor(hostRef) {
        index.registerInstance(this, hostRef);
        this.clickEvent = index.createEvent(this, "click-event");
        this.errorEvent = index.createEvent(this, "error-event");
        this.terminals = [];
        this.subAccounts = [];
        this.loading = true;
        this.paging = Pagination.pagingDefaults;
        this.pagingParams = {};
        this.handleClickPrevious = (beforeCursor) => {
            this.pagingParams = { before_cursor: beforeCursor };
            this.clickEvent.emit({ name: eventTypes.TableClickActions.previous });
        };
        this.handleClickNext = (afterCursor) => {
            this.pagingParams = { after_cursor: afterCursor };
            this.clickEvent.emit({ name: eventTypes.TableClickActions.next });
        };
        this.rowClickHandler = (e) => {
            const clickedTerminalID = e.target.closest('tr').dataset.rowEntityId;
            if (!clickedTerminalID)
                return;
            const terminalData = this.terminals.find((terminal) => terminal.id === clickedTerminalID);
            this.clickEvent.emit({ name: eventTypes.TableClickActions.row, data: terminalData });
        };
    }
    updateOnPropChange() {
        this.fetchData();
    }
    componentWillLoad() {
        this.terminalsTable = new table.Table(this.terminals, this.columns, terminalsTable.terminalTableColumns, terminalsTable.terminalTableCells);
        if (this.getTerminals && this.getSubAccounts) {
            this.fetchData();
        }
        terminalsListParamsState.onQueryParamsChange('set', () => {
            this.pagingParams = {};
        });
        terminalsListParamsState.onQueryParamsChange('reset', () => {
            this.pagingParams = {};
            this.errorMessage = '';
        });
    }
    fetchData() {
        this.loading = true;
        this.getTerminals({
            params: this.terminalParams,
            onSuccess: async ({ terminals, pagingInfo }) => {
                this.terminals = terminals;
                this.paging = pagingInfo;
                this.terminalsTable.collectionData = this.terminals;
                const shouldFetchSubAccounts = this.terminalsTable.columnKeys.includes('sub_account_name');
                if (shouldFetchSubAccounts) {
                    await this.fetchSubAccounts();
                }
                else {
                    this.loading = false;
                }
            },
            onError: ({ error, code, severity }) => {
                this.errorMessage = error;
                this.errorEvent.emit({
                    errorCode: code,
                    message: error,
                    severity,
                });
                this.loading = false;
            },
        });
    }
    async fetchSubAccounts() {
        this.getSubAccounts({
            params: this.subAccountParams,
            onSuccess: ({ subAccounts }) => {
                this.subAccounts = subAccounts;
                this.terminals = this.terminals.map((terminal) => {
                    var _a;
                    terminal.sub_account_name = (_a = this.subAccounts.find((subAccount) => subAccount.id === terminal.account_id)) === null || _a === void 0 ? void 0 : _a.name;
                    return terminal;
                });
                this.loading = false;
            },
            onError: ({ error, code, severity }) => {
                this.errorMessage = error;
                this.errorEvent.emit({
                    errorCode: code,
                    message: error,
                    severity,
                });
                this.loading = false;
            },
        });
    }
    get terminalParams() {
        const requestParams = terminalsListParamsState.getRequestParams();
        const params = Object.assign(Object.assign({}, requestParams), this.pagingParams);
        return params;
    }
    get subAccountParams() {
        let accountIdNumbers = this.terminals.map((terminal) => terminal.account_id);
        let uniqueAccountIds = [...new Set(accountIdNumbers)];
        let accountIdString = uniqueAccountIds.join(',');
        return { sub_account_id: accountIdString };
    }
    get entityId() {
        return this.terminals.map((terminal) => terminal.id);
    }
    get showEmptyState() {
        return !this.loading && !this.errorMessage && this.terminalsTable.rowData.length < 1;
    }
    get showErrorState() {
        return !this.loading && !!this.errorMessage;
    }
    get showRowData() {
        return !this.showEmptyState && !this.showErrorState && !this.loading;
    }
    render() {
        return (index.h(table.TableWrapper, { key: 'feaf37a5952ecbb6bd9c1bc1a0aa1239e809fa14' }, index.h(table.TableComponent, { key: '4f10f57069b2303cf4367cd43af6683385d48c93' }, index.h(table.TableHead, { key: '527818c903322fca90a9b30b48f46fdf9c51a4a1' }, index.h(table.TableHeadRow, { key: '4b5c0cf99b36e0224193efd5b013e6ca5f468133' }, this.terminalsTable.columnData.map((column) => column))), index.h(table.TableBody, { key: '94f3573897fecf7c520ceb51bfd6cf68706f14c2' }, index.h(table.TableLoadingState, { key: '709fe7ac553832df64034f9b9acbe1a64004c99b', columnSpan: this.terminalsTable.columnKeys.length, isLoading: this.loading }), index.h(table.TableEmptyState, { key: '25c050dfaaf86a3792e276c27938a066b014f619', isEmpty: this.showEmptyState, columnSpan: this.terminalsTable.columnKeys.length }), index.h(table.TableErrorState, { key: '6aeca4b673c92d095e7d871ca5acb10f66df9b7e', columnSpan: this.terminalsTable.columnKeys.length, errorMessage: this.errorMessage }), this.showRowData && this.terminalsTable.rowData.map((data, index$1) => (index.h(table.TableRow, { "data-test-id": "table-row", "data-row-entity-id": this.entityId[index$1], onClick: this.rowClickHandler }, data)))), this.paging && (index.h(table.TableFoot, { key: '89554de16c42f1016b7aa6173b6b89bf3e3159db' }, index.h(table.TableFootRow, { key: '97b8cbebcb3bc6152c2f1329a00ed6a44f785cbe' }, index.h(table.TableFootCell, { key: 'd299aa13feba175e46fd8ed9883232e9145ece52', colSpan: this.terminalsTable.columnData.length }, index.h("pagination-menu", { key: '01a3d9ee669d1865c167d2fc9a2ca9166b984a6c', paging: Object.assign(Object.assign({}, this.paging), { handleClickPrevious: this.handleClickPrevious, handleClickNext: this.handleClickNext }) }))))))));
    }
    static get watchers() { return {
        "pagingParams": ["updateOnPropChange"],
        "getTerminals": ["updateOnPropChange"],
        "getSubAccounts": ["updateOnPropChange"],
        "columns": ["updateOnPropChange"]
    }; }
};

exports.terminals_list_core = TerminalsListCore;
