'use strict';

var index = require('./index-D5bL1DOi.js');
var badge = require('./badge-DDksduwk.js');
var parts = require('./parts-9jMf1erK.js');
var utils = require('./utils-DqlrBltg.js');

const MapTerminalStatusToBadge = (status) => {
    const statusToBadgeProps = {
        connected: {
            variant: badge.BadgeVariant.SUCCESS,
            title: 'This terminal is connected',
            text: 'Connected',
        },
        disconnected: {
            variant: badge.BadgeVariant.DANGER,
            title: 'This terminal is disconnected',
            text: 'Disconnected',
        },
        unknown: {
            variant: badge.BadgeVariant.SECONDARY,
            title: 'The status of this terminal is unknown',
            text: 'Unknown',
        },
        pending_configuration: {
            variant: badge.BadgeVariant.WARNING,
            title: 'This terminal is pending configuration',
            text: 'Pending configuration',
        },
    };
    const badgeProps = statusToBadgeProps[status];
    return index.h(badge.Badge, Object.assign({}, badgeProps));
};

const defaultColumnsKeys = 'nickname,provider_serial_number,status';
const terminalTableColumns = {
    nickname: () => (index.h("th", { part: parts.tableHeadCell, scope: "col", title: "The nickname associated with the terminal" }, "Nickname")),
    model_name: () => (index.h("th", { part: parts.tableHeadCell, scope: "col", title: "The model name of the terminal" }, "Model Name")),
    id: () => (index.h("th", { part: parts.tableHeadCell, scope: "col", title: "The ID of the terminal" }, "ID")),
    provider: () => (index.h("th", { part: parts.tableHeadCell, scope: "col", title: "The provider of the terminal" }, "Provider")),
    provider_serial_number: () => (index.h("th", { part: parts.tableHeadCell, scope: "col", title: "The serial number of the terminal" }, "Serial Number")),
    device_id: () => (index.h("th", { part: parts.tableHeadCell, scope: "col", title: "The device/provider ID of the terminal" }, "Device ID")),
    sub_account_name: () => (index.h("th", { part: parts.tableHeadCell, scope: "col", title: "The sub account associated with the terminal" }, "Sub Account")),
    status: () => (index.h("th", { part: parts.tableHeadCell, scope: "col", title: "The current status of each terminal" }, "Status")),
};
const terminalTableCells = {
    nickname: (terminal, index$1) => (index.h("td", { part: parts.getAlternateTableCellPart(index$1) }, terminal.nickname)),
    model_name: (terminal, index$1) => (index.h("td", { part: parts.getAlternateTableCellPart(index$1) }, terminal.model_name)),
    id: (terminal, index$1) => (index.h("td", { part: parts.getAlternateTableCellPart(index$1) }, terminal.id)),
    provider: (terminal, index$1) => (index.h("td", { part: parts.getAlternateTableCellPart(index$1) }, utils.capitalFirstLetter(terminal.provider))),
    provider_serial_number: (terminal, index$1) => (index.h("td", { part: parts.getAlternateTableCellPart(index$1) }, terminal.provider_serial_number)),
    device_id: (terminal, index$1) => (index.h("td", { part: parts.getAlternateTableCellPart(index$1) }, terminal.provider_id)),
    sub_account_name: (terminal, index$1) => (index.h("td", { part: parts.getAlternateTableCellPart(index$1) }, terminal.sub_account_name)),
    status: (terminal, index$1) => (index.h("td", { part: parts.getAlternateTableCellPart(index$1) }, MapTerminalStatusToBadge(terminal.status))),
};

exports.defaultColumnsKeys = defaultColumnsKeys;
exports.terminalTableCells = terminalTableCells;
exports.terminalTableColumns = terminalTableColumns;
