import { h } from "@stencil/core";
import { ErrorState } from "../../ui-components/details/utils";
import { StyledHost } from "../../ui-components";
import { BusinessDetailsLoading } from "./business-details-loading";
var RENDER_STATES;
(function (RENDER_STATES) {
    RENDER_STATES["LOADING"] = "loading";
    RENDER_STATES["READY"] = "ready";
    RENDER_STATES["ERROR"] = "error";
})(RENDER_STATES || (RENDER_STATES = {}));
export class BusinessDetailsCore {
    constructor() {
        this.renderState = RENDER_STATES.LOADING;
    }
    async componentWillLoad() {
        if (this.getBusiness) {
            this.fetchData();
        }
    }
    fetchData() {
        this.renderState = RENDER_STATES.LOADING;
        this.getBusiness({
            onSuccess: ({ business }) => {
                this.business = business;
                this.renderState = RENDER_STATES.READY;
            },
            onError: ({ error, code, severity }) => {
                this.errorMessage = error;
                this.renderState = RENDER_STATES.ERROR;
                this.errorEvent.emit({
                    errorCode: code,
                    message: error,
                    severity,
                });
            }
        });
    }
    render() {
        if (this.renderState === RENDER_STATES.LOADING) {
            return (h(StyledHost, null, h(BusinessDetailsLoading, null)));
        }
        if (this.renderState === RENDER_STATES.ERROR) {
            return h(StyledHost, null, ErrorState(this.errorMessage));
        }
        return (h(StyledHost, null, h("justifi-details", { "error-message": this.errorMessage }, h("div", { slot: 'detail-sections' }, h("core-info-details", { business: this.business }), h("legal-address-details", { legalAddress: this.business.legal_address }), h("representative-details", { representative: this.business.representative }), h("owner-details", { owners: this.business.owners }), h("additional-questions-details", { additionalQuestions: this.business.additional_questions })))));
    }
    static get is() { return "business-details-core"; }
    static get properties() {
        return {
            "getBusiness": {
                "type": "unknown",
                "attribute": "get-business",
                "mutable": false,
                "complexType": {
                    "original": "Function",
                    "resolved": "Function",
                    "references": {
                        "Function": {
                            "location": "global",
                            "id": "global::Function"
                        }
                    }
                },
                "required": false,
                "optional": false,
                "docs": {
                    "tags": [],
                    "text": ""
                },
                "getter": false,
                "setter": false
            }
        };
    }
    static get states() {
        return {
            "business": {},
            "renderState": {},
            "errorMessage": {}
        };
    }
    static get events() {
        return [{
                "method": "errorEvent",
                "name": "error-event",
                "bubbles": true,
                "cancelable": true,
                "composed": true,
                "docs": {
                    "tags": [],
                    "text": ""
                },
                "complexType": {
                    "original": "ComponentErrorEvent",
                    "resolved": "ComponentErrorEvent",
                    "references": {
                        "ComponentErrorEvent": {
                            "location": "import",
                            "path": "../../api/ComponentEvents",
                            "id": "src/api/ComponentEvents.ts::ComponentErrorEvent"
                        }
                    }
                }
            }];
    }
}
