import { h } from "@stencil/core";
import { updateAddressFormValues, updateDateOfBirthFormValues, updateFormValues } from "../../utils/input-handlers";
import { PHONE_MASKS, SSN_MASK } from "../../../../utils/form-input-masks";
import { heading2 } from "../../../../styles/parts";
export class RepresentativeFormInputs {
    constructor() {
        this.inputHandler = (name, value) => {
            updateFormValues(this.formController, { [name]: value });
        };
        this.onAddressFormUpdate = (values) => {
            updateAddressFormValues(this.formController, Object.assign(Object.assign({}, this.formController.values.getValue().address), values));
        };
    }
    render() {
        var _a, _b, _c, _d, _e, _f, _g;
        return (h("form", { key: 'e4b7a532e18a921a5a28aab31f679fbbad164198' }, h("fieldset", { key: 'd7056e5ee25625adb563e2687f581157653c8a9d' }, h("div", { key: '456aab0ef1399a7c1d272059c881c6c6f3d0e87c', class: "d-flex align-items-center gap-2" }, h("legend", { key: '430b3731bbd97ff1589bd81bd6fdaa4082161180', class: "mb-0", part: heading2 }, "Representative"), h("form-control-tooltip", { key: '47676ededb80e0f766cb786265d8fb307c60d125', helpText: "The representative for your business needs to be someone who has significant control over managing your business\u2019s finance. You will have an opportunity to add owners later in the form." })), h("hr", { key: '514197b5bd4868ec29e75dc74367deb187b32063', class: "mt-2" }), h("div", { key: 'f2986d55d0bfbf0e6059f0b2a766d2dc603acdc5', class: "row gy-3" }, h("div", { key: 'e4a3749c5e972f505527b8fc172f9a4214806345', class: "col-12 col-md-8" }, h("form-control-text", { key: 'd54c8d17f0360277fe04dd91a528e303182495c7', name: "name", label: "Full Name", defaultValue: (_a = this.representativeDefaultValue) === null || _a === void 0 ? void 0 : _a.name, errorText: this.errors.name, inputHandler: this.inputHandler })), h("div", { key: '4fa0b1a192fb39a982c957d202ea2ac1e40dedd8', class: "col-12 col-md-4" }, h("form-control-text", { key: '8c3bca4234ea0e7ae3c79d810ffb469637898eb6', name: "title", label: "Title", defaultValue: (_b = this.representativeDefaultValue) === null || _b === void 0 ? void 0 : _b.title, errorText: this.errors.title, inputHandler: this.inputHandler, helpText: "Role at your business, e.g. President, CEO, Treasurer." })), h("div", { key: '7e14a61364883172f2938bd8b1e53883ddd369fe', class: "col-12 col-md-6" }, h("form-control-text", { key: '8d9c81d374998dbaea5322906fddb5eeadea1546', name: "email", label: "Email Address", defaultValue: (_c = this.representativeDefaultValue) === null || _c === void 0 ? void 0 : _c.email, errorText: this.errors.email, inputHandler: this.inputHandler })), h("div", { key: 'c3f369b226a08497926b26d0732b7dc9d6413559', class: "col-12 col-md-6" }, h("form-control-number-masked", { key: '734625aeac8384f2b8676c4d350368675cff3a6f', name: "phone", label: "Phone Number", defaultValue: (_d = this.representativeDefaultValue) === null || _d === void 0 ? void 0 : _d.phone, errorText: this.errors.phone, inputHandler: this.inputHandler, mask: PHONE_MASKS.US })), h("div", { key: '23d509b724f2617eb0a4f85c74238b09a052a6cb', class: "col-12 col-md-4" }, h("form-control-date", { key: '0f838cc474beab9822a84856733a86ecf43f0ec3', name: "dob_full", label: "Birth Date", defaultValue: (_e = this.representativeDefaultValue) === null || _e === void 0 ? void 0 : _e.dob_full, errorText: this.errors.dob_full, inputHandler: this.inputHandler, onFormControlInput: (e) => updateDateOfBirthFormValues(e, this.formController), helpText: "Must be 18 or older." })), h("div", { key: 'f6d08c53dad2e9a550adf893ac59166015ffb6e4', class: "col-12 col-md-8" }, h("form-control-number-masked", { key: 'dd610955fb7c62fd0aab9af925af34cdc47ab3e9', name: "identification_number", label: "SSN", defaultValue: (_f = this.representativeDefaultValue) === null || _f === void 0 ? void 0 : _f.identification_number, errorText: this.errors.identification_number, inputHandler: this.inputHandler, mask: SSN_MASK, helpText: "Enter your full Social Security Number. It is required for Federal OFAC check." })), h("div", { key: 'd4e2a212a87ca9be4be8e21f3e47008b2201871c', class: "col-12" }, h("justifi-identity-address-form", { key: 'bb2d0d01e07be4d37acfd448796c8a33460111ed', errors: this.errors.address, defaultValues: (_g = this.representativeDefaultValue) === null || _g === void 0 ? void 0 : _g.address, handleFormUpdate: this.onAddressFormUpdate }))))));
    }
    static get is() { return "justifi-business-representative-form-inputs"; }
    static get properties() {
        return {
            "representativeDefaultValue": {
                "type": "any",
                "attribute": "representative-default-value",
                "mutable": false,
                "complexType": {
                    "original": "any",
                    "resolved": "any",
                    "references": {}
                },
                "required": false,
                "optional": false,
                "docs": {
                    "tags": [],
                    "text": ""
                },
                "getter": false,
                "setter": false,
                "reflect": false
            },
            "errors": {
                "type": "any",
                "attribute": "errors",
                "mutable": false,
                "complexType": {
                    "original": "any",
                    "resolved": "any",
                    "references": {}
                },
                "required": false,
                "optional": false,
                "docs": {
                    "tags": [],
                    "text": ""
                },
                "getter": false,
                "setter": false,
                "reflect": false
            },
            "formController": {
                "type": "unknown",
                "attribute": "form-controller",
                "mutable": false,
                "complexType": {
                    "original": "FormController",
                    "resolved": "FormController",
                    "references": {
                        "FormController": {
                            "location": "import",
                            "path": "../../../../ui-components/form/form",
                            "id": "src/ui-components/form/form.ts::FormController"
                        }
                    }
                },
                "required": false,
                "optional": false,
                "docs": {
                    "tags": [],
                    "text": ""
                },
                "getter": false,
                "setter": false
            }
        };
    }
}
;
