import { h } from "@stencil/core";
import { ComponentErrorCodes, ComponentErrorSeverity } from "../../../api/ComponentError";
import { checkProvisioningStatus } from "../utils/helpers";
import { Header1, StyledHost } from "../../../ui-components";
import { text } from "../../../styles/parts";
import { BusinessFormClickActions } from "../utils/event-types";
export class PaymentProvisioningCore {
    constructor() {
        this.loading = false;
        this.businessProvisioned = false;
        this.currentStep = 0;
        this.allowOptionalFields = false;
        this.setBusinessProvisioned = () => {
            this.getBusiness({
                onSuccess: (response) => {
                    this.businessProvisioned = checkProvisioningStatus(response.data);
                    if (this.businessProvisioned) {
                        this.errorEvent.emit({
                            message: 'A request to provision payments for this business has already been submitted.',
                            errorCode: ComponentErrorCodes.PROVISIONING_REQUESTED,
                            severity: ComponentErrorSeverity.INFO,
                        });
                    }
                },
                onError: ({ error, code, severity }) => {
                    this.errorEvent.emit({
                        message: error,
                        errorCode: code,
                        severity: severity
                    });
                }
            });
        };
        this.postProvisioningData = () => {
            this.postProvisioning({
                onSuccess: (response) => {
                    this.submitEvent.emit({ response: response });
                },
                onError: ({ error, code, severity }) => {
                    this.submitEvent.emit({ response: { error } });
                    this.errorEvent.emit({
                        message: error,
                        errorCode: code,
                        severity: severity
                    });
                }
            });
        };
        this.refs = [];
        this.incrementSteps = () => {
            if (this.currentStep < this.totalSteps) {
                return this.currentStep++;
            }
        };
        this.decrementSteps = () => { return this.currentStep--; };
        this.previousStepButtonOnClick = () => {
            this.clickEvent.emit({ name: BusinessFormClickActions.previousStep });
            this.decrementSteps();
        };
        this.nextStepButtonOnClick = (e, clickEventName) => {
            e.preventDefault();
            this.clickEvent.emit({ name: clickEventName });
            const currentStep = this.refs[this.currentStep];
            currentStep.validateAndSubmit({ onSuccess: this.incrementSteps });
        };
    }
    handleFormCompleted() {
        this.postProvisioningData();
    }
    componentWillLoad() {
        this.getBusiness && this.setBusinessProvisioned();
        this.refs = [this.coreInfoRef, this.legalAddressRef, this.additionalQuestionsRef, this.representativeRef, this.ownersRef, this.bankAccountRef, this.termsRef];
    }
    get businessEndpoint() {
        return `entities/business/${this.businessId}`;
    }
    get formDisabled() {
        return this.loading || this.businessProvisioned;
    }
    get totalSteps() {
        return this.refs.length - 1;
    }
    get stepCounter() {
        return `${this.currentStep + 1} of ${this.totalSteps + 1}`;
    }
    handleFormLoading(event) {
        this.loading = event.detail;
    }
    render() {
        return (h(StyledHost, { key: '621b616a3b9d5be0fcc1180dcdb0db6a89ec5aa2' }, h("div", { key: 'b51c6814bb81a6cdc6cd0c5ede4d485582f154ee', class: 'row gap-3' }, h(Header1, { key: '7c03561b4c2b0cfc237d6b933aeffe532f35b626', text: this.formTitle }), h("justifi-payment-provisioning-form-steps", { key: 'b616b52cc9a0057f27ddbae1356710cee05c60fa', businessId: this.businessId, authToken: this.authToken, refs: this.refs, currentStep: this.currentStep, allowOptionalFields: this.allowOptionalFields, handleFormLoading: this.handleFormLoading }), h("div", { key: '2447bad174b5d32d253e821e76ebb32fb9ec50e3', class: 'd-flex justify-content-between align-items-center' }, h("div", { key: 'd746b5275ae0866a8619f67fe00217916153ea0a', class: 'd-flex align-items-center', part: text }, this.stepCounter), h("justifi-payment-provisioning-form-buttons", { key: 'add808398005b6076d91788cc220ab6620f3ddfc', currentStep: this.currentStep, totalSteps: this.totalSteps, formLoading: this.loading, formDisabled: this.formDisabled, previousStepButtonOnClick: this.previousStepButtonOnClick, nextStepButtonOnClick: this.nextStepButtonOnClick })))));
    }
    static get is() { return "justifi-payment-provisioning-core"; }
    static get properties() {
        return {
            "businessId": {
                "type": "string",
                "attribute": "business-id",
                "mutable": false,
                "complexType": {
                    "original": "string",
                    "resolved": "string",
                    "references": {}
                },
                "required": false,
                "optional": false,
                "docs": {
                    "tags": [],
                    "text": ""
                },
                "getter": false,
                "setter": false,
                "reflect": false
            },
            "authToken": {
                "type": "string",
                "attribute": "auth-token",
                "mutable": false,
                "complexType": {
                    "original": "string",
                    "resolved": "string",
                    "references": {}
                },
                "required": false,
                "optional": false,
                "docs": {
                    "tags": [],
                    "text": ""
                },
                "getter": false,
                "setter": false,
                "reflect": false
            },
            "allowOptionalFields": {
                "type": "boolean",
                "attribute": "allow-optional-fields",
                "mutable": false,
                "complexType": {
                    "original": "boolean",
                    "resolved": "boolean",
                    "references": {}
                },
                "required": false,
                "optional": true,
                "docs": {
                    "tags": [],
                    "text": ""
                },
                "getter": false,
                "setter": false,
                "reflect": false,
                "defaultValue": "false"
            },
            "formTitle": {
                "type": "string",
                "attribute": "form-title",
                "mutable": false,
                "complexType": {
                    "original": "string",
                    "resolved": "string",
                    "references": {}
                },
                "required": false,
                "optional": false,
                "docs": {
                    "tags": [],
                    "text": ""
                },
                "getter": false,
                "setter": false,
                "reflect": false
            },
            "getBusiness": {
                "type": "unknown",
                "attribute": "get-business",
                "mutable": false,
                "complexType": {
                    "original": "Function",
                    "resolved": "Function",
                    "references": {
                        "Function": {
                            "location": "global",
                            "id": "global::Function"
                        }
                    }
                },
                "required": false,
                "optional": false,
                "docs": {
                    "tags": [],
                    "text": ""
                },
                "getter": false,
                "setter": false
            },
            "postProvisioning": {
                "type": "unknown",
                "attribute": "post-provisioning",
                "mutable": false,
                "complexType": {
                    "original": "Function",
                    "resolved": "Function",
                    "references": {
                        "Function": {
                            "location": "global",
                            "id": "global::Function"
                        }
                    }
                },
                "required": false,
                "optional": false,
                "docs": {
                    "tags": [],
                    "text": ""
                },
                "getter": false,
                "setter": false
            }
        };
    }
    static get states() {
        return {
            "loading": {},
            "businessProvisioned": {},
            "currentStep": {},
            "errorMessage": {}
        };
    }
    static get events() {
        return [{
                "method": "clickEvent",
                "name": "click-event",
                "bubbles": true,
                "cancelable": true,
                "composed": true,
                "docs": {
                    "tags": [],
                    "text": ""
                },
                "complexType": {
                    "original": "ComponentClickEvent",
                    "resolved": "ComponentClickEvent",
                    "references": {
                        "ComponentClickEvent": {
                            "location": "import",
                            "path": "../../../api/ComponentEvents",
                            "id": "src/api/ComponentEvents.ts::ComponentClickEvent"
                        }
                    }
                }
            }, {
                "method": "errorEvent",
                "name": "error-event",
                "bubbles": true,
                "cancelable": true,
                "composed": true,
                "docs": {
                    "tags": [],
                    "text": ""
                },
                "complexType": {
                    "original": "ComponentErrorEvent",
                    "resolved": "ComponentErrorEvent",
                    "references": {
                        "ComponentErrorEvent": {
                            "location": "import",
                            "path": "../../../api/ComponentEvents",
                            "id": "src/api/ComponentEvents.ts::ComponentErrorEvent"
                        }
                    }
                }
            }, {
                "method": "submitEvent",
                "name": "submit-event",
                "bubbles": true,
                "cancelable": true,
                "composed": true,
                "docs": {
                    "tags": [],
                    "text": ""
                },
                "complexType": {
                    "original": "ComponentSubmitEvent",
                    "resolved": "ComponentSubmitEvent",
                    "references": {
                        "ComponentSubmitEvent": {
                            "location": "import",
                            "path": "../../../api/ComponentEvents",
                            "id": "src/api/ComponentEvents.ts::ComponentSubmitEvent"
                        }
                    }
                }
            }];
    }
    static get listeners() {
        return [{
                "name": "formCompleted",
                "method": "handleFormCompleted",
                "target": undefined,
                "capture": false,
                "passive": false
            }, {
                "name": "formLoading",
                "method": "handleFormLoading",
                "target": undefined,
                "capture": false,
                "passive": false
            }];
    }
}
