import { h, Host } from "@stencil/core";
import BankAccountFormSkeleton from "./bank-account-form-skeleton";
import { configState, waitForConfig } from "../../config-provider/config-state";
export class BankAccountForm {
    constructor() {
        this.isReady = false;
    }
    async componentWillLoad() {
        await waitForConfig();
        this.iframeOrigin = configState.iframeOrigin;
    }
    componentDidRender() {
        const elements = [
            this.accountNumberIframeElement,
            this.routingNumberIframeElement,
        ];
        Promise.all(elements.map((element) => {
            return new Promise((resolve) => {
                element.addEventListener('iframeLoaded', () => { resolve(); });
            });
        })).then(() => {
            this.isReady = true;
        });
    }
    async validate() {
        const accountNumberIsValid = await this.accountNumberIframeElement.validate();
        const routingNumberIsValid = await this.routingNumberIframeElement.validate();
        return accountNumberIsValid && routingNumberIsValid;
    }
    async tokenize(clientId, paymentMethodMetadata, account) {
        return this.accountNumberIframeElement.tokenize(clientId, paymentMethodMetadata, account);
    }
    render() {
        return (h(Host, { key: 'f7fccd7526b31937a7adb5c1eef5d7db21116b8b' }, h(BankAccountFormSkeleton, { key: '316e16b7bc09d15334c863323b338d61bf074ad4', isReady: this.isReady }), h("div", { key: '6676e15da0bc4f4dccbbbe035af3de9abd449ebf', class: "container-fluid p-0", style: {
                opacity: this.isReady ? '1' : '0',
                height: this.isReady ? 'auto' : '0',
            } }, h("div", { key: 'd689e889153f3efd693ff2acfe8a0bf2da84b786', class: "row mb-3" }, h("iframe-input", { key: 'd5405444fbd9776882cbaf649cdc4f709c60f7be', inputId: "accountNumber", ref: (el) => (this.accountNumberIframeElement = el), label: "Account Number", iframeOrigin: `${this.iframeOrigin}/v2/accountNumber` })), h("div", { key: '788b71169701d7a004ce668cd2126b85cd65a372', class: "row" }, h("iframe-input", { key: '13d88a9e446e4fa7d88424359737202baa1ff79b', inputId: "routingNumber", ref: (el) => (this.routingNumberIframeElement = el), label: "Routing Number", iframeOrigin: `${this.iframeOrigin}/v2/routingNumber` })))));
    }
    static get is() { return "bank-account-form"; }
    static get states() {
        return {
            "isReady": {},
            "iframeOrigin": {}
        };
    }
    static get methods() {
        return {
            "validate": {
                "complexType": {
                    "signature": "() => Promise<any>",
                    "parameters": [],
                    "references": {
                        "Promise": {
                            "location": "global",
                            "id": "global::Promise"
                        }
                    },
                    "return": "Promise<any>"
                },
                "docs": {
                    "text": "",
                    "tags": []
                }
            },
            "tokenize": {
                "complexType": {
                    "signature": "(clientId: string, paymentMethodMetadata: any, account?: string) => Promise<any>",
                    "parameters": [{
                            "name": "clientId",
                            "type": "string",
                            "docs": ""
                        }, {
                            "name": "paymentMethodMetadata",
                            "type": "any",
                            "docs": ""
                        }, {
                            "name": "account",
                            "type": "string",
                            "docs": ""
                        }],
                    "references": {
                        "Promise": {
                            "location": "global",
                            "id": "global::Promise"
                        }
                    },
                    "return": "Promise<any>"
                },
                "docs": {
                    "text": "",
                    "tags": []
                }
            }
        };
    }
}
