import { h } from "@stencil/core";
import { billingForm } from "../../../styles/parts";
export class BillingForm {
    get isPostalOnlyMode() {
        return this.paymentMethodType === 'card' && this.hideCardBillingForm;
    }
    get hideAllBillingFields() {
        return this.paymentMethodType === 'bankAccount' && this.hideBankAccountBillingForm;
    }
    async getValues() {
        return this.formRef.getValues();
    }
    async fill(fields) {
        return this.formRef.fill(fields);
    }
    async validate() {
        const { isValid, errors } = await this.formRef.validate();
        return { isValid, errors };
    }
    render() {
        const showHeader = !this.isPostalOnlyMode && !this.hideAllBillingFields;
        return (h("div", { key: 'b1d80f02eee8bdc4fe4b9bfd7e9fb86d89af53b3', part: billingForm, class: "mt-4", hidden: this.hideAllBillingFields }, showHeader && h("justifi-header", { key: 'f3d7d02561a3de2c777b869a8b874fe0e03d1924', text: "Billing address", level: "h3", class: "fs-6 fw-bold lh-lg mb-4" }), this.legend && h("legend", { key: '9218d5b52eed27d86970e745cbbd9d02c6df513b' }, this.legend), this.isPostalOnlyMode ? (h("justifi-postal-code-form", { ref: (el) => this.formRef = el })) : (h("justifi-billing-information-form", { ref: (el) => this.formRef = el }))));
    }
    static get is() { return "justifi-billing-form"; }
    static get properties() {
        return {
            "legend": {
                "type": "string",
                "attribute": "legend",
                "mutable": true,
                "complexType": {
                    "original": "string",
                    "resolved": "string",
                    "references": {}
                },
                "required": false,
                "optional": true,
                "docs": {
                    "tags": [],
                    "text": ""
                },
                "getter": false,
                "setter": false,
                "reflect": false
            },
            "hideCardBillingForm": {
                "type": "boolean",
                "attribute": "hide-card-billing-form",
                "mutable": false,
                "complexType": {
                    "original": "boolean",
                    "resolved": "boolean",
                    "references": {}
                },
                "required": false,
                "optional": true,
                "docs": {
                    "tags": [],
                    "text": ""
                },
                "getter": false,
                "setter": false,
                "reflect": false
            },
            "hideBankAccountBillingForm": {
                "type": "boolean",
                "attribute": "hide-bank-account-billing-form",
                "mutable": false,
                "complexType": {
                    "original": "boolean",
                    "resolved": "boolean",
                    "references": {}
                },
                "required": false,
                "optional": true,
                "docs": {
                    "tags": [],
                    "text": ""
                },
                "getter": false,
                "setter": false,
                "reflect": false
            },
            "paymentMethodType": {
                "type": "string",
                "attribute": "payment-method-type",
                "mutable": false,
                "complexType": {
                    "original": "string",
                    "resolved": "string",
                    "references": {}
                },
                "required": false,
                "optional": true,
                "docs": {
                    "tags": [],
                    "text": ""
                },
                "getter": false,
                "setter": false,
                "reflect": false
            }
        };
    }
    static get methods() {
        return {
            "getValues": {
                "complexType": {
                    "signature": "() => Promise<BillingFormFields>",
                    "parameters": [],
                    "references": {
                        "Promise": {
                            "location": "global",
                            "id": "global::Promise"
                        },
                        "BillingFormFields": {
                            "location": "import",
                            "path": "../../../components",
                            "id": "src/components.d.ts::BillingFormFields"
                        }
                    },
                    "return": "Promise<BillingFormFields>"
                },
                "docs": {
                    "text": "",
                    "tags": []
                }
            },
            "fill": {
                "complexType": {
                    "signature": "(fields: BillingFormFields) => Promise<any>",
                    "parameters": [{
                            "name": "fields",
                            "type": "BillingFormFields",
                            "docs": ""
                        }],
                    "references": {
                        "Promise": {
                            "location": "global",
                            "id": "global::Promise"
                        },
                        "BillingFormFields": {
                            "location": "import",
                            "path": "../../../components",
                            "id": "src/components.d.ts::BillingFormFields"
                        }
                    },
                    "return": "Promise<any>"
                },
                "docs": {
                    "text": "",
                    "tags": []
                }
            },
            "validate": {
                "complexType": {
                    "signature": "() => Promise<{ isValid: boolean; errors: any; }>",
                    "parameters": [],
                    "references": {
                        "Promise": {
                            "location": "global",
                            "id": "global::Promise"
                        }
                    },
                    "return": "Promise<{ isValid: boolean; errors: any; }>"
                },
                "docs": {
                    "text": "",
                    "tags": []
                }
            }
        };
    }
}
