import { h } from "@stencil/core";
import { DisputeManagementClickActions } from "./event-types";
import { Dispute, DisputeStatus } from "../../api/Dispute";
export class DisputeManagementCore {
    constructor() {
        this.isLoading = true;
        this.showDisputeResponseForm = false;
    }
    disputeResponseHandler(event) {
        if (event.detail.name === DisputeManagementClickActions.respondToDispute) {
            this.showDisputeResponseForm = true;
        }
        if (event.detail.name === DisputeManagementClickActions.cancelDispute) {
            this.showDisputeResponseForm = false;
        }
    }
    disputeSubmittedHandler() {
        this.fetchData();
    }
    componentWillLoad() {
        if (this.getDispute) {
            this.fetchData();
        }
    }
    updateOnPropChange() {
        this.fetchData();
    }
    fetchData() {
        this.isLoading = true;
        this.getDispute({
            onSuccess: ({ dispute }) => {
                this.dispute = new Dispute(dispute);
                this.isLoading = false;
                if (this.dispute.status !== DisputeStatus.needsResponse) {
                    this.showDisputeResponseForm = false;
                }
            },
            onError: ({ error, code, severity }) => {
                this.errorEvent.emit({
                    errorCode: code,
                    message: error,
                    severity,
                });
                this.isLoading = false;
            },
        });
    }
    render() {
        return (h("div", { key: 'b5a802e8c418b3b7f3235f43260186084a6ee079' }, this.showDisputeResponseForm ? (h("justifi-dispute-response", { disputeId: this.disputeId, disputeResponse: this.dispute.dispute_response, authToken: this.authToken })) : (h("justifi-dispute-notification", { dispute: this.dispute, authToken: this.authToken, isLoading: this.isLoading }))));
    }
    static get is() { return "justifi-dispute-management-core"; }
    static get properties() {
        return {
            "getDispute": {
                "type": "unknown",
                "attribute": "get-dispute",
                "mutable": false,
                "complexType": {
                    "original": "Function",
                    "resolved": "Function",
                    "references": {
                        "Function": {
                            "location": "global",
                            "id": "global::Function"
                        }
                    }
                },
                "required": false,
                "optional": false,
                "docs": {
                    "tags": [],
                    "text": ""
                },
                "getter": false,
                "setter": false
            },
            "disputeId": {
                "type": "string",
                "attribute": "dispute-id",
                "mutable": false,
                "complexType": {
                    "original": "string",
                    "resolved": "string",
                    "references": {}
                },
                "required": false,
                "optional": false,
                "docs": {
                    "tags": [],
                    "text": ""
                },
                "getter": false,
                "setter": false,
                "reflect": false
            },
            "authToken": {
                "type": "string",
                "attribute": "auth-token",
                "mutable": false,
                "complexType": {
                    "original": "string",
                    "resolved": "string",
                    "references": {}
                },
                "required": false,
                "optional": false,
                "docs": {
                    "tags": [],
                    "text": ""
                },
                "getter": false,
                "setter": false,
                "reflect": false
            }
        };
    }
    static get states() {
        return {
            "dispute": {},
            "isLoading": {},
            "showDisputeResponseForm": {}
        };
    }
    static get events() {
        return [{
                "method": "errorEvent",
                "name": "error-event",
                "bubbles": true,
                "cancelable": true,
                "composed": true,
                "docs": {
                    "tags": [],
                    "text": ""
                },
                "complexType": {
                    "original": "ComponentErrorEvent",
                    "resolved": "ComponentErrorEvent",
                    "references": {
                        "ComponentErrorEvent": {
                            "location": "import",
                            "path": "../../api/ComponentEvents",
                            "id": "src/api/ComponentEvents.ts::ComponentErrorEvent"
                        }
                    }
                }
            }];
    }
    static get watchers() {
        return [{
                "propName": "getDispute",
                "methodName": "updateOnPropChange"
            }];
    }
    static get listeners() {
        return [{
                "name": "click-event",
                "method": "disputeResponseHandler",
                "target": undefined,
                "capture": false,
                "passive": false
            }, {
                "name": "submit-event",
                "method": "disputeSubmittedHandler",
                "target": undefined,
                "capture": false,
                "passive": false
            }];
    }
}
;
