import { h } from "@stencil/core";
import { FormController } from "../../../ui-components/form/form";
import CustomerDetailsSchema from "./schemas/customer-details-schema";
import { DisputeResponseFormStep } from "./dispute-response-form-types";
import { heading5 } from "../../../styles/parts";
import fileInputHandler from "./file-input-handler";
export class CustomerDetails {
    constructor() {
        this.documentErrors = {};
        this.errors = {};
        this.documents = { customer_signature: [], customer_communication: [] };
        this.inputHandler = (name, value) => {
            this.form.setValues(Object.assign(Object.assign({}, this.form.values.getValue()), { [name]: value }));
        };
    }
    async validateAndSubmit(onSuccess) {
        const documentList = Object.values(this.documents).flat();
        this.form.validateAndSubmit((formData) => onSuccess(formData, documentList, DisputeResponseFormStep.customerDetails));
    }
    ;
    componentWillLoad() {
        this.form = new FormController(CustomerDetailsSchema);
    }
    componentDidLoad() {
        this.form.errors.subscribe(errors => {
            this.errors = Object.assign({}, errors);
        });
    }
    render() {
        var _a, _b, _c, _d, _e;
        return (h("div", { key: 'f5442efc59bb6a99a87f90feb5a4a147019af940' }, h("div", { key: 'd0f97e7ca943bfe8e4846ea84838ab08dc3658ab', class: "row gy-3" }, h("div", { key: 'da7f41d96c717f921010786f593c3776e2644738', class: "col-12" }, h("h2", { key: '0f7d56f400ec0f4250bbf7c8b2b736e084c17ab0', class: "h5", part: heading5 }, "Customer Details")), h("div", { key: 'eca73b10ec43454be35d4ec6e09b410b7a509b46', class: "col-12" }, h("form-control-text", { key: '1b67e031f3ac24b43319b09a01a5e297095ecc84', label: "Full Name", name: "customer_name", defaultValue: (_a = this.disputeResponse) === null || _a === void 0 ? void 0 : _a.customer_name, inputHandler: this.inputHandler, errorText: this.errors.customer_name })), h("div", { key: '967326bb10e6d2a64b2f3f0bae99432f238e361c', class: "col-12" }, h("form-control-text", { key: 'fc7d83cc51728920d9f4849dd85f4f019bb50fe4', label: "Email", name: "customer_email_address", defaultValue: (_b = this.disputeResponse) === null || _b === void 0 ? void 0 : _b.customer_email_address, inputHandler: this.inputHandler, errorText: this.errors.customer_email_address })), h("div", { key: '4e598f3e9bf118ddf22c4c160f0171c9789cd853', class: "col-12" }, h("form-control-textarea", { key: 'fe1c2e1a4c70ef463a31e890349a5b49f979e21b', label: "Billing Address", name: "customer_billing_address", defaultValue: (_c = this.disputeResponse) === null || _c === void 0 ? void 0 : _c.customer_billing_address, inputHandler: this.inputHandler, errorText: this.errors.customer_billing_address })), h("div", { key: 'a4345bc3b39f913cc233baa21373a6d7d93d3cda', class: "col-12" }, h("form-control-file-v2", { key: '82cb1b948807d901845a23137b5d488c9edd53ae', label: "Customer Signature", name: "customer_signature", onChange: (e) => fileInputHandler(e, this.documents), errorText: (_d = this.documentErrors) === null || _d === void 0 ? void 0 : _d.customer_signature })), h("div", { key: 'ffc589785e6114d604c2d98d3140de5487dc8af6', class: "col-12" }, h("form-control-file-v2", { key: '5b6b64927e4b90cc6dbb302fbc0d2067b70c6f4a', label: "Customer Communication", name: "customer_communication", onChange: (e) => fileInputHandler(e, this.documents), errorText: (_e = this.documentErrors) === null || _e === void 0 ? void 0 : _e.customer_communication })))));
    }
    static get is() { return "justifi-customer-details"; }
    static get properties() {
        return {
            "disputeResponse": {
                "type": "any",
                "attribute": "dispute-response",
                "mutable": false,
                "complexType": {
                    "original": "any",
                    "resolved": "any",
                    "references": {}
                },
                "required": false,
                "optional": false,
                "docs": {
                    "tags": [],
                    "text": ""
                },
                "getter": false,
                "setter": false,
                "reflect": false
            },
            "documentErrors": {
                "type": "any",
                "attribute": "document-errors",
                "mutable": false,
                "complexType": {
                    "original": "any",
                    "resolved": "any",
                    "references": {}
                },
                "required": false,
                "optional": false,
                "docs": {
                    "tags": [],
                    "text": ""
                },
                "getter": false,
                "setter": false,
                "reflect": false,
                "defaultValue": "{}"
            }
        };
    }
    static get states() {
        return {
            "form": {},
            "errors": {},
            "documents": {}
        };
    }
    static get methods() {
        return {
            "validateAndSubmit": {
                "complexType": {
                    "signature": "(onSuccess: (formData: any, documentList: DisputeEvidenceDocument[], formStep: DisputeResponseFormStep) => void) => Promise<void>",
                    "parameters": [{
                            "name": "onSuccess",
                            "type": "(formData: any, documentList: DisputeEvidenceDocument[], formStep: DisputeResponseFormStep) => void",
                            "docs": ""
                        }],
                    "references": {
                        "Promise": {
                            "location": "global",
                            "id": "global::Promise"
                        },
                        "DisputeEvidenceDocument": {
                            "location": "import",
                            "path": "../../../api/DisputeEvidenceDocument",
                            "id": "src/api/DisputeEvidenceDocument.ts::DisputeEvidenceDocument"
                        },
                        "DisputeResponseFormStep": {
                            "location": "import",
                            "path": "./dispute-response-form-types",
                            "id": "src/components/dispute-management/dispute-response/dispute-response-form-types.ts::DisputeResponseFormStep"
                        }
                    },
                    "return": "Promise<void>"
                },
                "docs": {
                    "text": "",
                    "tags": []
                }
            }
        };
    }
}
;
