import { h } from "@stencil/core";
import { checkPkgVersion } from "../../../utils/check-pkg-version";
import { StyledHost } from "../../../ui-components";
import { makeCreateDisputeEvidence, makeUpdateDisputeResponse, makeSubmitDisputeResponse } from "./dispute-response-actions";
import JustifiAnalytics from "../../../api/Analytics";
import { ComponentErrorCodes, ComponentErrorSeverity } from "../../../api/ComponentError";
import { DisputeService } from "../../../api/services/dispute.service";
export class DisputeResponse {
    constructor() {
        this.errorMessage = null;
        this.apiOrigin = PROXY_API_ORIGIN;
        this.handleErrorEvent = (event) => {
            this.errorMessage = event.detail.message;
            this.errorEvent.emit(event.detail);
        };
    }
    componentWillLoad() {
        checkPkgVersion();
        this.analytics = new JustifiAnalytics(this);
        this.initializeDisputeServiceMethods();
    }
    disconnectedCallback() {
        var _a;
        (_a = this.analytics) === null || _a === void 0 ? void 0 : _a.cleanup();
    }
    ;
    propChanged() {
        this.initializeDisputeServiceMethods();
    }
    initializeDisputeServiceMethods() {
        if (this.disputeId && this.authToken) {
            this.updateDisputeResponse = makeUpdateDisputeResponse({
                disputeId: this.disputeId,
                authToken: this.authToken,
                service: new DisputeService()
            });
            this.createDisputeEvidence = makeCreateDisputeEvidence({
                disputeId: this.disputeId,
                authToken: this.authToken,
                service: new DisputeService()
            });
            this.submitDisputeResponse = makeSubmitDisputeResponse({
                disputeId: this.disputeId,
                authToken: this.authToken,
                service: new DisputeService()
            });
        }
        else {
            this.errorMessage = 'Account ID and Auth Token are required';
            this.errorEvent.emit({
                errorCode: ComponentErrorCodes.MISSING_PROPS,
                message: this.errorMessage,
                severity: ComponentErrorSeverity.ERROR,
            });
        }
    }
    render() {
        return (h(StyledHost, { key: 'b90f636418c3e11b046d36dee9accf345756b407' }, h("justifi-dispute-response-core", { key: 'ff6e510faad54506eda24b1d8dc94b67afc18014', "onError-event": this.handleErrorEvent, "dispute-id": this.disputeId, disputeResponse: this.disputeResponse, createDisputeEvidence: this.createDisputeEvidence, updateDisputeResponse: this.updateDisputeResponse, submitDisputeResponse: this.submitDisputeResponse })));
    }
    ;
    static get is() { return "justifi-dispute-response"; }
    static get encapsulation() { return "shadow"; }
    static get properties() {
        return {
            "authToken": {
                "type": "string",
                "attribute": "auth-token",
                "mutable": false,
                "complexType": {
                    "original": "string",
                    "resolved": "string",
                    "references": {}
                },
                "required": false,
                "optional": false,
                "docs": {
                    "tags": [],
                    "text": ""
                },
                "getter": false,
                "setter": false,
                "reflect": false
            },
            "disputeId": {
                "type": "string",
                "attribute": "dispute-id",
                "mutable": false,
                "complexType": {
                    "original": "string",
                    "resolved": "string",
                    "references": {}
                },
                "required": false,
                "optional": false,
                "docs": {
                    "tags": [],
                    "text": ""
                },
                "getter": false,
                "setter": false,
                "reflect": false
            },
            "disputeResponse": {
                "type": "unknown",
                "attribute": "dispute-response",
                "mutable": false,
                "complexType": {
                    "original": "DisputeResponse",
                    "resolved": "DisputeResponse",
                    "references": {
                        "DisputeResponse": {
                            "location": "global",
                            "id": "global::DisputeResponse"
                        }
                    }
                },
                "required": false,
                "optional": false,
                "docs": {
                    "tags": [],
                    "text": ""
                },
                "getter": false,
                "setter": false
            },
            "apiOrigin": {
                "type": "string",
                "attribute": "api-origin",
                "mutable": false,
                "complexType": {
                    "original": "string",
                    "resolved": "string",
                    "references": {}
                },
                "required": false,
                "optional": true,
                "docs": {
                    "tags": [],
                    "text": ""
                },
                "getter": false,
                "setter": false,
                "reflect": false,
                "defaultValue": "PROXY_API_ORIGIN"
            }
        };
    }
    static get states() {
        return {
            "updateDisputeResponse": {},
            "submitDisputeResponse": {},
            "createDisputeEvidence": {},
            "errorMessage": {}
        };
    }
    static get events() {
        return [{
                "method": "errorEvent",
                "name": "error-event",
                "bubbles": true,
                "cancelable": true,
                "composed": true,
                "docs": {
                    "tags": [],
                    "text": ""
                },
                "complexType": {
                    "original": "ComponentErrorEvent",
                    "resolved": "ComponentErrorEvent",
                    "references": {
                        "ComponentErrorEvent": {
                            "location": "import",
                            "path": "../../../api/ComponentEvents",
                            "id": "src/api/ComponentEvents.ts::ComponentErrorEvent"
                        }
                    }
                }
            }];
    }
    static get watchers() {
        return [{
                "propName": "accountId",
                "methodName": "propChanged"
            }, {
                "propName": "authToken",
                "methodName": "propChanged"
            }];
    }
}
;
