import { h } from "@stencil/core";
import { FormController } from "../../../ui-components/form/form";
import ElectronicEvidenceSchema from "./schemas/electronic-evidence-schema";
import { DisputeResponseFormStep } from "./dispute-response-form-types";
import { heading5 } from "../../../styles/parts";
import fileInputHandler from "./file-input-handler";
export class ElectronicEvidence {
    constructor() {
        this.documentErrors = {};
        this.errors = {};
        this.documents = { activity_log: [] };
        this.inputHandler = (name, value) => {
            this.form.setValues(Object.assign(Object.assign({}, this.form.values.getValue()), { [name]: value }));
        };
    }
    async validateAndSubmit(onSuccess) {
        const documentList = Object.values(this.documents).flat();
        this.form.validateAndSubmit((formData) => onSuccess(formData, documentList, DisputeResponseFormStep.electronicEvidence));
    }
    ;
    componentWillLoad() {
        this.form = new FormController(ElectronicEvidenceSchema);
    }
    componentDidLoad() {
        this.form.errors.subscribe(errors => {
            this.errors = Object.assign({}, errors);
        });
    }
    render() {
        var _a, _b;
        return (h("div", { key: 'e23dbefec1d452aa3ba3cca69523eee0f5cfe923' }, h("div", { key: 'e1f11a356d05519b568b5bb65be9e8a1fc14e46f', class: "row gy-3" }, h("div", { key: 'a6208153a9a44d49e88f80d953477de8b40ed64b', class: "col-12" }, h("h2", { key: 'c80cc00343452fbf9d9ddacb6929d3a7e0a33f42', class: "h5", part: heading5 }, "Electronic Evidence")), h("div", { key: '1ed5c9f72596f33f41431eb62e6338f60adc9ab3', class: "col-12" }, h("form-control-text", { key: 'dfb38a1c00b8b09849840f4a071fbaa12321f7a8', label: "Purchase IP Address", name: "customer_purchase_ip_address", helpText: "The IP address used by the customer during the purchase.", defaultValue: (_a = this.disputeResponse) === null || _a === void 0 ? void 0 : _a.customer_purchase_ip_address, inputHandler: this.inputHandler, errorText: this.errors.customer_purchase_ip_address })), h("div", { key: 'd6f0a73cccf7eb2ea481836c6206ee39a0a21c6c', class: "col-12" }, h("form-control-file-v2", { key: '25dfd3efa3ec536f899fb263624bfea1b68dc397', label: "Activity Logs", name: "activity_log", helpText: "Any server or activity logs that provide evidence of the customer's access to or download of the purchased digital product. This information should encompass IP addresses, relevant timestamps, and any detailed records of activity.", onChange: (e) => fileInputHandler(e, this.documents), errorText: (_b = this.documentErrors) === null || _b === void 0 ? void 0 : _b.activity_log })))));
    }
    static get is() { return "justifi-electronic-evidence"; }
    static get properties() {
        return {
            "disputeResponse": {
                "type": "any",
                "attribute": "dispute-response",
                "mutable": false,
                "complexType": {
                    "original": "any",
                    "resolved": "any",
                    "references": {}
                },
                "required": false,
                "optional": false,
                "docs": {
                    "tags": [],
                    "text": ""
                },
                "getter": false,
                "setter": false,
                "reflect": false
            },
            "documentErrors": {
                "type": "any",
                "attribute": "document-errors",
                "mutable": false,
                "complexType": {
                    "original": "any",
                    "resolved": "any",
                    "references": {}
                },
                "required": false,
                "optional": false,
                "docs": {
                    "tags": [],
                    "text": ""
                },
                "getter": false,
                "setter": false,
                "reflect": false,
                "defaultValue": "{}"
            }
        };
    }
    static get states() {
        return {
            "form": {},
            "errors": {},
            "documents": {}
        };
    }
    static get methods() {
        return {
            "validateAndSubmit": {
                "complexType": {
                    "signature": "(onSuccess: (formData: any, documentList: DisputeEvidenceDocument[], formStep: DisputeResponseFormStep) => void) => Promise<void>",
                    "parameters": [{
                            "name": "onSuccess",
                            "type": "(formData: any, documentList: DisputeEvidenceDocument[], formStep: DisputeResponseFormStep) => void",
                            "docs": ""
                        }],
                    "references": {
                        "Promise": {
                            "location": "global",
                            "id": "global::Promise"
                        },
                        "DisputeEvidenceDocument": {
                            "location": "import",
                            "path": "../../../api/DisputeEvidenceDocument",
                            "id": "src/api/DisputeEvidenceDocument.ts::DisputeEvidenceDocument"
                        },
                        "DisputeResponseFormStep": {
                            "location": "import",
                            "path": "./dispute-response-form-types",
                            "id": "src/components/dispute-management/dispute-response/dispute-response-form-types.ts::DisputeResponseFormStep"
                        }
                    },
                    "return": "Promise<void>"
                },
                "docs": {
                    "text": "",
                    "tags": []
                }
            }
        };
    }
}
;
