import { h } from "@stencil/core";
import { FormController } from "../../../ui-components/form/form";
import RefundPolicySchema from "./schemas/refund-policy-schema";
import { DisputeResponseFormStep } from "./dispute-response-form-types";
import { heading5 } from "../../../styles/parts";
import fileInputHandler from "./file-input-handler";
export class RefundPolicy {
    constructor() {
        this.documentErrors = {};
        this.errors = {};
        this.documents = { refund_policy: [], receipt: [] };
        this.inputHandler = (name, value) => {
            this.form.setValues(Object.assign(Object.assign({}, this.form.values.getValue()), { [name]: value }));
        };
    }
    async validateAndSubmit(onSuccess) {
        const documentList = Object.values(this.documents).flat();
        this.form.validateAndSubmit((formData) => onSuccess(formData, documentList, DisputeResponseFormStep.refundPolicy));
    }
    ;
    componentWillLoad() {
        this.form = new FormController(RefundPolicySchema);
    }
    componentDidLoad() {
        this.form.errors.subscribe(errors => {
            this.errors = Object.assign({}, errors);
        });
    }
    render() {
        var _a, _b, _c, _d;
        return (h("div", { key: '75d1e4a99166f8b8f112746fd5a786ed4b41b6ae' }, h("div", { key: 'c4a137ad32f0a0e5580061b1cc2443399d5baf15', class: "row gy-3" }, h("div", { key: '8b864aacd4b1334f9a5e7ffdf116345db20aac58', class: "col-12" }, h("h2", { key: 'e319c7e0d2ebedf204e6845fb977651b96f4a9b8', class: "h5", part: heading5 }, "Refund Policy and Receipt")), h("div", { key: '72cc1aff194c70395f8002b4af6842cd42046d80', class: "col-12" }, h("form-control-textarea", { key: '798219393da9f68198205bb877a5a3aa2ac2d1bb', label: "Refund Policy Disclosure", name: "refund_policy_disclosure", defaultValue: (_a = this.disputeResponse) === null || _a === void 0 ? void 0 : _a.refund_policy_disclosure, inputHandler: this.inputHandler })), h("div", { key: 'bc0d341abb63327da6d97fba120c34aebabd50b3', class: "col-12" }, h("form-control-textarea", { key: '2aa931300951be7897d9ba4adeda6be5e94a00d8', label: "Refund Refusal Explanation", name: "refund_refusal_explanation", defaultValue: (_b = this.disputeResponse) === null || _b === void 0 ? void 0 : _b.refund_refusal_explanation, inputHandler: this.inputHandler })), h("div", { key: 'c3cad588c5b40a6133920a0c43f71d7b172abdab', class: "col-12" }, h("form-control-file-v2", { key: '8f2184a0d95804a85d61de763c14b1a6fb44c566', label: "Upload Refund Policy", name: "refund_policy", onChange: (e) => fileInputHandler(e, this.documents), errorText: (_c = this.documentErrors) === null || _c === void 0 ? void 0 : _c.refund_policy })), h("div", { key: '183f6286e96694e54fd31213b514349a43d0446f', class: "col-12" }, h("form-control-file-v2", { key: 'e3f97404946c8e6a813d397141d10e372df5f520', label: "Upload Receipt", name: "receipt", onChange: (e) => fileInputHandler(e, this.documents), errorText: (_d = this.documentErrors) === null || _d === void 0 ? void 0 : _d.receipt })))));
    }
    static get is() { return "justifi-refund-policy"; }
    static get properties() {
        return {
            "disputeResponse": {
                "type": "any",
                "attribute": "dispute-response",
                "mutable": false,
                "complexType": {
                    "original": "any",
                    "resolved": "any",
                    "references": {}
                },
                "required": false,
                "optional": false,
                "docs": {
                    "tags": [],
                    "text": ""
                },
                "getter": false,
                "setter": false,
                "reflect": false
            },
            "documentErrors": {
                "type": "any",
                "attribute": "document-errors",
                "mutable": false,
                "complexType": {
                    "original": "any",
                    "resolved": "any",
                    "references": {}
                },
                "required": false,
                "optional": false,
                "docs": {
                    "tags": [],
                    "text": ""
                },
                "getter": false,
                "setter": false,
                "reflect": false,
                "defaultValue": "{}"
            }
        };
    }
    static get states() {
        return {
            "form": {},
            "errors": {},
            "documents": {}
        };
    }
    static get methods() {
        return {
            "validateAndSubmit": {
                "complexType": {
                    "signature": "(onSuccess: (formData: any, documentList: DisputeEvidenceDocument[], formStep: DisputeResponseFormStep) => void) => Promise<void>",
                    "parameters": [{
                            "name": "onSuccess",
                            "type": "(formData: any, documentList: DisputeEvidenceDocument[], formStep: DisputeResponseFormStep) => void",
                            "docs": ""
                        }],
                    "references": {
                        "Promise": {
                            "location": "global",
                            "id": "global::Promise"
                        },
                        "DisputeEvidenceDocument": {
                            "location": "import",
                            "path": "../../../api/DisputeEvidenceDocument",
                            "id": "src/api/DisputeEvidenceDocument.ts::DisputeEvidenceDocument"
                        },
                        "DisputeResponseFormStep": {
                            "location": "import",
                            "path": "./dispute-response-form-types",
                            "id": "src/components/dispute-management/dispute-response/dispute-response-form-types.ts::DisputeResponseFormStep"
                        }
                    },
                    "return": "Promise<void>"
                },
                "docs": {
                    "text": "",
                    "tags": []
                }
            }
        };
    }
}
;
