import { h } from "@stencil/core";
import { FormController } from "../../../ui-components/form/form";
import ShippingDetailsSchema from "./schemas/shipping-details-schema";
import { DisputeResponseFormStep } from "./dispute-response-form-types";
import { heading5 } from "../../../styles/parts";
import fileInputHandler from "./file-input-handler";
export class ShippingDetails {
    constructor() {
        this.documentErrors = {};
        this.errors = {};
        this.documents = { shipping_documentation: [] };
        this.documentList = [];
        this.inputHandler = (name, value) => {
            this.form.setValues(Object.assign(Object.assign({}, this.form.values.getValue()), { [name]: value }));
        };
    }
    async validateAndSubmit(onSuccess) {
        const documentList = Object.values(this.documents).flat();
        this.form.validateAndSubmit((formData) => onSuccess(formData, documentList, DisputeResponseFormStep.shippingDetails));
    }
    ;
    componentWillLoad() {
        this.form = new FormController(ShippingDetailsSchema);
    }
    componentDidLoad() {
        this.form.errors.subscribe(errors => {
            this.errors = Object.assign({}, errors);
        });
    }
    render() {
        var _a, _b, _c, _d, _e;
        return (h("div", { key: 'a0907d5f1fe8d40876f816b6d332dbb0d9afe975' }, h("div", { key: '3f22d56b30227d9ce0d22dc45c4e29bba60b5366', class: "row gy-3" }, h("div", { key: 'ec768dcf266527e981712f55cdb1921d0e6ef257', class: "col-12" }, h("h2", { key: '0b0e92ba9164941f48e1162937d7bd694683b206', class: "h5", part: heading5 }, "Shipping Details")), h("div", { key: '2a5f5508c7f8b1a3a674d4bd18a2cba725ff86e7', class: "col-12" }, h("form-control-text", { key: 'deb04aa47dee3269ad8ad84b59edfdf251207520', label: "Shipping Carrier Name", name: "shipping_carrier", defaultValue: (_a = this.disputeResponse) === null || _a === void 0 ? void 0 : _a.shipping_carrier, inputHandler: this.inputHandler, errorText: this.errors.shipping_carrier })), h("div", { key: 'e340cf8f480c335b7e565e7d4bf052685bc3f78f', class: "col-12" }, h("form-control-text", { key: '8e3d040776e821518c0d04ea8d0da2d0ddb75cd3', label: "Tracking Number", name: "shipping_tracking_number", defaultValue: (_b = this.disputeResponse) === null || _b === void 0 ? void 0 : _b.shipping_tracking_number, inputHandler: this.inputHandler, errorText: this.errors.shipping_tracking_number })), h("div", { key: '71dab91e7befe734db1b8f02bb3fd8d1b8180ab8', class: "col-12" }, h("form-control-date", { key: 'f257e98c81762700c7164a8cbd86764ebe4e4353', label: "Date Shipped", name: "shipping_date", defaultValue: (_c = this.disputeResponse) === null || _c === void 0 ? void 0 : _c.shipping_date, inputHandler: this.inputHandler, errorText: this.errors.shipping_date })), h("div", { key: 'e69255a96e9292fea2269f7f0a7888e53e5a8be7', class: "col-12" }, h("form-control-textarea", { key: 'b40386270d12484982d81a85db0e95853f76ec58', label: "Shipping Address", name: "shipping_address", defaultValue: (_d = this.disputeResponse) === null || _d === void 0 ? void 0 : _d.shipping_address, inputHandler: this.inputHandler, errorText: this.errors.shipping_address })), h("div", { key: '23f2a4dabdaefef86940ae03e00a5d240d061a2f', class: "col-12" }, h("form-control-file-v2", { key: '6db6eb9ed1803d7c25f2b9dd03955be7e9c41a34', label: "Shipping Documentation", name: "shipping_documentation", onChange: (e) => fileInputHandler(e, this.documents), errorText: (_e = this.documentErrors) === null || _e === void 0 ? void 0 : _e.shipping_documentation })))));
    }
    static get is() { return "justifi-shipping-details"; }
    static get properties() {
        return {
            "disputeResponse": {
                "type": "any",
                "attribute": "dispute-response",
                "mutable": false,
                "complexType": {
                    "original": "any",
                    "resolved": "any",
                    "references": {}
                },
                "required": false,
                "optional": false,
                "docs": {
                    "tags": [],
                    "text": ""
                },
                "getter": false,
                "setter": false,
                "reflect": false
            },
            "documentErrors": {
                "type": "any",
                "attribute": "document-errors",
                "mutable": false,
                "complexType": {
                    "original": "any",
                    "resolved": "any",
                    "references": {}
                },
                "required": false,
                "optional": false,
                "docs": {
                    "tags": [],
                    "text": ""
                },
                "getter": false,
                "setter": false,
                "reflect": false,
                "defaultValue": "{}"
            }
        };
    }
    static get states() {
        return {
            "form": {},
            "errors": {},
            "documents": {},
            "documentList": {}
        };
    }
    static get methods() {
        return {
            "validateAndSubmit": {
                "complexType": {
                    "signature": "(onSuccess: (formData: any, documentList: DisputeEvidenceDocument[], formStep: DisputeResponseFormStep) => void) => Promise<void>",
                    "parameters": [{
                            "name": "onSuccess",
                            "type": "(formData: any, documentList: DisputeEvidenceDocument[], formStep: DisputeResponseFormStep) => void",
                            "docs": ""
                        }],
                    "references": {
                        "Promise": {
                            "location": "global",
                            "id": "global::Promise"
                        },
                        "DisputeEvidenceDocument": {
                            "location": "import",
                            "path": "../../../api/DisputeEvidenceDocument",
                            "id": "src/api/DisputeEvidenceDocument.ts::DisputeEvidenceDocument"
                        },
                        "DisputeResponseFormStep": {
                            "location": "import",
                            "path": "./dispute-response-form-types",
                            "id": "src/components/dispute-management/dispute-response/dispute-response-form-types.ts::DisputeResponseFormStep"
                        }
                    },
                    "return": "Promise<void>"
                },
                "docs": {
                    "text": "",
                    "tags": []
                }
            }
        };
    }
}
;
