import { Host, h } from "@stencil/core";
import { Chart, BarController, Colors, BarElement, CategoryScale, LinearScale, Legend, Tooltip, Title } from "chart.js";
import { generateChartOptions } from "./chart-utils";
import { ErrorState } from "../../ui-components/details/utils";
import Spinner from "../../ui-components/spinner";
Chart.register(Colors, BarController, BarElement, CategoryScale, LinearScale, Legend, Tooltip, Title);
export class GrossPaymentChartCore {
    constructor() {
        this.loading = true;
        this.errorMessage = '';
    }
    componentDidLoad() {
        if (this.getGrossPayment) {
            this.fetchData();
        }
    }
    propChanged() {
        if (this.getGrossPayment) {
            this.fetchData();
        }
    }
    grossVolumeReportChanged(grossVolumeReport) {
        if (grossVolumeReport) {
            if (!this.chart) {
                this.initChart(grossVolumeReport);
            }
            else {
                this.updateChartData(grossVolumeReport);
            }
        }
    }
    async fetchData() {
        this.loading = true;
        this.getGrossPayment({
            onSuccess: (data) => {
                this.loading = false;
                this.grossVolumeReport = data;
            },
            onError: ({ error, code, severity }) => {
                this.loading = false;
                this.errorMessage = error;
                this.errorEvent.emit({
                    errorCode: code,
                    message: error,
                    severity,
                });
            }
        });
    }
    initChart(grossVolumeReport) {
        const { dates, total } = grossVolumeReport;
        const reversedDates = dates.reverse();
        const endDate = reversedDates[dates.length - 1].date;
        const chartOptions = generateChartOptions(total, reversedDates, endDate);
        this.chart = new Chart(this.chartRef.getContext('2d'), chartOptions);
    }
    updateChartData(grossVolumeReport) {
        const newData = grossVolumeReport.dates.map((date) => date.value);
        this.chart.data.datasets.forEach((dataset) => {
            dataset.data = newData;
        });
        this.chart.update();
    }
    disconnectedCallback() {
        if (this.chart) {
            this.chart.destroy();
        }
    }
    render() {
        return (h(Host, { key: '14360f11f9b118e347ee73739f03c3631fbef1a4' }, this.loading && h(Spinner, { key: 'a5190472afdbf507c6c36c8aaae1473bffc80dcf' }), !this.errorMessage ? h("canvas", { id: "chart", ref: (elem) => this.chartRef = elem }) : ErrorState(this.errorMessage)));
    }
    static get is() { return "gross-payment-chart-core"; }
    static get properties() {
        return {
            "getGrossPayment": {
                "type": "unknown",
                "attribute": "get-gross-payment",
                "mutable": false,
                "complexType": {
                    "original": "Function",
                    "resolved": "Function",
                    "references": {
                        "Function": {
                            "location": "global",
                            "id": "global::Function"
                        }
                    }
                },
                "required": false,
                "optional": false,
                "docs": {
                    "tags": [],
                    "text": ""
                },
                "getter": false,
                "setter": false
            }
        };
    }
    static get states() {
        return {
            "grossVolumeReport": {},
            "loading": {},
            "errorMessage": {}
        };
    }
    static get events() {
        return [{
                "method": "errorEvent",
                "name": "error-event",
                "bubbles": true,
                "cancelable": true,
                "composed": true,
                "docs": {
                    "tags": [],
                    "text": ""
                },
                "complexType": {
                    "original": "ComponentErrorEvent",
                    "resolved": "ComponentErrorEvent",
                    "references": {
                        "ComponentErrorEvent": {
                            "location": "import",
                            "path": "../../api/ComponentEvents",
                            "id": "src/api/ComponentEvents.ts::ComponentErrorEvent"
                        }
                    }
                }
            }];
    }
    static get watchers() {
        return [{
                "propName": "getGrossPayment",
                "methodName": "propChanged"
            }, {
                "propName": "grossVolumeReport",
                "methodName": "grossVolumeReportChanged"
            }];
    }
}
