import { h } from "@stencil/core";
import { StyledHost } from "../../../ui-components";
import BankAccountFormSkeleton from "./bank-account-skeleton";
import { checkPkgVersion } from "../../../utils/check-pkg-version";
import JustifiAnalytics from "../../../api/Analytics";
import { configState, waitForConfig } from "../../config-provider/config-state";
export class BankAccountForm {
    constructor() {
        this.isReady = false;
    }
    async componentWillLoad() {
        await waitForConfig();
        this.iframeOrigin = configState.iframeOrigin;
        checkPkgVersion();
        this.analytics = new JustifiAnalytics(this);
    }
    componentDidRender() {
        const elements = [
            this.accountNumberIframeElement,
            this.routingNumberIframeElement,
        ];
        Promise.all(elements.map((element) => {
            return new Promise((resolve) => {
                element.addEventListener('iframeLoaded', () => { resolve(); });
            });
        })).then(() => {
            this.isReady = true;
        });
    }
    disconnectedCallback() {
        var _a;
        (_a = this.analytics) === null || _a === void 0 ? void 0 : _a.cleanup();
    }
    async validate() {
        const accountNumberIsValid = await this.accountNumberIframeElement.validate();
        const routingNumberIsValid = await this.routingNumberIframeElement.validate();
        return accountNumberIsValid && routingNumberIsValid;
    }
    async tokenize({ clientId, paymentMethodMetadata, account }) {
        return this.accountNumberIframeElement.tokenize(clientId, paymentMethodMetadata, account);
    }
    render() {
        return (h(StyledHost, { key: '62431aba939585a8a341942d9847e8d491b0a658' }, h(BankAccountFormSkeleton, { key: '2da8452c73e52a6fc67d80e483c40a2d0dd276f9', isReady: this.isReady }), h("hidden-input", { key: 'c34bc48ee7e1925ae272b5fe60fd362ddf2433eb' }), h("div", { key: '3fefe63e9f9c98d7e08e0ceac5df0f8008303aec', class: "container-fluid p-0", style: {
                opacity: this.isReady ? '1' : '0',
                height: this.isReady ? 'auto' : '0',
            } }, h("div", { key: '6c19ea238eb0bff6b245f2f39028d651438c55d0', class: "row mb-3" }, h("iframe-input", { key: 'b5588dc21d24ec873fecedd91fbcb0344fbe324c', inputId: "accountNumber", ref: (el) => (this.accountNumberIframeElement = el), label: "Account Number", iframeOrigin: `${this.iframeOrigin}/v2/accountNumber` })), h("div", { key: '910f130a307449a3d60ef76eee6cc27fc86c3fe0', class: "row" }, h("iframe-input", { key: '72756b92912c3031cc472dee5bbf945f06c38920', inputId: "routingNumber", ref: (el) => (this.routingNumberIframeElement = el), label: "Routing Number", iframeOrigin: `${this.iframeOrigin}/v2/routingNumber` })))));
    }
    static get is() { return "justifi-bank-account-form"; }
    static get encapsulation() { return "shadow"; }
    static get states() {
        return {
            "iframeOrigin": {},
            "isReady": {}
        };
    }
    static get methods() {
        return {
            "validate": {
                "complexType": {
                    "signature": "() => Promise<any>",
                    "parameters": [],
                    "references": {
                        "Promise": {
                            "location": "global",
                            "id": "global::Promise"
                        }
                    },
                    "return": "Promise<any>"
                },
                "docs": {
                    "text": "",
                    "tags": []
                }
            },
            "tokenize": {
                "complexType": {
                    "signature": "({ clientId, paymentMethodMetadata, account }: { clientId: string; paymentMethodMetadata: any; account?: string; }) => Promise<any>",
                    "parameters": [{
                            "name": "__0",
                            "type": "{ clientId: string; paymentMethodMetadata: any; account?: string; }",
                            "docs": ""
                        }],
                    "references": {
                        "Promise": {
                            "location": "global",
                            "id": "global::Promise"
                        }
                    },
                    "return": "Promise<any>"
                },
                "docs": {
                    "text": "",
                    "tags": []
                }
            }
        };
    }
}
