import { h } from "@stencil/core";
import { StyledHost } from "../../../ui-components";
import { numberOnlyHandler } from "../../../ui-components/form/utils";
import { FormController } from "../../../ui-components/form/form";
import { billingFormSchema } from "./billing-form-schema";
import { onChange } from "../../../store/checkout.store";
export class PostalCodeForm {
    constructor() {
        this.errors = {};
        this.inputHandler = (name, value) => {
            this.formController.setValues(Object.assign(Object.assign({}, this.formController.values.getValue()), { [name]: value }));
        };
    }
    connectedCallback() {
        this.unsubscribe = onChange('billingFormFields', (newValue) => {
            this.formController.setInitialValues(newValue);
        });
    }
    disconnectedCallback() {
        var _a;
        (_a = this.unsubscribe) === null || _a === void 0 ? void 0 : _a.call(this);
    }
    componentWillLoad() {
        this.formController = new FormController(billingFormSchema(true));
    }
    componentDidLoad() {
        this.formController.values.subscribe(values => this.billingInfo = Object.assign({}, values));
        this.formController.errors.subscribe(errors => {
            this.errors = Object.assign({}, errors);
        });
    }
    async getValues() {
        return this.formController.values.getValue();
    }
    async fill(fields) {
        this.formController.setInitialValues(fields);
    }
    async validate() {
        let isValid = await this.formController.validate();
        const errors = this.formController.errors.getValue();
        return { isValid, errors };
    }
    render() {
        const billingFormDefaultValue = this.formController.getInitialValues();
        return (h(StyledHost, { key: '881138113d82dd87a364cbadef1947f34d3cdf4f' }, h("form", { key: '647945d6264d0611fcc7970eded8ce22ac2b4db7' }, h("form-control-text", { key: '2308fdcc1634fa8b39ce0735ab3431a406bc7398', name: 'address_postal_code', label: "ZIP", defaultValue: billingFormDefaultValue.address_postal_code, errorText: this.errors.address_postal_code, inputHandler: this.inputHandler, maxLength: 5, keyDownHandler: numberOnlyHandler }))));
    }
    static get is() { return "justifi-postal-code-form"; }
    static get encapsulation() { return "shadow"; }
    static get states() {
        return {
            "formController": {},
            "billingInfo": {},
            "errors": {}
        };
    }
    static get methods() {
        return {
            "getValues": {
                "complexType": {
                    "signature": "() => Promise<BillingFormFields>",
                    "parameters": [],
                    "references": {
                        "Promise": {
                            "location": "global",
                            "id": "global::Promise"
                        },
                        "BillingFormFields": {
                            "location": "import",
                            "path": "./billing-form-schema",
                            "id": "src/components/modular-checkout/sub-components/billing-form-schema.ts::BillingFormFields"
                        }
                    },
                    "return": "Promise<BillingFormFields>"
                },
                "docs": {
                    "text": "",
                    "tags": []
                }
            },
            "fill": {
                "complexType": {
                    "signature": "(fields: BillingFormFields) => Promise<void>",
                    "parameters": [{
                            "name": "fields",
                            "type": "BillingFormFields",
                            "docs": ""
                        }],
                    "references": {
                        "Promise": {
                            "location": "global",
                            "id": "global::Promise"
                        },
                        "BillingFormFields": {
                            "location": "import",
                            "path": "./billing-form-schema",
                            "id": "src/components/modular-checkout/sub-components/billing-form-schema.ts::BillingFormFields"
                        }
                    },
                    "return": "Promise<void>"
                },
                "docs": {
                    "text": "",
                    "tags": []
                }
            },
            "validate": {
                "complexType": {
                    "signature": "() => Promise<{ isValid: boolean; errors: any; }>",
                    "parameters": [],
                    "references": {
                        "Promise": {
                            "location": "global",
                            "id": "global::Promise"
                        }
                    },
                    "return": "Promise<{ isValid: boolean; errors: any; }>"
                },
                "docs": {
                    "text": "",
                    "tags": []
                }
            }
        };
    }
}
