import { h } from "@stencil/core";
import { formatDate, formatTime, snakeCaseToHumanReadable } from "../../utils/utils";
import { MapPaymentStatusToBadge } from "../payments-list/payments-status";
import { CodeBlock, DetailItem, DetailSectionTitle, EntityHeadInfo, EntityHeadInfoItem, ErrorState } from "../../ui-components/details/utils";
import { StyledHost } from "../../ui-components";
import PaymentDetailsLoading from "./payment-details-loading";
import { Badge, BadgeVariant } from "../../ui-components/badge/badge";
export class PaymentDetailsCore {
    constructor() {
        this.loading = true;
    }
    componentWillLoad() {
        if (this.getPaymentDetails) {
            this.fetchData();
        }
    }
    updateOnPropChange() {
        this.fetchData();
    }
    fetchData() {
        this.loading = true;
        this.getPaymentDetails({
            onSuccess: ({ payment }) => {
                this.payment = payment;
                this.errorMessage = null;
            },
            onError: ({ error, code, severity }) => {
                this.errorMessage = error;
                this.errorEvent.emit({
                    errorCode: code,
                    message: error,
                    severity,
                });
            },
            final: () => {
                this.loading = false;
            },
        });
    }
    render() {
        return (h(StyledHost, { key: '5acae57b23c12cd033e876b7064fa1da53527113' }, this.loading && h(PaymentDetailsLoading, { key: 'db42d6d60e76de571551a20e01bea700ed4e16f4' }), !this.loading && this.errorMessage && ErrorState(this.errorMessage), !this.loading && !this.errorMessage &&
            this.payment && (h("justifi-details", { key: '36e906b2df77fccb24603d1c7253d5b935e4465e', "error-message": this.errorMessage }, h(EntityHeadInfo, { key: '49bc76fa5f5e58dc148d7037ff95271124498e5d', slot: "head-info", badge: (h("div", { class: "d-flex gap-1" }, MapPaymentStatusToBadge(this.payment.status), this.payment.expedited ? (h(Badge, { variant: BadgeVariant.WARNING, title: "Expedited", text: "Expedited" })) : null)), title: this.payment.formattedPaymentAmount(this.payment.amount) }, h(EntityHeadInfoItem, { key: '4f22b26195f8d122d8fe6e40a19bbbb4004abea4', classes: "border-1 border-end", title: "Updated At", value: `${formatDate(this.payment.updated_at)} ${formatTime(this.payment.updated_at)}` }), h(EntityHeadInfoItem, { key: '416770f35ca9cda497bd78b94f45add5a9aa183c', classes: "border-1 border-end", title: "Created At", value: `${formatDate(this.payment.created_at)} ${formatTime(this.payment.created_at)}` }), h(EntityHeadInfoItem, { key: 'd51a299c1fb98496301acba116fbc8bd02308f16', title: "ID", value: this.payment.id })), h("div", { key: '6e7bd343cbad8f74b698f83941255a5eba2a712c', slot: 'detail-sections' }, h(DetailSectionTitle, { key: 'c99dbf37a902826e4168820735a562632bf00fc1', sectionTitle: "Details" }), h("div", { key: '2d3e8d4483fa3043db2d3ee384723ef033b0fd77', class: "d-table gap-2 w-100" }, h(DetailItem, { key: '4d9d3e926535cd2d90d5d9808383c34885b5f0bf', title: "Amount", value: this.payment.formattedPaymentAmount(this.payment.amount) }), h(DetailItem, { key: '39d2a6c2cb0ee10a878fc80833e168d16ddb1420', title: "Fees", value: this.payment.formattedPaymentAmount(this.payment.fee_amount) }), h(DetailItem, { key: 'b55e1317033cd5f1fe8778cec6764cc445fe30de', title: "Refunded", value: this.payment.formattedPaymentAmount(this.payment.amount_refunded) }), h(DetailItem, { key: 'e08773e47e04eb24d78076a2012909e9cc9e66e2', title: "Net", value: this.payment.formattedPaymentAmount(this.payment.balance) }), h(DetailItem, { key: 'd215a59f20ce0799cce191b7b1b8b9104adf31b2', title: "Status", value: MapPaymentStatusToBadge(this.payment.status) }), h(DetailItem, { key: '7bdc91d6a9ea0ea6d1356e293be6b096cbe3fdd6', title: "Payment ID", value: this.payment.id }), h(DetailItem, { key: 'df04e3d0f29519fb0155d6c3dbe2789777eea4e8', title: "Processing Fees", value: this.payment.formattedPaymentAmount(this.payment.fee_amount) }), h(DetailItem, { key: '94e55b409ebe4d29c92f49b0e17b4934c40cec17', title: "Statement Descriptor", value: this.payment.statement_descriptor }), h(DetailItem, { key: 'b16820e416b57838fb9ee41ebb7968d2d87b0922', title: "Description", value: this.payment.description }), h(DetailItem, { key: 'f52579f2da829f16014a68e3f85f5544327e0da2', title: "Expedited", value: this.payment.expedited ? 'Yes' : 'No' })), this.payment.payment_method.card && [
            h(DetailSectionTitle, { key: 'fb8174ebec4bff736f0d8ae9f25ec33592d083ba', sectionTitle: "Payment Method" }),
            h("div", { key: '301ae61c63f3290f109fe87fbd306a9fe5b650b1', class: "d-table gap-2 w-100" }, h(DetailItem, { key: '90f7031b92d4c98fbf200acff5c69c8d7d3c6d59', title: "ID", value: this.payment.payment_method.card.id }), h(DetailItem, { key: '06bc828cec434a7e25b16433569b95867feb509b', title: "Payment Type", value: "Card" }), h(DetailItem, { key: '2ca0a51f91c7c8cfdc0ac9c5a4e7cb3e7af41e77', title: "Last 4 Numbers", value: this.payment.payment_method.lastFourDigits }), h(DetailItem, { key: '9b4e0f3c62d491a3ce31a72181e7eb2258e27571', title: "Brand", value: snakeCaseToHumanReadable(this.payment.payment_method.card.brand) }), h(DetailItem, { key: '3f987dfd88521e1f3c5ed87fdb561abba6b15ffe', title: "Cardholder", value: this.payment.payment_method.payersName }))
        ], this.payment.payment_method.bank_account && [
            h(DetailSectionTitle, { key: '5d6a4499fe5fcb49090b3846737304378ed72e9d', sectionTitle: "Payment Method" }),
            h("div", { key: 'cc4c4bdf5b4206e046263544dcc40b2647bd3d96', class: "d-table gap-2 w-100" }, h(DetailItem, { key: '394957be1477b450529256420f47a2baf61ba0ad', title: "ID", value: this.payment.payment_method.bank_account.id }), h(DetailItem, { key: '40256eb7252cf350b8044b911413adeb969fc149', title: "Last 4 Numbers", value: this.payment.last_four_digits }), h(DetailItem, { key: '6753602b063fcd34b9e0db84438ba782e3eb858d', title: "Bank Name", value: this.payment.payment_method.bank_account.brand }), h(DetailItem, { key: '1f216f44c78cbe79416241c7e9616bc778f60ab8', title: "Account Owner", value: this.payment.payment_method.payersName }))
        ], this.payment.metadata && [
            h(DetailSectionTitle, { key: 'de040eda2eb0ad1d5c7c08d20a22da56dc0c05aa', sectionTitle: 'Metadata' }),
            h("div", { key: 'd4d990042524da1e655b40cad77af26642c1dc9f', class: "d-table gap-2 w-100" }, h(CodeBlock, { key: '5468b34050c9159503862f8e12391299c603e8e8', metadata: this.payment.metadata }))
        ])))));
    }
    static get is() { return "payment-details-core"; }
    static get properties() {
        return {
            "getPaymentDetails": {
                "type": "unknown",
                "attribute": "get-payment-details",
                "mutable": false,
                "complexType": {
                    "original": "Function",
                    "resolved": "Function",
                    "references": {
                        "Function": {
                            "location": "global",
                            "id": "global::Function"
                        }
                    }
                },
                "required": false,
                "optional": false,
                "docs": {
                    "tags": [],
                    "text": ""
                },
                "getter": false,
                "setter": false
            }
        };
    }
    static get states() {
        return {
            "payment": {},
            "loading": {},
            "errorMessage": {}
        };
    }
    static get events() {
        return [{
                "method": "errorEvent",
                "name": "error-event",
                "bubbles": true,
                "cancelable": true,
                "composed": true,
                "docs": {
                    "tags": [],
                    "text": ""
                },
                "complexType": {
                    "original": "ComponentErrorEvent",
                    "resolved": "ComponentErrorEvent",
                    "references": {
                        "ComponentErrorEvent": {
                            "location": "import",
                            "path": "../../api/ComponentEvents",
                            "id": "src/api/ComponentEvents.ts::ComponentErrorEvent"
                        }
                    }
                }
            }];
    }
    static get watchers() {
        return [{
                "propName": "getPaymentDetails",
                "methodName": "updateOnPropChange"
            }];
    }
}
