import { h } from "@stencil/core";
import { debounce } from "lodash";
import { filterParams, propsParams, clearParams } from "./payments-list-params-state";
import { StyledHost } from "../../ui-components";
import { convertToLocal, convertToUTC } from "../../utils/utils";
import { paymentsListFilterMenu, createdAfterPaymentsListFilterParam, createdBeforePaymentsListFilterParam, paymentIdPaymentsListFilterParam, paymentStatusPaymentsListFilterParam, terminalIdPaymentsListFilterParam } from "../../styles/parts";
export class PaymentsListFilters {
    constructor() {
        this.setParamsOnChange = (name, value) => {
            filterParams[name] = value;
        };
        this.handleDateInput = (name, value) => {
            const utcDate = convertToUTC(value, { setExactTime: true });
            this.setParamsOnChange(name, utcDate);
        };
    }
    componentWillLoad() {
        // debounced input handler for text input
        this.debouncedSetParamsOnChange = debounce(this.setParamsOnChange, 300);
        const propsToSet = {
            payment_id: this.paymentId,
            terminal_id: this.terminalId,
            payment_status: this.paymentStatus,
            created_after: this.createdAfter,
            created_before: this.createdBefore
        };
        Object.entries(propsToSet).forEach(([key, value]) => {
            if (value) {
                propsParams[key] = value;
            }
        });
    }
    get paymentStatusOptions() {
        return [
            { label: 'All', value: '' },
            { label: 'Pending', value: 'pending' },
            { label: 'Authorized', value: 'authorized' },
            { label: 'Succeeded', value: 'succeeded' },
            { label: 'Failed', value: 'failed' },
            { label: 'Disputed', value: 'disputed' },
            { label: 'Refunded', value: 'refunded' }
        ];
    }
    render() {
        const filterMenuParams = Object.assign({}, filterParams);
        return (h(StyledHost, { key: 'edb76af8b61fe98b719f5f88418410659789a586' }, h("table-filters-menu", { key: '00281883e331c0f1d1b8a8a8ebd09fff40859c52', params: filterMenuParams, clearParams: clearParams, part: paymentsListFilterMenu }, h("div", { key: '2ba0e2b794aafc6e775ec0699846e35292b687f0', class: "grid-cols-2 gap-3 p-1" }, h("div", { key: '371d156495fcb8495288f1dd4c119ff9bb32a32d', class: "p-2" }, h("form-control-text", { key: '1bf10f06973fe3ee7ab1c2c6871a7c79a12543b9', name: "payment_id", label: "Payment ID", inputHandler: this.debouncedSetParamsOnChange, defaultValue: this.paymentId || filterParams.payment_id, disabled: !!this.paymentId, part: paymentIdPaymentsListFilterParam })), h("div", { key: 'ed1f0667a905aac7ac70c612ae3f1666b8e052f3', class: "p-2" }, h("form-control-text", { key: '841a6cf1cd66f942470f0d6c93f78dfad6865fd7', name: "terminal_id", label: "Terminal ID", inputHandler: this.debouncedSetParamsOnChange, defaultValue: this.terminalId || filterParams.terminal_id, disabled: !!this.terminalId, part: terminalIdPaymentsListFilterParam })), h("div", { key: '67be85f9eeb70c1adf1df71772f19e154c46f598', class: "p-2" }, h("form-control-select", { key: '403dc71eab722d8e4067b9a759e0795ba53bff9f', name: "payment_status", label: "Status", options: this.paymentStatusOptions, inputHandler: this.setParamsOnChange, defaultValue: this.paymentStatus || filterParams.payment_status, disabled: !!this.paymentStatus, part: paymentStatusPaymentsListFilterParam })), h("div", { key: '6d28b998413263d8b88f3fa425a7e30fd669d38e', class: "p-2" }, h("form-control-date", { key: '733b5e5e99a4a8ce670749a56fcd407583dba41b', name: "created_after", label: "Created After", inputHandler: this.handleDateInput, defaultValue: convertToLocal(this.createdAfter, { showInputDateTime: true }) ||
                convertToLocal(filterParams.created_after, { showInputDateTime: true }), showTime: true, disabled: !!this.createdAfter, part: createdAfterPaymentsListFilterParam })), h("div", { key: 'c8390389045dc56592e05d1ae7a2236575569df5', class: "p-2" }, h("form-control-date", { key: '718522151a88e3ffd9d3c1ceb3265767340ab60a', name: "created_before", label: "Created Before", inputHandler: this.handleDateInput, defaultValue: convertToLocal(this.createdBefore, { showInputDateTime: true }) ||
                convertToLocal(filterParams.created_before, { showInputDateTime: true }), showTime: true, disabled: !!this.createdBefore, part: createdBeforePaymentsListFilterParam }))))));
    }
    static get is() { return "justifi-payments-list-filters"; }
    static get encapsulation() { return "shadow"; }
    static get properties() {
        return {
            "paymentId": {
                "type": "string",
                "attribute": "payment-id",
                "mutable": false,
                "complexType": {
                    "original": "string",
                    "resolved": "string",
                    "references": {}
                },
                "required": false,
                "optional": true,
                "docs": {
                    "tags": [],
                    "text": ""
                },
                "getter": false,
                "setter": false,
                "reflect": false
            },
            "terminalId": {
                "type": "string",
                "attribute": "terminal-id",
                "mutable": false,
                "complexType": {
                    "original": "string",
                    "resolved": "string",
                    "references": {}
                },
                "required": false,
                "optional": true,
                "docs": {
                    "tags": [],
                    "text": ""
                },
                "getter": false,
                "setter": false,
                "reflect": false
            },
            "paymentStatus": {
                "type": "string",
                "attribute": "payment-status",
                "mutable": false,
                "complexType": {
                    "original": "string",
                    "resolved": "string",
                    "references": {}
                },
                "required": false,
                "optional": true,
                "docs": {
                    "tags": [],
                    "text": ""
                },
                "getter": false,
                "setter": false,
                "reflect": false
            },
            "createdAfter": {
                "type": "string",
                "attribute": "created-after",
                "mutable": false,
                "complexType": {
                    "original": "string",
                    "resolved": "string",
                    "references": {}
                },
                "required": false,
                "optional": true,
                "docs": {
                    "tags": [],
                    "text": ""
                },
                "getter": false,
                "setter": false,
                "reflect": false
            },
            "createdBefore": {
                "type": "string",
                "attribute": "created-before",
                "mutable": false,
                "complexType": {
                    "original": "string",
                    "resolved": "string",
                    "references": {}
                },
                "required": false,
                "optional": true,
                "docs": {
                    "tags": [],
                    "text": ""
                },
                "getter": false,
                "setter": false,
                "reflect": false
            }
        };
    }
}
