import { h } from "@stencil/core";
import { PayoutService } from "../../api/services/payout.service";
import { makeGetPayoutDetails } from "../../actions/payout/get-payout-details";
import { ErrorState } from "../../ui-components/details/utils";
import { ComponentErrorCodes, ComponentErrorSeverity } from "../../api/ComponentError";
import JustifiAnalytics from "../../api/Analytics";
import { makeGetPayoutCSV } from "./get-payout-csv";
import { checkPkgVersion } from "../../utils/check-pkg-version";
export class PayoutDetails {
    constructor() {
        this.errorMessage = null;
        this.handleErrorEvent = (event) => {
            this.errorMessage = event.detail.message;
            this.errorEvent.emit(event.detail);
        };
    }
    componentWillLoad() {
        checkPkgVersion();
        this.analytics = new JustifiAnalytics(this);
        this.initializeServices();
    }
    disconnectedCallback() {
        var _a;
        (_a = this.analytics) === null || _a === void 0 ? void 0 : _a.cleanup();
    }
    ;
    propChanged() {
        this.initializeServices();
    }
    initializeServices() {
        if (this.payoutId && this.authToken) {
            this.getPayout = makeGetPayoutDetails({
                id: this.payoutId,
                authToken: this.authToken,
                service: new PayoutService()
            });
            this.getPayoutCSV = makeGetPayoutCSV({
                authToken: this.authToken,
                service: new PayoutService()
            });
        }
        else {
            this.errorMessage = 'Failed to load payout details. payoutId or authToken is not provided.';
            this.errorEvent.emit({
                message: this.errorMessage,
                errorCode: ComponentErrorCodes.MISSING_PROPS,
                severity: ComponentErrorSeverity.ERROR
            });
        }
    }
    render() {
        if (this.errorMessage) {
            return ErrorState(this.errorMessage);
        }
        return (h("payout-details-core", { getPayout: this.getPayout, getPayoutCSV: this.getPayoutCSV, "onError-event": this.handleErrorEvent }));
    }
    static get is() { return "justifi-payout-details"; }
    static get encapsulation() { return "shadow"; }
    static get properties() {
        return {
            "payoutId": {
                "type": "string",
                "attribute": "payout-id",
                "mutable": false,
                "complexType": {
                    "original": "string",
                    "resolved": "string",
                    "references": {}
                },
                "required": false,
                "optional": false,
                "docs": {
                    "tags": [],
                    "text": ""
                },
                "getter": false,
                "setter": false,
                "reflect": false
            },
            "authToken": {
                "type": "string",
                "attribute": "auth-token",
                "mutable": false,
                "complexType": {
                    "original": "string",
                    "resolved": "string",
                    "references": {}
                },
                "required": false,
                "optional": false,
                "docs": {
                    "tags": [],
                    "text": ""
                },
                "getter": false,
                "setter": false,
                "reflect": false
            }
        };
    }
    static get states() {
        return {
            "getPayout": {},
            "getPayoutCSV": {},
            "errorMessage": {}
        };
    }
    static get events() {
        return [{
                "method": "errorEvent",
                "name": "error-event",
                "bubbles": true,
                "cancelable": true,
                "composed": true,
                "docs": {
                    "tags": [],
                    "text": ""
                },
                "complexType": {
                    "original": "ComponentErrorEvent",
                    "resolved": "ComponentErrorEvent",
                    "references": {
                        "ComponentErrorEvent": {
                            "location": "import",
                            "path": "../../api/ComponentEvents",
                            "id": "src/api/ComponentEvents.ts::ComponentErrorEvent"
                        }
                    }
                }
            }];
    }
    static get watchers() {
        return [{
                "propName": "payoutId",
                "methodName": "propChanged"
            }, {
                "propName": "authToken",
                "methodName": "propChanged"
            }];
    }
}
