import { h } from "@stencil/core";
import { filterParams, propsParams, clearParams } from "./terminal-orders-list-params-state";
import { StyledHost } from "../../ui-components";
import { TerminalOrderStatus, TerminalOrderType } from "../../api";
import { convertToLocal, convertToUTC } from "../../utils/utils";
import { terminalOrdersListFilterMenu, orderStatusTerminalOrdersListFilterParam, orderTypeTerminalOrdersListFilterParam, createdAfterTerminalOrdersListFilterParam, createdBeforeTerminalOrdersListFilterParam } from "../../styles/parts";
export class TerminalOrdersListFilters {
    constructor() {
        this.setParamsOnChange = (name, value) => {
            filterParams[name] = value;
        };
        this.handleDateInput = (name, value) => {
            const utcDate = convertToUTC(value, { setExactTime: true });
            this.setParamsOnChange(name, utcDate);
        };
    }
    componentWillLoad() {
        const propsToSet = {
            order_status: this.orderStatus,
            order_type: this.orderType,
            created_after: this.createdAfter,
            created_before: this.createdBefore
        };
        Object.entries(propsToSet).forEach(([key, value]) => {
            if (value) {
                propsParams[key] = value;
            }
        });
    }
    get terminalOrderStatusOptions() {
        return [
            { label: 'All', value: '' },
            { label: 'Created', value: TerminalOrderStatus.created },
            { label: 'Completed', value: TerminalOrderStatus.completed },
            { label: 'Submitted', value: TerminalOrderStatus.submitted },
            { label: 'In Progress', value: TerminalOrderStatus.in_progress },
            { label: 'On Hold', value: TerminalOrderStatus.on_hold },
            { label: 'Canceled', value: TerminalOrderStatus.canceled }
        ];
    }
    get terminalOrderTypeOptions() {
        return [
            { label: 'All', value: '' },
            { label: 'Boarding Only', value: TerminalOrderType.boardingOnly },
            { label: 'Boarding Shipping', value: TerminalOrderType.boardingShipping },
        ];
    }
    render() {
        const filterMenuParams = Object.assign({}, filterParams);
        return (h(StyledHost, { key: '24b9da56d6bef1aa545007f2dba95b1da7fa4f4d' }, h("table-filters-menu", { key: 'ac3c26800fff2176782cf8240916cfd7e9a20333', params: filterMenuParams, clearParams: clearParams, part: terminalOrdersListFilterMenu }, h("div", { key: 'cf11a3bc06453a9970120d0ac05334754a51181b', class: "grid-cols-2 gap-3 p-1" }, h("div", { key: 'e72c2e114463c57e0de6042f2b3c419359f416ab', class: "p-2" }, h("form-control-select", { key: 'b2a3d66f6c0bb9fcf1da45cddc0b9df78ffa5ef8', name: "order_status", label: "Order Status", options: this.terminalOrderStatusOptions, inputHandler: this.setParamsOnChange, defaultValue: this.orderStatus || filterParams.order_status, disabled: !!this.orderStatus, part: orderStatusTerminalOrdersListFilterParam })), h("div", { key: '944a5f0ff5ff2fb87bee60da154b8dd03660e4f3', class: "p-2" }, h("form-control-select", { key: '992921c6f9ecf20587f814f87a44179db3fe49fd', name: "order_type", label: "Order Type", options: this.terminalOrderTypeOptions, inputHandler: this.setParamsOnChange, defaultValue: this.orderType || filterParams.order_type, disabled: !!this.orderType, part: orderTypeTerminalOrdersListFilterParam })), h("div", { key: '5acb3775b09fd508cfc77bf4b309cf43ca71a47a', class: "p-2" }, h("form-control-date", { key: '2b712d2c2903f2d579ada15a0e27eb97cc38c2f9', name: "created_after", label: "Created After", inputHandler: this.handleDateInput, defaultValue: convertToLocal(this.createdAfter, { showInputDateTime: true }) ||
                convertToLocal(filterParams.created_after, { showInputDateTime: true }), showTime: true, disabled: !!this.createdAfter, part: createdAfterTerminalOrdersListFilterParam })), h("div", { key: '66dae53f3fe0a6147570b15e6e85f7a821d7a322', class: "p-2" }, h("form-control-date", { key: '3715aab2b7637c67b1373bd0135a8a35c2b5a34c', name: "created_before", label: "Created Before", inputHandler: this.handleDateInput, defaultValue: convertToLocal(this.createdBefore, { showInputDateTime: true }) ||
                convertToLocal(filterParams.created_before, { showInputDateTime: true }), showTime: true, disabled: !!this.createdBefore, part: createdBeforeTerminalOrdersListFilterParam }))))));
    }
    static get is() { return "justifi-terminal-orders-list-filters"; }
    static get encapsulation() { return "shadow"; }
    static get properties() {
        return {
            "orderStatus": {
                "type": "string",
                "attribute": "order-status",
                "mutable": false,
                "complexType": {
                    "original": "TerminalOrderStatus",
                    "resolved": "TerminalOrderStatus.canceled | TerminalOrderStatus.completed | TerminalOrderStatus.created | TerminalOrderStatus.in_progress | TerminalOrderStatus.on_hold | TerminalOrderStatus.submitted",
                    "references": {
                        "TerminalOrderStatus": {
                            "location": "import",
                            "path": "../../api",
                            "id": "src/api/index.ts::TerminalOrderStatus"
                        }
                    }
                },
                "required": false,
                "optional": true,
                "docs": {
                    "tags": [],
                    "text": ""
                },
                "getter": false,
                "setter": false,
                "reflect": false
            },
            "orderType": {
                "type": "string",
                "attribute": "order-type",
                "mutable": false,
                "complexType": {
                    "original": "TerminalOrderType",
                    "resolved": "TerminalOrderType.boardingOnly | TerminalOrderType.boardingShipping",
                    "references": {
                        "TerminalOrderType": {
                            "location": "import",
                            "path": "../../api",
                            "id": "src/api/index.ts::TerminalOrderType"
                        }
                    }
                },
                "required": false,
                "optional": true,
                "docs": {
                    "tags": [],
                    "text": ""
                },
                "getter": false,
                "setter": false,
                "reflect": false
            },
            "createdAfter": {
                "type": "string",
                "attribute": "created-after",
                "mutable": false,
                "complexType": {
                    "original": "string",
                    "resolved": "string",
                    "references": {}
                },
                "required": false,
                "optional": true,
                "docs": {
                    "tags": [],
                    "text": ""
                },
                "getter": false,
                "setter": false,
                "reflect": false
            },
            "createdBefore": {
                "type": "string",
                "attribute": "created-before",
                "mutable": false,
                "complexType": {
                    "original": "string",
                    "resolved": "string",
                    "references": {}
                },
                "required": false,
                "optional": true,
                "docs": {
                    "tags": [],
                    "text": ""
                },
                "getter": false,
                "setter": false,
                "reflect": false
            }
        };
    }
}
