import { h } from "@stencil/core";
import { StyledHost } from "../../ui-components";
import { checkPkgVersion } from "../../utils/check-pkg-version";
import { defaultColumnsKeys } from "./terminal-orders-table";
import { makeGetTerminalOrders } from "../../actions/terminal/get-terminal-orders";
import { TerminalOrderService } from "../../api/services/terminal_orders.service";
import { ComponentErrorCodes, ComponentErrorSeverity } from "../../api";
import JustifiAnalytics from "../../api/Analytics";
export class TerminalOrdersList {
    constructor() {
        this.errorMessage = null;
        this.columns = defaultColumnsKeys;
        this.handleErrorEvent = (event) => {
            this.errorMessage = event.detail.message;
            this.errorEvent.emit(event.detail);
        };
    }
    componentWillLoad() {
        checkPkgVersion();
        this.analytics = new JustifiAnalytics(this);
        this.initializeGetData();
    }
    disconnectedCallback() {
        var _a;
        (_a = this.analytics) === null || _a === void 0 ? void 0 : _a.cleanup();
    }
    ;
    initializeGetData() {
        if (this.accountId && this.authToken) {
            this.getTerminalOrders = makeGetTerminalOrders({
                id: this.accountId,
                authToken: this.authToken,
                service: new TerminalOrderService()
            });
        }
        else {
            this.errorMessage = 'Account ID and Auth Token are required';
            this.errorEvent.emit({
                errorCode: ComponentErrorCodes.MISSING_PROPS,
                message: this.errorMessage,
                severity: ComponentErrorSeverity.ERROR,
            });
        }
    }
    render() {
        return (h(StyledHost, { key: 'e0fcbc2ccb76acdbcd7a18772d509995c81b1ae1' }, h("terminal-orders-list-core", { key: '21b108f554caa4343ecbd3bffa404c01442ef938', getTerminalOrders: this.getTerminalOrders, "onError-event": this.handleErrorEvent, columns: this.columns })));
    }
    static get is() { return "justifi-terminal-orders-list"; }
    static get encapsulation() { return "shadow"; }
    static get properties() {
        return {
            "accountId": {
                "type": "string",
                "attribute": "account-id",
                "mutable": false,
                "complexType": {
                    "original": "string",
                    "resolved": "string",
                    "references": {}
                },
                "required": false,
                "optional": false,
                "docs": {
                    "tags": [],
                    "text": ""
                },
                "getter": false,
                "setter": false,
                "reflect": false
            },
            "authToken": {
                "type": "string",
                "attribute": "auth-token",
                "mutable": false,
                "complexType": {
                    "original": "string",
                    "resolved": "string",
                    "references": {}
                },
                "required": false,
                "optional": false,
                "docs": {
                    "tags": [],
                    "text": ""
                },
                "getter": false,
                "setter": false,
                "reflect": false
            },
            "columns": {
                "type": "string",
                "attribute": "columns",
                "mutable": false,
                "complexType": {
                    "original": "string",
                    "resolved": "string",
                    "references": {}
                },
                "required": false,
                "optional": true,
                "docs": {
                    "tags": [],
                    "text": ""
                },
                "getter": false,
                "setter": false,
                "reflect": false,
                "defaultValue": "defaultColumnsKeys"
            }
        };
    }
    static get states() {
        return {
            "getTerminalOrders": {},
            "errorMessage": {}
        };
    }
    static get events() {
        return [{
                "method": "errorEvent",
                "name": "error-event",
                "bubbles": true,
                "cancelable": true,
                "composed": true,
                "docs": {
                    "tags": [],
                    "text": ""
                },
                "complexType": {
                    "original": "ComponentErrorEvent",
                    "resolved": "ComponentErrorEvent",
                    "references": {
                        "ComponentErrorEvent": {
                            "location": "import",
                            "path": "../../api",
                            "id": "src/api/index.ts::ComponentErrorEvent"
                        }
                    }
                }
            }];
    }
}
