import { h } from "@stencil/core";
import { debounce } from "lodash";
import { filterParams, propsParams, clearParams } from "./terminals-list-params-state";
import { StyledHost } from "../../ui-components";
import { ITerminalStatus } from "../../api";
import { terminalsListFilterMenu, terminalIdTerminalsListFilterParam, terminalOrderIdTerminalsListFilterParam, terminalStatusTerminalsListFilterParam } from "../../styles/parts";
export class TerminalsListFilters {
    constructor() {
        this.setParamsOnChange = (name, value) => {
            filterParams[name] = value;
        };
    }
    componentWillLoad() {
        // debounced input handler for text input
        this.debouncedSetParamsOnChange = debounce(this.setParamsOnChange, 300);
        const propsToSet = {
            terminal_id: this.terminalId,
            status: this.terminalStatus,
            terminal_order_id: this.terminalOrderId
        };
        Object.entries(propsToSet).forEach(([key, value]) => {
            if (value) {
                propsParams[key] = value;
            }
        });
    }
    get terminalStatusOptions() {
        return [
            { label: 'All', value: '' },
            { label: 'Connected', value: ITerminalStatus.connected },
            { label: 'Disconnected', value: ITerminalStatus.disconnected },
            { label: 'Unknown', value: ITerminalStatus.unknown },
            { label: 'Pending Configuration', value: ITerminalStatus.pending_configuration }
        ];
    }
    render() {
        const filterMenuParams = Object.assign({}, filterParams);
        return (h(StyledHost, { key: 'a5fe1671dd03e1290544f3deaf5aa01b5d937d9d' }, h("table-filters-menu", { key: 'f7a3d95c1b0ad0b52b96f990fd56fdbe64643493', params: filterMenuParams, clearParams: clearParams, part: terminalsListFilterMenu }, h("div", { key: '92b0144a5ab7eee377e053e9b006af846ac43d64', class: "grid-cols-2 gap-3 p-1" }, h("div", { key: '3970a2e11f3be7953af299be4825166a829e9a0a', class: "p-2" }, h("form-control-text", { key: '0653692eaffdb14b092643a9f3c1b8e126c942db', name: "terminal_id", label: "Terminal ID", inputHandler: this.debouncedSetParamsOnChange, defaultValue: this.terminalId || filterParams.terminal_id, disabled: !!this.terminalId, part: terminalIdTerminalsListFilterParam })), h("div", { key: 'c9d152d0a2d7e7b7fd7e72693a2248a020545a24', class: "p-2" }, h("form-control-text", { key: '785e7b382d9cadb72e242a379f2525b2da5140de', name: "terminal_order_id", label: "Terminal Order ID", inputHandler: this.debouncedSetParamsOnChange, defaultValue: this.terminalOrderId || filterParams.terminal_order_id, disabled: !!this.terminalOrderId, part: terminalOrderIdTerminalsListFilterParam })), h("div", { key: 'f4f1e79eb81a72dd25bb4f4c14450ca82657f213', class: "p-2" }, h("form-control-select", { key: '52b390e42309e13e2f09df0681392bbf8e84aed8', name: "status", label: "Status", options: this.terminalStatusOptions, inputHandler: this.setParamsOnChange, defaultValue: this.terminalStatus || filterParams.status, disabled: !!this.terminalStatus, part: terminalStatusTerminalsListFilterParam }))))));
    }
    static get is() { return "justifi-terminals-list-filters"; }
    static get encapsulation() { return "shadow"; }
    static get properties() {
        return {
            "terminalId": {
                "type": "string",
                "attribute": "terminal-id",
                "mutable": false,
                "complexType": {
                    "original": "string",
                    "resolved": "string",
                    "references": {}
                },
                "required": false,
                "optional": true,
                "docs": {
                    "tags": [],
                    "text": ""
                },
                "getter": false,
                "setter": false,
                "reflect": false
            },
            "terminalOrderId": {
                "type": "string",
                "attribute": "terminal-order-id",
                "mutable": false,
                "complexType": {
                    "original": "string",
                    "resolved": "string",
                    "references": {}
                },
                "required": false,
                "optional": true,
                "docs": {
                    "tags": [],
                    "text": ""
                },
                "getter": false,
                "setter": false,
                "reflect": false
            },
            "terminalStatus": {
                "type": "string",
                "attribute": "terminal-status",
                "mutable": false,
                "complexType": {
                    "original": "ITerminalStatus",
                    "resolved": "ITerminalStatus.connected | ITerminalStatus.disconnected | ITerminalStatus.pending_configuration | ITerminalStatus.unknown",
                    "references": {
                        "ITerminalStatus": {
                            "location": "import",
                            "path": "../../api",
                            "id": "src/api/index.ts::ITerminalStatus"
                        }
                    }
                },
                "required": false,
                "optional": true,
                "docs": {
                    "tags": [],
                    "text": ""
                },
                "getter": false,
                "setter": false,
                "reflect": false
            }
        };
    }
}
