import { h } from "@stencil/core";
import { createPopper } from "@popperjs/core";
export class CustomPopper {
    constructor() {
        this.placement = 'bottom';
        this.offset = [0, 10];
        this.strategy = 'absolute';
        this.trigger = 'click'; // 'click', 'hover', 'focus'
        this.isOpen = false;
    }
    componentDidLoad() {
        this.popperInstance = createPopper(this.anchorRef, this.popperContentRef, this.popperOptions);
        if (this.trigger === 'click') {
            window.addEventListener('click', this.handleClick.bind(this));
        }
        else if (this.trigger === 'hover') {
            this.anchorRef.addEventListener('mouseenter', this.show.bind(this));
            this.anchorRef.addEventListener('mouseleave', this.hide.bind(this));
            this.popperContentRef.addEventListener('mouseenter', this.show.bind(this));
            this.popperContentRef.addEventListener('mouseleave', this.hide.bind(this));
        }
        else if (this.trigger === 'focus') {
            this.anchorRef.addEventListener('focus', this.show.bind(this));
            this.anchorRef.addEventListener('blur', this.hide.bind(this));
        }
    }
    disconnectedCallback() {
        if (this.trigger === 'click') {
            window.removeEventListener('click', this.handleClick.bind(this));
        }
        else if (this.trigger === 'hover') {
            this.anchorRef.removeEventListener('mouseenter', this.show.bind(this));
            this.anchorRef.removeEventListener('mouseleave', this.hide.bind(this));
            this.popperContentRef.removeEventListener('mouseenter', this.show.bind(this));
            this.popperContentRef.removeEventListener('mouseleave', this.hide.bind(this));
        }
        else if (this.trigger === 'focus') {
            this.anchorRef.removeEventListener('focus', this.show.bind(this));
            this.anchorRef.removeEventListener('blur', this.hide.bind(this));
        }
    }
    handleClick(event) {
        const path = event.composedPath();
        const isAnchorClicked = path.includes(this.anchorRef);
        const isPopperContentClicked = path.includes(this.popperContentRef);
        if (!this.isOpen && isAnchorClicked) {
            this.show();
        }
        else if (this.isOpen && !isPopperContentClicked) {
            this.hide();
        }
        else if (this.isOpen && isAnchorClicked) {
            this.hide();
        }
    }
    get popperOptions() {
        return {
            placement: this.placement,
            modifiers: [
                {
                    name: 'offset',
                    options: {
                        offset: this.offset,
                    },
                },
            ],
            strategy: this.strategy,
        };
    }
    show() {
        this.isOpen = true;
        this.popperContentRef.setAttribute('data-show', '');
        this.popperInstance.update();
        this.showEvent.emit();
    }
    hide() {
        this.isOpen = false;
        this.popperContentRef.removeAttribute('data-show');
        this.popperInstance.update();
        this.hideEvent.emit();
    }
    render() {
        return (h("div", { key: '00471f914090d5f7c9c4493334e37bc669178f68' }, h("style", { key: 'e4c72e453b7cbfde820a72c93cbcedc3a1c6d3c7' }, `
          .popper-content {
            display: none;
          }
          .popper-content[data-show] {
            display: block;
            z-index: 1030;
          }
          `), h("div", { key: '8677d950b63503711e50a2f3d5b14bd7085f319e', class: "popper-content", ref: (el) => this.popperContentRef = el }, h("slot", { key: '54c1259606ca9b91d60f175b1d9981d8871fdd50' }))));
    }
    static get is() { return "custom-popper"; }
    static get properties() {
        return {
            "placement": {
                "type": "string",
                "attribute": "placement",
                "mutable": false,
                "complexType": {
                    "original": "Placement",
                    "resolved": "\"auto\" | \"auto-end\" | \"auto-start\" | \"bottom\" | \"bottom-end\" | \"bottom-start\" | \"left\" | \"left-end\" | \"left-start\" | \"right\" | \"right-end\" | \"right-start\" | \"top\" | \"top-end\" | \"top-start\"",
                    "references": {
                        "Placement": {
                            "location": "import",
                            "path": "@popperjs/core",
                            "id": "../../node_modules/.pnpm/@popperjs+core@2.11.8/node_modules/@popperjs/core/index.d.ts::Placement"
                        }
                    }
                },
                "required": false,
                "optional": false,
                "docs": {
                    "tags": [],
                    "text": ""
                },
                "getter": false,
                "setter": false,
                "reflect": false,
                "defaultValue": "'bottom'"
            },
            "offset": {
                "type": "unknown",
                "attribute": "offset",
                "mutable": false,
                "complexType": {
                    "original": "[number, number]",
                    "resolved": "[number, number]",
                    "references": {}
                },
                "required": false,
                "optional": false,
                "docs": {
                    "tags": [],
                    "text": ""
                },
                "getter": false,
                "setter": false,
                "defaultValue": "[0, 10]"
            },
            "strategy": {
                "type": "string",
                "attribute": "strategy",
                "mutable": false,
                "complexType": {
                    "original": "PositioningStrategy",
                    "resolved": "\"absolute\" | \"fixed\"",
                    "references": {
                        "PositioningStrategy": {
                            "location": "import",
                            "path": "@popperjs/core",
                            "id": "../../node_modules/.pnpm/@popperjs+core@2.11.8/node_modules/@popperjs/core/index.d.ts::PositioningStrategy"
                        }
                    }
                },
                "required": false,
                "optional": false,
                "docs": {
                    "tags": [],
                    "text": ""
                },
                "getter": false,
                "setter": false,
                "reflect": false,
                "defaultValue": "'absolute'"
            },
            "trigger": {
                "type": "string",
                "attribute": "trigger",
                "mutable": false,
                "complexType": {
                    "original": "string",
                    "resolved": "string",
                    "references": {}
                },
                "required": false,
                "optional": false,
                "docs": {
                    "tags": [],
                    "text": ""
                },
                "getter": false,
                "setter": false,
                "reflect": false,
                "defaultValue": "'click'"
            },
            "anchorRef": {
                "type": "unknown",
                "attribute": "anchor-ref",
                "mutable": false,
                "complexType": {
                    "original": "HTMLElement | SVGElement",
                    "resolved": "HTMLElement | SVGElement",
                    "references": {
                        "HTMLElement": {
                            "location": "global",
                            "id": "global::HTMLElement"
                        },
                        "SVGElement": {
                            "location": "global",
                            "id": "global::SVGElement"
                        }
                    }
                },
                "required": false,
                "optional": false,
                "docs": {
                    "tags": [],
                    "text": ""
                },
                "getter": false,
                "setter": false
            }
        };
    }
    static get states() {
        return {
            "isOpen": {}
        };
    }
    static get events() {
        return [{
                "method": "showEvent",
                "name": "showEvent",
                "bubbles": true,
                "cancelable": true,
                "composed": true,
                "docs": {
                    "tags": [],
                    "text": ""
                },
                "complexType": {
                    "original": "any",
                    "resolved": "any",
                    "references": {}
                }
            }, {
                "method": "hideEvent",
                "name": "hideEvent",
                "bubbles": true,
                "cancelable": true,
                "composed": true,
                "docs": {
                    "tags": [],
                    "text": ""
                },
                "complexType": {
                    "original": "any",
                    "resolved": "any",
                    "references": {}
                }
            }];
    }
}
