import { Host, h, } from "@stencil/core";
import { FormControlErrorText, FormControlHelpText } from "..";
import { input, inputDisabled, inputFocused, inputInvalid, label, inputAdornment } from "../../styles/parts";
import { formatCurrency } from "../../utils/utils";
export class MonetaryInput {
    constructor() {
        this.isFocused = false;
        this.defaultValue = '0';
        this.formatRawValue = (value) => {
            // Remove everything from that is not a number.
            // This will parse out our display formatting as well as prevent users from entering non-numeric characters.
            const formattedValue = value.replace(/\D/g, '');
            return formattedValue;
        };
        this.formatDisplayValue = (value) => {
            return formatCurrency(+value, undefined, true);
        };
        this.updateInput = (newValue) => {
            const name = this.formControl.name;
            const formatRawValue = this.formatRawValue(newValue); // "100000"
            this.formControl.value = this.formatDisplayValue(formatRawValue); // "1,000.00"
            this.inputHandler(name, formatRawValue);
            this.formControlInput.emit({ name: name, value: formatRawValue });
        };
    }
    handleDefaultValueChange(newValue) {
        this.updateInput(newValue);
    }
    componentDidLoad() {
        this.updateInput(this.defaultValue);
    }
    get inputPart() {
        if (this.errorText) {
            return inputInvalid;
        }
        if (this.disabled) {
            return inputDisabled;
        }
        if (this.isFocused) {
            return inputFocused;
        }
        return input;
    }
    render() {
        return (h(Host, { key: '0842196a10a26630b99d9b10149edc52f9197d75' }, h("div", { key: '9195cd13c772720637f9f5c68c3d93ba0b7b2b03', class: "form-group d-flex flex-column" }, h("label", { key: '995e71be182068b0ef4629c4fd6d66539199be5d', part: label, class: "form-label", htmlFor: this.name }, this.label), h(FormControlHelpText, { key: 'b9d3a12f486d808bc9eeb4155ca0c7c8086cdd0b', name: this.name, helpText: this.helpText }), h("div", { key: '00a19cfca58d00169c831f3f138c7ebc4b5afd85', class: "input-group" }, h("span", { key: '36120c616e2eec08cdf4a29fdfc2cb472441bf2b', class: "input-group-text", part: inputAdornment }, "$"), h("input", { key: 'dff91515955e4bc2ceb60b48deaa27be8717d95b', ref: el => this.formControl = el, id: this.name, name: this.name, onFocus: () => this.isFocused = true, onBlur: () => {
                this.isFocused = false;
                this.formControlBlur.emit();
            }, onInput: (event) => this.updateInput(event.target.value), onKeyDown: this.keyDownHandler, onPaste: this.keyDownHandler, maxLength: this.maxLength, part: this.inputPart, class: this.errorText ? "form-control is-invalid" : "form-control", type: "text", disabled: this.disabled })), h(FormControlErrorText, { key: '52a89e9a6196eeff1fbc20c7474ce7016be16fe3', errorText: this.errorText, name: this.name }))));
    }
    static get is() { return "form-control-monetary"; }
    static get properties() {
        return {
            "name": {
                "type": "any",
                "attribute": "name",
                "mutable": false,
                "complexType": {
                    "original": "any",
                    "resolved": "any",
                    "references": {}
                },
                "required": false,
                "optional": false,
                "docs": {
                    "tags": [],
                    "text": ""
                },
                "getter": false,
                "setter": false,
                "reflect": false
            },
            "label": {
                "type": "string",
                "attribute": "label",
                "mutable": false,
                "complexType": {
                    "original": "string",
                    "resolved": "string",
                    "references": {}
                },
                "required": false,
                "optional": false,
                "docs": {
                    "tags": [],
                    "text": ""
                },
                "getter": false,
                "setter": false,
                "reflect": false
            },
            "inputHandler": {
                "type": "unknown",
                "attribute": "input-handler",
                "mutable": false,
                "complexType": {
                    "original": "(name: string, value: string) => void",
                    "resolved": "(name: string, value: string) => void",
                    "references": {}
                },
                "required": false,
                "optional": false,
                "docs": {
                    "tags": [],
                    "text": ""
                },
                "getter": false,
                "setter": false
            },
            "defaultValue": {
                "type": "string",
                "attribute": "default-value",
                "mutable": false,
                "complexType": {
                    "original": "string",
                    "resolved": "string",
                    "references": {}
                },
                "required": false,
                "optional": true,
                "docs": {
                    "tags": [],
                    "text": ""
                },
                "getter": false,
                "setter": false,
                "reflect": false,
                "defaultValue": "'0'"
            },
            "helpText": {
                "type": "string",
                "attribute": "help-text",
                "mutable": false,
                "complexType": {
                    "original": "string",
                    "resolved": "string",
                    "references": {}
                },
                "required": false,
                "optional": true,
                "docs": {
                    "tags": [],
                    "text": ""
                },
                "getter": false,
                "setter": false,
                "reflect": false
            },
            "errorText": {
                "type": "string",
                "attribute": "error-text",
                "mutable": false,
                "complexType": {
                    "original": "string",
                    "resolved": "string",
                    "references": {}
                },
                "required": false,
                "optional": true,
                "docs": {
                    "tags": [],
                    "text": ""
                },
                "getter": false,
                "setter": false,
                "reflect": false
            },
            "maxLength": {
                "type": "number",
                "attribute": "max-length",
                "mutable": false,
                "complexType": {
                    "original": "number",
                    "resolved": "number",
                    "references": {}
                },
                "required": false,
                "optional": true,
                "docs": {
                    "tags": [],
                    "text": ""
                },
                "getter": false,
                "setter": false,
                "reflect": false
            },
            "keyDownHandler": {
                "type": "unknown",
                "attribute": "key-down-handler",
                "mutable": false,
                "complexType": {
                    "original": "(event: any) => void",
                    "resolved": "(event: any) => void",
                    "references": {}
                },
                "required": false,
                "optional": true,
                "docs": {
                    "tags": [],
                    "text": ""
                },
                "getter": false,
                "setter": false
            },
            "disabled": {
                "type": "boolean",
                "attribute": "disabled",
                "mutable": false,
                "complexType": {
                    "original": "boolean",
                    "resolved": "boolean",
                    "references": {}
                },
                "required": false,
                "optional": true,
                "docs": {
                    "tags": [],
                    "text": ""
                },
                "getter": false,
                "setter": false,
                "reflect": false
            }
        };
    }
    static get states() {
        return {
            "isFocused": {}
        };
    }
    static get events() {
        return [{
                "method": "formControlInput",
                "name": "formControlInput",
                "bubbles": true,
                "cancelable": true,
                "composed": true,
                "docs": {
                    "tags": [],
                    "text": ""
                },
                "complexType": {
                    "original": "any",
                    "resolved": "any",
                    "references": {}
                }
            }, {
                "method": "formControlBlur",
                "name": "formControlBlur",
                "bubbles": true,
                "cancelable": true,
                "composed": true,
                "docs": {
                    "tags": [],
                    "text": ""
                },
                "complexType": {
                    "original": "any",
                    "resolved": "any",
                    "references": {}
                }
            }];
    }
    static get watchers() {
        return [{
                "propName": "defaultValue",
                "methodName": "handleDefaultValueChange"
            }];
    }
}
