import { h, Host } from "@stencil/core";
import iFrameResize from "iframe-resizer/js/iframeResizer";
import { FrameCommunicationService } from "../../utils/frame-comunication-service";
import { FormControlErrorText } from "./form-helpers/form-control-error-text";
import packageJson from "../../../package.json";
import { iframeInputStyles } from "./iframe-input-styles-state";
import { MessageEventType } from "../../components/checkout/message-event-types";
import { input, inputFocused, inputInvalid, inputInvalidAndFocused, label } from "../../styles/parts";
export class IframeInput {
    constructor() {
        this.isFocused = false;
        this.isValid = true;
        this.dispatchMessageEvent = (event) => {
            const { eventType, data } = event.data;
            if ((data === null || data === void 0 ? void 0 : data.id) !== this.inputId) {
                return;
            }
            if (eventType === 'focused') {
                this.isFocused = true;
            }
            if (eventType === 'blurred') {
                this.isFocused = false;
            }
        };
    }
    disconnectedCallback() {
        this.frameService.removeMessageListener(this.dispatchMessageEvent);
    }
    async validate() {
        const response = await this.frameService
            .postMessageWithResponseListener(MessageEventType.validate);
        this.isValid = response.isValid;
        this.errorText = response.error.message;
        return response;
    }
    async tokenize(clientId, paymentMethodMetadata, account) {
        return this.frameService.postMessageWithResponseListener(MessageEventType.tokenize, {
            clientId,
            paymentMethodMetadata,
            account,
            componentVersion: packageJson.version,
        });
    }
    initializeFrameCommunicationService() {
        var _a;
        this.frameService = new FrameCommunicationService(this.iframeElement, this.iframeOrigin);
        (_a = this.frameService) === null || _a === void 0 ? void 0 : _a.addMessageListener(this.dispatchMessageEvent);
    }
    get part() {
        if (this.isFocused && !this.isValid) {
            return inputInvalidAndFocused;
        }
        if (!this.isValid) {
            return inputInvalid;
        }
        if (this.isFocused) {
            return inputFocused;
        }
        return input;
    }
    get style() {
        if (this.isFocused) {
            if (!this.isValid) {
                return iframeInputStyles.focusedAndInvalid;
            }
            return iframeInputStyles.focused;
        }
        return null;
    }
    get urlParams() {
        // map the iframeInputStyles.fontStyles properties to the urlParams 
        // and encode each property with btoa
        const encodedObject = Object.fromEntries(Object
            .entries(iframeInputStyles.fontStyles)
            .map(([key, value]) => [key, btoa(String(value))]));
        const params = new URLSearchParams(encodedObject).toString();
        return params;
    }
    render() {
        return (h(Host, { key: '6317dc0f48d4b44a94a2172e2d7342b8b77d96c7', class: "form-group d-flex flex-column" }, h("div", { key: '928a638fd786fb3e0518586e7c91f43d8e78f869', style: {
                visibility: this.iframeLoaded ? 'visible' : 'hidden',
                height: this.iframeLoaded ? 'auto' : '0',
            } }, h("label", { key: '9489d0302ae3c1f9944c4563a4cf57a9864a0055', class: "form-label", htmlFor: "", part: label }, this.label || ''), h("div", { key: '024ba8303ad42a45ea0794c7bd551294bad67c84', class: `p-0 d-flex form-control ${this.isValid ? '' : 'is-invalid'}`, part: this.part, style: Object.assign(Object.assign({}, this.style), { overflow: 'hidden' }) }, h("iframe", { key: 'effd7074bf559e5dfb63450eda633af57edb7abc', id: this.inputId, name: this.inputId, src: `${this.iframeOrigin}?${this.urlParams}`, ref: el => {
                this.iframeElement = el;
                this.initializeFrameCommunicationService();
            }, width: "100%", onLoad: () => {
                iFrameResize({
                    log: false,
                    onResized: () => {
                        this.iframeLoaded.emit();
                    }
                }, this.iframeElement);
            } })), h(FormControlErrorText, { key: '718118cbaf63d8e287f9bb8a0175b9cdb44fe41b', errorText: this.errorText, name: this.inputId }))));
    }
    static get is() { return "iframe-input"; }
    static get properties() {
        return {
            "inputId": {
                "type": "string",
                "attribute": "input-id",
                "mutable": false,
                "complexType": {
                    "original": "string",
                    "resolved": "string",
                    "references": {}
                },
                "required": false,
                "optional": false,
                "docs": {
                    "tags": [],
                    "text": ""
                },
                "getter": false,
                "setter": false,
                "reflect": false
            },
            "label": {
                "type": "string",
                "attribute": "label",
                "mutable": false,
                "complexType": {
                    "original": "string",
                    "resolved": "string",
                    "references": {}
                },
                "required": false,
                "optional": false,
                "docs": {
                    "tags": [],
                    "text": ""
                },
                "getter": false,
                "setter": false,
                "reflect": false
            },
            "iframeOrigin": {
                "type": "string",
                "attribute": "iframe-origin",
                "mutable": false,
                "complexType": {
                    "original": "string",
                    "resolved": "string",
                    "references": {}
                },
                "required": false,
                "optional": false,
                "docs": {
                    "tags": [],
                    "text": ""
                },
                "getter": false,
                "setter": false,
                "reflect": false
            }
        };
    }
    static get states() {
        return {
            "isFocused": {},
            "isValid": {},
            "errorText": {}
        };
    }
    static get events() {
        return [{
                "method": "iframeLoaded",
                "name": "iframeLoaded",
                "bubbles": true,
                "cancelable": true,
                "composed": true,
                "docs": {
                    "tags": [],
                    "text": ""
                },
                "complexType": {
                    "original": "void",
                    "resolved": "void",
                    "references": {}
                }
            }];
    }
    static get methods() {
        return {
            "validate": {
                "complexType": {
                    "signature": "() => Promise<any>",
                    "parameters": [],
                    "references": {
                        "Promise": {
                            "location": "global",
                            "id": "global::Promise"
                        }
                    },
                    "return": "Promise<any>"
                },
                "docs": {
                    "text": "",
                    "tags": []
                }
            },
            "tokenize": {
                "complexType": {
                    "signature": "(clientId: string, paymentMethodMetadata: IPaymentMethodMetadata, account?: string) => Promise<any>",
                    "parameters": [{
                            "name": "clientId",
                            "type": "string",
                            "docs": ""
                        }, {
                            "name": "paymentMethodMetadata",
                            "type": "ISavedPaymentMethod & ISubmitCheckoutArgs",
                            "docs": ""
                        }, {
                            "name": "account",
                            "type": "string",
                            "docs": ""
                        }],
                    "references": {
                        "Promise": {
                            "location": "global",
                            "id": "global::Promise"
                        },
                        "IPaymentMethodMetadata": {
                            "location": "import",
                            "path": "../../api/PaymentMethod",
                            "id": "src/api/PaymentMethod.ts::IPaymentMethodMetadata"
                        }
                    },
                    "return": "Promise<any>"
                },
                "docs": {
                    "text": "",
                    "tags": []
                }
            }
        };
    }
    static get elementRef() { return "el"; }
}
