import { c as create$3 } from './index.esm-BCNUj0Dx.js';
import { d as dateOfIncorporationValidation, t as taxIdValidation, i as industryValidation, b as businessClassificationValidation, a as doingBusinessAsValidation, p as phoneValidation, e as emailValidation, w as websiteUrlValidation, c as businessNameValidation, o as otherPaymentDetailsValidation, s as seasonalBusinessValidation, r as recurringPaymentsPercentageValidation, f as recurringPaymentsValidation, g as whenServiceReceivedValidation, h as paymentVolumeValidation, j as revenueValidation } from './schema-validations-DLWfpHyI.js';

const businessCoreInfoSchema = (allowOptionalFields) => {
    const schema = create$3({
        legal_name: businessNameValidation.required('Enter legal name'),
        website_url: websiteUrlValidation.required('Enter business website url'),
        email: emailValidation.required('Enter business email'),
        phone: phoneValidation.required('Enter phone number'),
        doing_business_as: doingBusinessAsValidation.nullable(),
        classification: businessClassificationValidation.required('Select business classification'),
        industry: industryValidation.required('Enter a business industry'),
        tax_id: taxIdValidation.required('Enter valid tax ID (SSN or EIN) without dashes'),
        date_of_incorporation: dateOfIncorporationValidation.required('Enter date of incorporation'),
    });
    const easySchema = create$3({
        legal_name: businessNameValidation.required('Enter legal name'),
        website_url: websiteUrlValidation.nullable(),
        email: emailValidation.nullable(),
        phone: phoneValidation.nullable(),
        doing_business_as: doingBusinessAsValidation.nullable(),
        classification: businessClassificationValidation.nullable(),
        industry: industryValidation.nullable(),
        tax_id: taxIdValidation.nullable(),
        date_of_incorporation: dateOfIncorporationValidation.nullable(),
    });
    return allowOptionalFields ? easySchema : schema;
};

const additionalQuestionsSchema = (allowOptionalFields) => {
    const schema = create$3({
        business_revenue: revenueValidation.required('Enter business revenue'),
        business_payment_volume: paymentVolumeValidation.required('Enter business payment volume'),
        business_when_service_received: whenServiceReceivedValidation.required('Select when service is received'),
        business_recurring_payments: recurringPaymentsValidation.required('Select recurring payments'),
        business_recurring_payments_percentage: recurringPaymentsPercentageValidation,
        business_seasonal: seasonalBusinessValidation.required('Select business seasonal'),
        business_other_payment_details: otherPaymentDetailsValidation.nullable(),
    });
    const easySchema = create$3({
        business_revenue: revenueValidation.nullable(),
        business_payment_volume: paymentVolumeValidation.nullable(),
        business_when_service_received: whenServiceReceivedValidation.nullable(),
        business_recurring_payments: recurringPaymentsValidation.nullable(),
        business_recurring_payments_percentage: recurringPaymentsPercentageValidation,
        business_seasonal: seasonalBusinessValidation.nullable(),
        business_other_payment_details: otherPaymentDetailsValidation.nullable(),
    });
    return allowOptionalFields ? easySchema : schema;
};

export { additionalQuestionsSchema as a, businessCoreInfoSchema as b };
