import { r as registerInstance, c as createEvent, h, H as Host } from './index-N3w5zrz2.js';
import { I as IMask } from './index-Ce_F4E0f.js';
import { C as CURRENCY_MASK } from './form-input-masks-B-iV5cYd.js';
import { a1 as inputGroup, l as label, U as inputAdornment, b as inputInvalid, T as inputDisabled, a as inputFocused } from './parts-CKg_luIy.js';
import { F as FormControlHelpText } from './form-control-help-text-mOLCXs00.js';
import { F as FormControlErrorText } from './form-control-error-text-Bk3yfpFX.js';
import './event-types-CZfYo5-1.js';

const MonetaryInputProvisioning = class {
    constructor(hostRef) {
        registerInstance(this, hostRef);
        this.formControlInput = createEvent(this, "formControlInput");
        this.formControlBlur = createEvent(this, "formControlBlur");
        this.imask = null;
        this.isFocused = false;
        this.maskOptions = CURRENCY_MASK.DECIMAL;
        this.initializeIMask = () => {
            if (!this.textInput)
                return;
            this.imask = IMask(this.textInput, this.maskOptions);
            this.imask.on('accept', () => {
                const rawValue = this.imask.unmaskedValue;
                this.inputHandler(this.name, rawValue);
                this.formControlInput.emit({ name: this.name, value: rawValue });
            });
            this.textInput.addEventListener('blur', () => this.formControlBlur.emit());
        };
        this.handleFormControlInput = (event) => {
            const target = event.target;
            const name = target.getAttribute('name');
            const rawValue = this.imask.unmaskedValue;
            this.formControlInput.emit({ name: name, value: rawValue });
        };
        this.updateInput = (newValue) => {
            if (this.imask) {
                this.imask.value = String(newValue);
            }
        };
    }
    handleDefaultValueChange(newValue) {
        this.updateInput(newValue);
    }
    componentDidLoad() {
        this.initializeIMask();
        this.updateInput(this.defaultValue);
    }
    disconnectedCallback() {
        var _a;
        (_a = this.imask) === null || _a === void 0 ? void 0 : _a.destroy();
    }
    get inputPart() {
        let part = inputGroup;
        if (this.errorText) {
            part = inputInvalid;
        }
        if (this.disabled) {
            part = inputDisabled;
        }
        if (this.isFocused) {
            part = inputFocused;
        }
        return part;
    }
    render() {
        return (h(Host, { key: '59e5e4d46e7d4ece898464d846505756611f6635' }, h("div", { key: 'e82201d6777584666ec5ca04ad9e02b83fa956c0', class: "form-group d-flex flex-column" }, h("label", { key: '9bbb22bb201d3db07670e4f26521593ff229f583', part: label, class: "form-label", htmlFor: this.name }, this.label), h("div", { key: '61909b4796f78e22d9e6508d9257cdf16220e675', class: "input-group" }, h("span", { key: '152a4f1a6323e55bf6f48aa25353939569acc419', class: "input-group-text", part: inputAdornment }, "$"), h("input", { key: 'cc8055c02a4ccb4f63553f45b5ded4ee3d8cf972', ref: el => (this.textInput = el), id: this.name, name: this.name, onFocus: () => this.isFocused = true, onBlur: () => {
                this.isFocused = false;
                this.formControlBlur.emit();
            }, onInput: this.handleFormControlInput, part: this.inputPart, class: this.errorText ? 'form-control monetary is-invalid' : 'form-control monetary', type: "text", disabled: this.disabled })), h(FormControlHelpText, { key: '776dfb4a9d74342ba139dda6706af8e60b4700fc', helpText: this.helpText, name: this.name }), h(FormControlErrorText, { key: '74e503b7e525aeeb994b1ae94941f07365d2460e', errorText: this.errorText, name: this.name }))));
    }
    static get watchers() { return {
        "defaultValue": ["handleDefaultValueChange"]
    }; }
};

export { MonetaryInputProvisioning as form_control_monetary_provisioning };
