import { r as registerInstance, c as createEvent, h, H as Host } from './index-N3w5zrz2.js';
import { b as inputInvalid, T as inputDisabled, a as inputFocused, c as input, l as label, U as inputAdornment } from './parts-CKg_luIy.js';
import { F as FormControlHelpText } from './form-control-help-text-mOLCXs00.js';
import { F as FormControlErrorText } from './form-control-error-text-Bk3yfpFX.js';
import './event-types-CZfYo5-1.js';
import { f as formatCurrency } from './utils-Cu5hITuT.js';
import './dinero-DizZAUMY.js';
import './_commonjsHelpers-BFTU3MAI.js';

const MonetaryInput = class {
    constructor(hostRef) {
        registerInstance(this, hostRef);
        this.formControlInput = createEvent(this, "formControlInput");
        this.formControlBlur = createEvent(this, "formControlBlur");
        this.isFocused = false;
        this.defaultValue = '0';
        this.formatRawValue = (value) => {
            // Remove everything from that is not a number.
            // This will parse out our display formatting as well as prevent users from entering non-numeric characters.
            const formattedValue = value.replace(/\D/g, '');
            return formattedValue;
        };
        this.formatDisplayValue = (value) => {
            return formatCurrency(+value, undefined, true);
        };
        this.updateInput = (newValue) => {
            const name = this.formControl.name;
            const formatRawValue = this.formatRawValue(newValue); // "100000"
            this.formControl.value = this.formatDisplayValue(formatRawValue); // "1,000.00"
            this.inputHandler(name, formatRawValue);
            this.formControlInput.emit({ name: name, value: formatRawValue });
        };
    }
    handleDefaultValueChange(newValue) {
        this.updateInput(newValue);
    }
    componentDidLoad() {
        this.updateInput(this.defaultValue);
    }
    get inputPart() {
        if (this.errorText) {
            return inputInvalid;
        }
        if (this.disabled) {
            return inputDisabled;
        }
        if (this.isFocused) {
            return inputFocused;
        }
        return input;
    }
    render() {
        return (h(Host, { key: '0842196a10a26630b99d9b10149edc52f9197d75' }, h("div", { key: '9195cd13c772720637f9f5c68c3d93ba0b7b2b03', class: "form-group d-flex flex-column" }, h("label", { key: '995e71be182068b0ef4629c4fd6d66539199be5d', part: label, class: "form-label", htmlFor: this.name }, this.label), h(FormControlHelpText, { key: 'b9d3a12f486d808bc9eeb4155ca0c7c8086cdd0b', name: this.name, helpText: this.helpText }), h("div", { key: '00a19cfca58d00169c831f3f138c7ebc4b5afd85', class: "input-group" }, h("span", { key: '36120c616e2eec08cdf4a29fdfc2cb472441bf2b', class: "input-group-text", part: inputAdornment }, "$"), h("input", { key: 'dff91515955e4bc2ceb60b48deaa27be8717d95b', ref: el => this.formControl = el, id: this.name, name: this.name, onFocus: () => this.isFocused = true, onBlur: () => {
                this.isFocused = false;
                this.formControlBlur.emit();
            }, onInput: (event) => this.updateInput(event.target.value), onKeyDown: this.keyDownHandler, onPaste: this.keyDownHandler, maxLength: this.maxLength, part: this.inputPart, class: this.errorText ? "form-control is-invalid" : "form-control", type: "text", disabled: this.disabled })), h(FormControlErrorText, { key: '52a89e9a6196eeff1fbc20c7474ce7016be16fe3', errorText: this.errorText, name: this.name }))));
    }
    static get watchers() { return {
        "defaultValue": ["handleDefaultValueChange"]
    }; }
};

export { MonetaryInput as form_control_monetary };
