import { h, r as registerInstance, c as createEvent } from './index-N3w5zrz2.js';
import { c as create$3, F as FormController } from './index.esm-BCNUj0Dx.js';
import { b as businessCoreInfoSchema, a as additionalQuestionsSchema } from './business-additional-questions-schema-uQlQ8fXQ.js';
import { i as identitySchema, a as addressSchema } from './business-identity-schema-BsrgqgDl.js';
import './config-state-B3mtRA6f.js';
import './dinero-DizZAUMY.js';
import { C as ComponentErrorSeverity, a as ComponentErrorCodes } from './ComponentError-BhrFjjAs.js';
import './Refund-DBHZkemk.js';
import './Pagination-CLHwhyvu.js';
import { B as Business, b as BusinessFormServerErrors } from './Business-BCoP0TAV.js';
import './Dispute-BH0Xfn-F.js';
import { c as checkPkgVersion, J as JustifiAnalytics } from './check-pkg-version-Cic-MeLf.js';
import { B as Button } from './button-BB-N4vit.js';
import { S as StyledHost } from './styled-host-DtvbNFVU.js';
import { H as Header1 } from './header-1-DYuf6mkF.js';
import './event-types-CZfYo5-1.js';
import { S as Skeleton } from './skeleton-D1Z4a8af.js';
import { B as BusinessFormClickActions } from './event-types-XYgDHrVL.js';
import { m as makeGetBusiness, b as makePatchBusiness } from './payment-provisioning-actions-2qP7AtHj.js';
import { B as BusinessService } from './business.service-BPBxsb8B.js';
import './_commonjsHelpers-BFTU3MAI.js';
import './schema-validations-DLWfpHyI.js';
import './state-options-BX8GieXu.js';
import './business-form-options-CgssATyg.js';
import './index-BAq5IUBW.js';
import './utils-Cu5hITuT.js';
import './helpers-Mu7LQT-w.js';
import './package-BRJ4FIJH.js';
import './Api-BCeKXDaf.js';
import './parts-CKg_luIy.js';
import './utils-BZvep88z.js';

const businessFormSchema = create$3(Object.assign(Object.assign({}, businessCoreInfoSchema().fields), { legal_address: addressSchema(), additional_questions: additionalQuestionsSchema(), representative: identitySchema('representative') }));

const FormBlock = () => (h("div", { class: "row gap-3" },
    h("div", { class: "col-12" },
        h(Skeleton, { width: "25%" })),
    h("div", { class: "col-12" },
        h(Skeleton, { width: "100%" })),
    h("div", { class: "col-12 d-flex gap-3" },
        h(Skeleton, { width: "50%" }),
        h(Skeleton, { width: "50%" })),
    h("div", { class: "col-12 d-flex gap-3" },
        h(Skeleton, { width: "65%" }),
        h(Skeleton, { width: "35%" }))));
const BusinessFormLoading = () => {
    return (h("div", { class: "row gap-5" },
        h("div", { class: "col-12" },
            h(Skeleton, { width: "40%", height: "40px" })),
        h(FormBlock, null),
        h(FormBlock, null),
        h(FormBlock, null)));
};

const BusinessForm = class {
    constructor(hostRef) {
        registerInstance(this, hostRef);
        this.submitEvent = createEvent(this, "submit-event");
        this.clickEvent = createEvent(this, "click-event");
        this.errorEvent = createEvent(this, "error-event");
        this.isLoading = false;
        this.isSaving = false;
        this.hideErrors = false;
        this.formTitle = 'Business Information';
        this.removeTitle = false;
        this.instantiateBusiness = (data) => {
            const business = new Business(data);
            this.formController.setInitialValues(Object.assign({}, business));
        };
        this.sendData = async () => {
            this.isSaving = true;
            const values = this.formController.values.getValue();
            const initialValues = this.formController.getInitialValues();
            const payload = new Business(Object.assign(Object.assign({}, initialValues), values)).payload;
            this.patchBusiness({
                payload,
                onSuccess: (response) => {
                    this.handleReponse(response);
                },
                onError: ({ error, code, severity }) => {
                    this.errorMessage = error.message;
                    this.errorEvent.emit({ errorCode: code, message: error.message, severity });
                },
                final: () => {
                    this.isSaving = false;
                }
            });
        };
        this.validateAndSubmit = (event) => {
            event.preventDefault();
            this.formController.validateAndSubmit(this.sendData);
        };
    }
    componentWillLoad() {
        checkPkgVersion();
        this.analytics = new JustifiAnalytics(this);
        this.formController = new FormController(businessFormSchema);
        this.initializeApi();
    }
    disconnectedCallback() {
        var _a;
        (_a = this.analytics) === null || _a === void 0 ? void 0 : _a.cleanup();
    }
    ;
    get title() {
        return this.removeTitle ? '' : this.formTitle;
    }
    get disabledState() {
        return this.isSaving;
    }
    get businessEndpoint() {
        return `entities/business/${this.businessId}`;
    }
    initializeApi() {
        if (this.authToken && this.businessId) {
            this.getBusiness = makeGetBusiness({
                authToken: this.authToken,
                businessId: this.businessId,
                service: new BusinessService()
            });
            this.patchBusiness = makePatchBusiness({
                authToken: this.authToken,
                businessId: this.businessId,
                service: new BusinessService()
            });
            this.getBusiness({
                onSuccess: (response) => {
                    this.instantiateBusiness(response.data);
                },
                onError: ({ error, code, severity }) => {
                    this.errorMessage = error.message;
                    this.errorEvent.emit({ errorCode: code, message: error.message, severity });
                },
                final: () => {
                    this.isLoading = false;
                }
            });
        }
        else {
            this.errorEvent.emit({
                message: 'auth-token and business-id are required',
                errorCode: ComponentErrorCodes.MISSING_PROPS,
                severity: ComponentErrorSeverity.ERROR,
            });
        }
    }
    handleReponse(response) {
        if (response.error) {
            this.errorMessage = BusinessFormServerErrors.patchData;
        }
        this.submitEvent.emit({ response });
        this.instantiateBusiness(response.data);
    }
    render() {
        if (this.isLoading) {
            return h(StyledHost, null, h(BusinessFormLoading, null));
        }
        return (h(StyledHost, null, h("form", { onSubmit: this.validateAndSubmit }, h("div", { class: "row gap-3" }, h(Header1, { text: this.title }), h("form-alert", { text: this.errorMessage, hideAlert: this.hideErrors }), h("div", { class: "col-12 mb-4" }, h("justifi-business-core-info", { formController: this.formController })), h("div", { class: "col-12 mb-4" }, h("justifi-legal-address-form", { formController: this.formController })), h("div", { class: "col-12 mb-4" }, h("justifi-additional-questions", { formController: this.formController })), h("div", { class: "col-12 mb-4" }, h("justifi-business-representative", { formController: this.formController })), h("div", { class: "col-12 d-flex flex-row-reverse" }, h(Button, { type: "submit", disabled: this.disabledState, variant: 'primary', onClick: () => this.clickEvent.emit({ name: BusinessFormClickActions.submit }), isLoading: this.isSaving }, "Submit"))))));
    }
};

export { BusinessForm as justifi_business_form };
