import { r as registerInstance, h, c as createEvent, H as Host, a as getElement } from './index-N3w5zrz2.js';
import { D as text, r as radioListItem } from './parts-CKg_luIy.js';
import { f as formatCurrency } from './utils-Cu5hITuT.js';
import { c as checkoutStore, o as onChange } from './checkout.store-GXtlf5-4.js';
import { S as StyledHost } from './styled-host-DtvbNFVU.js';
import './event-types-CZfYo5-1.js';
import { J as JustifiAnalytics, c as checkPkgVersion } from './check-pkg-version-Cic-MeLf.js';
import './config-state-B3mtRA6f.js';
import './dinero-DizZAUMY.js';
import { C as ComponentErrorSeverity, a as ComponentErrorCodes } from './ComponentError-BhrFjjAs.js';
import './Refund-DBHZkemk.js';
import './Pagination-CLHwhyvu.js';
import './Business-BCoP0TAV.js';
import './Dispute-BH0Xfn-F.js';
import { g as getErrorCode, a as getErrorMessage } from './utils-BZvep88z.js';
import { C as CheckoutService } from './checkout.service-C1WAmUiU.js';
import { b as insuranceValuesOn, i as insuranceValues } from './insurance-state-DeyYNyas.js';
import { C as CardBrandLabels } from './payment-method-option-utils-zFDtQrgQ.js';
import './index-BAq5IUBW.js';
import './package-BRJ4FIJH.js';
import './Api-BCeKXDaf.js';
import './_commonjsHelpers-BFTU3MAI.js';
import './helpers-Mu7LQT-w.js';
import './state-options-BX8GieXu.js';

const Summary = class {
    constructor(hostRef) {
        registerInstance(this, hostRef);
    }
    render() {
        return (h(StyledHost, { key: '1bafeffc42f1e98f50551ca971f52e8294782168' }, h("section", { key: 'bf1a89bf030ae5a953abe092d0a5c543ed7f543f' }, h("div", { key: 'ce0b98733c2e158c1caef43b751513a0565ecfc6' }, h("div", { key: '8d0525c31ac3a93a5ce1aa2afde5c9bd7da26dc0', part: text }, checkoutStore === null || checkoutStore === void 0 ? void 0 : checkoutStore.paymentDescription), h("div", { key: '7885858ddcd2819522fa08fbbc2d3dce2f0132f6' }, h("span", { key: '57ce1d9a9dd1269c4d958c78210565e9cb68d22a', part: text }, "Total"), "\u00A0", h("span", { key: '0b6673bd2c841cb0e50db93c148bfe15f96b577a', part: text }, formatCurrency(+(checkoutStore === null || checkoutStore === void 0 ? void 0 : checkoutStore.totalAmount))))))));
    }
};

const makeGetCheckout = ({ authToken, checkoutId, service }) => async ({ onSuccess, onError }) => {
    var _a;
    try {
        const response = await service.fetchCheckout(authToken, checkoutId);
        if (!response.error) {
            const checkout = response.data;
            onSuccess({ checkout });
        }
        else {
            const responseError = getErrorMessage(response.error);
            const code = getErrorCode((_a = response.error) === null || _a === void 0 ? void 0 : _a.code);
            return onError({
                error: responseError,
                code,
                severity: ComponentErrorSeverity.ERROR,
            });
        }
    }
    catch (error) {
        const code = getErrorCode(error === null || error === void 0 ? void 0 : error.code);
        return onError({
            error: error.message || error,
            code,
            severity: ComponentErrorSeverity.ERROR,
        });
    }
};
const makeCheckoutComplete = ({ authToken, checkoutId, service }) => async ({ payment, onSuccess, onError }) => {
    var _a;
    try {
        const response = await service.complete(authToken, checkoutId, payment);
        if (!response.error) {
            onSuccess(response);
        }
        else {
            const responseError = getErrorMessage(response.error);
            const code = getErrorCode((_a = response.error) === null || _a === void 0 ? void 0 : _a.code);
            return onError({
                error: responseError,
                code,
                severity: ComponentErrorSeverity.ERROR,
            });
        }
    }
    catch (error) {
        const code = getErrorCode(error === null || error === void 0 ? void 0 : error.code);
        return onError({
            error: error.message || error,
            code,
            severity: ComponentErrorSeverity.ERROR,
        });
    }
};

const CheckoutWrapper = class {
    constructor(hostRef) {
        registerInstance(this, hostRef);
        this.errorEvent = createEvent(this, "error-event");
        this.submitEvent = createEvent(this, "submit-event");
        this.paymentMethodChangedEvent = createEvent(this, "payment-method-changed");
        this.savePaymentMethod = false;
    }
    connectedCallback() {
        this.observer = new MutationObserver(() => {
            this.queryFormRefs();
        });
        this.observer.observe(this.hostEl, {
            childList: true,
            subtree: true
        });
        checkoutStore.checkoutId = this.checkoutId;
        const config = {
            authToken: this.authToken,
            checkoutId: this.checkoutId,
            service: new CheckoutService()
        };
        this.getCheckout = makeGetCheckout(config);
        this.completeCheckout = makeCheckoutComplete(config);
        onChange('selectedPaymentMethod', (newValue) => {
            this.paymentMethodChangedEvent.emit(newValue);
        });
    }
    componentWillLoad() {
        this.analytics = new JustifiAnalytics(this);
        checkPkgVersion();
        checkoutStore.authToken = this.authToken;
        this.fetchCheckout();
        // Refresh the checkout data when insurance is added or removed
        insuranceValuesOn('set', (key) => {
            const value = insuranceValues[key];
            if (value !== undefined) {
                this.fetchCheckout();
            }
        });
    }
    componentDidLoad() {
        this.queryFormRefs();
    }
    disconnectedCallback() {
        var _a;
        (_a = this.observer) === null || _a === void 0 ? void 0 : _a.disconnect();
    }
    fetchCheckout() {
        if (this.getCheckout) {
            this.getCheckout({
                onSuccess: ({ checkout }) => {
                    this.updateStore(checkout);
                },
                onError: (error) => {
                    this.errorEvent.emit({
                        message: error.message,
                        errorCode: ComponentErrorCodes.FETCH_ERROR,
                        severity: ComponentErrorSeverity.ERROR,
                    });
                }
            });
        }
    }
    updateStore(checkout) {
        var _a, _b, _c, _d;
        checkoutStore.accountId = checkout.account_id;
        checkoutStore.paymentMethods = checkout.payment_methods;
        checkoutStore.paymentMethodGroupId = checkout.payment_method_group_id;
        checkoutStore.paymentDescription = checkout.payment_description;
        checkoutStore.totalAmount = checkout.total_amount;
        checkoutStore.paymentAmount = checkout.payment_amount;
        checkoutStore.bnplEnabled = checkout.payment_settings.bnpl_payments;
        checkoutStore.bnplProviderClientId = (_a = checkout === null || checkout === void 0 ? void 0 : checkout.bnpl) === null || _a === void 0 ? void 0 : _a.provider_client_id;
        checkoutStore.bnplProviderMode = (_b = checkout === null || checkout === void 0 ? void 0 : checkout.bnpl) === null || _b === void 0 ? void 0 : _b.provider_mode;
        checkoutStore.bnplProviderApiVersion = (_c = checkout === null || checkout === void 0 ? void 0 : checkout.bnpl) === null || _c === void 0 ? void 0 : _c.provider_api_version;
        checkoutStore.bnplProviderCheckoutUrl = (_d = checkout === null || checkout === void 0 ? void 0 : checkout.bnpl) === null || _d === void 0 ? void 0 : _d.provider_checkout_url;
    }
    queryFormRefs() {
        this.paymentMethodFormRef = this.hostEl.querySelector('justifi-card-form, justifi-bank-account-form');
        this.tokenizeComponentRef = this.hostEl.querySelector('justifi-tokenize-payment-method');
        this.billingInformationFormRef = this.hostEl.querySelector('justifi-billing-information-form, justifi-postal-code-form');
        this.insuranceFormRef = this.hostEl.querySelector('justifi-season-interruption-insurance');
        this.sezzlePaymentMethodRef = this.hostEl.querySelector('justifi-sezzle-payment-method');
    }
    async tokenizePaymentMethod(tokenizeArgs) {
        var _a, _b;
        const billingInfoValues = (_b = await ((_a = this.billingInformationFormRef) === null || _a === void 0 ? void 0 : _a.getValues())) !== null && _b !== void 0 ? _b : {};
        const combinedBillingInfo = Object.assign(Object.assign({}, tokenizeArgs), billingInfoValues);
        const paymentMethodMetadata = Object.assign({ accountId: checkoutStore.accountId, payment_method_group_id: undefined }, combinedBillingInfo);
        if (this.savePaymentMethod) {
            paymentMethodMetadata.payment_method_group_id = checkoutStore.paymentMethodGroupId;
        }
        if (this.tokenizeComponentRef) {
            const tokenizeResult = await this.tokenizeComponentRef.tokenizePaymentMethod();
            if (tokenizeResult.error) {
                return tokenizeResult;
            }
        }
        return this.paymentMethodFormRef.tokenize({
            clientId: this.authToken,
            paymentMethodMetadata,
            account: checkoutStore.accountId,
        });
    }
    async getPaymentMethod(submitCheckoutArgs) {
        if (!this.paymentMethodFormRef) {
            return checkoutStore.selectedPaymentMethod;
        }
        const { error, id: token } = await this.tokenizePaymentMethod(submitCheckoutArgs);
        if (error) {
            this.errorEvent.emit({
                errorCode: error.code,
                message: error.message,
                severity: ComponentErrorSeverity.ERROR,
            });
            return undefined;
        }
        return token;
    }
    async validate() {
        var _a, _b;
        const promises = [
            (_a = this.paymentMethodFormRef) === null || _a === void 0 ? void 0 : _a.validate(),
            (_b = this.billingInformationFormRef) === null || _b === void 0 ? void 0 : _b.validate()
        ];
        if (this.insuranceFormRef) {
            promises.push(this.insuranceFormRef.validate());
        }
        const validationResults = await Promise.all(promises);
        return validationResults.every(result => (result === null || result === void 0 ? void 0 : result.isValid) !== false);
    }
    async submitCheckout(submitCheckoutArgs) {
        var _a;
        const isValid = await this.validate();
        if (!isValid) {
            this.errorEvent.emit({
                message: 'Please fill in all required fields.',
                errorCode: ComponentErrorCodes.VALIDATION_ERROR,
                severity: ComponentErrorSeverity.ERROR,
            });
            return;
        }
        let payment;
        if (checkoutStore.selectedPaymentMethod === 'sezzle') {
            const insuranceValidation = this.insuranceFormRef ? await this.insuranceFormRef.validate() : { isValid: true };
            const sezzleResult = await this.sezzlePaymentMethodRef.resolvePaymentMethod(insuranceValidation);
            if (sezzleResult.error) {
                this.errorEvent.emit({
                    message: sezzleResult.error.message,
                    errorCode: ComponentErrorCodes.TOKENIZE_ERROR,
                    severity: ComponentErrorSeverity.ERROR,
                });
                return;
            }
            else if (((_a = sezzleResult.bnpl) === null || _a === void 0 ? void 0 : _a.status) === 'success') {
                payment = {
                    payment_mode: 'bnpl',
                    payment_token: undefined,
                };
            }
        }
        else {
            const paymentMethod = await this.getPaymentMethod(submitCheckoutArgs);
            if (!paymentMethod) {
                this.errorEvent.emit({
                    message: 'Payment method tokenization failed.',
                    errorCode: ComponentErrorCodes.TOKENIZE_ERROR,
                    severity: ComponentErrorSeverity.ERROR,
                });
                return;
            }
            payment = {
                payment_mode: 'ecom',
                payment_token: paymentMethod,
            };
        }
        this.completeCheckout({
            payment,
            onSuccess: ({ checkout }) => {
                this.submitEvent.emit({
                    checkout,
                    message: 'Checkout completed successfully',
                });
            },
            onError: (error) => {
                this.errorEvent.emit({
                    message: error.message,
                    errorCode: ComponentErrorCodes.COMPLETE_CHECKOUT_ERROR,
                    severity: ComponentErrorSeverity.ERROR,
                });
            },
        });
    }
    async setSelectedPaymentMethod(paymentMethodId) {
        checkoutStore.selectedPaymentMethod = paymentMethodId;
    }
    render() {
        return (h(Host, { key: '6949f68031572493fae333731c78cc07ccd7fafd' }));
    }
    get hostEl() { return getElement(this); }
};

const SavedPaymentMethods = class {
    constructor(hostRef) {
        registerInstance(this, hostRef);
        this.onPaymentMethodOptionClick = (paymentMethodId) => (e) => {
            e.preventDefault();
            checkoutStore.selectedPaymentMethod = paymentMethodId;
        };
        this.isAllowedPaymentMethod = (paymentMethod) => {
            if (paymentMethod.type === 'card' && checkoutStore.disableCreditCard) {
                return false;
            }
            if (paymentMethod.type === 'bank_account' && checkoutStore.disableBankAccount) {
                return false;
            }
            return true;
        };
    }
    componentWillLoad() {
        if (!checkoutStore.paymentMethods.length) {
            console.warn('No saved payment methods available.');
        }
        if (checkoutStore.disablePaymentMethodGroup) {
            console.warn('Payment method group is disabled.');
        }
    }
    render() {
        if (checkoutStore.disablePaymentMethodGroup) {
            return null;
        }
        return (h(StyledHost, null, h("div", { class: "saved-payment-methods" }, checkoutStore.paymentMethods.length ? checkoutStore.paymentMethods
            .filter(this.isAllowedPaymentMethod)
            .map((paymentMethod) => (h("div", { class: "radio-list-item p-3", part: radioListItem, onClick: this.onPaymentMethodOptionClick(paymentMethod === null || paymentMethod === void 0 ? void 0 : paymentMethod.id) }, h("form-control-radio", { name: "paymentMethodType", value: paymentMethod === null || paymentMethod === void 0 ? void 0 : paymentMethod.id, checked: checkoutStore.selectedPaymentMethod === (paymentMethod === null || paymentMethod === void 0 ? void 0 : paymentMethod.id), label: `${CardBrandLabels[paymentMethod === null || paymentMethod === void 0 ? void 0 : paymentMethod.brand] || ''} *${paymentMethod === null || paymentMethod === void 0 ? void 0 : paymentMethod.acct_last_four}` })))) : null)));
    }
};

const sezzleLogo = (h("img", { class: "sezzle-smart-button-logo-img", src: "https://media.sezzle.com/branding/2.0/Sezzle_Logo_FullColor.svg", alt: "Sezzle", style: {
        display: 'inline',
        width: '80px',
        marginLeft: '5px',
        marginTop: '-5px',
    } }));
const SezzlePaymentMethod = class {
    constructor(hostRef) {
        registerInstance(this, hostRef);
        this.paymentMethodOptionSelected = createEvent(this, "paymentMethodOptionSelected");
        this.paymentMethodOptionId = 'sezzle';
        this.onPaymentMethodOptionClick = (e) => {
            e.preventDefault();
            checkoutStore.selectedPaymentMethod = this.paymentMethodOptionId;
            this.paymentMethodOptionSelected.emit(this.paymentMethodOptionId);
        };
        this.initializeSezzleCheckout = () => {
            let resolveSezzlePromise;
            this.sezzlePromise = new Promise((resolve) => { resolveSezzlePromise = resolve; });
            const amount = Number(checkoutStore.paymentAmount);
            const Checkout = window.Checkout;
            const checkout = new Checkout({
                mode: 'popup',
                publicKey: checkoutStore.bnplProviderClientId,
                apiMode: checkoutStore.bnplProviderMode,
                apiVersion: checkoutStore.bnplProviderApiVersion,
            });
            checkout.sezzleButtonElement = this.sezzleButtonRef;
            checkout.init({
                onClick: function (event) {
                    event.preventDefault();
                    checkout.startCheckout({
                        checkout_url: checkoutStore.bnplProviderCheckoutUrl,
                    });
                },
                onComplete: (event) => resolveSezzlePromise({ bnpl: event.data }),
                onCancel: (event) => resolveSezzlePromise({ bnpl: event.data }),
                onFailure: (event) => resolveSezzlePromise({ bnpl: event.data }),
            });
            this.sezzleCheckout = checkout;
            this.installmentPlan = this.sezzleCheckout.getInstallmentPlan(amount);
        };
    }
    componentDidRender() {
        if (!this.scriptRef)
            return;
        this.scriptRef.onload = () => {
            this.sezzleButtonRef = document.createElement('button');
            this.initializeSezzleCheckout();
        };
    }
    async resolvePaymentMethod(insuranceValidation) {
        if (!insuranceValidation.isValid) {
            return { validationError: true };
        }
        this.sezzleButtonRef.click();
        return this.sezzlePromise;
    }
    render() {
        var _a, _b;
        if (!checkoutStore.bnplEnabled || checkoutStore.disableBnpl) {
            console.warn('justifi-sezzle-payment-method: BNPL is not enabled for this account.');
            return null;
        }
        return (h(StyledHost, { class: "payment-method" }, h("script", { src: "https://checkout-sdk.sezzle.com/checkout.min.js", async: true, ref: (el) => (this.scriptRef = el) }), h("div", { class: "radio-list-item p-3", part: radioListItem, onClick: this.onPaymentMethodOptionClick }, h("form-control-radio", { name: "paymentMethodType", value: this.paymentMethodOptionId, checked: checkoutStore.selectedPaymentMethod === this.paymentMethodOptionId, label: h("div", null, h("div", null, "Buy now, pay later with ", sezzleLogo), this.installmentPlan && (h("small", null, h("span", null, (_a = this.installmentPlan) === null || _a === void 0 ? void 0 : _a.installments.length), "\u00A0", h("span", null, this.installmentPlan.schedule, " payments of"), "\u00A0", h("span", { class: "fw-bold" }, formatCurrency((_b = this.installmentPlan) === null || _b === void 0 ? void 0 : _b.installments[0].amountInCents))))) }))));
    }
};

const PaymentMethodOption = class {
    constructor(hostRef) {
        registerInstance(this, hostRef);
    }
    render() {
        return (h(StyledHost, { key: 'a8c7ba94cf471c0b12f65c6fa9be1d1b6fc28910', class: "payment-method" }, h("div", { key: 'fae8daae8c7b3d00a5ba7a713522766bfe41dfae', class: "radio-list-item p-3", part: radioListItem, onClick: this.clickHandler, hidden: this.radioButtonHidden }, h("form-control-radio", { key: '51b8f509374e771c9e0cd7ff463c8a3d3b9d9a35', name: "paymentMethodType", value: this.paymentMethodOptionId, checked: this.isSelected, label: this.label }))));
    }
};

export { Summary as justifi_checkout_summary, CheckoutWrapper as justifi_modular_checkout, SavedPaymentMethods as justifi_saved_payment_methods, SezzlePaymentMethod as justifi_sezzle_payment_method, PaymentMethodOption as payment_method_option };
