import { r as registerInstance, c as createEvent, h } from './index-N3w5zrz2.js';
import './config-state-B3mtRA6f.js';
import './dinero-DizZAUMY.js';
import { C as ComponentErrorSeverity, a as ComponentErrorCodes } from './ComponentError-BhrFjjAs.js';
import { C as Checkout } from './Refund-DBHZkemk.js';
import './Pagination-CLHwhyvu.js';
import './Business-BCoP0TAV.js';
import './Dispute-BH0Xfn-F.js';
import { g as getErrorCode, a as getErrorMessage } from './utils-BZvep88z.js';
import { c as checkPkgVersion, J as JustifiAnalytics } from './check-pkg-version-Cic-MeLf.js';
import { C as CheckoutService } from './checkout.service-C1WAmUiU.js';
import { m as makeGetSubAccounts, S as SubAccountService } from './get-subaccounts-DcgISPei.js';
import { S as StyledHost } from './styled-host-DtvbNFVU.js';
import './event-types-CZfYo5-1.js';
import { d as defaultColumnsKeys } from './checkouts-table-COpCngi0.js';
import './index-BAq5IUBW.js';
import './_commonjsHelpers-BFTU3MAI.js';
import './utils-Cu5hITuT.js';
import './helpers-Mu7LQT-w.js';
import './state-options-BX8GieXu.js';
import './package-BRJ4FIJH.js';
import './Api-BCeKXDaf.js';
import './badge-BrapPg3R.js';
import './parts-CKg_luIy.js';

const makeGetCheckouts = ({ accountId, authToken, service }) => async ({ params, onSuccess, onError }) => {
    var _a, _b;
    try {
        const response = await service.fetchCheckouts(accountId, authToken, params);
        if (!response.error) {
            const pagingInfo = Object.assign({}, response.page_info);
            const checkouts = ((_a = response.data) === null || _a === void 0 ? void 0 : _a.map((dataItem) => new Checkout(dataItem))) || [];
            onSuccess({ checkouts, pagingInfo });
        }
        else {
            const responseError = getErrorMessage(response.error);
            const code = getErrorCode((_b = response.error) === null || _b === void 0 ? void 0 : _b.code);
            return onError({
                error: responseError,
                code,
                severity: ComponentErrorSeverity.ERROR,
            });
        }
    }
    catch (error) {
        const code = getErrorCode(error === null || error === void 0 ? void 0 : error.code);
        return onError({
            error: error.message || error,
            code,
            severity: ComponentErrorSeverity.ERROR,
        });
    }
};

const CheckoutsList = class {
    constructor(hostRef) {
        registerInstance(this, hostRef);
        this.errorEvent = createEvent(this, "error-event");
        this.errorMessage = null;
        this.columns = defaultColumnsKeys;
        this.handleErrorEvent = (event) => {
            this.errorMessage = event.detail.message;
            this.errorEvent.emit(event.detail);
        };
    }
    componentWillLoad() {
        checkPkgVersion();
        this.analytics = new JustifiAnalytics(this);
        this.initializeGetData();
    }
    disconnectedCallback() {
        var _a;
        (_a = this.analytics) === null || _a === void 0 ? void 0 : _a.cleanup();
    }
    ;
    propChanged() {
        this.initializeGetData();
    }
    initializeGetData() {
        this.initializeGetCheckouts();
        this.initializeGetSubAccounts();
    }
    initializeGetCheckouts() {
        if (this.accountId && this.authToken) {
            this.getCheckouts = makeGetCheckouts({
                accountId: this.accountId,
                authToken: this.authToken,
                service: new CheckoutService()
            });
        }
        else {
            this.errorMessage = 'Account ID and Auth Token are required';
            this.errorEvent.emit({
                errorCode: ComponentErrorCodes.MISSING_PROPS,
                message: this.errorMessage,
                severity: ComponentErrorSeverity.ERROR,
            });
        }
    }
    initializeGetSubAccounts() {
        if (this.accountId && this.authToken) {
            this.getSubAccounts = makeGetSubAccounts({
                accountId: this.accountId,
                authToken: this.authToken,
                service: new SubAccountService()
            });
        }
    }
    render() {
        return (h(StyledHost, { key: 'b0c774c4f56f94cd6b4a3dc8651938f9f33ca94e' }, h("checkouts-list-core", { key: 'd524423a791f70c234044f5ba27d7bc3648fc988', getCheckouts: this.getCheckouts, getSubAccounts: this.getSubAccounts, "onError-event": this.handleErrorEvent, columns: this.columns })));
    }
    static get watchers() { return {
        "accountId": ["propChanged"],
        "authToken": ["propChanged"]
    }; }
};

export { CheckoutsList as justifi_checkouts_list };
