import { r as registerInstance, c as createEvent, h } from './index-N3w5zrz2.js';
import { D as DisputeManagementClickActions } from './event-types-Bg2SZArf.js';
import { D as Dispute, a as DisputeStatus } from './Dispute-BH0Xfn-F.js';

const DisputeManagementCore = class {
    constructor(hostRef) {
        registerInstance(this, hostRef);
        this.errorEvent = createEvent(this, "error-event");
        this.isLoading = true;
        this.showDisputeResponseForm = false;
    }
    disputeResponseHandler(event) {
        if (event.detail.name === DisputeManagementClickActions.respondToDispute) {
            this.showDisputeResponseForm = true;
        }
        if (event.detail.name === DisputeManagementClickActions.cancelDispute) {
            this.showDisputeResponseForm = false;
        }
    }
    disputeSubmittedHandler() {
        this.fetchData();
    }
    componentWillLoad() {
        if (this.getDispute) {
            this.fetchData();
        }
    }
    updateOnPropChange() {
        this.fetchData();
    }
    fetchData() {
        this.isLoading = true;
        this.getDispute({
            onSuccess: ({ dispute }) => {
                this.dispute = new Dispute(dispute);
                this.isLoading = false;
                if (this.dispute.status !== DisputeStatus.needsResponse) {
                    this.showDisputeResponseForm = false;
                }
            },
            onError: ({ error, code, severity }) => {
                this.errorEvent.emit({
                    errorCode: code,
                    message: error,
                    severity,
                });
                this.isLoading = false;
            },
        });
    }
    render() {
        return (h("div", { key: 'b5a802e8c418b3b7f3235f43260186084a6ee079' }, this.showDisputeResponseForm ? (h("justifi-dispute-response", { disputeId: this.disputeId, disputeResponse: this.dispute.dispute_response, authToken: this.authToken })) : (h("justifi-dispute-notification", { dispute: this.dispute, authToken: this.authToken, isLoading: this.isLoading }))));
    }
    static get watchers() { return {
        "getDispute": ["updateOnPropChange"]
    }; }
};

export { DisputeManagementCore as justifi_dispute_management_core };
