import { r as registerInstance, c as createEvent, h } from './index-N3w5zrz2.js';
import { f as formatCurrency } from './utils-Cu5hITuT.js';
import { D as text, am as heading4 } from './parts-CKg_luIy.js';
import { B as Button } from './button-BB-N4vit.js';
import { S as StyledHost } from './styled-host-DtvbNFVU.js';
import { S as Skeleton } from './skeleton-D1Z4a8af.js';
import './event-types-CZfYo5-1.js';
import { C as ComponentErrorSeverity, a as ComponentErrorCodes } from './ComponentError-BhrFjjAs.js';
import { g as getErrorCode, a as getErrorMessage } from './utils-BZvep88z.js';
import { D as DisputeService } from './dispute.service-bQh-LG0z.js';
import { D as DisputeManagementClickActions } from './event-types-Bg2SZArf.js';
import { c as checkPkgVersion, J as JustifiAnalytics } from './check-pkg-version-Cic-MeLf.js';
import './dinero-DizZAUMY.js';
import './_commonjsHelpers-BFTU3MAI.js';
import './Api-BCeKXDaf.js';
import './config-state-B3mtRA6f.js';
import './index-BAq5IUBW.js';
import './Refund-DBHZkemk.js';
import './Dispute-BH0Xfn-F.js';
import './Pagination-CLHwhyvu.js';
import './Business-BCoP0TAV.js';
import './helpers-Mu7LQT-w.js';
import './state-options-BX8GieXu.js';
import './package-BRJ4FIJH.js';

const makeUpdateDisputeResponse = ({ authToken, disputeId, service }) => async ({ payload, onSuccess, onError, final = () => { } }) => {
    var _a;
    try {
        const response = await service.updateDisputeResponse(disputeId, authToken, payload);
        if (!response.error) {
            onSuccess(response);
        }
        else {
            const responseError = getErrorMessage(response.error);
            const code = getErrorCode((_a = response.error) === null || _a === void 0 ? void 0 : _a.code);
            return onError({
                error: responseError,
                code,
                severity: ComponentErrorSeverity.ERROR,
            });
        }
    }
    catch (error) {
        const code = getErrorCode(error === null || error === void 0 ? void 0 : error.code);
        return onError({
            error: error.message || error,
            code,
            severity: ComponentErrorSeverity.ERROR,
        });
    }
    finally {
        return final();
    }
};
const makeSubmitDisputeResponse = ({ authToken, disputeId, service }) => async ({ payload, onSuccess, onError, final = () => { } }) => {
    var _a;
    try {
        const response = await service.submitDisputeResponse(disputeId, authToken, payload);
        if (!response.error) {
            onSuccess(response);
        }
        else {
            const responseError = getErrorMessage(response.error);
            const code = getErrorCode((_a = response.error) === null || _a === void 0 ? void 0 : _a.code);
            return onError({
                error: responseError,
                code,
                severity: ComponentErrorSeverity.ERROR,
            });
        }
    }
    catch (error) {
        const code = getErrorCode(error === null || error === void 0 ? void 0 : error.code);
        return onError({
            error: error.message || error,
            code,
            severity: ComponentErrorSeverity.ERROR,
        });
    }
    finally {
        return final();
    }
};
const makeCreateDisputeEvidence = ({ authToken, disputeId, service }) => async ({ payload, onSuccess, onError, final = () => { } }) => {
    var _a;
    try {
        const response = await service.createDisputeEvidence(disputeId, authToken, payload);
        if (!response.error) {
            onSuccess(response);
        }
        else {
            const responseError = getErrorMessage(response.error);
            const code = getErrorCode((_a = response.error) === null || _a === void 0 ? void 0 : _a.code);
            return onError({
                error: responseError,
                code,
                severity: ComponentErrorSeverity.ERROR,
            });
        }
    }
    catch (error) {
        const code = getErrorCode(error === null || error === void 0 ? void 0 : error.code);
        return onError({
            error: error.message || error,
            code,
            severity: ComponentErrorSeverity.ERROR,
        });
    }
    finally {
        return final();
    }
};

const DisputeNotification = class {
    constructor(hostRef) {
        registerInstance(this, hostRef);
        this.clickEvent = createEvent(this, "click-event");
        this.errorEvent = createEvent(this, "error-event");
        this.submitEvent = createEvent(this, "submit-event");
    }
    acceptDispute() {
        makeSubmitDisputeResponse({
            disputeId: this.dispute.id,
            authToken: this.authToken,
            service: new DisputeService()
        })({
            payload: { forfeit: true },
            onSuccess: (response) => {
                this.submitEvent.emit({ response: response });
            },
            onError: ({ error, code, severity }) => {
                this.errorEvent.emit({
                    errorCode: code,
                    message: error,
                    severity,
                });
            },
        });
    }
    initiateRespondToDispute() {
        this.clickEvent.emit({ name: DisputeManagementClickActions.respondToDispute });
    }
    render() {
        var _a, _b, _c, _d, _e, _f, _g;
        return (h(StyledHost, { key: '90d2506d5bde2ea478fa3575fc162bb356b67fac' }, this.isLoading && (h("div", { key: '4877ae22d3d8e312640b122c9107b6bdd8f924cb', style: { marginBottom: '8px' } }, h(Skeleton, { key: '31fa0717949bbc6aa49db1c6ae0e324099ae1de2', height: '28px', width: '70%', styles: { marginBottom: '16px' } }), h(Skeleton, { key: 'ac5179232cb9ee33d3f3e16d9f93536ecfbf46a5', height: '18px', styles: { marginBottom: '8px' } }), h(Skeleton, { key: 'c22a5e3b257d01f92de7f6188fa0758861abc747', height: '18px', styles: { marginBottom: '8px' } }))), ((_a = this.dispute) === null || _a === void 0 ? void 0 : _a.needsResponse) && (h("div", { key: 'be331b1a5e2fa0baf46bc593ef7ce4f5872abcff', part: text }, h("h1", { key: '8094c16d3b375f28ffe314613f21ae25b63e59ef', class: "h4", part: heading4 }, "This payment is disputed"), h("p", { key: 'd89ae665e1f9bd99c9338e2132c1dc56e5386696' }, "The cardholder is disputing this payment. You may accept this dispute, or proceed to provide evidence in a counter dispute."), h("h2", { key: '2786733eac76628019993e13473d1f43c0c395ed', class: "h5" }, "Dispute details"), h("div", { key: '663c28c46136bd56889b6ad0b9bfce9e5adbb590', class: "d-table gap-2" }, h("div", { key: 'dc688fad875d1591dcb7f31d423b61a3df2ff954', class: "d-table-row gap-2" }, h("span", { key: '442db7a6e95524ca6b092794c7a4a4d987c9866e', part: "detail-section-item-title", class: "fw-bold d-table-cell pe-4" }, "Amount"), h("span", { key: '0a31de8692c9b00f43fcf3c0508e4d00a221d096', part: "detail-section-item-data", class: "flex-1 d-table-cell text-wrap" }, formatCurrency((_b = this.dispute) === null || _b === void 0 ? void 0 : _b.amount))), h("div", { key: '9fe0c1a3d3350c36fca190ae748dafe24d41b5fc', class: "d-table-row gap-2" }, h("span", { key: '12165cb6671519130a5f2e0d8938aaa55e7e3ead', part: "detail-section-item-title", class: "fw-bold d-table-cell pe-4" }, "Reason"), h("span", { key: '4a37ca8a7d64b97142997bb50ec11d737ac6a882', part: "detail-section-item-data", class: "flex-1 d-table-cell text-wrap" }, (_c = this.dispute) === null || _c === void 0 ? void 0 : _c.reason)), h("div", { key: '4d9cf74a8ed26dd84e4ce7325d4b8703352362a4', class: "d-table-row gap-2" }, h("span", { key: '8c0eaa24ebec7703eb18384b0b1f2eae8a684b55', part: "detail-section-item-title", class: "fw-bold d-table-cell pe-4" }, "Dispute ID"), h("span", { key: '238813abf2ea0848e1fe817d5798b9b0d0b78ffc', part: "detail-section-item-data", class: "flex-1 d-table-cell text-wrap" }, (_d = this.dispute) === null || _d === void 0 ? void 0 : _d.id))), h("div", { key: 'd156a7e9bf0e7214ff2164fc09b12c0b8f1d2b36', class: "d-flex gap-2 mt-4 justify-content-end" }, h(Button, { key: '7822fd12dfc39bd2aced043956d012fd34cc1b01', variant: "secondary", onClick: () => this.acceptDispute() }, "Accept dispute"), h(Button, { key: '05132b3a6d1fc3d136dc227008ea1999330cdb96', variant: "primary", onClick: () => this.initiateRespondToDispute() }, "Counter dispute")))), ((_e = this.dispute) === null || _e === void 0 ? void 0 : _e.underReview) && (h("div", { key: 'b04dd0c34f608b75ea3997a9c28ce948fa9dba5c' }, h("h1", { key: 'ac2a13373315703e86247b6707097af7cf2e6757', class: "h4" }, "This payment is disputed and under review"), h("p", { key: '203aed553e01bbaebe44bb370a1d088c149cda06' }, "The cardholder is disputing this payment. A counter dispute has been submitted and is under review."))), ((_f = this.dispute) === null || _f === void 0 ? void 0 : _f.won) && (h("div", { key: '6325264f8ad7b6678825878ed59f03f90eee421a' }, h("h1", { key: '7b647ed77373884e0751de4fc39403211c249db6', class: "h4" }, "This payment was disputed"), h("p", { key: '2a5c1560d341af9b743234a058a1187f245a2ae8' }, "The cardholder disputed this payment and the card issuer has settled it in your favor."))), ((_g = this.dispute) === null || _g === void 0 ? void 0 : _g.lost) && (h("div", { key: 'a89e7f4d7e8926ed052023c7dbbbaf076a03ed9c' }, h("h1", { key: '534b560aa35dd43ba0eba668904ef70dc1a6954f', class: "h4" }, "This payment was disputed"), h("p", { key: '2381f2f6418b47dce67c498c56d5f3789add57dc' }, "The cardholder disputed this payment and the card issuer has settled it in their favor.")))));
    }
};

const DisputeResponse = class {
    constructor(hostRef) {
        registerInstance(this, hostRef);
        this.errorEvent = createEvent(this, "error-event");
        this.errorMessage = null;
        this.apiOrigin = "https://wc-proxy.justifi.ai";
        this.handleErrorEvent = (event) => {
            this.errorMessage = event.detail.message;
            this.errorEvent.emit(event.detail);
        };
    }
    componentWillLoad() {
        checkPkgVersion();
        this.analytics = new JustifiAnalytics(this);
        this.initializeDisputeServiceMethods();
    }
    disconnectedCallback() {
        var _a;
        (_a = this.analytics) === null || _a === void 0 ? void 0 : _a.cleanup();
    }
    ;
    propChanged() {
        this.initializeDisputeServiceMethods();
    }
    initializeDisputeServiceMethods() {
        if (this.disputeId && this.authToken) {
            this.updateDisputeResponse = makeUpdateDisputeResponse({
                disputeId: this.disputeId,
                authToken: this.authToken,
                service: new DisputeService()
            });
            this.createDisputeEvidence = makeCreateDisputeEvidence({
                disputeId: this.disputeId,
                authToken: this.authToken,
                service: new DisputeService()
            });
            this.submitDisputeResponse = makeSubmitDisputeResponse({
                disputeId: this.disputeId,
                authToken: this.authToken,
                service: new DisputeService()
            });
        }
        else {
            this.errorMessage = 'Account ID and Auth Token are required';
            this.errorEvent.emit({
                errorCode: ComponentErrorCodes.MISSING_PROPS,
                message: this.errorMessage,
                severity: ComponentErrorSeverity.ERROR,
            });
        }
    }
    render() {
        return (h(StyledHost, { key: 'b90f636418c3e11b046d36dee9accf345756b407' }, h("justifi-dispute-response-core", { key: 'ff6e510faad54506eda24b1d8dc94b67afc18014', "onError-event": this.handleErrorEvent, "dispute-id": this.disputeId, disputeResponse: this.disputeResponse, createDisputeEvidence: this.createDisputeEvidence, updateDisputeResponse: this.updateDisputeResponse, submitDisputeResponse: this.submitDisputeResponse })));
    }
    ;
    static get watchers() { return {
        "accountId": ["propChanged"],
        "authToken": ["propChanged"]
    }; }
};

const DisputeResponseCore = class {
    constructor(hostRef) {
        registerInstance(this, hostRef);
        this.clickEvent = createEvent(this, "click-event");
        this.errorEvent = createEvent(this, "error-event");
        this.stepCompleteEvent = createEvent(this, "complete-form-step-event");
        this.submitEvent = createEvent(this, "submit-event");
        this.disputeResponse = {};
        this.isLoading = false;
        this.documentList = [];
        this.documentErrors = {};
        this.currentStep = 0;
        this.componentStepMapping = [
            () => h("justifi-product-or-service", { ref: (el) => this.currentStepComponentRef = el, disputeResponse: this.disputeResponse, documentErrors: this.documentErrors }),
            () => h("justifi-customer-details", { ref: (el) => this.currentStepComponentRef = el, disputeResponse: this.disputeResponse, documentErrors: this.documentErrors }),
            () => h("justifi-cancellation-policy", { ref: (el) => this.currentStepComponentRef = el, disputeResponse: this.disputeResponse, documentErrors: this.documentErrors }),
            () => h("justifi-refund-policy", { ref: (el) => this.currentStepComponentRef = el, disputeResponse: this.disputeResponse, documentErrors: this.documentErrors }),
            () => h("justifi-duplicate-charge", { ref: (el) => this.currentStepComponentRef = el, disputeResponse: this.disputeResponse, documentErrors: this.documentErrors }),
            () => h("justifi-electronic-evidence", { ref: (el) => this.currentStepComponentRef = el, disputeResponse: this.disputeResponse, documentErrors: this.documentErrors }),
            () => h("justifi-shipping-details", { ref: (el) => this.currentStepComponentRef = el, disputeResponse: this.disputeResponse, documentErrors: this.documentErrors }),
            () => h("justifi-additional-statement", { ref: (el) => this.currentStepComponentRef = el, disputeResponse: this.disputeResponse, documentErrors: this.documentErrors }),
        ];
        this.saveData = async (formData, formStep) => {
            const hasFormData = Object.keys(formData).length;
            if (!hasFormData) {
                this.stepCompleteEvent.emit({ response: null, formStep: formStep });
                return;
            }
            if (this.isLastStep) {
                return this.submitDisputeResponse({
                    payload: formData,
                    onSuccess: (response) => {
                        this.submitEvent.emit({ response: response });
                        this.stepCompleteEvent.emit({ response: response, formStep: formStep });
                    },
                    onError: ({ error, code, severity }) => {
                        this.errorEvent.emit({
                            errorCode: code,
                            message: error,
                            severity,
                        });
                    },
                });
            }
            else {
                return this.updateDisputeResponse({
                    payload: formData,
                    onSuccess: (response) => {
                        this.disputeResponse = Object.assign({}, response.data);
                        this.stepCompleteEvent.emit({ response: response, formStep: formStep });
                    },
                    onError: ({ error, code, severity }) => {
                        this.errorEvent.emit({
                            errorCode: code,
                            message: error,
                            severity,
                        });
                    },
                });
            }
        };
        this.initializeMakePresignedURLs = async () => {
            const presignedUrlPromises = this.documentList.map((document) => {
                return this.getPresignedFileUrl(document);
            });
            return await Promise.all(presignedUrlPromises);
        };
        this.initializeFileUploads = async () => {
            const uploadDocumentPromises = this.documentList.map((document) => {
                return this.uploadDocument(document);
            });
            return Promise.all(uploadDocumentPromises);
        };
        this.getPresignedFileUrl = async (document) => {
            return this.createDisputeEvidence({
                payload: {
                    file_name: document.file_name,
                    file_type: document.file_type,
                    dispute_evidence_type: document.dispute_evidence_type,
                },
                onSuccess: (response) => {
                    document.presignedUrl = response.data.presigned_url;
                },
                onError: ({ error, code, severity }) => {
                    const errors = { [document.dispute_evidence_type]: error };
                    this.documentErrors = Object.assign(Object.assign({}, this.documentErrors), errors);
                    this.errorEvent.emit({
                        errorCode: code,
                        message: error,
                        severity,
                    });
                },
            });
        };
        this.uploadDocument = async (document) => {
            const fileData = await document.getFileString();
            if (!document.presignedUrl) {
                throw new Error('Presigned URL is not set');
            }
            const response = await fetch(document.presignedUrl, {
                method: 'PUT',
                body: fileData,
            });
            return response;
        };
        this.handleSubmit = async (formData, documentList, formStep) => {
            this.isLoading = true;
            if (documentList.length) {
                this.documentErrors = {};
                this.documentList = documentList;
                await this.initializeMakePresignedURLs();
                const hasPresigningErrors = Object.keys(this.documentErrors).length;
                if (hasPresigningErrors) {
                    this.isLoading = false;
                    throw new Error('Could not presign all documents');
                }
                await this.initializeFileUploads();
            }
            // this needs to happen last because it fires the 'submit-event' and 'complete-form-step-event' event
            await this.saveData(formData, formStep);
            this.isLoading = false;
        };
        this.onCancel = () => {
            this.clickEvent.emit({ name: DisputeManagementClickActions.cancelDispute });
        };
        // after each of these steps where validateAndSubmit is called, reload the dispute
        // and set isLoading, and pass defaults into each step
        this.onBack = async () => {
            await this.currentStepComponentRef.validateAndSubmit(async (formData, documentList, formStep) => {
                this.clickEvent.emit({ name: DisputeManagementClickActions.previousStep });
                await this.handleSubmit(formData, documentList, formStep);
                this.currentStep--;
            });
        };
        this.onNext = async () => {
            await this.currentStepComponentRef.validateAndSubmit(async (formData, documentList, formStep) => {
                this.clickEvent.emit({ name: DisputeManagementClickActions.nextStep });
                await this.handleSubmit(formData, documentList, formStep);
                this.currentStep++;
            });
        };
        this.onSubmit = async () => {
            await this.currentStepComponentRef.validateAndSubmit(async (formData, documentList, formStep) => {
                this.clickEvent.emit({ name: DisputeManagementClickActions.submit });
                const submitData = Object.assign(Object.assign({}, formData), { forfeit: false });
                await this.handleSubmit(submitData, documentList, formStep);
            });
        };
    }
    get currentStepComponent() {
        return this.componentStepMapping[this.currentStep]();
    }
    get isLastStep() {
        return this.currentStep === this.componentStepMapping.length - 1;
    }
    get isFirstStep() {
        return this.currentStep === 0;
    }
    render() {
        return (h("div", { key: '09b09843d54a2dbced9788d16e244b2e59a3a78f', class: "row gy-3" }, h("div", { key: '6a3fe32d65ea1a74161d9ba9984543cf950e47ea', class: "col-12" }, h("h1", { key: 'bbb6f1334fd6b120e592117ba191d90b628e620f', class: "h4", part: heading4 }, "Counter dispute")), h("div", { key: '19cbc45842294e9344dbffb725f5f053bf370af7', class: "col-12" }, this.currentStepComponent), h("div", { key: 'fa875ca152ea77fc4c8363216d8ba16c7699b597', class: "col-12" }, h("div", { key: 'fa7b62fff0cbac81c19ebad919f5dd54c3679e84', class: "d-flex gap-2 mt-4 justify-content-end" }, this.isFirstStep ? (h(Button, { variant: "secondary", onClick: () => this.onCancel(), disabled: this.isLoading, isLoading: this.isLoading }, "Cancel")) : (h(Button, { variant: "secondary", onClick: () => this.onBack(), disabled: this.isLoading, isLoading: this.isLoading }, "Back")), this.isLastStep ? (h(Button, { variant: "primary", onClick: () => this.onSubmit(), disabled: this.isLoading, isLoading: this.isLoading }, "Submit Counter Dispute")) : (h(Button, { variant: "primary", onClick: () => this.onNext(), disabled: this.isLoading, isLoading: this.isLoading }, "Next"))))));
    }
};

export { DisputeNotification as justifi_dispute_notification, DisputeResponse as justifi_dispute_response, DisputeResponseCore as justifi_dispute_response_core };
