import { r as registerInstance, c as createEvent, h } from './index-N3w5zrz2.js';
import { c as makeGetIdentity, d as makePatchIdentity, e as makePostIdentity } from './payment-provisioning-actions-2qP7AtHj.js';
import { I as IdentityService } from './business.service-BPBxsb8B.js';
import { F as FormController } from './index.esm-BCNUj0Dx.js';
import { O as Owner } from './Business-BCoP0TAV.js';
import { i as identitySchema } from './business-identity-schema-BsrgqgDl.js';
import { B as Button } from './button-BB-N4vit.js';
import { ai as heading3 } from './parts-CKg_luIy.js';
import './event-types-CZfYo5-1.js';
import { B as BusinessFormClickActions } from './event-types-XYgDHrVL.js';
import { S as SSN_MASK, P as PHONE_MASKS } from './form-input-masks-B-iV5cYd.js';
import { u as updateFormValues, a as updateAddressFormValues, b as updateDateOfBirthFormValues } from './input-handlers-CX6mSvOM.js';
import './ComponentError-BhrFjjAs.js';
import './utils-BZvep88z.js';
import './Api-BCeKXDaf.js';
import './config-state-B3mtRA6f.js';
import './index-BAq5IUBW.js';
import './utils-Cu5hITuT.js';
import './dinero-DizZAUMY.js';
import './_commonjsHelpers-BFTU3MAI.js';
import './Refund-DBHZkemk.js';
import './Dispute-BH0Xfn-F.js';
import './Pagination-CLHwhyvu.js';
import './helpers-Mu7LQT-w.js';
import './state-options-BX8GieXu.js';
import './schema-validations-DLWfpHyI.js';
import './business-form-options-CgssATyg.js';

const BusinessOwnerForm = class {
    constructor(hostRef) {
        registerInstance(this, hostRef);
        this.errorEvent = createEvent(this, "error-event");
    }
    async validate() {
        return this.coreComponent.validate();
    }
    async submit() {
        return this.coreComponent.submit();
    }
    async validateAndSubmit({ onSuccess }) {
        this.coreComponent.validateAndSubmit({ onSuccess });
    }
    componentWillLoad() {
        this.initializeApi();
    }
    initializeApi() {
        if (!this.authToken) {
            return;
        }
        this.getOwner = makeGetIdentity({
            authToken: this.authToken,
            identityId: this.ownerId,
            service: new IdentityService()
        });
        this.patchOwner = makePatchIdentity({
            authToken: this.authToken,
            identityId: this.ownerId,
            service: new IdentityService()
        });
        this.postOwner = makePostIdentity({
            authToken: this.authToken,
            service: new IdentityService()
        });
    }
    render() {
        return (h("owner-form-core", { key: '07ad7cd2bb38442dc591c9e3421223294690ee8c', ownerId: this.ownerId, businessId: this.businessId, getOwner: this.getOwner, patchOwner: this.patchOwner, postOwner: this.postOwner, allowOptionalFields: this.allowOptionalFields, removeOwner: this.removeOwner, newFormOpen: this.newFormOpen, ownersLength: this.ownersLength, ref: ref => this.coreComponent = ref }));
    }
};

const BusinessOwnerFormCore = class {
    loadingWatcher() {
        this.formLoading.emit(this.isLoading);
    }
    constructor(hostRef) {
        registerInstance(this, hostRef);
        this.clickEvent = createEvent(this, "click-event");
        this.errorEvent = createEvent(this, "error-event");
        this.formLoading = createEvent(this, "formLoading");
        this.ownerSubmitted = createEvent(this, "ownerSubmitted");
        this.isLoading = false;
        this.errors = {};
        this.owner = {};
        this.getData = () => {
            this.isLoading = true;
            this.getOwner({
                onSuccess: (response) => {
                    this.instantiateOwner(response.data);
                },
                onError: ({ error, code, severity }) => {
                    this.errorEvent.emit({
                        message: error,
                        errorCode: code,
                        severity: severity
                    });
                },
                final: () => this.isLoading = false
            });
        };
        this.sendData = () => {
            this.isLoading = true;
            return new Promise((resolve) => {
                if (this.ownerId) {
                    this.patchOwner({
                        payload: this.payload,
                        onSuccess: (response) => {
                            this.ownerSubmitted.emit({ id: response.data.id });
                            this.instantiateOwner(response.data);
                            resolve(true);
                        },
                        onError: ({ error, code, severity }) => {
                            this.errorEvent.emit({
                                message: error,
                                errorCode: code,
                                severity: severity
                            });
                            resolve(false);
                        },
                        final: () => this.isLoading = false
                    });
                }
                else {
                    this.postOwner({
                        payload: this.payload,
                        onSuccess: (response) => {
                            this.ownerSubmitted.emit({ id: response.data.id });
                            this.instantiateOwner(response.data);
                            resolve(true);
                        },
                        onError: ({ error, code, severity }) => {
                            this.errorEvent.emit({
                                message: error,
                                errorCode: code,
                                severity: severity
                            });
                            resolve(false);
                        },
                        final: () => this.isLoading = false
                    });
                }
            });
        };
        this.instantiateOwner = async (data) => {
            this.owner = Object.assign({}, new Owner(data));
            await this.formController.setInitialValues(this.owner);
        };
        this.handleAddOwner = () => {
            const eventName = this.ownerId ? BusinessFormClickActions.updateOwner : BusinessFormClickActions.addOwner;
            this.clickEvent.emit({ name: eventName });
        };
        this.handleRemoveOwner = () => {
            this.removeOwner(this.ownerId);
            this.clickEvent.emit({ name: BusinessFormClickActions.removeOwner });
        };
        this.validate = this.validate.bind(this);
        this.submit = this.submit.bind(this);
        this.validateAndSubmit = this.validateAndSubmit.bind(this);
    }
    async returnOwnerData() {
        return this.ownerId;
    }
    async validate() {
        return this.formController.validate();
    }
    async submit() {
        const isValid = await this.validate();
        if (isValid) {
            return this.sendData();
        }
    }
    async validateAndSubmit(event) {
        event.preventDefault();
        const isValid = await this.validate();
        if (isValid) {
            this.submit();
        }
    }
    get payload() {
        let formValues = new Owner(this.formController.values.getValue()).payload;
        if (this.ownerId) {
            return formValues;
        }
        else {
            return Object.assign(Object.assign({}, formValues), { business_id: this.businessId });
        }
    }
    get formTitle() {
        return this.ownerId ? 'Edit Business Owner' : 'Add Business Owner';
    }
    get submitButtonText() {
        return this.ownerId ? 'Update' : 'Add';
    }
    get showRemoveButton() {
        const blankForm = !this.ownerId && this.newFormOpen;
        if (this.ownersLength <= 1) {
            return false;
        }
        else {
            if (blankForm) {
                return true;
            }
            else if (this.ownerId && !this.newFormOpen) {
                return true;
            }
        }
    }
    componentWillLoad() {
        this.formController = new FormController(identitySchema('owner', this.allowOptionalFields));
        this.ownerId ? this.getData() : this.instantiateOwner({});
    }
    componentDidLoad() {
        this.formController.errors.subscribe(errors => (this.errors = Object.assign({}, errors)));
    }
    render() {
        return (h("form", { key: '570c20c1fdf79268e6c8193a393515c8602a3a44', onSubmit: this.validateAndSubmit }, h("fieldset", { key: 'f4f75a735438baef254d4578b779ca16e5080a41' }, h("legend", { key: 'dc0c83a7ada9f908afec56d7560f7d9d116baa40', class: "fw-semibold fs-5", part: heading3 }, this.formTitle), h("br", { key: '5d97c0b38073618aef80ff9576cd57ab0e70d44e' }), h("div", { key: 'b15a207a4c4afc1249ce3b8a381e7b57ceb32e7a', class: "row gy-3" }, h("owner-form-inputs", { key: '21bd3e9b00580e7293338ad746c189d19ac3d98e', ownerDefaultValue: this.formController.getInitialValues(), errors: this.errors, formController: this.formController }), h("div", { key: 'b4653d9b78094b15bfba61e3a18ea3703dc53162', class: "d-flex gap-2 justify-content-start" }, h(Button, { key: '0328aa7af6e3c2f7ed8aa16724dedcb576bb9870', variant: "secondary", type: "button", onClick: this.handleRemoveOwner, hidden: !this.showRemoveButton }, "Remove"), h(Button, { key: 'e42671667156149d5424243eef1d6675a3bd6506', variant: "primary", type: "submit", onClick: this.handleAddOwner, disabled: this.isLoading }, this.submitButtonText))), h("hr", { key: 'ee7bf4cdb63cdc31df8b307ffb1772e5c0f0348c' }))));
    }
    static get watchers() { return {
        "isLoading": ["loadingWatcher"]
    }; }
};

const BusinessOwnerFormInputs = class {
    constructor(hostRef) {
        registerInstance(this, hostRef);
        this.inputHandler = (name, value) => {
            updateFormValues(this.formController, { [name]: value });
        };
        this.onAddressFormUpdate = (values) => {
            updateAddressFormValues(this.formController, Object.assign(Object.assign({}, this.formController.values.getValue().address), values));
        };
    }
    render() {
        return (h("div", { key: '86abe1713fdfd297e88c1fc1734fadb2c9eab966', class: "row gy-3" }, h("div", { key: '63a03271f2a777d4cede3b0790e11c7f4108797f', class: "col-12 col-md-8" }, h("form-control-text", { key: 'b86dd9184dbf50e00e047a733ff708526e32d6dc', name: "name", label: "Full Name", defaultValue: this.ownerDefaultValue.name, errorText: this.errors.name, inputHandler: this.inputHandler })), h("div", { key: 'c3850b7425ca0d8a118a6b78933f3a2fbe343124', class: "col-12 col-md-4" }, h("form-control-text", { key: 'f1f6e801eb36bcae5f2e51f8cd4ea9b7ed6a34a8', name: "title", label: "Title", defaultValue: this.ownerDefaultValue.title, errorText: this.errors.title, inputHandler: this.inputHandler, helpText: "Role at your business, e.g. President, CEO, Treasurer." })), h("div", { key: 'b07a8a86dbdef296c9438953ef311ccae3aed23c', class: "col-12 col-md-6" }, h("form-control-text", { key: '714ca04b0bf0e5ed1b116b8f4963ba12f7fd6b77', name: "email", label: "Email Address", defaultValue: this.ownerDefaultValue.email, errorText: this.errors.email, inputHandler: this.inputHandler })), h("div", { key: '46c11c80bb58d0190ff05f1e87ba962443b07c59', class: "col-12 col-md-6" }, h("form-control-number-masked", { key: '6da40db9fb8b3e4f3a744cd0426f4e6436350594', name: "phone", label: "Phone Number", defaultValue: this.ownerDefaultValue.phone, errorText: this.errors.phone, inputHandler: this.inputHandler, mask: PHONE_MASKS.US })), h("div", { key: '0960ea2fb399d0098caeabf45347a89c74066f57', class: "col-12 col-md-4" }, h("form-control-date", { key: 'fe0891a3f42c093d70db1dd1d1a7e121ba3091c1', name: "dob_full", label: "Birth Date", defaultValue: this.ownerDefaultValue.dob_full, errorText: this.errors.dob_full, inputHandler: this.inputHandler, onFormControlInput: (e) => updateDateOfBirthFormValues(e, this.formController), helpText: "Must be 18 or older." })), h("div", { key: 'e7cbc519fa6f4fa5b03a0d0b69c7d7f1c42185ff', class: "col-12 col-md-8" }, h("form-control-number-masked", { key: 'cf2b280c1560bd1a9f80cf81c1543d41bd807233', name: "identification_number", label: "SSN", defaultValue: this.ownerDefaultValue.identification_number, errorText: this.errors.identification_number, inputHandler: this.inputHandler, mask: SSN_MASK, helpText: "Enter your full Social Security Number. It is required for Federal OFAC check." })), h("div", { key: '1755c849992bfd9f459b65b4cf7e967039fdbe27', class: "col-12" }, h("justifi-identity-address-form", { key: 'ac5372d4a9fad8ee3cfe2af20c11868e8753cc35', errors: this.errors.address, defaultValues: this.ownerDefaultValue.address, handleFormUpdate: this.onAddressFormUpdate }))));
    }
    ;
};

export { BusinessOwnerForm as justifi_owner_form, BusinessOwnerFormCore as owner_form_core, BusinessOwnerFormInputs as owner_form_inputs };
