import { r as registerInstance, c as createEvent, h } from './index-N3w5zrz2.js';
import { P as PayoutService } from './payout.service-j8w34GsW.js';
import './config-state-B3mtRA6f.js';
import './dinero-DizZAUMY.js';
import { C as ComponentErrorSeverity, a as ComponentErrorCodes } from './ComponentError-BhrFjjAs.js';
import { e as Payout } from './Refund-DBHZkemk.js';
import './Pagination-CLHwhyvu.js';
import './Business-BCoP0TAV.js';
import './Dispute-BH0Xfn-F.js';
import { g as getErrorCode, a as getErrorMessage } from './utils-BZvep88z.js';
import { E as ErrorState } from './utils-sZ_6zOKQ.js';
import { c as checkPkgVersion, J as JustifiAnalytics } from './check-pkg-version-Cic-MeLf.js';
import { m as makeGetPayoutCSV } from './get-payout-csv-U_pgdPpb.js';
import './Api-BCeKXDaf.js';
import './utils-Cu5hITuT.js';
import './index-BAq5IUBW.js';
import './_commonjsHelpers-BFTU3MAI.js';
import './helpers-Mu7LQT-w.js';
import './state-options-BX8GieXu.js';
import './parts-CKg_luIy.js';
import './package-BRJ4FIJH.js';

const makeGetPayoutDetails = ({ id, authToken, service }) => async ({ onSuccess, onError }) => {
    var _a;
    try {
        const response = await service.fetchPayout(id, authToken);
        if (!response.error) {
            const payout = new Payout(response.data);
            onSuccess(payout);
        }
        else {
            const errorMessage = getErrorMessage(response.error);
            const code = getErrorCode((_a = response.error) === null || _a === void 0 ? void 0 : _a.code);
            onError({
                error: errorMessage,
                code,
                severity: ComponentErrorSeverity.ERROR,
            });
        }
    }
    catch (error) {
        const errorMessage = getErrorMessage(error);
        const code = getErrorCode(error === null || error === void 0 ? void 0 : error.code);
        onError({
            error: errorMessage,
            code,
            severity: ComponentErrorSeverity.ERROR,
        });
    }
};

const PayoutDetails = class {
    constructor(hostRef) {
        registerInstance(this, hostRef);
        this.errorEvent = createEvent(this, "error-event");
        this.errorMessage = null;
        this.handleErrorEvent = (event) => {
            this.errorMessage = event.detail.message;
            this.errorEvent.emit(event.detail);
        };
    }
    componentWillLoad() {
        checkPkgVersion();
        this.analytics = new JustifiAnalytics(this);
        this.initializeServices();
    }
    disconnectedCallback() {
        var _a;
        (_a = this.analytics) === null || _a === void 0 ? void 0 : _a.cleanup();
    }
    ;
    propChanged() {
        this.initializeServices();
    }
    initializeServices() {
        if (this.payoutId && this.authToken) {
            this.getPayout = makeGetPayoutDetails({
                id: this.payoutId,
                authToken: this.authToken,
                service: new PayoutService()
            });
            this.getPayoutCSV = makeGetPayoutCSV({
                authToken: this.authToken,
                service: new PayoutService()
            });
        }
        else {
            this.errorMessage = 'Failed to load payout details. payoutId or authToken is not provided.';
            this.errorEvent.emit({
                message: this.errorMessage,
                errorCode: ComponentErrorCodes.MISSING_PROPS,
                severity: ComponentErrorSeverity.ERROR
            });
        }
    }
    render() {
        if (this.errorMessage) {
            return ErrorState(this.errorMessage);
        }
        return (h("payout-details-core", { getPayout: this.getPayout, getPayoutCSV: this.getPayoutCSV, "onError-event": this.handleErrorEvent }));
    }
    static get watchers() { return {
        "payoutId": ["propChanged"],
        "authToken": ["propChanged"]
    }; }
};

export { PayoutDetails as justifi_payout_details };
