import { r as registerInstance, c as createEvent, h } from './index-N3w5zrz2.js';
import { C as ComponentErrorSeverity, a as ComponentErrorCodes } from './ComponentError-BhrFjjAs.js';
import { c as checkPkgVersion, J as JustifiAnalytics } from './check-pkg-version-Cic-MeLf.js';
import { P as PayoutService } from './payout.service-j8w34GsW.js';
import './config-state-B3mtRA6f.js';
import './dinero-DizZAUMY.js';
import { e as Payout } from './Refund-DBHZkemk.js';
import './Pagination-CLHwhyvu.js';
import './Business-BCoP0TAV.js';
import './Dispute-BH0Xfn-F.js';
import { g as getErrorCode, a as getErrorMessage } from './utils-BZvep88z.js';
import { m as makeGetPayoutCSV } from './get-payout-csv-U_pgdPpb.js';
import { m as makeGetSubAccounts, S as SubAccountService } from './get-subaccounts-DcgISPei.js';
import { S as StyledHost } from './styled-host-DtvbNFVU.js';
import './event-types-CZfYo5-1.js';
import { d as defaultColumnsKeys } from './payouts-table-DRISll8u.js';
import './package-BRJ4FIJH.js';
import './Api-BCeKXDaf.js';
import './utils-Cu5hITuT.js';
import './index-BAq5IUBW.js';
import './_commonjsHelpers-BFTU3MAI.js';
import './helpers-Mu7LQT-w.js';
import './state-options-BX8GieXu.js';
import './payouts-status-DB_PJap6.js';
import './badge-BrapPg3R.js';
import './parts-CKg_luIy.js';

const makeGetPayouts = ({ id, authToken, service }) => async ({ params, onSuccess, onError }) => {
    var _a, _b;
    try {
        const response = await service.fetchPayouts(id, authToken, params);
        if (!response.error) {
            const pagingInfo = Object.assign({}, response.page_info);
            const payouts = ((_a = response.data) === null || _a === void 0 ? void 0 : _a.map((dataItem) => new Payout(dataItem))) || [];
            onSuccess({ payouts, pagingInfo });
        }
        else {
            const error = getErrorMessage(response.error);
            const code = getErrorCode((_b = response.error) === null || _b === void 0 ? void 0 : _b.code);
            return onError({
                error,
                code,
                severity: ComponentErrorSeverity.ERROR,
            });
        }
    }
    catch (error) {
        const code = getErrorCode(error === null || error === void 0 ? void 0 : error.code);
        return onError({
            error: error.message || error,
            code,
            severity: ComponentErrorSeverity.ERROR,
        });
    }
};

const PayoutsList = class {
    constructor(hostRef) {
        registerInstance(this, hostRef);
        this.errorEvent = createEvent(this, "error-event");
        this.errorMessage = null;
        this.columns = defaultColumnsKeys;
        this.handleOnError = (event) => {
            this.errorMessage = event.detail.message;
            this.errorEvent.emit(event.detail);
        };
    }
    componentWillLoad() {
        checkPkgVersion();
        this.analytics = new JustifiAnalytics(this);
        this.initializeGetData();
    }
    disconnectedCallback() {
        var _a;
        (_a = this.analytics) === null || _a === void 0 ? void 0 : _a.cleanup();
    }
    ;
    propChanged() {
        this.initializeGetData();
    }
    initializeGetData() {
        this.initializePayoutsServices();
        this.initializeGetSubAccounts();
    }
    initializePayoutsServices() {
        if (this.accountId && this.authToken) {
            const serviceParams = {
                id: this.accountId,
                authToken: this.authToken,
                service: new PayoutService()
            };
            this.getPayouts = makeGetPayouts(serviceParams);
            this.getPayoutCSV = makeGetPayoutCSV(serviceParams);
        }
        else {
            this.errorMessage = 'Account ID and Auth Token are required';
            this.errorEvent.emit({
                errorCode: ComponentErrorCodes.MISSING_PROPS,
                message: this.errorMessage,
                severity: ComponentErrorSeverity.ERROR,
            });
        }
    }
    initializeGetSubAccounts() {
        if (this.accountId && this.authToken) {
            this.getSubAccounts = makeGetSubAccounts({
                accountId: this.accountId,
                authToken: this.authToken,
                service: new SubAccountService()
            });
        }
    }
    render() {
        return (h(StyledHost, { key: 'b01ebbd64e4f09083663f01429c3d19ca9790c4d' }, h("payouts-list-core", { key: 'ee137e4322ef9ccf567b4172b0b8831dc18b38eb', getPayouts: this.getPayouts, getPayoutCSV: this.getPayoutCSV, getSubAccounts: this.getSubAccounts, "onError-event": this.handleOnError, columns: this.columns })));
    }
    static get watchers() { return {
        "accountId": ["propChanged"],
        "authToken": ["propChanged"]
    }; }
};

export { PayoutsList as justifi_payouts_list };
