import { h, r as registerInstance, c as createEvent } from './index-N3w5zrz2.js';
import { c as create$3, a as create$6, F as FormController } from './index.esm-BCNUj0Dx.js';
import { f as formatCurrency } from './utils-Cu5hITuT.js';
import './config-state-B3mtRA6f.js';
import { C as ComponentErrorSeverity, a as ComponentErrorCodes } from './ComponentError-BhrFjjAs.js';
import { R as RefundReasons, k as RefundPayload } from './Refund-DBHZkemk.js';
import './Pagination-CLHwhyvu.js';
import './Business-BCoP0TAV.js';
import './Dispute-BH0Xfn-F.js';
import { B as Button } from './button-BB-N4vit.js';
import { S as StyledHost } from './styled-host-DtvbNFVU.js';
import './event-types-CZfYo5-1.js';
import { P as PaymentService } from './payment.service-BTVtIbcY.js';
import { m as makeGetPaymentDetails } from './get-payment-details-B193kh7P.js';
import { c as checkPkgVersion, J as JustifiAnalytics } from './check-pkg-version-Cic-MeLf.js';
import { g as getErrorCode, a as getErrorMessage } from './utils-BZvep88z.js';
import { A as Api } from './Api-BCeKXDaf.js';
import { S as Skeleton } from './skeleton-D1Z4a8af.js';
import './_commonjsHelpers-BFTU3MAI.js';
import './dinero-DizZAUMY.js';
import './index-BAq5IUBW.js';
import './helpers-Mu7LQT-w.js';
import './state-options-BX8GieXu.js';
import './parts-CKg_luIy.js';
import './package-BRJ4FIJH.js';

const amountValidation = (maxAmount) => {
    const max = +maxAmount;
    return (create$6()
        .required('Amount is required')
        .test('max-amount', `Refund amount cannot be more than payment amount: ${formatCurrency(max)}`, function (value) {
        return +value <= +max;
    })
        .test('min-amount', 'Refund amount must be greater than 0', function (value) {
        return +value > 0;
    }));
};
const RefundPaymentSchema = (maxRefundAmount) => {
    if (!maxRefundAmount) {
        return;
    }
    const schema = create$3({
        amount: amountValidation(maxRefundAmount),
        description: create$6().optional(),
        reason: create$6().optional()
            .oneOf([
            RefundReasons.customerRequest,
            RefundReasons.duplicate,
            RefundReasons.fraudulent,
        ], 'Select a reason')
    });
    return schema;
};

const refundReasonOptions = [
    {
        label: 'Select a reason',
        value: '',
    },
    {
        label: 'Customer requested a refund',
        value: 'customer_request',
    },
    {
        label: 'Customer was double-charged',
        value: 'duplicate',
    },
    {
        label: 'Payment was reported as fraud',
        value: 'fraudulent',
    }
];

const makePostRefund = ({ authToken, accountId, paymentId, service }) => async ({ refundBody, onSuccess, onError, final }) => {
    var _a;
    try {
        const response = await service.postRefund(paymentId, accountId, authToken, refundBody);
        if (!response.error) {
            onSuccess(response);
        }
        else {
            const responseError = getErrorMessage(response.error);
            const code = getErrorCode((_a = response.error) === null || _a === void 0 ? void 0 : _a.code);
            return onError({
                error: responseError,
                code,
                severity: ComponentErrorSeverity.ERROR,
            });
        }
    }
    catch (error) {
        const code = getErrorCode(error === null || error === void 0 ? void 0 : error.code);
        return onError({
            error: error.message || error,
            code,
            severity: ComponentErrorSeverity.ERROR,
        });
    }
    finally {
        return final();
    }
};

const api = Api();
class RefundService {
    async postRefund(paymentId, accountId, authToken, refundBody) {
        const endpoint = `payments/${paymentId}/refunds`;
        const headers = { 'Sub-Account': accountId };
        const body = refundBody;
        return api.post({ endpoint, headers, body, authToken });
    }
}

const FormBlock = () => (h("div", { class: "row gap-3" },
    h("div", { class: "col-12" },
        h(Skeleton, { width: "100%", height: "40px" }))));
const RefundLoading = () => {
    return (h(StyledHost, null,
        h("div", { class: "row gap-5" },
            h(FormBlock, null),
            h(FormBlock, null),
            h(FormBlock, null))));
};

const RefundPayment = class {
    constructor(hostRef) {
        registerInstance(this, hostRef);
        this.errorEvent = createEvent(this, "error-event");
        this.submitEvent = createEvent(this, "submit-event");
        this.refundPayload = {};
        this.displayAmount = '';
        this.errors = {};
        this.paymentLoading = true;
        this.refundLoading = false;
        this.hideSubmitButton = false;
        this.inputHandler = (name, value) => {
            this.formController.setValues(Object.assign(Object.assign({}, this.formController.values.getValue()), { [name]: value }));
        };
    }
    componentWillLoad() {
        checkPkgVersion();
        this.analytics = new JustifiAnalytics(this);
        this.initializeApi();
        this.formController = new FormController(RefundPaymentSchema());
    }
    handleError(code, errorMessage, severity) {
        this.errorEvent.emit({ errorCode: code, message: errorMessage, severity });
    }
    checkAmount(amount) {
        return amount > 0;
    }
    handleInvalidAmount() {
        this.submitDisabled = true;
        const errorMessage = 'Refund amount must be greater than 0';
        this.handleError(ComponentErrorCodes.INVALID_REFUND_AMOUNT, errorMessage, ComponentErrorSeverity.ERROR);
    }
    initializeFormController() {
        const amount = this.refundPayload.amount;
        const amountRefundable = amount ? amount.toString() : '0';
        this.formController = new FormController(RefundPaymentSchema(amountRefundable));
        this.formController.setInitialValues({
            amount: amountRefundable
        });
        this.formController.values.subscribe(values => {
            this.refundPayload = Object.assign({}, values);
        });
        this.formController.errors.subscribe(errors => {
            this.errors = Object.assign({}, errors);
        });
    }
    initializeApi() {
        if (this.paymentId && this.authToken) {
            const getPayment = makeGetPaymentDetails({
                id: this.paymentId,
                authToken: this.authToken,
                service: new PaymentService()
            });
            getPayment({
                onSuccess: ({ payment }) => {
                    this.refundPayload = new RefundPayload({ amount: payment.amount_refundable });
                },
                onError: ({ error, code, severity }) => {
                    this.handleError(code, error, severity);
                },
                final: () => {
                    const amount = this.refundPayload.amount;
                    const validAmount = this.checkAmount(amount);
                    !validAmount ? this.handleInvalidAmount() : this.initializeFormController();
                    this.paymentLoading = false;
                }
            });
        }
        else {
            const errorMessage = 'Payment ID and Auth Token are required';
            this.handleError(ComponentErrorCodes.MISSING_PROPS, errorMessage, ComponentErrorSeverity.ERROR);
        }
    }
    async refundPayment(event) {
        event && event.preventDefault();
        const valid = await this.formController.validate();
        if (!valid)
            return;
        const postRefund = makePostRefund({
            authToken: this.authToken,
            accountId: this.accountId,
            paymentId: this.paymentId,
            service: new RefundService()
        });
        const values = this.formController.values.getValue();
        this.refundLoading = true;
        return new Promise((resolve) => {
            let refundResponse;
            postRefund({
                refundBody: values,
                onSuccess: (response) => { refundResponse = response; },
                onError: ({ error, code, severity }) => {
                    refundResponse = error;
                    this.handleError(error, code, severity);
                },
                final: () => {
                    this.submitEvent.emit({ response: refundResponse });
                    this.submitDisabled = true;
                    this.refundLoading = false;
                    resolve(refundResponse.data);
                },
            });
        });
    }
    render() {
        if (this.paymentLoading) {
            return h(RefundLoading, null);
        }
        const defaultValues = this.formController.getInitialValues();
        const currentRefundAmount = this.refundPayload.amount;
        return (h(StyledHost, null, h("form", null, h("fieldset", null, h("div", { class: "row gy-3" }, h("div", { class: "col-12" }, h("form-control-monetary", { name: "amount", label: "Refund Amount", defaultValue: defaultValues.amount, inputHandler: this.inputHandler, errorText: this.errors.amount })), h("div", { class: "col-12" }, h("form-control-select", { name: "reason", label: "Reason for refund (optional)", defaultValue: defaultValues.reason, inputHandler: this.inputHandler, options: refundReasonOptions, errorText: this.errors.reason })), h("div", { class: "col-12" }, h("form-control-textarea", { name: "description", label: "Note (optional)", defaultValue: defaultValues.description, inputHandler: this.inputHandler, maxLength: 250, errorText: this.errors.description })), h("div", { class: "form-group d-flex flex-row-reverse" }, h(Button, { variant: "primary", type: "submit", onClick: this.refundPayment.bind(this), isLoading: this.paymentLoading || this.refundLoading, hidden: this.hideSubmitButton, disabled: this.submitDisabled }, `Refund ${formatCurrency(+currentRefundAmount)}`)))))));
    }
};

export { RefundPayment as justifi_refund_payment };
