import { h, r as registerInstance, c as createEvent } from './index-N3w5zrz2.js';
import { p as processHTML, f as formatCurrency, r as removeAttribute, h as addAttribute } from './utils-Cu5hITuT.js';
import { v as validateInsuranceValues, i as insuranceValues, a as insuranceErrors } from './insurance-state-DeyYNyas.js';
import { D as text, E as textDanger } from './parts-CKg_luIy.js';
import { S as StyledHost } from './styled-host-DtvbNFVU.js';
import { H as Header2 } from './header-2-C4ZCdZwi.js';
import './event-types-CZfYo5-1.js';
import { S as Skeleton } from './skeleton-D1Z4a8af.js';
import './dinero-DizZAUMY.js';
import './_commonjsHelpers-BFTU3MAI.js';
import './index-BAq5IUBW.js';

const SeasonInterruptionInsuranceLoading = () => (h("div", { class: "row gap-3" },
    h("div", { class: "col-12" },
        h(Skeleton, { width: "35%", height: "30px" })),
    h("div", { class: "col-12" },
        h(Skeleton, { width: "70%" })),
    h("div", { class: "col-12" },
        h(Skeleton, { width: "40%" })),
    h("div", { class: "col-12" },
        h(Skeleton, { width: "40%" })),
    h("div", { class: "col-12" },
        h(Skeleton, { width: "100%" })),
    h("div", { class: "col-12" },
        h(Skeleton, { width: "80%" }))));

const SeasonInterruptionInsuranceCore = class {
    constructor(hostRef) {
        registerInstance(this, hostRef);
        this.insuranceUpdated = createEvent(this, "insurance-updated");
        this.errorEvent = createEvent(this, "error-event");
        this.isLoading = true;
    }
    async validate() {
        return validateInsuranceValues();
    }
    componentWillLoad() {
        if (this.getQuote) {
            this.fetchData();
        }
    }
    ;
    fetchData() {
        this.isLoading = true;
        this.getQuote({
            payload: {
                checkout_id: this.checkoutId,
                policy_type: "season_interruption",
                primary_identity: {
                    state: this.primaryIdentityState,
                    email: this.primaryIdentityEmailAddress,
                    first_name: this.primaryIdentityFirstName,
                    last_name: this.primaryIdentityLastName,
                    postal_code: this.primaryIdentityPostalCode,
                    country: this.primaryIdentityCountry
                },
                policy_attributes: {
                    insurable_amount: this.policyAttributesInsurableAmount,
                    start_date: this.policyAttributesStartDate,
                    end_date: this.policyAttributesEndDate,
                    covered_identity: {
                        first_name: this.coveredIdentityFirstName,
                        last_name: this.coveredIdentityLastName
                    }
                }
            },
            onSuccess: ({ quote }) => {
                this.quote = quote;
                this.quote.product.description = processHTML(this.quote.product.description, [
                    (html) => removeAttribute(html, 'style'),
                    (html) => addAttribute(html, 'a', 'part', text)
                ]);
                this.quote.product.legal_disclaimer = processHTML(this.quote.product.legal_disclaimer, [
                    (html) => removeAttribute(html, 'style'),
                    (html) => addAttribute(html, 'a', 'part', text)
                ]);
                insuranceValues[quote.policy_type] = quote.accepted;
                this.isLoading = false;
            },
            onError: ({ error, code, severity }) => {
                this.isLoading = false;
                this.errorEvent.emit({
                    errorCode: code,
                    message: error,
                    severity,
                });
            }
        });
    }
    ;
    onChangeHandler(_name, value) {
        this.accepted = value;
        insuranceErrors[this.quote.policy_type] = false;
        this.toggleCoverage({
            quoteId: this.quote.id,
            payload: { accepted: this.accepted },
            onSuccess: () => {
                this.insuranceUpdated.emit();
                insuranceValues[this.quote.policy_type] = this.accepted;
            },
            onError: ({ error, code, severity }) => {
                this.errorEvent.emit({
                    errorCode: code,
                    message: error,
                    severity,
                });
            }
        });
    }
    get error() {
        var _a;
        return insuranceErrors[(_a = this.quote) === null || _a === void 0 ? void 0 : _a.policy_type];
    }
    render() {
        var _a, _b, _c, _d;
        if (this.isLoading)
            return (h(StyledHost, null, h(SeasonInterruptionInsuranceLoading, null)));
        return (h(StyledHost, null, h(Header2, { text: (_a = this.quote) === null || _a === void 0 ? void 0 : _a.product.title, class: "fs-5 fw-bold pb-3" }), h("small", { innerHTML: (_b = this.quote) === null || _b === void 0 ? void 0 : _b.product.description, part: text }), h("form-control-radio", { label: `Accept coverage for ${formatCurrency((_c = this.quote) === null || _c === void 0 ? void 0 : _c.total_cents)}`, name: "opt-in", value: 'true', checked: this.accepted === 'true', inputHandler: this.onChangeHandler.bind(this),
            // don't wanna show error message, but need to show the red border
            errorText: this.error ? ' ' : undefined }), h("form-control-radio", { label: "Decline coverage", name: "opt-in", value: 'false', checked: this.accepted === 'false', inputHandler: this.onChangeHandler.bind(this), errorText: this.error ? ' ' : undefined }), h("div", { class: "invalid-feedback", style: { display: this.error ? 'block' : 'none' }, part: textDanger }, "Please select an option"), h("small", { innerHTML: (_d = this.quote) === null || _d === void 0 ? void 0 : _d.product.legal_disclaimer, part: text })));
    }
};

export { SeasonInterruptionInsuranceCore as justifi_season_interruption_insurance_core };
