import { r as registerInstance, c as createEvent, h } from './index-N3w5zrz2.js';
import { S as StyledHost } from './styled-host-DtvbNFVU.js';
import './event-types-CZfYo5-1.js';
import { c as checkPkgVersion, J as JustifiAnalytics } from './check-pkg-version-Cic-MeLf.js';
import { d as defaultColumnsKeys } from './terminal-orders-table-BWf9quiN.js';
import './config-state-B3mtRA6f.js';
import './dinero-DizZAUMY.js';
import { C as ComponentErrorSeverity, a as ComponentErrorCodes } from './ComponentError-BhrFjjAs.js';
import { i as TerminalOrder } from './Refund-DBHZkemk.js';
import './Pagination-CLHwhyvu.js';
import './Business-BCoP0TAV.js';
import './Dispute-BH0Xfn-F.js';
import { g as getErrorCode, a as getErrorMessage } from './utils-BZvep88z.js';
import { A as Api } from './Api-BCeKXDaf.js';
import './package-BRJ4FIJH.js';
import './parts-CKg_luIy.js';
import './utils-Cu5hITuT.js';
import './badge-BrapPg3R.js';
import './index-BAq5IUBW.js';
import './_commonjsHelpers-BFTU3MAI.js';
import './helpers-Mu7LQT-w.js';
import './state-options-BX8GieXu.js';

const makeGetTerminalOrders = ({ id, authToken, service }) => async ({ params, onSuccess, onError, final }) => {
    var _a, _b;
    try {
        const response = await service.fetchTerminalOrders(id, authToken, params);
        if (!response.error) {
            const pagingInfo = Object.assign({}, response.page_info);
            const terminalOrders = ((_a = response.data) === null || _a === void 0 ? void 0 : _a.map((dataItem) => new TerminalOrder(dataItem))) || [];
            onSuccess({ terminalOrders, pagingInfo });
        }
        else {
            const responseError = getErrorMessage(response.error);
            const code = getErrorCode((_b = response.error) === null || _b === void 0 ? void 0 : _b.code);
            return onError({
                error: responseError,
                code,
                severity: ComponentErrorSeverity.ERROR,
            });
        }
    }
    catch (error) {
        const code = getErrorCode(error === null || error === void 0 ? void 0 : error.code);
        return onError({
            error: error.message || error,
            code,
            severity: ComponentErrorSeverity.ERROR,
        });
    }
    finally {
        return final();
    }
};

const api = Api();
class TerminalOrderService {
    async fetchTerminalOrders(accountId, authToken, params) {
        const endpoint = 'terminals/orders';
        const headers = { account: accountId };
        return api.get({ endpoint, params, headers, authToken });
    }
}

const TerminalOrdersList = class {
    constructor(hostRef) {
        registerInstance(this, hostRef);
        this.errorEvent = createEvent(this, "error-event");
        this.errorMessage = null;
        this.columns = defaultColumnsKeys;
        this.handleErrorEvent = (event) => {
            this.errorMessage = event.detail.message;
            this.errorEvent.emit(event.detail);
        };
    }
    componentWillLoad() {
        checkPkgVersion();
        this.analytics = new JustifiAnalytics(this);
        this.initializeGetData();
    }
    disconnectedCallback() {
        var _a;
        (_a = this.analytics) === null || _a === void 0 ? void 0 : _a.cleanup();
    }
    ;
    initializeGetData() {
        if (this.accountId && this.authToken) {
            this.getTerminalOrders = makeGetTerminalOrders({
                id: this.accountId,
                authToken: this.authToken,
                service: new TerminalOrderService()
            });
        }
        else {
            this.errorMessage = 'Account ID and Auth Token are required';
            this.errorEvent.emit({
                errorCode: ComponentErrorCodes.MISSING_PROPS,
                message: this.errorMessage,
                severity: ComponentErrorSeverity.ERROR,
            });
        }
    }
    render() {
        return (h(StyledHost, { key: 'e0fcbc2ccb76acdbcd7a18772d509995c81b1ae1' }, h("terminal-orders-list-core", { key: '21b108f554caa4343ecbd3bffa404c01442ef938', getTerminalOrders: this.getTerminalOrders, "onError-event": this.handleErrorEvent, columns: this.columns })));
    }
};

export { TerminalOrdersList as justifi_terminal_orders_list };
