import { r as registerInstance, c as createEvent, h } from './index-N3w5zrz2.js';
import { C as ComponentErrorSeverity, a as ComponentErrorCodes } from './ComponentError-BhrFjjAs.js';
import { c as checkPkgVersion, J as JustifiAnalytics } from './check-pkg-version-Cic-MeLf.js';
import { T as TerminalService } from './terminal.service-BDRGcUj-.js';
import './config-state-B3mtRA6f.js';
import './dinero-DizZAUMY.js';
import { f as Terminal } from './Refund-DBHZkemk.js';
import './Pagination-CLHwhyvu.js';
import './Business-BCoP0TAV.js';
import './Dispute-BH0Xfn-F.js';
import { g as getErrorCode, a as getErrorMessage } from './utils-BZvep88z.js';
import { m as makeGetSubAccounts, S as SubAccountService } from './get-subaccounts-DcgISPei.js';
import { S as StyledHost } from './styled-host-DtvbNFVU.js';
import './event-types-CZfYo5-1.js';
import { d as defaultColumnsKeys } from './terminals-table-BBPQRWja.js';
import './package-BRJ4FIJH.js';
import './Api-BCeKXDaf.js';
import './utils-Cu5hITuT.js';
import './index-BAq5IUBW.js';
import './_commonjsHelpers-BFTU3MAI.js';
import './helpers-Mu7LQT-w.js';
import './state-options-BX8GieXu.js';
import './badge-BrapPg3R.js';
import './parts-CKg_luIy.js';

const makeGetTerminals = ({ id, authToken, service }) => async ({ params, onSuccess, onError }) => {
    var _a, _b;
    try {
        const response = await service.fetchTerminals(id, authToken, params);
        if (!response.error) {
            const pagingInfo = Object.assign({}, response.page_info);
            const terminals = ((_a = response.data) === null || _a === void 0 ? void 0 : _a.map((dataItem) => new Terminal(dataItem))) || [];
            onSuccess({ terminals, pagingInfo });
        }
        else {
            const responseError = getErrorMessage(response.error);
            const code = getErrorCode((_b = response.error) === null || _b === void 0 ? void 0 : _b.code);
            return onError({
                error: responseError,
                code,
                severity: ComponentErrorSeverity.ERROR,
            });
        }
    }
    catch (error) {
        const code = getErrorCode(error === null || error === void 0 ? void 0 : error.code);
        return onError({
            error: error.message || error,
            code,
            severity: ComponentErrorSeverity.ERROR,
        });
    }
};

const TerminalsList = class {
    constructor(hostRef) {
        registerInstance(this, hostRef);
        this.errorEvent = createEvent(this, "error-event");
        this.errorMessage = null;
        this.columns = defaultColumnsKeys;
        this.handleErrorEvent = (event) => {
            this.errorMessage = event.detail.message;
            this.errorEvent.emit(event.detail);
        };
    }
    componentWillLoad() {
        checkPkgVersion();
        this.analytics = new JustifiAnalytics(this);
        this.initializeGetData();
    }
    disconnectedCallback() {
        var _a;
        (_a = this.analytics) === null || _a === void 0 ? void 0 : _a.cleanup();
    }
    ;
    propChanged() {
        this.initializeGetData();
    }
    initializeGetData() {
        this.initializeGetTerminals();
        this.initializeGetSubAccounts();
    }
    initializeGetTerminals() {
        if (this.accountId && this.authToken) {
            this.getTerminals = makeGetTerminals({
                id: this.accountId,
                authToken: this.authToken,
                service: new TerminalService()
            });
        }
        else {
            this.errorMessage = 'Account ID and Auth Token are required';
            this.errorEvent.emit({
                errorCode: ComponentErrorCodes.MISSING_PROPS,
                message: this.errorMessage,
                severity: ComponentErrorSeverity.ERROR,
            });
        }
    }
    initializeGetSubAccounts() {
        if (this.accountId && this.authToken) {
            this.getSubAccounts = makeGetSubAccounts({
                accountId: this.accountId,
                authToken: this.authToken,
                service: new SubAccountService()
            });
        }
    }
    render() {
        return (h(StyledHost, { key: '57a9be57de845dc3f905260445e245cf30458af8' }, h("terminals-list-core", { key: '00f79218e216fffc12ecfc3b158cd299ad054349', getTerminals: this.getTerminals, getSubAccounts: this.getSubAccounts, "onError-event": this.handleErrorEvent, columns: this.columns })));
    }
    static get watchers() { return {
        "accountId": ["propChanged"],
        "authToken": ["propChanged"]
    }; }
};

export { TerminalsList as justifi_terminals_list };
