import { r as registerInstance, c as createEvent, h } from './index-N3w5zrz2.js';
import { S as StyledHost } from './styled-host-DtvbNFVU.js';
import './event-types-CZfYo5-1.js';
import { c as checkPkgVersion, J as JustifiAnalytics } from './check-pkg-version-Cic-MeLf.js';
import { P as PaymentMethodTypes } from './Refund-DBHZkemk.js';
import './config-state-B3mtRA6f.js';
import './dinero-DizZAUMY.js';
import { a as ComponentErrorCodes, C as ComponentErrorSeverity } from './ComponentError-BhrFjjAs.js';
import './Pagination-CLHwhyvu.js';
import './Business-BCoP0TAV.js';
import './Dispute-BH0Xfn-F.js';
import { c as checkoutStore } from './checkout.store-GXtlf5-4.js';
import './package-BRJ4FIJH.js';
import './Api-BCeKXDaf.js';
import './utils-Cu5hITuT.js';
import './index-BAq5IUBW.js';
import './_commonjsHelpers-BFTU3MAI.js';
import './helpers-Mu7LQT-w.js';
import './state-options-BX8GieXu.js';

// Constants
const PAYMENT_METHOD_TYPE_LABELS = {
    [PaymentMethodTypes.bankAccount]: 'New bank account',
    [PaymentMethodTypes.card]: 'New credit or debit card',
};
const ERROR_MESSAGES = {
    AUTH_TOKEN_REQUIRED: 'Auth token is required when using the tokenize-payment-method component not slotted in justifi-modular-checkout',
    ACCOUNT_ID_REQUIRED: 'Account ID is required when using the tokenize-payment-method component not slotted in justifi-modular-checkout',
    FORM_NOT_READY: 'Payment form not ready',
    VALIDATION_ERROR: 'Validation error',
};
const TokenizePaymentMethod = class {
    constructor(hostRef) {
        registerInstance(this, hostRef);
        this.errorEvent = createEvent(this, "error-event");
        this.submitEvent = createEvent(this, "submit-event");
        this.isLoading = false;
        this.saveNewPaymentMethodChecked = false;
        this.submitButtonText = 'Submit';
    }
    componentWillLoad() {
        checkPkgVersion();
        this.analytics = new JustifiAnalytics(this);
        this.validateRequiredProps();
    }
    connectedCallback() {
        this.setDefaultSelectedPaymentMethod();
    }
    disconnectedCallback() {
        var _a;
        (_a = this.analytics) === null || _a === void 0 ? void 0 : _a.cleanup();
    }
    paymentMethodsChanged() {
        this.setDefaultSelectedPaymentMethod();
    }
    handleRadioClick(event) {
        this.selectedPaymentMethodId = event.detail;
    }
    handleCheckboxChanged(event) {
        this.saveNewPaymentMethodChecked = event.detail;
    }
    async fillBillingForm(fields) {
        var _a;
        (_a = this.billingFormRef) === null || _a === void 0 ? void 0 : _a.fill(fields);
    }
    async tokenizePaymentMethod(event) {
        event === null || event === void 0 ? void 0 : event.preventDefault();
        this.isLoading = true;
        try {
            const validation = await this.validate();
            if (!validation.isValid) {
                this.errorEvent.emit({
                    errorCode: ComponentErrorCodes.TOKENIZE_ERROR,
                    message: ERROR_MESSAGES.VALIDATION_ERROR,
                });
                this.isLoading = false;
                return;
            }
            const tokenizeResponse = await this.resolvePaymentMethod({ isValid: true });
            if (tokenizeResponse.error) {
                this.emitError({
                    errorCode: tokenizeResponse.error.code,
                    message: tokenizeResponse.error.message,
                });
            }
            this.submitEvent.emit({ response: tokenizeResponse });
            return tokenizeResponse;
        }
        catch (error) {
            const errorResponse = this.createErrorResponse(ComponentErrorCodes.TOKENIZE_ERROR, error.message);
            this.emitError({
                errorCode: ComponentErrorCodes.TOKENIZE_ERROR,
                message: error.message,
            });
            this.submitEvent.emit({ response: errorResponse });
            return errorResponse;
        }
        finally {
            this.isLoading = false;
        }
    }
    async validate() {
        if (!this.areFormsReady()) {
            return { isValid: false, errors: { general: ERROR_MESSAGES.FORM_NOT_READY } };
        }
        const [billingValidation, paymentMethodValidation] = await Promise.all([
            this.billingFormRef.validate(),
            this.paymentMethodFormRef.validate(),
        ]);
        return {
            isValid: billingValidation.isValid && paymentMethodValidation.isValid,
            errors: Object.assign(Object.assign({}, billingValidation.errors), paymentMethodValidation.errors),
        };
    }
    validateRequiredProps() {
        if (!this.authToken && !checkoutStore.authToken) {
            this.emitError({
                errorCode: ComponentErrorCodes.TOKENIZE_ERROR,
                message: ERROR_MESSAGES.AUTH_TOKEN_REQUIRED,
            });
        }
        if (!this.accountId && !checkoutStore.accountId) {
            this.emitError({
                errorCode: ComponentErrorCodes.TOKENIZE_ERROR,
                message: ERROR_MESSAGES.ACCOUNT_ID_REQUIRED,
            });
        }
    }
    setDefaultSelectedPaymentMethod() {
        if (!this.selectedPaymentMethodId) {
            if (!this.disableCreditCard) {
                this.selectedPaymentMethodId = PaymentMethodTypes.card;
            }
            else if (!this.disableBankAccount) {
                this.selectedPaymentMethodId = PaymentMethodTypes.bankAccount;
            }
        }
    }
    get availablePaymentMethods() {
        const methods = [];
        if (!this.disableCreditCard) {
            methods.push(PaymentMethodTypes.card);
        }
        if (!this.disableBankAccount) {
            methods.push(PaymentMethodTypes.bankAccount);
        }
        return methods;
    }
    areFormsReady() {
        return !!(this.billingFormRef && this.paymentMethodFormRef);
    }
    emitError(errorData) {
        this.errorEvent.emit(Object.assign(Object.assign({}, errorData), { severity: ComponentErrorSeverity.ERROR }));
    }
    createErrorResponse(code, message) {
        return {
            error: {
                code: code,
                message,
                decline_code: undefined,
            },
        };
    }
    async resolvePaymentMethod(insuranceValidation) {
        if (!this.areFormsReady()) {
            return this.createErrorResponse('form_not_ready', ERROR_MESSAGES.FORM_NOT_READY);
        }
        try {
            const validation = await this.validate();
            if (!validation.isValid || !insuranceValidation.isValid) {
                const errorMessage = Object.values(validation.errors)[0] || ERROR_MESSAGES.VALIDATION_ERROR;
                return {
                    validationError: true,
                    error: {
                        code: 'validation_error',
                        message: String(errorMessage),
                        decline_code: undefined,
                    },
                };
            }
            return await this.performTokenization();
        }
        catch (error) {
            return { error };
        }
    }
    async performTokenization() {
        var _a, _b;
        const tokenizeResponse = await this.tokenize();
        if (tokenizeResponse.error) {
            return { error: tokenizeResponse.error };
        }
        const tokenizeResponseData = tokenizeResponse.data;
        return {
            token: ((_a = tokenizeResponseData.card) === null || _a === void 0 ? void 0 : _a.token) || ((_b = tokenizeResponseData.bank_account) === null || _b === void 0 ? void 0 : _b.token),
            data: tokenizeResponseData,
        };
    }
    async tokenize() {
        try {
            const billingFormFieldValues = await this.billingFormRef.getValues();
            const config = {
                clientId: this.authToken || checkoutStore.authToken,
                account: this.accountId || checkoutStore.accountId,
                paymentMethodMetadata: this.buildPaymentMethodMetadata(billingFormFieldValues),
            };
            return await this.paymentMethodFormRef.tokenize(config);
        }
        catch (error) {
            return error;
        }
    }
    buildPaymentMethodMetadata(billingFormFieldValues) {
        return this.saveNewPaymentMethodChecked
            ? Object.assign(Object.assign({}, billingFormFieldValues), { payment_method_group_id: this.paymentMethodGroupId }) : Object.assign({}, billingFormFieldValues);
    }
    get shouldHideRadioInput() {
        const showCard = !this.disableCreditCard;
        const showAch = !this.disableBankAccount;
        return !showAch || !showCard;
    }
    renderPaymentMethodOption(paymentMethodType) {
        const isSelected = this.selectedPaymentMethodId === paymentMethodType;
        return (h("div", { class: "payment-method" }, h("justifi-radio-list-item", { name: "paymentMethodType", value: paymentMethodType, checked: isSelected, label: PAYMENT_METHOD_TYPE_LABELS[paymentMethodType], hidden: this.shouldHideRadioInput }), isSelected && this.renderSelectedPaymentMethodForm(paymentMethodType)));
    }
    renderSelectedPaymentMethodForm(paymentMethodId) {
        return (h("div", { class: "mt-4 pb-4" }, this.renderPaymentMethodForm(paymentMethodId), h("justifi-billing-form", { ref: (el) => (this.billingFormRef = el), hideCardBillingForm: this.hideCardBillingForm, hideBankAccountBillingForm: this.hideBankAccountBillingForm, paymentMethodType: paymentMethodId }), h("justifi-save-new-payment-method", { hidden: !this.paymentMethodGroupId })));
    }
    renderPaymentMethodForm(paymentMethodId) {
        return paymentMethodId === PaymentMethodTypes.card ? (h("justifi-card-form", { ref: (el) => (this.paymentMethodFormRef = el) })) : (h("justifi-bank-account-form", { ref: (el) => (this.paymentMethodFormRef = el) }));
    }
    render() {
        return (h(StyledHost, { key: 'c3c12d1c58540f7fe794bc999e8cc8f47e9e1f8c' }, h("form", { key: 'aeb7843431a96feb79da49f1c28e0de6dc2d65c4' }, h("fieldset", { key: 'e890fbe8bb05bb6d74f8cabc9f4eb4feee4284ee' }, h("div", { key: '5abfab85b050239deea655dc777ff026b6627b8b', class: "row gy-3" }, h("div", { key: '9bb9dd865d6b2162d19a773ca232934da71bd792', class: "col-12" }, this.availablePaymentMethods.map((method) => this.renderPaymentMethodOption(method))), h("div", { key: 'aac644f69aa0e68632b850fc0f5c1442e26979e4', class: "col-12" }, h("justifi-button", { key: 'd2a35bd402b0d45dbcb48fefd44a624d4ab27a64', text: this.submitButtonText, variant: "primary", type: "submit", clickHandler: (e) => this.tokenizePaymentMethod(e), isLoading: this.isLoading, "data-testid": "submit-button", hidden: this.hideSubmitButton })))))));
    }
    static get watchers() { return {
        "disableCreditCard": ["paymentMethodsChanged"],
        "disableBankAccount": ["paymentMethodsChanged"]
    }; }
};

export { TokenizePaymentMethod as justifi_tokenize_payment_method };
