import { r as registerInstance, c as createEvent, h } from './index-N3w5zrz2.js';
import './config-state-B3mtRA6f.js';
import './dinero-DizZAUMY.js';
import './ComponentError-BhrFjjAs.js';
import './Refund-DBHZkemk.js';
import { p as pagingDefaults } from './Pagination-CLHwhyvu.js';
import './Business-BCoP0TAV.js';
import './Dispute-BH0Xfn-F.js';
import { T as Table, a as TableComponent, b as TableHead, c as TableHeadRow, d as TableBody, e as TableLoadingState, f as TableEmptyState, g as TableErrorState, h as TableRow, i as TableFoot, j as TableFootRow, k as TableFootCell, l as TableWrapper } from './table-BqxKVRry.js';
import { T as TableClickActions } from './event-types-CZfYo5-1.js';
import { p as paymentTableColumns, a as paymentTableCells } from './payments-table-WQAD1CSz.js';
import { o as onQueryParamsChange, g as getRequestParams } from './payments-list-params-state-DFWVMJRJ.js';
import './index-BAq5IUBW.js';
import './_commonjsHelpers-BFTU3MAI.js';
import './utils-Cu5hITuT.js';
import './helpers-Mu7LQT-w.js';
import './state-options-BX8GieXu.js';
import './parts-CKg_luIy.js';
import './spinner-BlffecO5.js';
import './payments-status-CawBLR48.js';
import './badge-BrapPg3R.js';

const PaymentsListCore = class {
    constructor(hostRef) {
        registerInstance(this, hostRef);
        this.clickEvent = createEvent(this, "click-event");
        this.errorEvent = createEvent(this, "error-event");
        this.payments = [];
        this.loading = true;
        this.paging = pagingDefaults;
        this.pagingParams = {};
        this.handleClickPrevious = (beforeCursor) => {
            this.pagingParams = { before_cursor: beforeCursor };
            this.clickEvent.emit({ name: TableClickActions.previous });
        };
        this.handleClickNext = (afterCursor) => {
            this.pagingParams = { after_cursor: afterCursor };
            this.clickEvent.emit({ name: TableClickActions.next });
        };
        this.rowClickHandler = (e) => {
            const clickedPaymentID = e.target.closest('tr').dataset.rowEntityId;
            if (!clickedPaymentID)
                return;
            const paymentData = this.payments.find((payment) => payment.id === clickedPaymentID);
            this.clickEvent.emit({ name: TableClickActions.row, data: paymentData });
        };
    }
    updateOnPropChange() {
        this.fetchData();
    }
    componentWillLoad() {
        this.paymentsTable = new Table(this.payments, this.columns, paymentTableColumns, paymentTableCells);
        if (this.getPayments) {
            this.fetchData();
        }
        onQueryParamsChange('set', () => {
            this.pagingParams = {};
        });
        onQueryParamsChange('reset', () => {
            this.pagingParams = {};
            this.errorMessage = '';
        });
    }
    fetchData() {
        this.loading = true;
        this.getPayments({
            params: this.paymentParams,
            onSuccess: ({ payments, pagingInfo }) => {
                this.payments = payments;
                this.paging = pagingInfo;
                this.paymentsTable.collectionData = this.payments;
            },
            onError: ({ error, code, severity }) => {
                this.errorMessage = error;
                this.errorEvent.emit({
                    errorCode: code,
                    message: error,
                    severity,
                });
            },
            final: () => {
                this.loading = false;
            }
        });
    }
    get paymentParams() {
        const requestParams = getRequestParams();
        const params = Object.assign(Object.assign({}, requestParams), this.pagingParams);
        return params;
    }
    get entityId() {
        return this.payments.map((payment) => payment.id);
    }
    get showEmptyState() {
        return !this.loading && !this.errorMessage && this.paymentsTable.rowData.length < 1;
    }
    get showErrorState() {
        return !this.loading && !!this.errorMessage;
    }
    get showRowData() {
        return !this.showEmptyState && !this.showErrorState && !this.loading;
    }
    render() {
        return (h(TableWrapper, { key: '8717c3554e0d5c8a2cd20b3a5510691c57d9f89a' }, h(TableComponent, { key: 'f23e5222c49c9d2f74c47ee0ded1c79319bd662c' }, h(TableHead, { key: '1cc4cf3bb057247bb0f26efc8414f574685ea134' }, h(TableHeadRow, { key: 'cfb828ecbe828cdd096e1e00710443627c00e72a' }, this.paymentsTable.columnData.map((column) => column))), h(TableBody, { key: 'da5eff4f32f2c47e700665a417f3d71605a287c3' }, h(TableLoadingState, { key: 'f5214c8760d679e47d50d1ac6883176abfd8aa91', columnSpan: this.paymentsTable.columnData.length, isLoading: this.loading }), h(TableEmptyState, { key: 'cbc72d572081b54b42d5adcb4e86937bf6c10fde', isEmpty: this.showEmptyState, columnSpan: this.paymentsTable.columnData.length }), h(TableErrorState, { key: 'ce954f66d360840e0c00d7acc77e8e8d43d93dd6', columnSpan: this.paymentsTable.columnData.length, errorMessage: this.errorMessage }), this.showRowData && this.paymentsTable.rowData.map((data, index) => (h(TableRow, { "data-test-id": "table-row", "data-row-entity-id": this.entityId[index], onClick: this.rowClickHandler }, data)))), this.paging && (h(TableFoot, { key: 'b6794bb85eb48d3ca9fd284a538eecba052b4e41' }, h(TableFootRow, { key: '923942c6cc9e110a93e0ea63dc4a99296ed10d63' }, h(TableFootCell, { key: 'ad259631ffc9d9a567375c7d28f48d449ac40990', colSpan: this.paymentsTable.columnData.length }, h("pagination-menu", { key: 'c06a9e46d23c851a9271bf893889cb3360475070', paging: Object.assign(Object.assign({}, this.paging), { handleClickPrevious: this.handleClickPrevious, handleClickNext: this.handleClickNext }) }))))))));
    }
    static get watchers() { return {
        "pagingParams": ["updateOnPropChange"],
        "getPayments": ["updateOnPropChange"],
        "columns": ["updateOnPropChange"]
    }; }
};

export { PaymentsListCore as payments_list_core };
