import { r as registerInstance, c as createEvent, h } from './index-N3w5zrz2.js';
import './config-state-B3mtRA6f.js';
import './dinero-DizZAUMY.js';
import { C as ComponentErrorSeverity, a as ComponentErrorCodes } from './ComponentError-BhrFjjAs.js';
import './Refund-DBHZkemk.js';
import { p as pagingDefaults } from './Pagination-CLHwhyvu.js';
import './Business-BCoP0TAV.js';
import './Dispute-BH0Xfn-F.js';
import { T as Table, a as TableComponent, b as TableHead, c as TableHeadRow, d as TableBody, e as TableLoadingState, f as TableEmptyState, g as TableErrorState, h as TableRow, i as TableFoot, j as TableFootRow, k as TableFootCell, l as TableWrapper } from './table-BqxKVRry.js';
import { T as TableClickActions } from './event-types-CZfYo5-1.js';
import { p as payoutTableColumns, a as payoutTableCells } from './payouts-table-DRISll8u.js';
import { o as onQueryParamsChange, g as getRequestParams } from './payouts-list-params-state-DFWVMJRJ.js';
import './index-BAq5IUBW.js';
import './_commonjsHelpers-BFTU3MAI.js';
import './utils-Cu5hITuT.js';
import './helpers-Mu7LQT-w.js';
import './state-options-BX8GieXu.js';
import './parts-CKg_luIy.js';
import './spinner-BlffecO5.js';
import './payouts-status-DB_PJap6.js';
import './badge-BrapPg3R.js';

const PayoutsListCore = class {
    constructor(hostRef) {
        registerInstance(this, hostRef);
        this.clickEvent = createEvent(this, "click-event");
        this.errorEvent = createEvent(this, "error-event");
        this.payouts = [];
        this.subAccounts = [];
        this.loading = true;
        this.paging = pagingDefaults;
        this.pagingParams = {};
        this.downloadCSV = (payoutId) => {
            this.getPayoutCSV({
                payoutId,
                onError: () => {
                    this.errorEvent.emit({
                        errorCode: ComponentErrorCodes.FETCH_ERROR,
                        message: 'Failed to download CSV',
                        severity: ComponentErrorSeverity.ERROR,
                    });
                },
            });
        };
        this.handleClickPrevious = (beforeCursor) => {
            this.pagingParams = { before_cursor: beforeCursor };
            this.clickEvent.emit({ name: TableClickActions.previous });
        };
        this.handleClickNext = (afterCursor) => {
            this.pagingParams = { after_cursor: afterCursor };
            this.clickEvent.emit({ name: TableClickActions.next });
        };
        this.rowClickHandler = (e) => {
            const clickedRow = e.target.closest('tr');
            const clickedPayoutID = clickedRow.dataset.rowEntityId;
            if (!clickedPayoutID)
                return;
            const clickedCSV = clickedRow.querySelector('a');
            if (clickedCSV === e.target)
                return;
            const payoutData = this.payouts.find((payout) => payout.id === clickedPayoutID);
            this.clickEvent.emit({ name: TableClickActions.row, data: payoutData });
        };
    }
    updateOnPropChange() {
        this.fetchData();
    }
    componentWillLoad() {
        this.payoutsTable = new Table(this.payouts, this.columns, payoutTableColumns, payoutTableCells(this.downloadCSV));
        if (this.getPayouts && this.getSubAccounts) {
            this.fetchData();
        }
        onQueryParamsChange('set', () => {
            this.pagingParams = {};
        });
        onQueryParamsChange('reset', () => {
            this.pagingParams = {};
            this.errorMessage = '';
        });
    }
    fetchData() {
        this.loading = true;
        this.getPayouts({
            params: this.payoutParams,
            onSuccess: ({ payouts, pagingInfo }) => {
                this.payouts = payouts;
                this.paging = pagingInfo;
                this.payoutsTable.collectionData = this.payouts;
                const shouldFetchSubAccounts = this.payoutsTable.columnKeys.includes('sub_account_name');
                if (shouldFetchSubAccounts) {
                    this.fetchSubAccounts();
                }
                else {
                    this.loading = false;
                }
            },
            onError: ({ error, code, severity }) => {
                this.errorMessage = error;
                this.errorEvent.emit({
                    errorCode: code,
                    message: error,
                    severity,
                });
                this.loading = false;
            },
        });
    }
    async fetchSubAccounts() {
        this.getSubAccounts({
            params: this.subAccountParams,
            onSuccess: ({ subAccounts }) => {
                this.subAccounts = subAccounts;
                this.payouts = this.payouts.map((payout) => {
                    var _a;
                    payout.sub_account_name = (_a = this.subAccounts.find((subAccount) => subAccount.id === payout.account_id)) === null || _a === void 0 ? void 0 : _a.name;
                    return payout;
                });
                this.loading = false;
            },
            onError: ({ error, code, severity }) => {
                this.errorMessage = error;
                this.errorEvent.emit({
                    errorCode: code,
                    message: error,
                    severity,
                });
                this.loading = false;
            },
        });
    }
    get payoutParams() {
        const requestParams = getRequestParams();
        const params = Object.assign(Object.assign({}, requestParams), this.pagingParams);
        return params;
    }
    get subAccountParams() {
        let accountIdNumbers = this.payouts.map((payout) => payout.account_id);
        let uniqueAccountIds = [...new Set(accountIdNumbers)];
        let accountIdString = uniqueAccountIds.join(',');
        return { sub_account_id: accountIdString };
    }
    get entityId() {
        return this.payouts.map((payout) => payout.id);
    }
    get showEmptyState() {
        return !this.loading && !this.errorMessage && this.payoutsTable.rowData.length < 1;
    }
    get showErrorState() {
        return !this.loading && !!this.errorMessage;
    }
    get showRowData() {
        return !this.showEmptyState && !this.showErrorState && !this.loading;
    }
    render() {
        return (h(TableWrapper, { key: '14a73ad4e8a841a731667d77a5be88d81a32a4e4' }, h(TableComponent, { key: 'aeb950f72b44547884da8d825604e36fd0d10945' }, h(TableHead, { key: 'e938550e08cc10f9f9bcf332c1ac187761849344' }, h(TableHeadRow, { key: '08e692828490e85cb7764a14a95a499d113136a1' }, this.payoutsTable.columnData.map((column) => column))), h(TableBody, { key: '9127ceac1604c85476cd4803a7e7ad2646bc5bf0' }, h(TableLoadingState, { key: 'd0e58b5ec8b8aad83922f8863fa7c0ba7136aca3', columnSpan: this.payoutsTable.columnKeys.length, isLoading: this.loading }), h(TableEmptyState, { key: '6e0b794a28b8067ba88330b96090362f0454c894', isEmpty: this.showEmptyState, columnSpan: this.payoutsTable.columnKeys.length }), h(TableErrorState, { key: 'c858aa45775a92fc0b9e76326cbd23d8054f5342', columnSpan: this.payoutsTable.columnKeys.length, errorMessage: this.errorMessage }), this.showRowData && this.payoutsTable.rowData.map((data, index) => (h(TableRow, { "data-test-id": "table-row", "data-row-entity-id": this.entityId[index], onClick: this.rowClickHandler }, data)))), this.paging && (h(TableFoot, { key: '98bf326a59c4b32d06c6738f086a660116576aa8' }, h(TableFootRow, { key: '36a2b0e17a94f5e361d12d6bc0e9fd9aaebf41e8' }, h(TableFootCell, { key: '54daa1d4c6e86128d74a75142b13184d3ec74502', colSpan: this.payoutsTable.columnData.length }, h("pagination-menu", { key: '7199ea8e69d351cc07d014770c8b48f6d01d04e3', paging: Object.assign(Object.assign({}, this.paging), { handleClickPrevious: this.handleClickPrevious, handleClickNext: this.handleClickNext }) }))))))));
    }
    static get watchers() { return {
        "pagingParams": ["updateOnPropChange"],
        "getPayouts": ["updateOnPropChange"],
        "getSubAccounts": ["updateOnPropChange"]
    }; }
};

export { PayoutsListCore as payouts_list_core };
