import { r as registerInstance, c as createEvent, h } from './index-N3w5zrz2.js';
import { T as Table, a as TableComponent, b as TableHead, c as TableHeadRow, d as TableBody, e as TableLoadingState, f as TableEmptyState, g as TableErrorState, h as TableRow, i as TableFoot, j as TableFootRow, k as TableFootCell, l as TableWrapper } from './table-BqxKVRry.js';
import { T as TableClickActions } from './event-types-CZfYo5-1.js';
import './config-state-B3mtRA6f.js';
import './dinero-DizZAUMY.js';
import './ComponentError-BhrFjjAs.js';
import './Refund-DBHZkemk.js';
import { p as pagingDefaults } from './Pagination-CLHwhyvu.js';
import './Business-BCoP0TAV.js';
import './Dispute-BH0Xfn-F.js';
import { t as terminalOrdersTableColumns, a as terminalOrdersTableCells } from './terminal-orders-table-BWf9quiN.js';
import { o as onQueryParamsChange, g as getRequestParams } from './terminal-orders-list-params-state-DFWVMJRJ.js';
import './parts-CKg_luIy.js';
import './spinner-BlffecO5.js';
import './index-BAq5IUBW.js';
import './_commonjsHelpers-BFTU3MAI.js';
import './utils-Cu5hITuT.js';
import './helpers-Mu7LQT-w.js';
import './state-options-BX8GieXu.js';
import './badge-BrapPg3R.js';

const TerminalOrdersListCore = class {
    constructor(hostRef) {
        registerInstance(this, hostRef);
        this.clickEvent = createEvent(this, "click-event");
        this.errorEvent = createEvent(this, "error-event");
        this.terminalOrders = [];
        this.loading = true;
        this.paging = pagingDefaults;
        this.pagingParams = {};
        this.handleClickPrevious = (beforeCursor) => {
            this.pagingParams = { before_cursor: beforeCursor };
            this.clickEvent.emit({ name: TableClickActions.previous });
        };
        this.handleClickNext = (afterCursor) => {
            this.pagingParams = { after_cursor: afterCursor };
            this.clickEvent.emit({ name: TableClickActions.next });
        };
        this.rowClickHandler = (e) => {
            const clickedOrderId = e.target.closest('tr').dataset.rowEntityId;
            if (!clickedOrderId)
                return;
            const orderData = this.terminalOrders.find((order) => order.id === clickedOrderId);
            this.clickEvent.emit({ name: TableClickActions.row, data: orderData });
        };
    }
    updateOnPropChange() {
        this.fetchData();
    }
    componentWillLoad() {
        this.terminalOrdersTable = new Table(this.terminalOrders, this.columns, terminalOrdersTableColumns, terminalOrdersTableCells);
        if (this.getTerminalOrders) {
            this.fetchData();
        }
        onQueryParamsChange('set', () => {
            this.pagingParams = {};
        });
        onQueryParamsChange('reset', () => {
            this.pagingParams = {};
            this.errorMessage = '';
        });
    }
    fetchData() {
        this.loading = true;
        this.getTerminalOrders({
            params: this.terminalOrderParams,
            onSuccess: async ({ terminalOrders, pagingInfo }) => {
                this.terminalOrders = terminalOrders;
                this.paging = pagingInfo;
                this.terminalOrdersTable.collectionData = this.terminalOrders;
            },
            onError: ({ error, code, severity }) => {
                this.errorMessage = error;
                this.errorEvent.emit({
                    errorCode: code,
                    message: error,
                    severity,
                });
            },
            final: () => { this.loading = false; },
        });
    }
    get terminalOrderParams() {
        const requestParams = getRequestParams();
        const params = Object.assign(Object.assign({}, requestParams), this.pagingParams);
        return params;
    }
    get entityId() {
        return this.terminalOrders.map((terminalOrder) => terminalOrder.id);
    }
    get showEmptyState() {
        return !this.loading && !this.errorMessage && this.terminalOrdersTable.rowData.length < 1;
    }
    get showErrorState() {
        return !this.loading && !!this.errorMessage;
    }
    get showRowData() {
        return !this.showEmptyState && !this.showErrorState && !this.loading;
    }
    render() {
        return (h(TableWrapper, { key: '85a1a02fb87d8582cb58716fceab3037f2b2db59' }, h(TableComponent, { key: '16d1f186acc00b28437ebb5608a69b6b69fa7914' }, h(TableHead, { key: 'dce803614dd4c1fd7844aeeb9539cfa32368b277' }, h(TableHeadRow, { key: 'f8c81e2b7e35064e8f2699366045fdf63d0b6a25' }, this.terminalOrdersTable.columnData.map((column) => column))), h(TableBody, { key: 'f1d27f78f5985b0e7b0e24bc370e787d08d7d441' }, h(TableLoadingState, { key: '036e603cd4ba2785b931f9c101c73bda204e0c3b', columnSpan: this.terminalOrdersTable.columnKeys.length, isLoading: this.loading }), h(TableEmptyState, { key: '7b7e58eebc3644e05e989e6593cc0b995f52f3fc', isEmpty: this.showEmptyState, columnSpan: this.terminalOrdersTable.columnKeys.length }), h(TableErrorState, { key: '2ba2fa702cc279cfb4bb6116aef5f99bcc6cdeea', columnSpan: this.terminalOrdersTable.columnKeys.length, errorMessage: this.errorMessage }), this.showRowData && this.terminalOrdersTable.rowData.map((data, index) => (h(TableRow, { "data-test-id": "table-row", "data-row-entity-id": this.entityId[index], onClick: this.rowClickHandler }, data)))), this.paging && (h(TableFoot, { key: '8448f124fd6d5cb82983af8b163532e067d44e7f' }, h(TableFootRow, { key: '3172efc0062b99a291ef945c900321d4db112dda' }, h(TableFootCell, { key: '690c7414a1a3071a0d662c14ebe86b5f771da10a', colSpan: this.terminalOrdersTable.columnData.length }, h("pagination-menu", { key: '8034a4c00f149c1b720db9c78b91e6ea635bd86e', paging: Object.assign(Object.assign({}, this.paging), { handleClickPrevious: this.handleClickPrevious, handleClickNext: this.handleClickNext }) }))))))));
    }
    static get watchers() { return {
        "pagingParams": ["updateOnPropChange"],
        "getTerminalOrders": ["updateOnPropChange"],
        "columns": ["updateOnPropChange"]
    }; }
};

export { TerminalOrdersListCore as terminal_orders_list_core };
