import { h } from './index-N3w5zrz2.js';
import { B as BadgeVariant, a as Badge } from './badge-BrapPg3R.js';
import { R as tableHeadCell, S as getAlternateTableCellPart } from './parts-CKg_luIy.js';
import { e as capitalFirstLetter } from './utils-Cu5hITuT.js';

const MapTerminalStatusToBadge = (status) => {
    const statusToBadgeProps = {
        connected: {
            variant: BadgeVariant.SUCCESS,
            title: 'This terminal is connected',
            text: 'Connected',
        },
        disconnected: {
            variant: BadgeVariant.DANGER,
            title: 'This terminal is disconnected',
            text: 'Disconnected',
        },
        unknown: {
            variant: BadgeVariant.SECONDARY,
            title: 'The status of this terminal is unknown',
            text: 'Unknown',
        },
        pending_configuration: {
            variant: BadgeVariant.WARNING,
            title: 'This terminal is pending configuration',
            text: 'Pending configuration',
        },
    };
    const badgeProps = statusToBadgeProps[status];
    return h(Badge, Object.assign({}, badgeProps));
};

const defaultColumnsKeys = 'nickname,provider_serial_number,status';
const terminalTableColumns = {
    nickname: () => (h("th", { part: tableHeadCell, scope: "col", title: "The nickname associated with the terminal" }, "Nickname")),
    model_name: () => (h("th", { part: tableHeadCell, scope: "col", title: "The model name of the terminal" }, "Model Name")),
    id: () => (h("th", { part: tableHeadCell, scope: "col", title: "The ID of the terminal" }, "ID")),
    provider: () => (h("th", { part: tableHeadCell, scope: "col", title: "The provider of the terminal" }, "Provider")),
    provider_serial_number: () => (h("th", { part: tableHeadCell, scope: "col", title: "The serial number of the terminal" }, "Serial Number")),
    device_id: () => (h("th", { part: tableHeadCell, scope: "col", title: "The device/provider ID of the terminal" }, "Device ID")),
    sub_account_name: () => (h("th", { part: tableHeadCell, scope: "col", title: "The sub account associated with the terminal" }, "Sub Account")),
    status: () => (h("th", { part: tableHeadCell, scope: "col", title: "The current status of each terminal" }, "Status")),
};
const terminalTableCells = {
    nickname: (terminal, index) => (h("td", { part: getAlternateTableCellPart(index) }, terminal.nickname)),
    model_name: (terminal, index) => (h("td", { part: getAlternateTableCellPart(index) }, terminal.model_name)),
    id: (terminal, index) => (h("td", { part: getAlternateTableCellPart(index) }, terminal.id)),
    provider: (terminal, index) => (h("td", { part: getAlternateTableCellPart(index) }, capitalFirstLetter(terminal.provider))),
    provider_serial_number: (terminal, index) => (h("td", { part: getAlternateTableCellPart(index) }, terminal.provider_serial_number)),
    device_id: (terminal, index) => (h("td", { part: getAlternateTableCellPart(index) }, terminal.provider_id)),
    sub_account_name: (terminal, index) => (h("td", { part: getAlternateTableCellPart(index) }, terminal.sub_account_name)),
    status: (terminal, index) => (h("td", { part: getAlternateTableCellPart(index) }, MapTerminalStatusToBadge(terminal.status))),
};

export { terminalTableCells as a, defaultColumnsKeys as d, terminalTableColumns as t };
