import { h, proxyCustomElement, HTMLElement, Host } from '@stencil/core/internal/client';
import { S as Skeleton } from './skeleton.js';
import { w as waitForConfig, c as configState } from './config-state.js';
import { d as defineCustomElement$2 } from './iframe-input2.js';

const BankAccountFormSkeleton = (props) => {
    const { isReady } = props;
    if (isReady) {
        return null;
    }
    return (h("div", { class: "container-fluid p-0" },
        h("div", { class: "row mb-3" },
            h("div", { class: "col-12 align-content-end" },
                h(Skeleton, { height: "18px", width: "120px" }),
                h(Skeleton, { height: "36px" }))),
        h("div", { class: "row" },
            h("div", { class: "col-12 align-content-end" },
                h(Skeleton, { height: "18px", width: "110px" }),
                h(Skeleton, { height: "36px" })))));
};

const BankAccountForm$1 = /*@__PURE__*/ proxyCustomElement(class BankAccountForm extends HTMLElement {
    constructor() {
        super();
        this.__registerHost();
        this.isReady = false;
    }
    async componentWillLoad() {
        await waitForConfig();
        this.iframeOrigin = configState.iframeOrigin;
    }
    componentDidRender() {
        const elements = [
            this.accountNumberIframeElement,
            this.routingNumberIframeElement,
        ];
        Promise.all(elements.map((element) => {
            return new Promise((resolve) => {
                element.addEventListener('iframeLoaded', () => { resolve(); });
            });
        })).then(() => {
            this.isReady = true;
        });
    }
    async validate() {
        const accountNumberIsValid = await this.accountNumberIframeElement.validate();
        const routingNumberIsValid = await this.routingNumberIframeElement.validate();
        return accountNumberIsValid && routingNumberIsValid;
    }
    async tokenize(clientId, paymentMethodMetadata, account) {
        return this.accountNumberIframeElement.tokenize(clientId, paymentMethodMetadata, account);
    }
    render() {
        return (h(Host, { key: 'f7fccd7526b31937a7adb5c1eef5d7db21116b8b' }, h(BankAccountFormSkeleton, { key: '316e16b7bc09d15334c863323b338d61bf074ad4', isReady: this.isReady }), h("div", { key: '6676e15da0bc4f4dccbbbe035af3de9abd449ebf', class: "container-fluid p-0", style: {
                opacity: this.isReady ? '1' : '0',
                height: this.isReady ? 'auto' : '0',
            } }, h("div", { key: 'd689e889153f3efd693ff2acfe8a0bf2da84b786', class: "row mb-3" }, h("iframe-input", { key: 'd5405444fbd9776882cbaf649cdc4f709c60f7be', inputId: "accountNumber", ref: (el) => (this.accountNumberIframeElement = el), label: "Account Number", iframeOrigin: `${this.iframeOrigin}/v2/accountNumber` })), h("div", { key: '788b71169701d7a004ce668cd2126b85cd65a372', class: "row" }, h("iframe-input", { key: '13d88a9e446e4fa7d88424359737202baa1ff79b', inputId: "routingNumber", ref: (el) => (this.routingNumberIframeElement = el), label: "Routing Number", iframeOrigin: `${this.iframeOrigin}/v2/routingNumber` })))));
    }
}, [0, "bank-account-form", {
        "isReady": [32],
        "iframeOrigin": [32],
        "validate": [64],
        "tokenize": [64]
    }]);
function defineCustomElement$1() {
    if (typeof customElements === "undefined") {
        return;
    }
    const components = ["bank-account-form", "iframe-input"];
    components.forEach(tagName => { switch (tagName) {
        case "bank-account-form":
            if (!customElements.get(tagName)) {
                customElements.define(tagName, BankAccountForm$1);
            }
            break;
        case "iframe-input":
            if (!customElements.get(tagName)) {
                defineCustomElement$2();
            }
            break;
    } });
}
defineCustomElement$1();

const BankAccountForm = BankAccountForm$1;
const defineCustomElement = defineCustomElement$1;

export { BankAccountForm, defineCustomElement };
