import { h, proxyCustomElement, HTMLElement } from '@stencil/core/internal/client';
import { S as StyledHost } from './styled-host.js';
import './details.js';
import './event-types.js';
import './justifi-radio-list-item2.js';
import { S as Skeleton } from './skeleton.js';
import { c as checkPkgVersion, J as JustifiAnalytics } from './Analytics.js';
import { w as waitForConfig, c as configState } from './config-state.js';
import { d as defineCustomElement$2 } from './hidden-input2.js';
import { d as defineCustomElement$1 } from './iframe-input2.js';

const BankAccountFormSkeleton = (props) => {
    const { isReady } = props;
    if (isReady) {
        return null;
    }
    return (h("div", { class: "container-fluid p-0" },
        h("div", { class: "row mb-3" },
            h("div", { class: "col-12 align-content-end" },
                h(Skeleton, { height: "18px", width: "120px" }),
                h(Skeleton, { height: "36px" }))),
        h("div", { class: "row" },
            h("div", { class: "col-12 align-content-end" },
                h(Skeleton, { height: "18px", width: "110px" }),
                h(Skeleton, { height: "36px" })))));
};

const BankAccountForm = /*@__PURE__*/ proxyCustomElement(class BankAccountForm extends HTMLElement {
    constructor() {
        super();
        this.__registerHost();
        this.__attachShadow();
        this.isReady = false;
    }
    async componentWillLoad() {
        await waitForConfig();
        this.iframeOrigin = configState.iframeOrigin;
        checkPkgVersion();
        this.analytics = new JustifiAnalytics(this);
    }
    componentDidRender() {
        const elements = [
            this.accountNumberIframeElement,
            this.routingNumberIframeElement,
        ];
        Promise.all(elements.map((element) => {
            return new Promise((resolve) => {
                element.addEventListener('iframeLoaded', () => { resolve(); });
            });
        })).then(() => {
            this.isReady = true;
        });
    }
    disconnectedCallback() {
        var _a;
        (_a = this.analytics) === null || _a === void 0 ? void 0 : _a.cleanup();
    }
    async validate() {
        const accountNumberIsValid = await this.accountNumberIframeElement.validate();
        const routingNumberIsValid = await this.routingNumberIframeElement.validate();
        return accountNumberIsValid && routingNumberIsValid;
    }
    async tokenize({ clientId, paymentMethodMetadata, account }) {
        return this.accountNumberIframeElement.tokenize(clientId, paymentMethodMetadata, account);
    }
    render() {
        return (h(StyledHost, { key: '62431aba939585a8a341942d9847e8d491b0a658' }, h(BankAccountFormSkeleton, { key: '2da8452c73e52a6fc67d80e483c40a2d0dd276f9', isReady: this.isReady }), h("hidden-input", { key: 'c34bc48ee7e1925ae272b5fe60fd362ddf2433eb' }), h("div", { key: '3fefe63e9f9c98d7e08e0ceac5df0f8008303aec', class: "container-fluid p-0", style: {
                opacity: this.isReady ? '1' : '0',
                height: this.isReady ? 'auto' : '0',
            } }, h("div", { key: '6c19ea238eb0bff6b245f2f39028d651438c55d0', class: "row mb-3" }, h("iframe-input", { key: 'b5588dc21d24ec873fecedd91fbcb0344fbe324c', inputId: "accountNumber", ref: (el) => (this.accountNumberIframeElement = el), label: "Account Number", iframeOrigin: `${this.iframeOrigin}/v2/accountNumber` })), h("div", { key: '910f130a307449a3d60ef76eee6cc27fc86c3fe0', class: "row" }, h("iframe-input", { key: '72756b92912c3031cc472dee5bbf945f06c38920', inputId: "routingNumber", ref: (el) => (this.routingNumberIframeElement = el), label: "Routing Number", iframeOrigin: `${this.iframeOrigin}/v2/routingNumber` })))));
    }
}, [1, "justifi-bank-account-form", {
        "iframeOrigin": [32],
        "isReady": [32],
        "validate": [64],
        "tokenize": [64]
    }]);
function defineCustomElement() {
    if (typeof customElements === "undefined") {
        return;
    }
    const components = ["justifi-bank-account-form", "hidden-input", "iframe-input"];
    components.forEach(tagName => { switch (tagName) {
        case "justifi-bank-account-form":
            if (!customElements.get(tagName)) {
                customElements.define(tagName, BankAccountForm);
            }
            break;
        case "hidden-input":
            if (!customElements.get(tagName)) {
                defineCustomElement$2();
            }
            break;
        case "iframe-input":
            if (!customElements.get(tagName)) {
                defineCustomElement$1();
            }
            break;
    } });
}
defineCustomElement();

export { BankAccountForm as B, defineCustomElement as d };
