import { proxyCustomElement, HTMLElement, h } from '@stencil/core/internal/client';
import { V as billingForm } from './parts.js';
import { d as defineCustomElement$7 } from './custom-popper2.js';
import { d as defineCustomElement$6 } from './form-control-select2.js';
import { d as defineCustomElement$5 } from './form-control-text2.js';
import { d as defineCustomElement$4 } from './form-control-tooltip2.js';
import { d as defineCustomElement$3 } from './billing-information-form.js';
import { d as defineCustomElement$2 } from './justifi-header2.js';
import { d as defineCustomElement$1 } from './postal-code-form.js';

const BillingForm = /*@__PURE__*/ proxyCustomElement(class BillingForm extends HTMLElement {
    constructor() {
        super();
        this.__registerHost();
    }
    get isPostalOnlyMode() {
        return this.paymentMethodType === 'card' && this.hideCardBillingForm;
    }
    get hideAllBillingFields() {
        return this.paymentMethodType === 'bankAccount' && this.hideBankAccountBillingForm;
    }
    async getValues() {
        return this.formRef.getValues();
    }
    async fill(fields) {
        return this.formRef.fill(fields);
    }
    async validate() {
        const { isValid, errors } = await this.formRef.validate();
        return { isValid, errors };
    }
    render() {
        const showHeader = !this.isPostalOnlyMode && !this.hideAllBillingFields;
        return (h("div", { key: 'b1d80f02eee8bdc4fe4b9bfd7e9fb86d89af53b3', part: billingForm, class: "mt-4", hidden: this.hideAllBillingFields }, showHeader && h("justifi-header", { key: 'f3d7d02561a3de2c777b869a8b874fe0e03d1924', text: "Billing address", level: "h3", class: "fs-6 fw-bold lh-lg mb-4" }), this.legend && h("legend", { key: '9218d5b52eed27d86970e745cbbd9d02c6df513b' }, this.legend), this.isPostalOnlyMode ? (h("justifi-postal-code-form", { ref: (el) => this.formRef = el })) : (h("justifi-billing-information-form", { ref: (el) => this.formRef = el }))));
    }
}, [0, "justifi-billing-form", {
        "legend": [1025],
        "hideCardBillingForm": [4, "hide-card-billing-form"],
        "hideBankAccountBillingForm": [4, "hide-bank-account-billing-form"],
        "paymentMethodType": [1, "payment-method-type"],
        "getValues": [64],
        "fill": [64],
        "validate": [64]
    }]);
function defineCustomElement() {
    if (typeof customElements === "undefined") {
        return;
    }
    const components = ["justifi-billing-form", "custom-popper", "form-control-select", "form-control-text", "form-control-tooltip", "justifi-billing-information-form", "justifi-header", "justifi-postal-code-form"];
    components.forEach(tagName => { switch (tagName) {
        case "justifi-billing-form":
            if (!customElements.get(tagName)) {
                customElements.define(tagName, BillingForm);
            }
            break;
        case "custom-popper":
            if (!customElements.get(tagName)) {
                defineCustomElement$7();
            }
            break;
        case "form-control-select":
            if (!customElements.get(tagName)) {
                defineCustomElement$6();
            }
            break;
        case "form-control-text":
            if (!customElements.get(tagName)) {
                defineCustomElement$5();
            }
            break;
        case "form-control-tooltip":
            if (!customElements.get(tagName)) {
                defineCustomElement$4();
            }
            break;
        case "justifi-billing-information-form":
            if (!customElements.get(tagName)) {
                defineCustomElement$3();
            }
            break;
        case "justifi-header":
            if (!customElements.get(tagName)) {
                defineCustomElement$2();
            }
            break;
        case "justifi-postal-code-form":
            if (!customElements.get(tagName)) {
                defineCustomElement$1();
            }
            break;
    } });
}
defineCustomElement();

export { BillingForm as B, defineCustomElement as d };
