import { proxyCustomElement, HTMLElement, h } from '@stencil/core/internal/client';
import { b as billingFormSchema } from './billing-form-schema.js';
import { V as billingForm } from './parts.js';
import { n as numberOnlyHandler } from './utils3.js';
import { S as StateOptions } from './state-options.js';
import { F as FormController } from './form.js';
import { S as StyledHost } from './styled-host.js';
import './details.js';
import './event-types.js';
import './justifi-radio-list-item2.js';
import { o as onChange } from './checkout.store.js';
import { d as defineCustomElement$4 } from './custom-popper2.js';
import { d as defineCustomElement$3 } from './form-control-select2.js';
import { d as defineCustomElement$2 } from './form-control-text2.js';
import { d as defineCustomElement$1 } from './form-control-tooltip2.js';

const BillingInformationForm = /*@__PURE__*/ proxyCustomElement(class BillingInformationForm extends HTMLElement {
    constructor() {
        super();
        this.__registerHost();
        this.__attachShadow();
        this.errors = {};
        this.inputHandler = (name, value) => {
            this.formController.setValues(Object.assign(Object.assign({}, this.formController.values.getValue()), { [name]: value }));
        };
    }
    connectedCallback() {
        this.unsubscribe = onChange('billingFormFields', (newValue) => {
            this.formController.setInitialValues(newValue);
        });
    }
    disconnectedCallback() {
        var _a;
        (_a = this.unsubscribe) === null || _a === void 0 ? void 0 : _a.call(this);
    }
    componentWillLoad() {
        this.formController = new FormController(billingFormSchema());
    }
    componentDidLoad() {
        this.formController.values.subscribe(values => this.billingInfo = Object.assign({}, values));
        this.formController.errors.subscribe(errors => {
            this.errors = Object.assign({}, errors);
        });
    }
    async fill(values) {
        this.formController.setInitialValues(values);
        return this.formController.values.getValue();
    }
    async getValues() {
        return this.formController.values.getValue();
    }
    async validate() {
        const isValid = await this.formController.validate();
        const errors = this.formController.errors.getValue();
        return { isValid, errors };
    }
    render() {
        const billingFormDefaultValue = this.formController.getInitialValues();
        return (h(StyledHost, { key: 'a88e767bb2e49c21e9ce48c44895f592a3a38aad' }, h("div", { key: '7f7766669fefa6096c9967a36d007d87a2487805', part: billingForm }, h("form", { key: '32d6f2128425b41e67a01f295d4f41c3dd452dd6' }, h("fieldset", { key: 'b42d5fb584bb4e8a6d75ae31adab81162094d605' }, h("div", { key: 'b50049072ff30b9d49e2fb101cdd25a4ce3d69d4', class: "row gy-3" }, h("div", { key: '77daf407dbfaa961bbb05f2293a926bf71e3465c', class: "col-12" }, h("form-control-text", { key: 'f865d1247e0d07e3f55d58cc8f5e5c54bd3b8756', name: 'name', label: 'Full Name', defaultValue: billingFormDefaultValue.name, errorText: this.errors.name, inputHandler: this.inputHandler })), h("div", { key: '3260e35526ec7293aaf177d2a052ddb170df5934', class: "col-12" }, h("form-control-text", { key: '7e4d3e8f2d19d5f83b173a7f852ca7f7dabafec4', name: 'address_line1', label: 'Street Address', defaultValue: billingFormDefaultValue.address_line1, errorText: this.errors.address_line1, inputHandler: this.inputHandler })), h("div", { key: 'ed66dd692aa1f6542866a66bf962c751c95e6b9e', class: "col-12" }, h("form-control-text", { key: '4d092e34e70455ff890e68c94db4a150bb468df3', name: 'address_line2', label: "Apartment, Suite, etc. (optional)", defaultValue: billingFormDefaultValue.address_line2, errorText: this.errors.address_line2, inputHandler: this.inputHandler })), h("div", { key: '14eb1dda040024dd1fadde8c12b4421ae6691d93', class: "col-12" }, h("form-control-text", { key: 'e5cc48df0a79438605d601cc31423ce7ae410a7e', name: 'address_city', label: "City", defaultValue: billingFormDefaultValue.address_city, errorText: this.errors.address_city, inputHandler: this.inputHandler })), h("div", { key: '15699e13436a9742afd72ff3a799af11839609ae', class: "col-12" }, h("form-control-select", { key: '82bf4f8cbec206f8c942e2b2c3a4896b769683c3', name: 'address_state', label: 'State', options: StateOptions, defaultValue: billingFormDefaultValue.address_state, errorText: this.errors.address_state, inputHandler: this.inputHandler })), h("div", { key: '6f341fd1f9580830d460cbc2ef1f96bf4a6c87da', class: "col-12" }, h("form-control-text", { key: '2ff9907c1e36c01360f601a895d34fffbd3476a7', name: 'address_postal_code', label: "ZIP", defaultValue: billingFormDefaultValue.address_postal_code, errorText: this.errors.address_postal_code, inputHandler: this.inputHandler, maxLength: 5, keyDownHandler: numberOnlyHandler }))))))));
    }
}, [1, "justifi-billing-information-form", {
        "formController": [32],
        "billingInfo": [32],
        "errors": [32],
        "fill": [64],
        "getValues": [64],
        "validate": [64]
    }]);
function defineCustomElement() {
    if (typeof customElements === "undefined") {
        return;
    }
    const components = ["justifi-billing-information-form", "custom-popper", "form-control-select", "form-control-text", "form-control-tooltip"];
    components.forEach(tagName => { switch (tagName) {
        case "justifi-billing-information-form":
            if (!customElements.get(tagName)) {
                customElements.define(tagName, BillingInformationForm);
            }
            break;
        case "custom-popper":
            if (!customElements.get(tagName)) {
                defineCustomElement$4();
            }
            break;
        case "form-control-select":
            if (!customElements.get(tagName)) {
                defineCustomElement$3();
            }
            break;
        case "form-control-text":
            if (!customElements.get(tagName)) {
                defineCustomElement$2();
            }
            break;
        case "form-control-tooltip":
            if (!customElements.get(tagName)) {
                defineCustomElement$1();
            }
            break;
    } });
}
defineCustomElement();

export { BillingInformationForm as B, defineCustomElement as d };
