import { proxyCustomElement, HTMLElement, h, Host } from '@stencil/core/internal/client';
import { c as businessClassificationOptions } from './business-form-options.js';
import { T as TAX_ID_MASKS, P as PHONE_MASKS } from './form-input-masks.js';
import { C as CoreBusinessInfo } from './Business.js';
import { h as heading2 } from './parts.js';
import { d as defineCustomElement$6 } from './custom-popper2.js';
import { d as defineCustomElement$5 } from './form-control-date2.js';
import { d as defineCustomElement$4 } from './form-control-number-masked2.js';
import { d as defineCustomElement$3 } from './form-control-select2.js';
import { d as defineCustomElement$2 } from './form-control-text2.js';
import { d as defineCustomElement$1 } from './form-control-tooltip2.js';

const BusinessCoreInfo = /*@__PURE__*/ proxyCustomElement(class BusinessCoreInfo extends HTMLElement {
    constructor() {
        super();
        this.__registerHost();
        this.errors = {};
        this.coreInfo = {};
        this.inputHandler = this.inputHandler.bind(this);
    }
    componentDidLoad() {
        this.formController.values.subscribe(values => (this.coreInfo = Object.assign({}, new CoreBusinessInfo(values))));
        this.formController.errors.subscribe(errors => {
            this.errors = Object.assign({}, errors);
        });
    }
    inputHandler(name, value) {
        this.formController.setValues(Object.assign(Object.assign({}, this.formController.values.getValue()), { [name]: value }));
    }
    render() {
        const coreInfoDefaultValue = this.formController.getInitialValues();
        return (h(Host, { key: '75bbee71e68fb0dafa609838f4d3e22bf4388332' }, h("fieldset", { key: '1e1cc71bfd46b278ad3f7d3a73d5b126fbf19533' }, h("legend", { key: '341b82942f116b4a2b0b29ce505fda3a153f88ec', part: heading2 }, "General Info"), h("div", { key: 'e97b3c3a38f888795c24c887d42854c79f1f7b34', class: "row gy-3" }, h("div", { key: '6d560585e9843143c836a302ad83b19719732467', class: "col-12" }, h("form-control-text", { key: '9868049d15e3f2552feba3ff6fa6b1ab43c7ae9c', name: "legal_name", label: "Legal Name", defaultValue: coreInfoDefaultValue.legal_name, errorText: this.errors.legal_name, inputHandler: this.inputHandler })), h("div", { key: 'f77c1d66117c29b6f5963a99bbb531f76242d052', class: "col-12" }, h("form-control-text", { key: '2708d678c35d4fa9838cd3fd834c77105b94feff', name: "doing_business_as", label: "Doing Business As (DBA)", defaultValue: coreInfoDefaultValue.doing_business_as, errorText: this.errors.doing_business_as, inputHandler: this.inputHandler })), h("div", { key: 'bb17f23c8f7fc1be73524dce8ed11ce9a9524a21', class: "col-12 col-md-8" }, h("form-control-select", { key: 'bc4175a9ed29127d89cf9c6135448c80733f6959', name: "classification", label: "Business Classification", options: businessClassificationOptions, defaultValue: coreInfoDefaultValue.classification, errorText: this.errors.classification, inputHandler: this.inputHandler })), h("div", { key: '6c5faad25c64ec50023be5128b8b0527584f9a7c', class: "col-12 col-md-4" }, h("form-control-date", { key: '54a151222d7eabc40a66ffbd5d0dba2e765cd135', name: "date_of_incorporation", label: "Date of Incorporation", defaultValue: coreInfoDefaultValue.date_of_incorporation, errorText: this.errors.date_of_incorporation, inputHandler: this.inputHandler })), h("div", { key: '5a562ba1811a319d2f5dd10197be2e1ecb94da8b', class: "col-12 col-md-6" }, h("form-control-text", { key: '03780a900fd4c176e5658b0784ef57eb48d2b3f7', name: "industry", label: "Industry", defaultValue: coreInfoDefaultValue.industry, errorText: this.errors.industry, inputHandler: this.inputHandler })), h("div", { key: '96e4110eb7b40f87a804b24a2ec94defca0be899', class: "col-12 col-md-6" }, h("form-control-number-masked", { key: '3cfda64e576a93bbed143b34c235b5388dade635', name: "tax_id", label: "Tax ID", defaultValue: coreInfoDefaultValue.tax_id, errorText: this.errors.tax_id, inputHandler: this.inputHandler, mask: TAX_ID_MASKS.US })), h("div", { key: '6a6e4d87838f2666c2750662c1f031f3b8d0effe', class: "col-12" }, h("form-control-text", { key: '68f28a6b78e2df1cd69631097a001369722d8081', name: "website_url", label: "Website URL", defaultValue: coreInfoDefaultValue.website_url, errorText: this.errors.website_url, inputHandler: this.inputHandler })), h("div", { key: '8a334f64bc214d1211772e5a5018b82dadd88d1a', class: "col-12 col-md-6" }, h("form-control-text", { key: '639888a2d30e785e1d403830c718b7991f28285a', name: "email", label: "Email Address", defaultValue: coreInfoDefaultValue.email, errorText: this.errors.email, inputHandler: this.inputHandler })), h("div", { key: 'b4aac33c17ce96c5c9a9ce5a90f322f69941df5e', class: "col-12 col-md-6" }, h("form-control-number-masked", { key: 'c384d24cc34fefca964a5eb412b28360361ab780', name: "phone", label: "Phone Number", defaultValue: coreInfoDefaultValue.phone, errorText: this.errors.phone, inputHandler: this.inputHandler, mask: PHONE_MASKS.US }))))));
    }
}, [0, "justifi-business-core-info", {
        "formController": [16, "form-controller"],
        "errors": [32],
        "coreInfo": [32]
    }]);
function defineCustomElement() {
    if (typeof customElements === "undefined") {
        return;
    }
    const components = ["justifi-business-core-info", "custom-popper", "form-control-date", "form-control-number-masked", "form-control-select", "form-control-text", "form-control-tooltip"];
    components.forEach(tagName => { switch (tagName) {
        case "justifi-business-core-info":
            if (!customElements.get(tagName)) {
                customElements.define(tagName, BusinessCoreInfo);
            }
            break;
        case "custom-popper":
            if (!customElements.get(tagName)) {
                defineCustomElement$6();
            }
            break;
        case "form-control-date":
            if (!customElements.get(tagName)) {
                defineCustomElement$5();
            }
            break;
        case "form-control-number-masked":
            if (!customElements.get(tagName)) {
                defineCustomElement$4();
            }
            break;
        case "form-control-select":
            if (!customElements.get(tagName)) {
                defineCustomElement$3();
            }
            break;
        case "form-control-text":
            if (!customElements.get(tagName)) {
                defineCustomElement$2();
            }
            break;
        case "form-control-tooltip":
            if (!customElements.get(tagName)) {
                defineCustomElement$1();
            }
            break;
    } });
}
defineCustomElement();

export { BusinessCoreInfo as B, defineCustomElement as d };
