import { h, Fragment, proxyCustomElement, HTMLElement, createEvent } from '@stencil/core/internal/client';
import { E as ErrorState } from './utils.js';
import { S as StyledHost } from './styled-host.js';
import { d as defineCustomElement$4 } from './details.js';
import './event-types.js';
import './justifi-radio-list-item2.js';
import { S as Skeleton } from './skeleton.js';
import { d as defineCustomElement$6 } from './additional-questions-details2.js';
import { d as defineCustomElement$5 } from './core-info-details2.js';
import { d as defineCustomElement$3 } from './legal-address-details2.js';
import { d as defineCustomElement$2 } from './owner-details2.js';
import { d as defineCustomElement$1 } from './representative-details2.js';

const BusinessDetailsLoading = () => {
    const Block = () => (h("div", { class: "mt-5" },
        h(Skeleton, { width: "40%", height: "1.5rem" }),
        h("hr", null),
        h("div", { class: "row g-3" },
            h("div", { class: "col-12 col-md-6" },
                h(Skeleton, null),
                h(Skeleton, null),
                h(Skeleton, null)),
            h("div", { class: "col-12 col-md-6" },
                h(Skeleton, null),
                h(Skeleton, null),
                h(Skeleton, null)))));
    return (h(Fragment, null,
        h(Block, null),
        h(Block, null),
        h(Block, null),
        h(Block, null)));
};

var RENDER_STATES;
(function (RENDER_STATES) {
    RENDER_STATES["LOADING"] = "loading";
    RENDER_STATES["READY"] = "ready";
    RENDER_STATES["ERROR"] = "error";
})(RENDER_STATES || (RENDER_STATES = {}));
const BusinessDetailsCore = /*@__PURE__*/ proxyCustomElement(class BusinessDetailsCore extends HTMLElement {
    constructor() {
        super();
        this.__registerHost();
        this.errorEvent = createEvent(this, "error-event", 7);
        this.renderState = RENDER_STATES.LOADING;
    }
    async componentWillLoad() {
        if (this.getBusiness) {
            this.fetchData();
        }
    }
    fetchData() {
        this.renderState = RENDER_STATES.LOADING;
        this.getBusiness({
            onSuccess: ({ business }) => {
                this.business = business;
                this.renderState = RENDER_STATES.READY;
            },
            onError: ({ error, code, severity }) => {
                this.errorMessage = error;
                this.renderState = RENDER_STATES.ERROR;
                this.errorEvent.emit({
                    errorCode: code,
                    message: error,
                    severity,
                });
            }
        });
    }
    render() {
        if (this.renderState === RENDER_STATES.LOADING) {
            return (h(StyledHost, null, h(BusinessDetailsLoading, null)));
        }
        if (this.renderState === RENDER_STATES.ERROR) {
            return h(StyledHost, null, ErrorState(this.errorMessage));
        }
        return (h(StyledHost, null, h("justifi-details", { "error-message": this.errorMessage }, h("div", { slot: 'detail-sections' }, h("core-info-details", { business: this.business }), h("legal-address-details", { legalAddress: this.business.legal_address }), h("representative-details", { representative: this.business.representative }), h("owner-details", { owners: this.business.owners }), h("additional-questions-details", { additionalQuestions: this.business.additional_questions })))));
    }
}, [0, "business-details-core", {
        "getBusiness": [16, "get-business"],
        "business": [32],
        "renderState": [32],
        "errorMessage": [32]
    }]);
function defineCustomElement() {
    if (typeof customElements === "undefined") {
        return;
    }
    const components = ["business-details-core", "additional-questions-details", "core-info-details", "justifi-details", "legal-address-details", "owner-details", "representative-details"];
    components.forEach(tagName => { switch (tagName) {
        case "business-details-core":
            if (!customElements.get(tagName)) {
                customElements.define(tagName, BusinessDetailsCore);
            }
            break;
        case "additional-questions-details":
            if (!customElements.get(tagName)) {
                defineCustomElement$6();
            }
            break;
        case "core-info-details":
            if (!customElements.get(tagName)) {
                defineCustomElement$5();
            }
            break;
        case "justifi-details":
            if (!customElements.get(tagName)) {
                defineCustomElement$4();
            }
            break;
        case "legal-address-details":
            if (!customElements.get(tagName)) {
                defineCustomElement$3();
            }
            break;
        case "owner-details":
            if (!customElements.get(tagName)) {
                defineCustomElement$2();
            }
            break;
        case "representative-details":
            if (!customElements.get(tagName)) {
                defineCustomElement$1();
            }
            break;
    } });
}
defineCustomElement();

export { BusinessDetailsCore as B, defineCustomElement as d };
