import { h, proxyCustomElement, HTMLElement } from '@stencil/core/internal/client';
import { S as Skeleton } from './skeleton.js';
import './details.js';
import './event-types.js';
import './justifi-radio-list-item2.js';
import { S as StyledHost } from './styled-host.js';
import { c as checkPkgVersion, J as JustifiAnalytics } from './Analytics.js';
import { w as waitForConfig, c as configState } from './config-state.js';
import { d as defineCustomElement$2 } from './hidden-input2.js';
import { d as defineCustomElement$1 } from './iframe-input2.js';

const CardFormSkeleton = (props) => {
    const { isReady } = props;
    if (isReady) {
        return null;
    }
    return (h("div", { class: "container-fluid p-0" },
        h("div", { class: "mb-3" },
            h(Skeleton, { height: "18px", width: "100px" }),
            h(Skeleton, { height: "36px" })),
        h("div", { class: "row" },
            h("div", { class: "col-4 align-content-end" },
                h(Skeleton, { height: "18px", width: "80px" }),
                h(Skeleton, { height: "36px" })),
            h("div", { class: "col-4 align-content-end" },
                h(Skeleton, { height: "36px" })),
            h("div", { class: "col-4 align-content-end" },
                h(Skeleton, { height: "18px", width: "30px" }),
                h(Skeleton, { height: "36px" })))));
};

const JustifiCardForm = /*@__PURE__*/ proxyCustomElement(class JustifiCardForm extends HTMLElement {
    constructor() {
        super();
        this.__registerHost();
        this.__attachShadow();
        this.isReady = false;
    }
    async componentWillLoad() {
        await waitForConfig();
        this.iframeOrigin = configState.iframeOrigin;
        checkPkgVersion();
        this.analytics = new JustifiAnalytics(this);
    }
    componentDidRender() {
        const elements = [
            this.cardNumberIframeElement,
            this.expirationMonthIframeElement,
            this.expirationYearIframeElement,
            this.cvvIframeElement,
        ];
        Promise.all(elements.map((element) => {
            return new Promise((resolve) => {
                element.addEventListener('iframeLoaded', () => { resolve(); });
            });
        })).then(() => {
            this.isReady = true;
        });
    }
    disconnectedCallback() {
        var _a;
        (_a = this.analytics) === null || _a === void 0 ? void 0 : _a.cleanup();
    }
    async validate() {
        const cardNumberIsValid = await this.cardNumberIframeElement.validate();
        const expirationMonthIsValid = await this.expirationMonthIframeElement.validate();
        const expirationYearIsValid = await this.expirationYearIframeElement.validate();
        const cvvIsValid = await this.cvvIframeElement.validate();
        return cardNumberIsValid && expirationMonthIsValid && expirationYearIsValid && cvvIsValid;
    }
    async tokenize({ clientId, paymentMethodMetadata, account, }) {
        return this.cardNumberIframeElement.tokenize(clientId, paymentMethodMetadata, account);
    }
    render() {
        return (h(StyledHost, { key: 'c6a8109b35d9ef920747aadf75bea99bbba4ae21' }, h(CardFormSkeleton, { key: 'c1868489482ccb4125ffb47f981638a2c6016ffe', isReady: this.isReady }), h("hidden-input", { key: 'f21158c4fe6e63b8ffebbb084830e0331af5979a' }), h("div", { key: '8a4852e0a2e2db75672af221a0c9ca9822602da2', class: "container-fluid p-0", style: {
                opacity: this.isReady ? '1' : '0',
                height: this.isReady ? 'auto' : '0',
            } }, h("div", { key: '437a1e6d5d1dd7517fa87d876f017f28fb4f8c15', class: "mb-3" }, h("iframe-input", { key: '0d8582e8b9eb4fdd9a3c4e1c86eda90fa9eadf13', inputId: "cardNumber", ref: (el) => (this.cardNumberIframeElement = el), label: "Card Number", iframeOrigin: `${this.iframeOrigin}/v2/cardNumber` })), h("div", { key: '8311f0aac3f3826802d2fec0fd7de9ceae6af06c', class: "row" }, h("div", { key: '50c24e8cd76931f3ea19ffc3d4e52607f4bed78c', class: "col-4 align-content-end" }, h("iframe-input", { key: '82e610abedf2d4f42eb67e05a4de3a349fe0ff59', inputId: "expirationMonth", ref: (el) => (this.expirationMonthIframeElement = el), label: "Expiration", iframeOrigin: `${this.iframeOrigin}/v2/expirationMonth` })), h("div", { key: 'fa13540819346d3caf09d863a7bb6d2a2ea47cb0', class: "col-4 align-content-end" }, h("iframe-input", { key: '5292e69953eb0fbd3b36871fe7bd433e791f60f9', inputId: "expirationYear", ref: (el) => (this.expirationYearIframeElement = el), label: "", iframeOrigin: `${this.iframeOrigin}/v2/expirationYear` })), h("div", { key: 'd6ddb4af11e44ed0f1de6273c0d3fd0ba19522ad', class: "col-4 align-content-end" }, h("iframe-input", { key: '7491af49747367001b8eee954cd18464d929431b', inputId: "CVV", ref: (el) => (this.cvvIframeElement = el), label: "CVV", iframeOrigin: `${this.iframeOrigin}/v2/CVV` }))))));
    }
}, [1, "justifi-card-form", {
        "isReady": [32],
        "iframeOrigin": [32],
        "validate": [64],
        "tokenize": [64]
    }]);
function defineCustomElement() {
    if (typeof customElements === "undefined") {
        return;
    }
    const components = ["justifi-card-form", "hidden-input", "iframe-input"];
    components.forEach(tagName => { switch (tagName) {
        case "justifi-card-form":
            if (!customElements.get(tagName)) {
                customElements.define(tagName, JustifiCardForm);
            }
            break;
        case "hidden-input":
            if (!customElements.get(tagName)) {
                defineCustomElement$2();
            }
            break;
        case "iframe-input":
            if (!customElements.get(tagName)) {
                defineCustomElement$1();
            }
            break;
    } });
}
defineCustomElement();

export { JustifiCardForm as J, defineCustomElement as d };
