import { proxyCustomElement, HTMLElement, h } from '@stencil/core/internal/client';
import { c as create$3, a as create$6, F as FormController } from './form.js';
import { D as DisputeResponseFormStep, f as fileInputHandler } from './file-input-handler.js';
import { _ as heading5 } from './parts.js';
import { d as defineCustomElement$6 } from './custom-popper2.js';
import { d as defineCustomElement$5 } from './form-control-file-v22.js';
import { d as defineCustomElement$4 } from './form-control-help-text2.js';
import { d as defineCustomElement$3 } from './form-control-text2.js';
import { d as defineCustomElement$2 } from './form-control-textarea2.js';
import { d as defineCustomElement$1 } from './form-control-tooltip2.js';

const CustomerDetailsSchema = create$3({
    customer_name: create$6().nullable(),
    customer_email_address: create$6().nullable(),
    customer_billing_address: create$6().nullable(),
});

const CustomerDetails = /*@__PURE__*/ proxyCustomElement(class CustomerDetails extends HTMLElement {
    constructor() {
        super();
        this.__registerHost();
        this.documentErrors = {};
        this.errors = {};
        this.documents = { customer_signature: [], customer_communication: [] };
        this.inputHandler = (name, value) => {
            this.form.setValues(Object.assign(Object.assign({}, this.form.values.getValue()), { [name]: value }));
        };
    }
    async validateAndSubmit(onSuccess) {
        const documentList = Object.values(this.documents).flat();
        this.form.validateAndSubmit((formData) => onSuccess(formData, documentList, DisputeResponseFormStep.customerDetails));
    }
    ;
    componentWillLoad() {
        this.form = new FormController(CustomerDetailsSchema);
    }
    componentDidLoad() {
        this.form.errors.subscribe(errors => {
            this.errors = Object.assign({}, errors);
        });
    }
    render() {
        var _a, _b, _c, _d, _e;
        return (h("div", { key: 'f5442efc59bb6a99a87f90feb5a4a147019af940' }, h("div", { key: 'd0f97e7ca943bfe8e4846ea84838ab08dc3658ab', class: "row gy-3" }, h("div", { key: 'da7f41d96c717f921010786f593c3776e2644738', class: "col-12" }, h("h2", { key: '0f7d56f400ec0f4250bbf7c8b2b736e084c17ab0', class: "h5", part: heading5 }, "Customer Details")), h("div", { key: 'eca73b10ec43454be35d4ec6e09b410b7a509b46', class: "col-12" }, h("form-control-text", { key: '1b67e031f3ac24b43319b09a01a5e297095ecc84', label: "Full Name", name: "customer_name", defaultValue: (_a = this.disputeResponse) === null || _a === void 0 ? void 0 : _a.customer_name, inputHandler: this.inputHandler, errorText: this.errors.customer_name })), h("div", { key: '967326bb10e6d2a64b2f3f0bae99432f238e361c', class: "col-12" }, h("form-control-text", { key: 'fc7d83cc51728920d9f4849dd85f4f019bb50fe4', label: "Email", name: "customer_email_address", defaultValue: (_b = this.disputeResponse) === null || _b === void 0 ? void 0 : _b.customer_email_address, inputHandler: this.inputHandler, errorText: this.errors.customer_email_address })), h("div", { key: '4e598f3e9bf118ddf22c4c160f0171c9789cd853', class: "col-12" }, h("form-control-textarea", { key: 'fe1c2e1a4c70ef463a31e890349a5b49f979e21b', label: "Billing Address", name: "customer_billing_address", defaultValue: (_c = this.disputeResponse) === null || _c === void 0 ? void 0 : _c.customer_billing_address, inputHandler: this.inputHandler, errorText: this.errors.customer_billing_address })), h("div", { key: 'a4345bc3b39f913cc233baa21373a6d7d93d3cda', class: "col-12" }, h("form-control-file-v2", { key: '82cb1b948807d901845a23137b5d488c9edd53ae', label: "Customer Signature", name: "customer_signature", onChange: (e) => fileInputHandler(e, this.documents), errorText: (_d = this.documentErrors) === null || _d === void 0 ? void 0 : _d.customer_signature })), h("div", { key: 'ffc589785e6114d604c2d98d3140de5487dc8af6', class: "col-12" }, h("form-control-file-v2", { key: '5b6b64927e4b90cc6dbb302fbc0d2067b70c6f4a', label: "Customer Communication", name: "customer_communication", onChange: (e) => fileInputHandler(e, this.documents), errorText: (_e = this.documentErrors) === null || _e === void 0 ? void 0 : _e.customer_communication })))));
    }
}, [0, "justifi-customer-details", {
        "disputeResponse": [8, "dispute-response"],
        "documentErrors": [8, "document-errors"],
        "form": [32],
        "errors": [32],
        "documents": [32],
        "validateAndSubmit": [64]
    }]);
function defineCustomElement() {
    if (typeof customElements === "undefined") {
        return;
    }
    const components = ["justifi-customer-details", "custom-popper", "form-control-file-v2", "form-control-help-text", "form-control-text", "form-control-textarea", "form-control-tooltip"];
    components.forEach(tagName => { switch (tagName) {
        case "justifi-customer-details":
            if (!customElements.get(tagName)) {
                customElements.define(tagName, CustomerDetails);
            }
            break;
        case "custom-popper":
            if (!customElements.get(tagName)) {
                defineCustomElement$6();
            }
            break;
        case "form-control-file-v2":
            if (!customElements.get(tagName)) {
                defineCustomElement$5();
            }
            break;
        case "form-control-help-text":
            if (!customElements.get(tagName)) {
                defineCustomElement$4();
            }
            break;
        case "form-control-text":
            if (!customElements.get(tagName)) {
                defineCustomElement$3();
            }
            break;
        case "form-control-textarea":
            if (!customElements.get(tagName)) {
                defineCustomElement$2();
            }
            break;
        case "form-control-tooltip":
            if (!customElements.get(tagName)) {
                defineCustomElement$1();
            }
            break;
    } });
}
defineCustomElement();

export { CustomerDetails as C, defineCustomElement as d };
