import { proxyCustomElement, HTMLElement, createEvent, h } from '@stencil/core/internal/client';
import { D as DisputeManagementClickActions } from './event-types3.js';
import { D as Dispute, b as DisputeStatus } from './Refund.js';
import { d as defineCustomElement$i } from './custom-popper2.js';
import { d as defineCustomElement$h } from './form-control-date2.js';
import { d as defineCustomElement$g } from './form-control-file-v22.js';
import { d as defineCustomElement$f } from './form-control-help-text2.js';
import { d as defineCustomElement$e } from './form-control-text2.js';
import { d as defineCustomElement$d } from './form-control-textarea2.js';
import { d as defineCustomElement$c } from './form-control-tooltip2.js';
import { d as defineCustomElement$b } from './additional-statement.js';
import { d as defineCustomElement$a } from './cancellation-policy.js';
import { d as defineCustomElement$9 } from './customer-details.js';
import { d as defineCustomElement$8 } from './dispute-notification.js';
import { d as defineCustomElement$7 } from './dispute-response.js';
import { d as defineCustomElement$6 } from './dispute-response-core.js';
import { d as defineCustomElement$5 } from './duplicate-charge.js';
import { d as defineCustomElement$4 } from './electronic-evidence.js';
import { d as defineCustomElement$3 } from './product-or-service.js';
import { d as defineCustomElement$2 } from './refund-policy.js';
import { d as defineCustomElement$1 } from './shipping-details.js';

const DisputeManagementCore = /*@__PURE__*/ proxyCustomElement(class DisputeManagementCore extends HTMLElement {
    constructor() {
        super();
        this.__registerHost();
        this.errorEvent = createEvent(this, "error-event", 7);
        this.isLoading = true;
        this.showDisputeResponseForm = false;
    }
    disputeResponseHandler(event) {
        if (event.detail.name === DisputeManagementClickActions.respondToDispute) {
            this.showDisputeResponseForm = true;
        }
        if (event.detail.name === DisputeManagementClickActions.cancelDispute) {
            this.showDisputeResponseForm = false;
        }
    }
    disputeSubmittedHandler() {
        this.fetchData();
    }
    componentWillLoad() {
        if (this.getDispute) {
            this.fetchData();
        }
    }
    updateOnPropChange() {
        this.fetchData();
    }
    fetchData() {
        this.isLoading = true;
        this.getDispute({
            onSuccess: ({ dispute }) => {
                this.dispute = new Dispute(dispute);
                this.isLoading = false;
                if (this.dispute.status !== DisputeStatus.needsResponse) {
                    this.showDisputeResponseForm = false;
                }
            },
            onError: ({ error, code, severity }) => {
                this.errorEvent.emit({
                    errorCode: code,
                    message: error,
                    severity,
                });
                this.isLoading = false;
            },
        });
    }
    render() {
        return (h("div", { key: 'b5a802e8c418b3b7f3235f43260186084a6ee079' }, this.showDisputeResponseForm ? (h("justifi-dispute-response", { disputeId: this.disputeId, disputeResponse: this.dispute.dispute_response, authToken: this.authToken })) : (h("justifi-dispute-notification", { dispute: this.dispute, authToken: this.authToken, isLoading: this.isLoading }))));
    }
    static get watchers() { return {
        "getDispute": ["updateOnPropChange"]
    }; }
}, [0, "justifi-dispute-management-core", {
        "getDispute": [16, "get-dispute"],
        "disputeId": [1, "dispute-id"],
        "authToken": [1, "auth-token"],
        "dispute": [32],
        "isLoading": [32],
        "showDisputeResponseForm": [32]
    }, [[0, "click-event", "disputeResponseHandler"], [0, "submit-event", "disputeSubmittedHandler"]], {
        "getDispute": ["updateOnPropChange"]
    }]);
function defineCustomElement() {
    if (typeof customElements === "undefined") {
        return;
    }
    const components = ["justifi-dispute-management-core", "custom-popper", "form-control-date", "form-control-file-v2", "form-control-help-text", "form-control-text", "form-control-textarea", "form-control-tooltip", "justifi-additional-statement", "justifi-cancellation-policy", "justifi-customer-details", "justifi-dispute-notification", "justifi-dispute-response", "justifi-dispute-response-core", "justifi-duplicate-charge", "justifi-electronic-evidence", "justifi-product-or-service", "justifi-refund-policy", "justifi-shipping-details"];
    components.forEach(tagName => { switch (tagName) {
        case "justifi-dispute-management-core":
            if (!customElements.get(tagName)) {
                customElements.define(tagName, DisputeManagementCore);
            }
            break;
        case "custom-popper":
            if (!customElements.get(tagName)) {
                defineCustomElement$i();
            }
            break;
        case "form-control-date":
            if (!customElements.get(tagName)) {
                defineCustomElement$h();
            }
            break;
        case "form-control-file-v2":
            if (!customElements.get(tagName)) {
                defineCustomElement$g();
            }
            break;
        case "form-control-help-text":
            if (!customElements.get(tagName)) {
                defineCustomElement$f();
            }
            break;
        case "form-control-text":
            if (!customElements.get(tagName)) {
                defineCustomElement$e();
            }
            break;
        case "form-control-textarea":
            if (!customElements.get(tagName)) {
                defineCustomElement$d();
            }
            break;
        case "form-control-tooltip":
            if (!customElements.get(tagName)) {
                defineCustomElement$c();
            }
            break;
        case "justifi-additional-statement":
            if (!customElements.get(tagName)) {
                defineCustomElement$b();
            }
            break;
        case "justifi-cancellation-policy":
            if (!customElements.get(tagName)) {
                defineCustomElement$a();
            }
            break;
        case "justifi-customer-details":
            if (!customElements.get(tagName)) {
                defineCustomElement$9();
            }
            break;
        case "justifi-dispute-notification":
            if (!customElements.get(tagName)) {
                defineCustomElement$8();
            }
            break;
        case "justifi-dispute-response":
            if (!customElements.get(tagName)) {
                defineCustomElement$7();
            }
            break;
        case "justifi-dispute-response-core":
            if (!customElements.get(tagName)) {
                defineCustomElement$6();
            }
            break;
        case "justifi-duplicate-charge":
            if (!customElements.get(tagName)) {
                defineCustomElement$5();
            }
            break;
        case "justifi-electronic-evidence":
            if (!customElements.get(tagName)) {
                defineCustomElement$4();
            }
            break;
        case "justifi-product-or-service":
            if (!customElements.get(tagName)) {
                defineCustomElement$3();
            }
            break;
        case "justifi-refund-policy":
            if (!customElements.get(tagName)) {
                defineCustomElement$2();
            }
            break;
        case "justifi-shipping-details":
            if (!customElements.get(tagName)) {
                defineCustomElement$1();
            }
            break;
    } });
}
defineCustomElement();

export { DisputeManagementCore as D, defineCustomElement as d };
