import { proxyCustomElement, HTMLElement, createEvent, h } from '@stencil/core/internal/client';
import { c as formatCurrency } from './utils2.js';
import { t as text, X as heading4 } from './parts.js';
import { B as Button } from './button.js';
import { S as StyledHost } from './styled-host.js';
import { S as Skeleton } from './skeleton.js';
import './details.js';
import './event-types.js';
import './justifi-radio-list-item2.js';
import { m as makeSubmitDisputeResponse, D as DisputeService } from './dispute-response-actions.js';
import { D as DisputeManagementClickActions } from './event-types3.js';

const DisputeNotification = /*@__PURE__*/ proxyCustomElement(class DisputeNotification extends HTMLElement {
    constructor() {
        super();
        this.__registerHost();
        this.__attachShadow();
        this.clickEvent = createEvent(this, "click-event", 7);
        this.errorEvent = createEvent(this, "error-event", 7);
        this.submitEvent = createEvent(this, "submit-event", 7);
    }
    acceptDispute() {
        makeSubmitDisputeResponse({
            disputeId: this.dispute.id,
            authToken: this.authToken,
            service: new DisputeService()
        })({
            payload: { forfeit: true },
            onSuccess: (response) => {
                this.submitEvent.emit({ response: response });
            },
            onError: ({ error, code, severity }) => {
                this.errorEvent.emit({
                    errorCode: code,
                    message: error,
                    severity,
                });
            },
        });
    }
    initiateRespondToDispute() {
        this.clickEvent.emit({ name: DisputeManagementClickActions.respondToDispute });
    }
    render() {
        var _a, _b, _c, _d, _e, _f, _g;
        return (h(StyledHost, { key: '90d2506d5bde2ea478fa3575fc162bb356b67fac' }, this.isLoading && (h("div", { key: '4877ae22d3d8e312640b122c9107b6bdd8f924cb', style: { marginBottom: '8px' } }, h(Skeleton, { key: '31fa0717949bbc6aa49db1c6ae0e324099ae1de2', height: '28px', width: '70%', styles: { marginBottom: '16px' } }), h(Skeleton, { key: 'ac5179232cb9ee33d3f3e16d9f93536ecfbf46a5', height: '18px', styles: { marginBottom: '8px' } }), h(Skeleton, { key: 'c22a5e3b257d01f92de7f6188fa0758861abc747', height: '18px', styles: { marginBottom: '8px' } }))), ((_a = this.dispute) === null || _a === void 0 ? void 0 : _a.needsResponse) && (h("div", { key: 'be331b1a5e2fa0baf46bc593ef7ce4f5872abcff', part: text }, h("h1", { key: '8094c16d3b375f28ffe314613f21ae25b63e59ef', class: "h4", part: heading4 }, "This payment is disputed"), h("p", { key: 'd89ae665e1f9bd99c9338e2132c1dc56e5386696' }, "The cardholder is disputing this payment. You may accept this dispute, or proceed to provide evidence in a counter dispute."), h("h2", { key: '2786733eac76628019993e13473d1f43c0c395ed', class: "h5" }, "Dispute details"), h("div", { key: '663c28c46136bd56889b6ad0b9bfce9e5adbb590', class: "d-table gap-2" }, h("div", { key: 'dc688fad875d1591dcb7f31d423b61a3df2ff954', class: "d-table-row gap-2" }, h("span", { key: '442db7a6e95524ca6b092794c7a4a4d987c9866e', part: "detail-section-item-title", class: "fw-bold d-table-cell pe-4" }, "Amount"), h("span", { key: '0a31de8692c9b00f43fcf3c0508e4d00a221d096', part: "detail-section-item-data", class: "flex-1 d-table-cell text-wrap" }, formatCurrency((_b = this.dispute) === null || _b === void 0 ? void 0 : _b.amount))), h("div", { key: '9fe0c1a3d3350c36fca190ae748dafe24d41b5fc', class: "d-table-row gap-2" }, h("span", { key: '12165cb6671519130a5f2e0d8938aaa55e7e3ead', part: "detail-section-item-title", class: "fw-bold d-table-cell pe-4" }, "Reason"), h("span", { key: '4a37ca8a7d64b97142997bb50ec11d737ac6a882', part: "detail-section-item-data", class: "flex-1 d-table-cell text-wrap" }, (_c = this.dispute) === null || _c === void 0 ? void 0 : _c.reason)), h("div", { key: '4d9cf74a8ed26dd84e4ce7325d4b8703352362a4', class: "d-table-row gap-2" }, h("span", { key: '8c0eaa24ebec7703eb18384b0b1f2eae8a684b55', part: "detail-section-item-title", class: "fw-bold d-table-cell pe-4" }, "Dispute ID"), h("span", { key: '238813abf2ea0848e1fe817d5798b9b0d0b78ffc', part: "detail-section-item-data", class: "flex-1 d-table-cell text-wrap" }, (_d = this.dispute) === null || _d === void 0 ? void 0 : _d.id))), h("div", { key: 'd156a7e9bf0e7214ff2164fc09b12c0b8f1d2b36', class: "d-flex gap-2 mt-4 justify-content-end" }, h(Button, { key: '7822fd12dfc39bd2aced043956d012fd34cc1b01', variant: "secondary", onClick: () => this.acceptDispute() }, "Accept dispute"), h(Button, { key: '05132b3a6d1fc3d136dc227008ea1999330cdb96', variant: "primary", onClick: () => this.initiateRespondToDispute() }, "Counter dispute")))), ((_e = this.dispute) === null || _e === void 0 ? void 0 : _e.underReview) && (h("div", { key: 'b04dd0c34f608b75ea3997a9c28ce948fa9dba5c' }, h("h1", { key: 'ac2a13373315703e86247b6707097af7cf2e6757', class: "h4" }, "This payment is disputed and under review"), h("p", { key: '203aed553e01bbaebe44bb370a1d088c149cda06' }, "The cardholder is disputing this payment. A counter dispute has been submitted and is under review."))), ((_f = this.dispute) === null || _f === void 0 ? void 0 : _f.won) && (h("div", { key: '6325264f8ad7b6678825878ed59f03f90eee421a' }, h("h1", { key: '7b647ed77373884e0751de4fc39403211c249db6', class: "h4" }, "This payment was disputed"), h("p", { key: '2a5c1560d341af9b743234a058a1187f245a2ae8' }, "The cardholder disputed this payment and the card issuer has settled it in your favor."))), ((_g = this.dispute) === null || _g === void 0 ? void 0 : _g.lost) && (h("div", { key: 'a89e7f4d7e8926ed052023c7dbbbaf076a03ed9c' }, h("h1", { key: '534b560aa35dd43ba0eba668904ef70dc1a6954f', class: "h4" }, "This payment was disputed"), h("p", { key: '2381f2f6418b47dce67c498c56d5f3789add57dc' }, "The cardholder disputed this payment and the card issuer has settled it in their favor.")))));
    }
}, [1, "justifi-dispute-notification", {
        "dispute": [16],
        "authToken": [1, "auth-token"],
        "isLoading": [4, "is-loading"]
    }]);
function defineCustomElement() {
    if (typeof customElements === "undefined") {
        return;
    }
    const components = ["justifi-dispute-notification"];
    components.forEach(tagName => { switch (tagName) {
        case "justifi-dispute-notification":
            if (!customElements.get(tagName)) {
                customElements.define(tagName, DisputeNotification);
            }
            break;
    } });
}
defineCustomElement();

export { DisputeNotification as D, defineCustomElement as d };
