import { A as Api } from './Api.js';
import { C as ComponentErrorSeverity } from './Refund.js';
import './Pagination.js';
import './Business.js';
import { g as getErrorCode, a as getErrorMessage } from './utils4.js';

const api = Api();
class DisputeService {
    async fetchDispute(disputeId, authToken) {
        const endpoint = `disputes/${disputeId}`;
        return api.get({ endpoint, authToken });
    }
    async updateDisputeResponse(disputeId, authToken, payload) {
        const endpoint = `disputes/${disputeId}/response`;
        const body = payload;
        return api.patch({ endpoint, body, authToken });
    }
    async submitDisputeResponse(disputeId, authToken, payload) {
        const endpoint = `disputes/${disputeId}/response`;
        const body = payload;
        return api.post({ endpoint, body, authToken });
    }
    async createDisputeEvidence(disputeId, authToken, payload) {
        const endpoint = `disputes/${disputeId}/evidence`;
        const body = payload;
        return api.put({ endpoint, body, authToken });
    }
}

const makeUpdateDisputeResponse = ({ authToken, disputeId, service }) => async ({ payload, onSuccess, onError, final = () => { } }) => {
    var _a;
    try {
        const response = await service.updateDisputeResponse(disputeId, authToken, payload);
        if (!response.error) {
            onSuccess(response);
        }
        else {
            const responseError = getErrorMessage(response.error);
            const code = getErrorCode((_a = response.error) === null || _a === void 0 ? void 0 : _a.code);
            return onError({
                error: responseError,
                code,
                severity: ComponentErrorSeverity.ERROR,
            });
        }
    }
    catch (error) {
        const code = getErrorCode(error === null || error === void 0 ? void 0 : error.code);
        return onError({
            error: error.message || error,
            code,
            severity: ComponentErrorSeverity.ERROR,
        });
    }
    finally {
        return final();
    }
};
const makeSubmitDisputeResponse = ({ authToken, disputeId, service }) => async ({ payload, onSuccess, onError, final = () => { } }) => {
    var _a;
    try {
        const response = await service.submitDisputeResponse(disputeId, authToken, payload);
        if (!response.error) {
            onSuccess(response);
        }
        else {
            const responseError = getErrorMessage(response.error);
            const code = getErrorCode((_a = response.error) === null || _a === void 0 ? void 0 : _a.code);
            return onError({
                error: responseError,
                code,
                severity: ComponentErrorSeverity.ERROR,
            });
        }
    }
    catch (error) {
        const code = getErrorCode(error === null || error === void 0 ? void 0 : error.code);
        return onError({
            error: error.message || error,
            code,
            severity: ComponentErrorSeverity.ERROR,
        });
    }
    finally {
        return final();
    }
};
const makeCreateDisputeEvidence = ({ authToken, disputeId, service }) => async ({ payload, onSuccess, onError, final = () => { } }) => {
    var _a;
    try {
        const response = await service.createDisputeEvidence(disputeId, authToken, payload);
        if (!response.error) {
            onSuccess(response);
        }
        else {
            const responseError = getErrorMessage(response.error);
            const code = getErrorCode((_a = response.error) === null || _a === void 0 ? void 0 : _a.code);
            return onError({
                error: responseError,
                code,
                severity: ComponentErrorSeverity.ERROR,
            });
        }
    }
    catch (error) {
        const code = getErrorCode(error === null || error === void 0 ? void 0 : error.code);
        return onError({
            error: error.message || error,
            code,
            severity: ComponentErrorSeverity.ERROR,
        });
    }
    finally {
        return final();
    }
};

export { DisputeService as D, makeUpdateDisputeResponse as a, makeCreateDisputeEvidence as b, makeSubmitDisputeResponse as m };
