import { proxyCustomElement, HTMLElement, createEvent, h } from '@stencil/core/internal/client';
import { c as checkPkgVersion, J as JustifiAnalytics } from './Analytics.js';
import { S as StyledHost } from './styled-host.js';
import './details.js';
import './event-types.js';
import './justifi-radio-list-item2.js';
import { a as makeUpdateDisputeResponse, b as makeCreateDisputeEvidence, m as makeSubmitDisputeResponse, D as DisputeService } from './dispute-response-actions.js';
import { C as ComponentErrorSeverity, a as ComponentErrorCodes } from './Refund.js';
import { d as defineCustomElement$g } from './custom-popper2.js';
import { d as defineCustomElement$f } from './form-control-date2.js';
import { d as defineCustomElement$e } from './form-control-file-v22.js';
import { d as defineCustomElement$d } from './form-control-help-text2.js';
import { d as defineCustomElement$c } from './form-control-text2.js';
import { d as defineCustomElement$b } from './form-control-textarea2.js';
import { d as defineCustomElement$a } from './form-control-tooltip2.js';
import { d as defineCustomElement$9 } from './additional-statement.js';
import { d as defineCustomElement$8 } from './cancellation-policy.js';
import { d as defineCustomElement$7 } from './customer-details.js';
import { d as defineCustomElement$6 } from './dispute-response-core.js';
import { d as defineCustomElement$5 } from './duplicate-charge.js';
import { d as defineCustomElement$4 } from './electronic-evidence.js';
import { d as defineCustomElement$3 } from './product-or-service.js';
import { d as defineCustomElement$2 } from './refund-policy.js';
import { d as defineCustomElement$1 } from './shipping-details.js';

const DisputeResponse = /*@__PURE__*/ proxyCustomElement(class DisputeResponse extends HTMLElement {
    constructor() {
        super();
        this.__registerHost();
        this.__attachShadow();
        this.errorEvent = createEvent(this, "error-event", 7);
        this.errorMessage = null;
        this.apiOrigin = "https://wc-proxy.justifi.ai";
        this.handleErrorEvent = (event) => {
            this.errorMessage = event.detail.message;
            this.errorEvent.emit(event.detail);
        };
    }
    componentWillLoad() {
        checkPkgVersion();
        this.analytics = new JustifiAnalytics(this);
        this.initializeDisputeServiceMethods();
    }
    disconnectedCallback() {
        var _a;
        (_a = this.analytics) === null || _a === void 0 ? void 0 : _a.cleanup();
    }
    ;
    propChanged() {
        this.initializeDisputeServiceMethods();
    }
    initializeDisputeServiceMethods() {
        if (this.disputeId && this.authToken) {
            this.updateDisputeResponse = makeUpdateDisputeResponse({
                disputeId: this.disputeId,
                authToken: this.authToken,
                service: new DisputeService()
            });
            this.createDisputeEvidence = makeCreateDisputeEvidence({
                disputeId: this.disputeId,
                authToken: this.authToken,
                service: new DisputeService()
            });
            this.submitDisputeResponse = makeSubmitDisputeResponse({
                disputeId: this.disputeId,
                authToken: this.authToken,
                service: new DisputeService()
            });
        }
        else {
            this.errorMessage = 'Account ID and Auth Token are required';
            this.errorEvent.emit({
                errorCode: ComponentErrorCodes.MISSING_PROPS,
                message: this.errorMessage,
                severity: ComponentErrorSeverity.ERROR,
            });
        }
    }
    render() {
        return (h(StyledHost, { key: 'b90f636418c3e11b046d36dee9accf345756b407' }, h("justifi-dispute-response-core", { key: 'ff6e510faad54506eda24b1d8dc94b67afc18014', "onError-event": this.handleErrorEvent, "dispute-id": this.disputeId, disputeResponse: this.disputeResponse, createDisputeEvidence: this.createDisputeEvidence, updateDisputeResponse: this.updateDisputeResponse, submitDisputeResponse: this.submitDisputeResponse })));
    }
    ;
    static get watchers() { return {
        "accountId": ["propChanged"],
        "authToken": ["propChanged"]
    }; }
}, [1, "justifi-dispute-response", {
        "authToken": [1, "auth-token"],
        "disputeId": [1, "dispute-id"],
        "disputeResponse": [16, "dispute-response"],
        "apiOrigin": [1, "api-origin"],
        "updateDisputeResponse": [32],
        "submitDisputeResponse": [32],
        "createDisputeEvidence": [32],
        "errorMessage": [32]
    }, undefined, {
        "accountId": ["propChanged"],
        "authToken": ["propChanged"]
    }]);
function defineCustomElement() {
    if (typeof customElements === "undefined") {
        return;
    }
    const components = ["justifi-dispute-response", "custom-popper", "form-control-date", "form-control-file-v2", "form-control-help-text", "form-control-text", "form-control-textarea", "form-control-tooltip", "justifi-additional-statement", "justifi-cancellation-policy", "justifi-customer-details", "justifi-dispute-response-core", "justifi-duplicate-charge", "justifi-electronic-evidence", "justifi-product-or-service", "justifi-refund-policy", "justifi-shipping-details"];
    components.forEach(tagName => { switch (tagName) {
        case "justifi-dispute-response":
            if (!customElements.get(tagName)) {
                customElements.define(tagName, DisputeResponse);
            }
            break;
        case "custom-popper":
            if (!customElements.get(tagName)) {
                defineCustomElement$g();
            }
            break;
        case "form-control-date":
            if (!customElements.get(tagName)) {
                defineCustomElement$f();
            }
            break;
        case "form-control-file-v2":
            if (!customElements.get(tagName)) {
                defineCustomElement$e();
            }
            break;
        case "form-control-help-text":
            if (!customElements.get(tagName)) {
                defineCustomElement$d();
            }
            break;
        case "form-control-text":
            if (!customElements.get(tagName)) {
                defineCustomElement$c();
            }
            break;
        case "form-control-textarea":
            if (!customElements.get(tagName)) {
                defineCustomElement$b();
            }
            break;
        case "form-control-tooltip":
            if (!customElements.get(tagName)) {
                defineCustomElement$a();
            }
            break;
        case "justifi-additional-statement":
            if (!customElements.get(tagName)) {
                defineCustomElement$9();
            }
            break;
        case "justifi-cancellation-policy":
            if (!customElements.get(tagName)) {
                defineCustomElement$8();
            }
            break;
        case "justifi-customer-details":
            if (!customElements.get(tagName)) {
                defineCustomElement$7();
            }
            break;
        case "justifi-dispute-response-core":
            if (!customElements.get(tagName)) {
                defineCustomElement$6();
            }
            break;
        case "justifi-duplicate-charge":
            if (!customElements.get(tagName)) {
                defineCustomElement$5();
            }
            break;
        case "justifi-electronic-evidence":
            if (!customElements.get(tagName)) {
                defineCustomElement$4();
            }
            break;
        case "justifi-product-or-service":
            if (!customElements.get(tagName)) {
                defineCustomElement$3();
            }
            break;
        case "justifi-refund-policy":
            if (!customElements.get(tagName)) {
                defineCustomElement$2();
            }
            break;
        case "justifi-shipping-details":
            if (!customElements.get(tagName)) {
                defineCustomElement$1();
            }
            break;
    } });
}
defineCustomElement();

export { DisputeResponse as D, defineCustomElement as d };
