import { proxyCustomElement, HTMLElement, h } from '@stencil/core/internal/client';
import { c as create$3, a as create$6, F as FormController } from './form.js';
import { D as DisputeResponseFormStep, f as fileInputHandler } from './file-input-handler.js';
import { _ as heading5 } from './parts.js';
import { d as defineCustomElement$4 } from './custom-popper2.js';
import { d as defineCustomElement$3 } from './form-control-file-v22.js';
import { d as defineCustomElement$2 } from './form-control-text2.js';
import { d as defineCustomElement$1 } from './form-control-tooltip2.js';

const ElectronicEvidenceSchema = create$3({
    customer_purchase_ip_address: create$6().nullable(),
});

const ElectronicEvidence = /*@__PURE__*/ proxyCustomElement(class ElectronicEvidence extends HTMLElement {
    constructor() {
        super();
        this.__registerHost();
        this.documentErrors = {};
        this.errors = {};
        this.documents = { activity_log: [] };
        this.inputHandler = (name, value) => {
            this.form.setValues(Object.assign(Object.assign({}, this.form.values.getValue()), { [name]: value }));
        };
    }
    async validateAndSubmit(onSuccess) {
        const documentList = Object.values(this.documents).flat();
        this.form.validateAndSubmit((formData) => onSuccess(formData, documentList, DisputeResponseFormStep.electronicEvidence));
    }
    ;
    componentWillLoad() {
        this.form = new FormController(ElectronicEvidenceSchema);
    }
    componentDidLoad() {
        this.form.errors.subscribe(errors => {
            this.errors = Object.assign({}, errors);
        });
    }
    render() {
        var _a, _b;
        return (h("div", { key: 'e23dbefec1d452aa3ba3cca69523eee0f5cfe923' }, h("div", { key: 'e1f11a356d05519b568b5bb65be9e8a1fc14e46f', class: "row gy-3" }, h("div", { key: 'a6208153a9a44d49e88f80d953477de8b40ed64b', class: "col-12" }, h("h2", { key: 'c80cc00343452fbf9d9ddacb6929d3a7e0a33f42', class: "h5", part: heading5 }, "Electronic Evidence")), h("div", { key: '1ed5c9f72596f33f41431eb62e6338f60adc9ab3', class: "col-12" }, h("form-control-text", { key: 'dfb38a1c00b8b09849840f4a071fbaa12321f7a8', label: "Purchase IP Address", name: "customer_purchase_ip_address", helpText: "The IP address used by the customer during the purchase.", defaultValue: (_a = this.disputeResponse) === null || _a === void 0 ? void 0 : _a.customer_purchase_ip_address, inputHandler: this.inputHandler, errorText: this.errors.customer_purchase_ip_address })), h("div", { key: 'd6f0a73cccf7eb2ea481836c6206ee39a0a21c6c', class: "col-12" }, h("form-control-file-v2", { key: '25dfd3efa3ec536f899fb263624bfea1b68dc397', label: "Activity Logs", name: "activity_log", helpText: "Any server or activity logs that provide evidence of the customer's access to or download of the purchased digital product. This information should encompass IP addresses, relevant timestamps, and any detailed records of activity.", onChange: (e) => fileInputHandler(e, this.documents), errorText: (_b = this.documentErrors) === null || _b === void 0 ? void 0 : _b.activity_log })))));
    }
}, [0, "justifi-electronic-evidence", {
        "disputeResponse": [8, "dispute-response"],
        "documentErrors": [8, "document-errors"],
        "form": [32],
        "errors": [32],
        "documents": [32],
        "validateAndSubmit": [64]
    }]);
function defineCustomElement() {
    if (typeof customElements === "undefined") {
        return;
    }
    const components = ["justifi-electronic-evidence", "custom-popper", "form-control-file-v2", "form-control-text", "form-control-tooltip"];
    components.forEach(tagName => { switch (tagName) {
        case "justifi-electronic-evidence":
            if (!customElements.get(tagName)) {
                customElements.define(tagName, ElectronicEvidence);
            }
            break;
        case "custom-popper":
            if (!customElements.get(tagName)) {
                defineCustomElement$4();
            }
            break;
        case "form-control-file-v2":
            if (!customElements.get(tagName)) {
                defineCustomElement$3();
            }
            break;
        case "form-control-text":
            if (!customElements.get(tagName)) {
                defineCustomElement$2();
            }
            break;
        case "form-control-tooltip":
            if (!customElements.get(tagName)) {
                defineCustomElement$1();
            }
            break;
    } });
}
defineCustomElement();

export { ElectronicEvidence as E, defineCustomElement as d };
