import { proxyCustomElement, HTMLElement, createEvent, h, Host } from '@stencil/core/internal/client';
import { U as inputInvalidAndFocused, d as inputFocused, b as inputInvalid, i as input, l as label } from './parts.js';
import { F as FormControlHelpText } from './form-control-help-text3.js';
import { F as FormControlErrorText } from './form-control-error-text.js';
import './details.js';
import './event-types.js';
import './justifi-radio-list-item2.js';

const NumberInput = /*@__PURE__*/ proxyCustomElement(class NumberInput extends HTMLElement {
    constructor() {
        super();
        this.__registerHost();
        this.formControlInput = createEvent(this, "formControlInput", 7);
        this.formControlBlur = createEvent(this, "formControlBlur", 7);
        this.isFocused = false;
        this.handleFormControlInput = (event) => {
            const target = event.target;
            const name = target.getAttribute('name');
            this.inputHandler(name, target.value);
            this.formControlInput.emit({ name, value: target.value });
        };
        this.updateInput = (newValue) => {
            const inputElement = this.el.querySelector('input');
            if (inputElement) {
                inputElement.value = newValue || '';
            }
        };
    }
    handleDefaultValueChange(newValue) {
        this.updateInput(newValue);
    }
    componentDidLoad() {
        this.updateInput(this.defaultValue);
    }
    get part() {
        if (this.isFocused && this.errorText) {
            return inputInvalidAndFocused;
        }
        if (this.isFocused) {
            return inputFocused;
        }
        if (this.errorText) {
            return inputInvalid;
        }
        return input;
    }
    render() {
        return (h(Host, { key: '0c518001e14574c5c7bce66643ec03571eb80e86' }, h("div", { key: 'd09fbf1cd01990d2d73fe8ca3b0ee59ba48b4631', class: 'form-group d-flex flex-column' }, h("label", { key: '51476220a170a30e6fb8eabb06c0dc16b5231a59', part: label, class: "form-label", htmlFor: this.name }, this.label), h("input", { key: '3d31c0cbb62e9f9957994b3a4d2fc26330aa4ee8', id: this.name, name: this.name, onFocus: () => this.isFocused = true, onBlur: () => {
                this.isFocused = false;
                this.formControlBlur.emit();
            }, onInput: this.handleFormControlInput, part: this.part, class: this.errorText ? 'form-control is-invalid' : 'form-control', type: "number", disabled: this.disabled }), h(FormControlHelpText, { key: '48241a9ebf6118a0b231d05b7aa14ade91e105b7', helpText: this.helpText, name: this.name }), h(FormControlErrorText, { key: '53b60709bd2c431e93fe411c498df28dca5dbc30', errorText: this.errorText, name: this.name }))));
    }
    get el() { return this; }
    static get watchers() { return {
        "defaultValue": ["handleDefaultValueChange"]
    }; }
}, [0, "form-control-number", {
        "label": [1],
        "name": [8],
        "helpText": [1, "help-text"],
        "errorText": [1, "error-text"],
        "defaultValue": [1, "default-value"],
        "inputHandler": [16, "input-handler"],
        "disabled": [4],
        "isFocused": [32]
    }, undefined, {
        "defaultValue": ["handleDefaultValueChange"]
    }]);
function defineCustomElement$1() {
    if (typeof customElements === "undefined") {
        return;
    }
    const components = ["form-control-number"];
    components.forEach(tagName => { switch (tagName) {
        case "form-control-number":
            if (!customElements.get(tagName)) {
                customElements.define(tagName, NumberInput);
            }
            break;
    } });
}
defineCustomElement$1();

const FormControlNumber = NumberInput;
const defineCustomElement = defineCustomElement$1;

export { FormControlNumber, defineCustomElement };
