import { proxyCustomElement, HTMLElement, createEvent, h, Host } from '@stencil/core/internal/client';
import { U as inputInvalidAndFocused, b as inputInvalid, d as inputFocused, c as inputDisabled, i as input, l as label } from './parts.js';
import { d as defineCustomElement$1 } from './form-control-help-text2.js';

const TextInput = /*@__PURE__*/ proxyCustomElement(class TextInput extends HTMLElement {
    constructor() {
        super();
        this.__registerHost();
        this.formControlInput = createEvent(this, "formControlInput", 7);
        this.formControlBlur = createEvent(this, "formControlBlur", 7);
        this.isFocused = false;
        this.handleFormControlInput = (event) => {
            const target = event.target;
            const name = target.getAttribute('name');
            this.inputHandler(name, target.value);
            this.formControlInput.emit({ name, value: target.value });
        };
        this.updateInput = (newValue) => {
            const inputElement = this.el.querySelector('textarea');
            if (inputElement) {
                inputElement.value = newValue || '';
            }
        };
    }
    handleDefaultValueChange(newValue) {
        this.updateInput(newValue);
    }
    componentDidLoad() {
        this.updateInput(this.defaultValue);
    }
    get part() {
        if (this.isFocused && this.errorText) {
            return inputInvalidAndFocused;
        }
        if (this.errorText) {
            return inputInvalid;
        }
        if (this.isFocused) {
            return inputFocused;
        }
        if (this.disabled) {
            return inputDisabled;
        }
        return input;
    }
    render() {
        return (h(Host, { key: '8b7aa0820fe8e28893564b1db81f9a46af19ba5a' }, h("div", { key: '430c5979f3926703d09bbe33319634b77d8061e4', class: "form-group d-flex flex-column" }, h("label", { key: '74e5ea2805d737f43350d95ee95a3de0b3283661', part: label, class: "form-label", htmlFor: this.name }, this.label), h("textarea", { key: '64d7394cb65fcb16330c34efee4b343b7017be92', id: this.name, name: this.name, onFocus: () => this.isFocused = true, onBlur: () => {
                this.isFocused = false;
                this.formControlBlur.emit();
            }, onInput: this.handleFormControlInput, onKeyDown: this.keyDownHandler, onPaste: this.keyDownHandler, maxLength: this.maxLength, part: this.part, class: this.errorText ? 'form-control is-invalid' : 'form-control', disabled: this.disabled }), h("form-control-help-text", { key: '83b3b2f47a805d6896cc7b2c43bb57fce3242c4c', helpText: this.helpText, name: this.name }), h("form-control-error-text", { key: '9670a3995f4530352df05956bbd6827def43baed', errorText: this.errorText, name: this.name }))));
    }
    get el() { return this; }
    static get watchers() { return {
        "defaultValue": ["handleDefaultValueChange"]
    }; }
}, [0, "form-control-textarea", {
        "label": [1],
        "name": [8],
        "helpText": [1, "help-text"],
        "errorText": [1, "error-text"],
        "defaultValue": [1, "default-value"],
        "maxLength": [2, "max-length"],
        "inputHandler": [16, "input-handler"],
        "keyDownHandler": [16, "key-down-handler"],
        "disabled": [4],
        "isFocused": [32]
    }, undefined, {
        "defaultValue": ["handleDefaultValueChange"]
    }]);
function defineCustomElement() {
    if (typeof customElements === "undefined") {
        return;
    }
    const components = ["form-control-textarea", "form-control-help-text"];
    components.forEach(tagName => { switch (tagName) {
        case "form-control-textarea":
            if (!customElements.get(tagName)) {
                customElements.define(tagName, TextInput);
            }
            break;
        case "form-control-help-text":
            if (!customElements.get(tagName)) {
                defineCustomElement$1();
            }
            break;
    } });
}
defineCustomElement();

export { TextInput as T, defineCustomElement as d };
