import { proxyCustomElement, HTMLElement, createEvent, h } from '@stencil/core/internal/client';
import { E as ErrorState } from './utils.js';
import { B as BusinessService } from './business.service.js';
import { m as makeGetBusiness } from './get-business.js';
import { C as ComponentErrorSeverity, a as ComponentErrorCodes } from './Refund.js';
import { c as checkPkgVersion, J as JustifiAnalytics } from './Analytics.js';
import { d as defineCustomElement$8 } from './additional-questions-details2.js';
import { d as defineCustomElement$7 } from './business-details-core2.js';
import { d as defineCustomElement$6 } from './core-info-details2.js';
import { d as defineCustomElement$5 } from './details.js';
import { d as defineCustomElement$4 } from './legal-address-details2.js';
import { d as defineCustomElement$3 } from './owner-details2.js';
import { d as defineCustomElement$2 } from './representative-details2.js';

const BusinessDetails = /*@__PURE__*/ proxyCustomElement(class BusinessDetails extends HTMLElement {
    constructor() {
        super();
        this.__registerHost();
        this.__attachShadow();
        this.errorEvent = createEvent(this, "error-event", 7);
        this.errorMessage = null;
        this.handleErrorEvent = event => {
            this.errorMessage = event.detail.message;
            this.errorEvent.emit(event.detail);
        };
    }
    componentWillLoad() {
        checkPkgVersion();
        this.analytics = new JustifiAnalytics(this);
        this.initializeGetBusiness();
    }
    disconnectedCallback() {
        var _a;
        (_a = this.analytics) === null || _a === void 0 ? void 0 : _a.cleanup();
    }
    ;
    initializeGetBusiness() {
        if (!this.businessId || !this.authToken) {
            this.errorMessage = 'Invalid business id or auth token';
            this.errorEvent.emit({
                errorCode: ComponentErrorCodes.MISSING_PROPS,
                message: this.errorMessage,
                severity: ComponentErrorSeverity.ERROR,
            });
            return;
        }
        this.getBusiness = makeGetBusiness({
            id: this.businessId,
            authToken: this.authToken,
            service: new BusinessService(),
        });
    }
    render() {
        if (this.errorMessage) {
            return ErrorState(this.errorMessage);
        }
        return (h("business-details-core", { getBusiness: this.getBusiness, "onError-event": this.handleErrorEvent }));
    }
}, [1, "justifi-business-details", {
        "businessId": [1, "business-id"],
        "authToken": [1, "auth-token"],
        "errorMessage": [32],
        "getBusiness": [32]
    }]);
function defineCustomElement$1() {
    if (typeof customElements === "undefined") {
        return;
    }
    const components = ["justifi-business-details", "additional-questions-details", "business-details-core", "core-info-details", "justifi-details", "legal-address-details", "owner-details", "representative-details"];
    components.forEach(tagName => { switch (tagName) {
        case "justifi-business-details":
            if (!customElements.get(tagName)) {
                customElements.define(tagName, BusinessDetails);
            }
            break;
        case "additional-questions-details":
            if (!customElements.get(tagName)) {
                defineCustomElement$8();
            }
            break;
        case "business-details-core":
            if (!customElements.get(tagName)) {
                defineCustomElement$7();
            }
            break;
        case "core-info-details":
            if (!customElements.get(tagName)) {
                defineCustomElement$6();
            }
            break;
        case "justifi-details":
            if (!customElements.get(tagName)) {
                defineCustomElement$5();
            }
            break;
        case "legal-address-details":
            if (!customElements.get(tagName)) {
                defineCustomElement$4();
            }
            break;
        case "owner-details":
            if (!customElements.get(tagName)) {
                defineCustomElement$3();
            }
            break;
        case "representative-details":
            if (!customElements.get(tagName)) {
                defineCustomElement$2();
            }
            break;
    } });
}
defineCustomElement$1();

const JustifiBusinessDetails = BusinessDetails;
const defineCustomElement = defineCustomElement$1;

export { JustifiBusinessDetails, defineCustomElement };
