import { h, proxyCustomElement, HTMLElement, createEvent } from '@stencil/core/internal/client';
import { c as create$3, F as FormController } from './form.js';
import { b as businessCoreInfoSchema } from './business-core-info-schema.js';
import { a as additionalQuestionsSchema } from './business-additional-questions-schema.js';
import { i as identitySchema } from './business-identity-schema.js';
import { a as addressSchema } from './business-address-schema.js';
import './config-state.js';
import './dinero.js';
import { C as ComponentErrorSeverity, a as ComponentErrorCodes } from './Refund.js';
import './Pagination.js';
import { a as Business, c as BusinessFormServerErrors } from './Business.js';
import { c as checkPkgVersion, J as JustifiAnalytics } from './Analytics.js';
import { B as Button } from './button.js';
import { S as StyledHost } from './styled-host.js';
import { H as Header1 } from './header-1.js';
import './details.js';
import './event-types.js';
import './justifi-radio-list-item2.js';
import { S as Skeleton } from './skeleton.js';
import { a as BusinessFormClickActions } from './event-types2.js';
import { m as makeGetBusiness, a as makePatchBusiness } from './payment-provisioning-actions.js';
import { B as BusinessService } from './business.service.js';
import { d as defineCustomElement$e } from './custom-popper2.js';
import { d as defineCustomElement$d } from './form-alert2.js';
import { d as defineCustomElement$c } from './form-control-date2.js';
import { d as defineCustomElement$b } from './form-control-monetary-provisioning2.js';
import { d as defineCustomElement$a } from './form-control-number-masked2.js';
import { d as defineCustomElement$9 } from './form-control-select2.js';
import { d as defineCustomElement$8 } from './form-control-text2.js';
import { d as defineCustomElement$7 } from './form-control-tooltip2.js';
import { d as defineCustomElement$6 } from './additional-questions.js';
import { d as defineCustomElement$5 } from './business-core-info.js';
import { d as defineCustomElement$4 } from './business-representative.js';
import { d as defineCustomElement$3 } from './identity-address-form.js';
import { d as defineCustomElement$2 } from './legal-address-form.js';

const businessFormSchema = create$3(Object.assign(Object.assign({}, businessCoreInfoSchema().fields), { legal_address: addressSchema(), additional_questions: additionalQuestionsSchema(), representative: identitySchema('representative') }));

const FormBlock = () => (h("div", { class: "row gap-3" },
    h("div", { class: "col-12" },
        h(Skeleton, { width: "25%" })),
    h("div", { class: "col-12" },
        h(Skeleton, { width: "100%" })),
    h("div", { class: "col-12 d-flex gap-3" },
        h(Skeleton, { width: "50%" }),
        h(Skeleton, { width: "50%" })),
    h("div", { class: "col-12 d-flex gap-3" },
        h(Skeleton, { width: "65%" }),
        h(Skeleton, { width: "35%" }))));
const BusinessFormLoading = () => {
    return (h("div", { class: "row gap-5" },
        h("div", { class: "col-12" },
            h(Skeleton, { width: "40%", height: "40px" })),
        h(FormBlock, null),
        h(FormBlock, null),
        h(FormBlock, null)));
};

const BusinessForm = /*@__PURE__*/ proxyCustomElement(class BusinessForm extends HTMLElement {
    constructor() {
        super();
        this.__registerHost();
        this.__attachShadow();
        this.submitEvent = createEvent(this, "submit-event", 7);
        this.clickEvent = createEvent(this, "click-event", 7);
        this.errorEvent = createEvent(this, "error-event", 7);
        this.isLoading = false;
        this.isSaving = false;
        this.hideErrors = false;
        this.formTitle = 'Business Information';
        this.removeTitle = false;
        this.instantiateBusiness = (data) => {
            const business = new Business(data);
            this.formController.setInitialValues(Object.assign({}, business));
        };
        this.sendData = async () => {
            this.isSaving = true;
            const values = this.formController.values.getValue();
            const initialValues = this.formController.getInitialValues();
            const payload = new Business(Object.assign(Object.assign({}, initialValues), values)).payload;
            this.patchBusiness({
                payload,
                onSuccess: (response) => {
                    this.handleReponse(response);
                },
                onError: ({ error, code, severity }) => {
                    this.errorMessage = error.message;
                    this.errorEvent.emit({ errorCode: code, message: error.message, severity });
                },
                final: () => {
                    this.isSaving = false;
                }
            });
        };
        this.validateAndSubmit = (event) => {
            event.preventDefault();
            this.formController.validateAndSubmit(this.sendData);
        };
    }
    componentWillLoad() {
        checkPkgVersion();
        this.analytics = new JustifiAnalytics(this);
        this.formController = new FormController(businessFormSchema);
        this.initializeApi();
    }
    disconnectedCallback() {
        var _a;
        (_a = this.analytics) === null || _a === void 0 ? void 0 : _a.cleanup();
    }
    ;
    get title() {
        return this.removeTitle ? '' : this.formTitle;
    }
    get disabledState() {
        return this.isSaving;
    }
    get businessEndpoint() {
        return `entities/business/${this.businessId}`;
    }
    initializeApi() {
        if (this.authToken && this.businessId) {
            this.getBusiness = makeGetBusiness({
                authToken: this.authToken,
                businessId: this.businessId,
                service: new BusinessService()
            });
            this.patchBusiness = makePatchBusiness({
                authToken: this.authToken,
                businessId: this.businessId,
                service: new BusinessService()
            });
            this.getBusiness({
                onSuccess: (response) => {
                    this.instantiateBusiness(response.data);
                },
                onError: ({ error, code, severity }) => {
                    this.errorMessage = error.message;
                    this.errorEvent.emit({ errorCode: code, message: error.message, severity });
                },
                final: () => {
                    this.isLoading = false;
                }
            });
        }
        else {
            this.errorEvent.emit({
                message: 'auth-token and business-id are required',
                errorCode: ComponentErrorCodes.MISSING_PROPS,
                severity: ComponentErrorSeverity.ERROR,
            });
        }
    }
    handleReponse(response) {
        if (response.error) {
            this.errorMessage = BusinessFormServerErrors.patchData;
        }
        this.submitEvent.emit({ response });
        this.instantiateBusiness(response.data);
    }
    render() {
        if (this.isLoading) {
            return h(StyledHost, null, h(BusinessFormLoading, null));
        }
        return (h(StyledHost, null, h("form", { onSubmit: this.validateAndSubmit }, h("div", { class: "row gap-3" }, h(Header1, { text: this.title }), h("form-alert", { text: this.errorMessage, hideAlert: this.hideErrors }), h("div", { class: "col-12 mb-4" }, h("justifi-business-core-info", { formController: this.formController })), h("div", { class: "col-12 mb-4" }, h("justifi-legal-address-form", { formController: this.formController })), h("div", { class: "col-12 mb-4" }, h("justifi-additional-questions", { formController: this.formController })), h("div", { class: "col-12 mb-4" }, h("justifi-business-representative", { formController: this.formController })), h("div", { class: "col-12 d-flex flex-row-reverse" }, h(Button, { type: "submit", disabled: this.disabledState, variant: 'primary', onClick: () => this.clickEvent.emit({ name: BusinessFormClickActions.submit }), isLoading: this.isSaving }, "Submit"))))));
    }
}, [1, "justifi-business-form", {
        "authToken": [1, "auth-token"],
        "businessId": [1, "business-id"],
        "hideErrors": [4, "hide-errors"],
        "formTitle": [1, "form-title"],
        "removeTitle": [4, "remove-title"],
        "isLoading": [32],
        "isSaving": [32],
        "errorMessage": [32]
    }]);
function defineCustomElement$1() {
    if (typeof customElements === "undefined") {
        return;
    }
    const components = ["justifi-business-form", "custom-popper", "form-alert", "form-control-date", "form-control-monetary-provisioning", "form-control-number-masked", "form-control-select", "form-control-text", "form-control-tooltip", "justifi-additional-questions", "justifi-business-core-info", "justifi-business-representative", "justifi-identity-address-form", "justifi-legal-address-form"];
    components.forEach(tagName => { switch (tagName) {
        case "justifi-business-form":
            if (!customElements.get(tagName)) {
                customElements.define(tagName, BusinessForm);
            }
            break;
        case "custom-popper":
            if (!customElements.get(tagName)) {
                defineCustomElement$e();
            }
            break;
        case "form-alert":
            if (!customElements.get(tagName)) {
                defineCustomElement$d();
            }
            break;
        case "form-control-date":
            if (!customElements.get(tagName)) {
                defineCustomElement$c();
            }
            break;
        case "form-control-monetary-provisioning":
            if (!customElements.get(tagName)) {
                defineCustomElement$b();
            }
            break;
        case "form-control-number-masked":
            if (!customElements.get(tagName)) {
                defineCustomElement$a();
            }
            break;
        case "form-control-select":
            if (!customElements.get(tagName)) {
                defineCustomElement$9();
            }
            break;
        case "form-control-text":
            if (!customElements.get(tagName)) {
                defineCustomElement$8();
            }
            break;
        case "form-control-tooltip":
            if (!customElements.get(tagName)) {
                defineCustomElement$7();
            }
            break;
        case "justifi-additional-questions":
            if (!customElements.get(tagName)) {
                defineCustomElement$6();
            }
            break;
        case "justifi-business-core-info":
            if (!customElements.get(tagName)) {
                defineCustomElement$5();
            }
            break;
        case "justifi-business-representative":
            if (!customElements.get(tagName)) {
                defineCustomElement$4();
            }
            break;
        case "justifi-identity-address-form":
            if (!customElements.get(tagName)) {
                defineCustomElement$3();
            }
            break;
        case "justifi-legal-address-form":
            if (!customElements.get(tagName)) {
                defineCustomElement$2();
            }
            break;
    } });
}
defineCustomElement$1();

const JustifiBusinessForm = BusinessForm;
const defineCustomElement = defineCustomElement$1;

export { JustifiBusinessForm, defineCustomElement };
