import { proxyCustomElement, HTMLElement, createEvent, h } from '@stencil/core/internal/client';
import { c as checkPkgVersion, J as JustifiAnalytics } from './Analytics.js';
import { c as checkoutStore } from './checkout.store.js';
import { a2 as checkoutSummary } from './parts.js';
import { c as PaymentMethodTypes } from './Refund.js';
import { S as StyledHost } from './styled-host.js';
import './details.js';
import './event-types.js';
import './justifi-radio-list-item2.js';
import { d as defineCustomElement$m } from './custom-popper2.js';
import { d as defineCustomElement$l } from './form-control-checkbox2.js';
import { d as defineCustomElement$k } from './form-control-help-text2.js';
import { d as defineCustomElement$j } from './form-control-radio2.js';
import { d as defineCustomElement$i } from './form-control-select2.js';
import { d as defineCustomElement$h } from './form-control-text2.js';
import { d as defineCustomElement$g } from './form-control-tooltip2.js';
import { d as defineCustomElement$f } from './hidden-input2.js';
import { d as defineCustomElement$e } from './iframe-input2.js';
import { d as defineCustomElement$d } from './bank-account.js';
import { d as defineCustomElement$c } from './billing-information-form.js';
import { d as defineCustomElement$b } from './justifi-button2.js';
import { d as defineCustomElement$a } from './card-form2.js';
import { d as defineCustomElement$9 } from './summary.js';
import { d as defineCustomElement$8 } from './justifi-header2.js';
import { d as defineCustomElement$7 } from './modular-checkout.js';
import { d as defineCustomElement$6 } from './postal-code-form.js';
import { d as defineCustomElement$5 } from './save-new-payment-method.js';
import { d as defineCustomElement$4 } from './saved-payment-methods.js';
import { d as defineCustomElement$3 } from './sezzle-payment-method.js';
import { d as defineCustomElement$2 } from './payment-method-option2.js';

const PaymentMethodTypeLabels = {
    bankAccount: 'New bank account',
    card: 'New credit or debit card',
};
const Checkout = /*@__PURE__*/ proxyCustomElement(class Checkout extends HTMLElement {
    constructor() {
        super();
        this.__registerHost();
        this.errorEvent = createEvent(this, "error-event", 7);
        this.loadedEvent = createEvent(this, "loaded", 7);
        this.submitEvent = createEvent(this, "submit-event", 7);
        this.errorMessage = '';
        this.insuranceToggled = false;
        this.isSubmitting = false; // This is used to prevent multiple submissions and is different from loading state
        this.paymentMethodOptions = [];
        this.savePaymentMethod = false;
        this.disableBankAccount = false;
        this.disableBnpl = false;
        this.disableCreditCard = false;
        this.disablePaymentMethodGroup = false;
        this.hideBankAccountBillingForm = false;
        this.hideCardBillingForm = false;
    }
    propChanged() {
        this.updateStore();
    }
    connectedCallback() {
        if (this.authToken && this.checkoutId) {
            this.updateStore();
        }
    }
    componentWillLoad() {
        checkPkgVersion();
        this.analytics = new JustifiAnalytics(this);
    }
    disconnectedCallback() {
        var _a;
        (_a = this.analytics) === null || _a === void 0 ? void 0 : _a.cleanup();
    }
    savePaymentMethodChanged(event) {
        this.savePaymentMethod = event.detail;
    }
    checkoutComplete(_event) {
        this.isSubmitting = false;
    }
    checkoutError(event) {
        this.isSubmitting = false;
        console.error('checkout error', event.detail);
    }
    paymentMethodOptionSelected(event) {
        checkoutStore.selectedPaymentMethod = event.detail.id;
    }
    async fillBillingForm(fields) {
        checkoutStore.billingFormFields = fields;
    }
    async validate() {
        var _a;
        return { isValid: await ((_a = this.modularCheckoutRef) === null || _a === void 0 ? void 0 : _a.validate()) };
    }
    updateStore() {
        checkoutStore.checkoutId = this.checkoutId;
        checkoutStore.authToken = this.authToken;
        checkoutStore.disableCreditCard = this.disableCreditCard;
        checkoutStore.disableBankAccount = this.disableBankAccount;
        checkoutStore.disableBnpl = this.disableBnpl;
        checkoutStore.disablePaymentMethodGroup = this.disablePaymentMethodGroup;
    }
    async submit(_event) {
        this.isSubmitting = true;
        this.modularCheckoutRef.submitCheckout(checkoutStore.billingFormFields);
    }
    get canSavePaymentMethod() {
        return checkoutStore.selectedPaymentMethod === PaymentMethodTypes.card || checkoutStore.selectedPaymentMethod === PaymentMethodTypes.bankAccount;
    }
    get showBillingForm() {
        return (checkoutStore.selectedPaymentMethod === PaymentMethodTypes.card && !this.hideCardBillingForm)
            || (checkoutStore.selectedPaymentMethod === PaymentMethodTypes.bankAccount && !this.hideBankAccountBillingForm);
    }
    get showBillingFormSection() {
        return checkoutStore.selectedPaymentMethod === PaymentMethodTypes.card || checkoutStore.selectedPaymentMethod === PaymentMethodTypes.bankAccount;
    }
    get showPaymentTypeHeader() {
        return !this.disableCreditCard && !this.disableBankAccount;
    }
    get showPostalCodeForm() {
        return checkoutStore.selectedPaymentMethod === PaymentMethodTypes.card && this.hideCardBillingForm;
    }
    render() {
        return (h(StyledHost, { key: '66b064eb09a9d14357b5f67ed6cb06a315e28cd3' }, h("justifi-modular-checkout", { key: '0c175af8ee77ba66a6c9e6e338f8e148485e1a44', ref: (el) => (this.modularCheckoutRef = el), authToken: this.authToken, checkoutId: this.checkoutId, savePaymentMethod: this.canSavePaymentMethod && this.savePaymentMethod }, h("div", { key: '27a831604928bae01d8a4f056065cf4bb22ed078', class: "row gy-3 jfi-checkout-core" }, h("div", { key: '42f396148f51c83fcfb6af8385bfeaa0809c80b4', class: "col-12", part: checkoutSummary }, h("justifi-header", { key: '4fdee03c9f6c2d8cb125cf00e7774486f748024b', text: "Summary", level: "h2", class: "fs-5 fw-bold pb-3" }), h("section", { key: '9dd9f8f49c714d915d33f4767196cb31912fe2d4' }, h("justifi-checkout-summary", { key: 'ab3a241477367ace71894a89cdb8df6b02b6a475' }))), h("div", { key: '2fcfa4852da6ab570999e00c900a38ce3f7b22d6', class: "col-12 mt-4" }, h("slot", { key: '0d8990a3c78a59cfad5b31de02d885dd85bdff3b', name: "insurance" })), h("div", { key: '02bcacf6467c99b50b61cd46c4393d2f21ac7f30', class: "col-12 mt-4" }, h("justifi-header", { key: 'f6c88155bcd68d4c76dd1c6d812cb3bf96556454', text: "Payment", level: "h2", class: "fs-5 fw-bold pb-3" }), this.showPaymentTypeHeader && (h("justifi-header", { key: 'dfc55a62398f0baeb3eef4d934644f68cc8483b9', text: "Select payment type", level: "h3", class: "fs-6 fw-bold lh-lg" })), h("div", { key: '3bfdf78062b252b9fc53f63e3248966cd4bd6513', class: "d-flex flex-column" }, h("section", { key: '5f51a590d33ae9074314df4a5808fa4355c3711f' }, h("div", { key: '048568eb658167dcb267a406d11e9672539e5454' }, h("justifi-saved-payment-methods", { key: '150ba48b60bd5818a6fd2004ed1d3b0571050221' }), h("justifi-sezzle-payment-method", { key: 'c959ccbba4683f37706daa889eaa60d0a371d682' }), !this.disableCreditCard && (h("div", { key: '412255d8cf36a0e3669680e09ca77d5efedf7969' }, h("payment-method-option", { key: '9aaaecfd5880a7de93e6f3c986e12f2e63407674', paymentMethodOptionId: PaymentMethodTypes.card, isSelected: checkoutStore.selectedPaymentMethod === PaymentMethodTypes.card, clickHandler: () => { checkoutStore.selectedPaymentMethod = PaymentMethodTypes.card; }, radioButtonHidden: this.disableCreditCard, label: PaymentMethodTypeLabels[PaymentMethodTypes.card] }), checkoutStore.selectedPaymentMethod === PaymentMethodTypes.card && (h("div", { key: '4fefd1eb74d9c6ba17a1d01fe59ab3334bf8bdac', class: "mt-4 mb-4" }, h("justifi-card-form", { key: '6c78f67bce200b47201220a528fb289861761727' }))))), !this.disableBankAccount && (h("div", { key: 'c5b97b68abaf8fa754b9f12e08a1b68c85b4c852' }, h("payment-method-option", { key: '24c013b3e317d26c9c7b961c0b0a87f2f94949f2', paymentMethodOptionId: PaymentMethodTypes.bankAccount, isSelected: checkoutStore.selectedPaymentMethod === PaymentMethodTypes.bankAccount, clickHandler: () => { checkoutStore.selectedPaymentMethod = PaymentMethodTypes.bankAccount; }, radioButtonHidden: this.disableBankAccount, label: PaymentMethodTypeLabels[PaymentMethodTypes.bankAccount] }), checkoutStore.selectedPaymentMethod === PaymentMethodTypes.bankAccount && (h("div", { key: 'b61b75f7e449b1217357bdaddfbfcf37d863612f', class: "mt-4 mb-4" }, h("justifi-bank-account-form", { key: 'e6d182d60e1b308f76b4364c9a757c7ca59debf2' }))))))))), this.showBillingFormSection && (h("div", { key: '71ea650fdb37ff7227b4f8027a54f74c8bf8a575', class: "col-12 mt-4" }, this.showBillingForm && (h("justifi-header", { key: 'f36db4e0d6d008d924ada83a83899377e46ece90', text: "Billing Address", level: "h2", class: "fs-5 fw-bold pb-3" })), this.showPostalCodeForm && (h("justifi-postal-code-form", { key: '19005f53df4bd597ccf6484d662d7d230a8a7b83' })), this.showBillingForm && (h("justifi-billing-information-form", { key: 'e5f501833f7aef3c603d18b29b21c39f990e8ef1' })))), h("div", { key: '828ba958634f58c641a5f6e3a848993d03e4aba0', class: "col-12" }, this.canSavePaymentMethod && (h("justifi-save-new-payment-method", { key: 'e94caf3d77e0299008e6a0bbf6852347eaa02ebf' }))), h("div", { key: '8436468192642a3f20f82b390e5ec53c4dc951bf', class: "mt-4" }, h("justifi-button", { key: '981448c550a72eb1aa936d785912729a1d788cac', text: "Pay", type: "submit", variant: "primary", clickHandler: (e) => this.submit(e), disabled: this.isSubmitting, isLoading: this.isSubmitting, customStyle: { width: '100%', textAlign: "center" } }))))));
    }
    static get watchers() { return {
        "authToken": ["propChanged"],
        "checkoutId": ["propChanged"],
        "disableCreditCard": ["propChanged"],
        "disableBankAccount": ["propChanged"],
        "disableBnpl": ["propChanged"],
        "disablePaymentMethodGroup": ["propChanged"]
    }; }
}, [4, "justifi-checkout", {
        "authToken": [1, "auth-token"],
        "checkoutId": [1, "checkout-id"],
        "disableBankAccount": [4, "disable-bank-account"],
        "disableBnpl": [4, "disable-bnpl"],
        "disableCreditCard": [4, "disable-credit-card"],
        "disablePaymentMethodGroup": [4, "disable-payment-method-group"],
        "hideBankAccountBillingForm": [4, "hide-bank-account-billing-form"],
        "hideCardBillingForm": [4, "hide-card-billing-form"],
        "checkout": [32],
        "complete": [32],
        "errorMessage": [32],
        "insuranceToggled": [32],
        "isSubmitting": [32],
        "paymentMethodOptions": [32],
        "savePaymentMethod": [32],
        "serverError": [32],
        "fillBillingForm": [64],
        "validate": [64]
    }, [[0, "checkboxChanged", "savePaymentMethodChanged"], [0, "submit-event", "checkoutComplete"], [0, "error-event", "checkoutError"], [0, "paymentMethodOptionSelected", "paymentMethodOptionSelected"]], {
        "authToken": ["propChanged"],
        "checkoutId": ["propChanged"],
        "disableCreditCard": ["propChanged"],
        "disableBankAccount": ["propChanged"],
        "disableBnpl": ["propChanged"],
        "disablePaymentMethodGroup": ["propChanged"]
    }]);
function defineCustomElement$1() {
    if (typeof customElements === "undefined") {
        return;
    }
    const components = ["justifi-checkout", "custom-popper", "form-control-checkbox", "form-control-help-text", "form-control-radio", "form-control-select", "form-control-text", "form-control-tooltip", "hidden-input", "iframe-input", "justifi-bank-account-form", "justifi-billing-information-form", "justifi-button", "justifi-card-form", "justifi-checkout-summary", "justifi-header", "justifi-modular-checkout", "justifi-postal-code-form", "justifi-save-new-payment-method", "justifi-saved-payment-methods", "justifi-sezzle-payment-method", "payment-method-option"];
    components.forEach(tagName => { switch (tagName) {
        case "justifi-checkout":
            if (!customElements.get(tagName)) {
                customElements.define(tagName, Checkout);
            }
            break;
        case "custom-popper":
            if (!customElements.get(tagName)) {
                defineCustomElement$m();
            }
            break;
        case "form-control-checkbox":
            if (!customElements.get(tagName)) {
                defineCustomElement$l();
            }
            break;
        case "form-control-help-text":
            if (!customElements.get(tagName)) {
                defineCustomElement$k();
            }
            break;
        case "form-control-radio":
            if (!customElements.get(tagName)) {
                defineCustomElement$j();
            }
            break;
        case "form-control-select":
            if (!customElements.get(tagName)) {
                defineCustomElement$i();
            }
            break;
        case "form-control-text":
            if (!customElements.get(tagName)) {
                defineCustomElement$h();
            }
            break;
        case "form-control-tooltip":
            if (!customElements.get(tagName)) {
                defineCustomElement$g();
            }
            break;
        case "hidden-input":
            if (!customElements.get(tagName)) {
                defineCustomElement$f();
            }
            break;
        case "iframe-input":
            if (!customElements.get(tagName)) {
                defineCustomElement$e();
            }
            break;
        case "justifi-bank-account-form":
            if (!customElements.get(tagName)) {
                defineCustomElement$d();
            }
            break;
        case "justifi-billing-information-form":
            if (!customElements.get(tagName)) {
                defineCustomElement$c();
            }
            break;
        case "justifi-button":
            if (!customElements.get(tagName)) {
                defineCustomElement$b();
            }
            break;
        case "justifi-card-form":
            if (!customElements.get(tagName)) {
                defineCustomElement$a();
            }
            break;
        case "justifi-checkout-summary":
            if (!customElements.get(tagName)) {
                defineCustomElement$9();
            }
            break;
        case "justifi-header":
            if (!customElements.get(tagName)) {
                defineCustomElement$8();
            }
            break;
        case "justifi-modular-checkout":
            if (!customElements.get(tagName)) {
                defineCustomElement$7();
            }
            break;
        case "justifi-postal-code-form":
            if (!customElements.get(tagName)) {
                defineCustomElement$6();
            }
            break;
        case "justifi-save-new-payment-method":
            if (!customElements.get(tagName)) {
                defineCustomElement$5();
            }
            break;
        case "justifi-saved-payment-methods":
            if (!customElements.get(tagName)) {
                defineCustomElement$4();
            }
            break;
        case "justifi-sezzle-payment-method":
            if (!customElements.get(tagName)) {
                defineCustomElement$3();
            }
            break;
        case "payment-method-option":
            if (!customElements.get(tagName)) {
                defineCustomElement$2();
            }
            break;
    } });
}
defineCustomElement$1();

const JustifiCheckout = Checkout;
const defineCustomElement = defineCustomElement$1;

export { JustifiCheckout, defineCustomElement };
