import { proxyCustomElement, HTMLElement, h } from '@stencil/core/internal/client';
import './config-state.js';
import './dinero.js';
import { I as ICheckoutStatus, d as ICheckoutPaymentModeParam } from './Refund.js';
import './Pagination.js';
import './Business.js';
import { f as filterParams, p as propsParams, c as clearParams } from './checkouts-list-params-state.js';
import { a3 as checkoutsListFilterMenu, a4 as statusCheckoutsListFilterParam, a5 as paymentModeCheckoutsListFilterParam } from './parts.js';
import { S as StyledHost } from './styled-host.js';
import './details.js';
import './event-types.js';
import './justifi-radio-list-item2.js';
import { d as defineCustomElement$5 } from './custom-popper2.js';
import { d as defineCustomElement$4 } from './form-control-select2.js';
import { d as defineCustomElement$3 } from './form-control-tooltip2.js';
import { d as defineCustomElement$2 } from './table-filters-menu2.js';

const CheckoutsListFilters = /*@__PURE__*/ proxyCustomElement(class CheckoutsListFilters extends HTMLElement {
    constructor() {
        super();
        this.__registerHost();
        this.__attachShadow();
        this.setParamsOnChange = (name, value) => {
            filterParams[name] = value;
        };
    }
    componentWillLoad() {
        const propsToSet = {
            status: this.checkoutStatus,
            payment_mode: this.paymentMode,
        };
        Object.entries(propsToSet).forEach(([key, value]) => {
            if (value) {
                propsParams[key] = value;
            }
        });
    }
    get checkoutStatusOptions() {
        return [
            { label: 'All', value: '' },
            { label: 'Created', value: ICheckoutStatus.created },
            { label: 'Completed', value: ICheckoutStatus.completed },
            { label: 'Attempted', value: ICheckoutStatus.attempted },
            { label: 'Expired', value: ICheckoutStatus.expired },
        ];
    }
    get checkoutPaymentModeOptions() {
        return [
            { label: 'All', value: '' },
            { label: 'E-commerce', value: ICheckoutPaymentModeParam.ecom },
            { label: 'BNPL', value: ICheckoutPaymentModeParam.bnpl },
        ];
    }
    render() {
        const filterMenuParams = Object.assign({}, filterParams);
        return (h(StyledHost, { key: '05a4d429a1acd7bbaf202872523284e2b2cd3677' }, h("table-filters-menu", { key: 'abf61654a75212537af580f3bfd2646042eaba8a', params: filterMenuParams, clearParams: clearParams, part: checkoutsListFilterMenu }, h("div", { key: 'f8e5cfe4b0a23723d0df939a1d1873adffcb1da9', class: "grid-cols-2 gap-3 p-1" }, h("div", { key: 'd9e23e96a7269b3609e690a1e64e8c20bd125cb7', class: "p-2" }, h("form-control-select", { key: 'e1899dbc615be07486bc54f8baa395bee776d8ce', name: "status", label: "Status", options: this.checkoutStatusOptions, inputHandler: this.setParamsOnChange, defaultValue: this.checkoutStatus || filterParams.status, disabled: !!this.checkoutStatus, part: statusCheckoutsListFilterParam })), h("div", { key: 'bedbc26d9d9f6906013ef4b80542d9031822b19c', class: "p-2" }, h("form-control-select", { key: '3bfef7fabeb85a29304e11093005bb1f58b23f41', name: "payment_mode", label: "Payment Mode", options: this.checkoutPaymentModeOptions, inputHandler: this.setParamsOnChange, defaultValue: this.paymentMode || filterParams.payment_mode, disabled: !!this.paymentMode, part: paymentModeCheckoutsListFilterParam }))))));
    }
}, [1, "justifi-checkouts-list-filters", {
        "checkoutStatus": [1, "checkout-status"],
        "paymentMode": [1, "payment-mode"]
    }]);
function defineCustomElement$1() {
    if (typeof customElements === "undefined") {
        return;
    }
    const components = ["justifi-checkouts-list-filters", "custom-popper", "form-control-select", "form-control-tooltip", "table-filters-menu"];
    components.forEach(tagName => { switch (tagName) {
        case "justifi-checkouts-list-filters":
            if (!customElements.get(tagName)) {
                customElements.define(tagName, CheckoutsListFilters);
            }
            break;
        case "custom-popper":
            if (!customElements.get(tagName)) {
                defineCustomElement$5();
            }
            break;
        case "form-control-select":
            if (!customElements.get(tagName)) {
                defineCustomElement$4();
            }
            break;
        case "form-control-tooltip":
            if (!customElements.get(tagName)) {
                defineCustomElement$3();
            }
            break;
        case "table-filters-menu":
            if (!customElements.get(tagName)) {
                defineCustomElement$2();
            }
            break;
    } });
}
defineCustomElement$1();

const JustifiCheckoutsListFilters = CheckoutsListFilters;
const defineCustomElement = defineCustomElement$1;

export { JustifiCheckoutsListFilters, defineCustomElement };
