import { proxyCustomElement, HTMLElement, createEvent, h } from '@stencil/core/internal/client';
import './config-state.js';
import './dinero.js';
import { i as Checkout, C as ComponentErrorSeverity, a as ComponentErrorCodes } from './Refund.js';
import './Pagination.js';
import './Business.js';
import { g as getErrorCode, a as getErrorMessage } from './utils4.js';
import { c as checkPkgVersion, J as JustifiAnalytics } from './Analytics.js';
import { C as CheckoutService } from './checkout.service.js';
import { m as makeGetSubAccounts, S as SubAccountService } from './get-subaccounts.js';
import { S as StyledHost } from './styled-host.js';
import './details.js';
import './event-types.js';
import './justifi-radio-list-item2.js';
import { d as defineCustomElement$3, a as defaultColumnsKeys } from './checkouts-list-core2.js';
import { d as defineCustomElement$2 } from './pagination-menu2.js';

const makeGetCheckouts = ({ accountId, authToken, service }) => async ({ params, onSuccess, onError }) => {
    var _a, _b;
    try {
        const response = await service.fetchCheckouts(accountId, authToken, params);
        if (!response.error) {
            const pagingInfo = Object.assign({}, response.page_info);
            const checkouts = ((_a = response.data) === null || _a === void 0 ? void 0 : _a.map((dataItem) => new Checkout(dataItem))) || [];
            onSuccess({ checkouts, pagingInfo });
        }
        else {
            const responseError = getErrorMessage(response.error);
            const code = getErrorCode((_b = response.error) === null || _b === void 0 ? void 0 : _b.code);
            return onError({
                error: responseError,
                code,
                severity: ComponentErrorSeverity.ERROR,
            });
        }
    }
    catch (error) {
        const code = getErrorCode(error === null || error === void 0 ? void 0 : error.code);
        return onError({
            error: error.message || error,
            code,
            severity: ComponentErrorSeverity.ERROR,
        });
    }
};

const CheckoutsList = /*@__PURE__*/ proxyCustomElement(class CheckoutsList extends HTMLElement {
    constructor() {
        super();
        this.__registerHost();
        this.__attachShadow();
        this.errorEvent = createEvent(this, "error-event", 7);
        this.errorMessage = null;
        this.columns = defaultColumnsKeys;
        this.handleErrorEvent = (event) => {
            this.errorMessage = event.detail.message;
            this.errorEvent.emit(event.detail);
        };
    }
    componentWillLoad() {
        checkPkgVersion();
        this.analytics = new JustifiAnalytics(this);
        this.initializeGetData();
    }
    disconnectedCallback() {
        var _a;
        (_a = this.analytics) === null || _a === void 0 ? void 0 : _a.cleanup();
    }
    ;
    propChanged() {
        this.initializeGetData();
    }
    initializeGetData() {
        this.initializeGetCheckouts();
        this.initializeGetSubAccounts();
    }
    initializeGetCheckouts() {
        if (this.accountId && this.authToken) {
            this.getCheckouts = makeGetCheckouts({
                accountId: this.accountId,
                authToken: this.authToken,
                service: new CheckoutService()
            });
        }
        else {
            this.errorMessage = 'Account ID and Auth Token are required';
            this.errorEvent.emit({
                errorCode: ComponentErrorCodes.MISSING_PROPS,
                message: this.errorMessage,
                severity: ComponentErrorSeverity.ERROR,
            });
        }
    }
    initializeGetSubAccounts() {
        if (this.accountId && this.authToken) {
            this.getSubAccounts = makeGetSubAccounts({
                accountId: this.accountId,
                authToken: this.authToken,
                service: new SubAccountService()
            });
        }
    }
    render() {
        return (h(StyledHost, { key: 'b0c774c4f56f94cd6b4a3dc8651938f9f33ca94e' }, h("checkouts-list-core", { key: 'd524423a791f70c234044f5ba27d7bc3648fc988', getCheckouts: this.getCheckouts, getSubAccounts: this.getSubAccounts, "onError-event": this.handleErrorEvent, columns: this.columns })));
    }
    static get watchers() { return {
        "accountId": ["propChanged"],
        "authToken": ["propChanged"]
    }; }
}, [1, "justifi-checkouts-list", {
        "accountId": [1, "account-id"],
        "authToken": [1, "auth-token"],
        "columns": [1],
        "getCheckouts": [32],
        "getSubAccounts": [32],
        "errorMessage": [32]
    }, undefined, {
        "accountId": ["propChanged"],
        "authToken": ["propChanged"]
    }]);
function defineCustomElement$1() {
    if (typeof customElements === "undefined") {
        return;
    }
    const components = ["justifi-checkouts-list", "checkouts-list-core", "pagination-menu"];
    components.forEach(tagName => { switch (tagName) {
        case "justifi-checkouts-list":
            if (!customElements.get(tagName)) {
                customElements.define(tagName, CheckoutsList);
            }
            break;
        case "checkouts-list-core":
            if (!customElements.get(tagName)) {
                defineCustomElement$3();
            }
            break;
        case "pagination-menu":
            if (!customElements.get(tagName)) {
                defineCustomElement$2();
            }
            break;
    } });
}
defineCustomElement$1();

const JustifiCheckoutsList = CheckoutsList;
const defineCustomElement = defineCustomElement$1;

export { JustifiCheckoutsList, defineCustomElement };
