import { proxyCustomElement, HTMLElement, createEvent, h } from '@stencil/core/internal/client';
import { D as Dispute, C as ComponentErrorSeverity, a as ComponentErrorCodes } from './Refund.js';
import { c as checkPkgVersion, J as JustifiAnalytics } from './Analytics.js';
import { g as getErrorCode, a as getErrorMessage } from './utils4.js';
import { D as DisputeService } from './dispute-response-actions.js';
import { d as defineCustomElement$k } from './custom-popper2.js';
import { d as defineCustomElement$j } from './form-control-date2.js';
import { d as defineCustomElement$i } from './form-control-file-v22.js';
import { d as defineCustomElement$h } from './form-control-help-text2.js';
import { d as defineCustomElement$g } from './form-control-text2.js';
import { d as defineCustomElement$f } from './form-control-textarea2.js';
import { d as defineCustomElement$e } from './form-control-tooltip2.js';
import { d as defineCustomElement$d } from './additional-statement.js';
import { d as defineCustomElement$c } from './cancellation-policy.js';
import { d as defineCustomElement$b } from './customer-details.js';
import { d as defineCustomElement$a } from './dispute-management-core.js';
import { d as defineCustomElement$9 } from './dispute-notification.js';
import { d as defineCustomElement$8 } from './dispute-response.js';
import { d as defineCustomElement$7 } from './dispute-response-core.js';
import { d as defineCustomElement$6 } from './duplicate-charge.js';
import { d as defineCustomElement$5 } from './electronic-evidence.js';
import { d as defineCustomElement$4 } from './product-or-service.js';
import { d as defineCustomElement$3 } from './refund-policy.js';
import { d as defineCustomElement$2 } from './shipping-details.js';

const makeGetDispute = ({ id, authToken, service }) => async ({ onSuccess, onError }) => {
    var _a;
    try {
        const response = await service.fetchDispute(id, authToken);
        if (!response.error) {
            const pagingInfo = Object.assign({}, response.page_info);
            const dispute = new Dispute(response.data);
            onSuccess({ dispute, pagingInfo });
        }
        else {
            const responseError = getErrorMessage(response.error);
            const code = getErrorCode((_a = response.error) === null || _a === void 0 ? void 0 : _a.code);
            return onError({
                error: responseError,
                code,
                severity: ComponentErrorSeverity.ERROR,
            });
        }
    }
    catch (error) {
        const code = getErrorCode(error === null || error === void 0 ? void 0 : error.code);
        return onError({
            error: error.message || error,
            code,
            severity: ComponentErrorSeverity.ERROR,
        });
    }
};

const DisputeManagement = /*@__PURE__*/ proxyCustomElement(class DisputeManagement extends HTMLElement {
    constructor() {
        super();
        this.__registerHost();
        this.errorEvent = createEvent(this, "error-event", 7);
        this.errorMessage = null;
        this.handleErrorEvent = event => {
            this.errorMessage = event.detail.message;
            this.errorEvent.emit(event.detail);
        };
    }
    componentWillLoad() {
        checkPkgVersion();
        this.analytics = new JustifiAnalytics(this);
        this.initializeGetDispute();
    }
    disconnectedCallback() {
        var _a;
        (_a = this.analytics) === null || _a === void 0 ? void 0 : _a.cleanup();
    }
    ;
    propChanged() {
        this.initializeGetDispute();
    }
    initializeGetDispute() {
        if (this.disputeId && this.authToken) {
            this.getDispute = makeGetDispute({
                id: this.disputeId,
                authToken: this.authToken,
                service: new DisputeService()
            });
        }
        else {
            this.errorMessage = 'Dispute ID and Auth Token are required';
            this.errorEvent.emit({
                message: this.errorMessage,
                errorCode: ComponentErrorCodes.MISSING_PROPS,
                severity: ComponentErrorSeverity.ERROR,
            });
        }
    }
    render() {
        return (h("justifi-dispute-management-core", { key: '8c800827aaa9d549a734ea05698763685e160a98', getDispute: this.getDispute, disputeId: this.disputeId, authToken: this.authToken, "onError-event": this.handleErrorEvent }));
    }
    static get watchers() { return {
        "disputeId": ["propChanged"],
        "authToken": ["propChanged"]
    }; }
}, [0, "justifi-dispute-management", {
        "disputeId": [1, "dispute-id"],
        "authToken": [1, "auth-token"],
        "getDispute": [32],
        "errorMessage": [32]
    }, undefined, {
        "disputeId": ["propChanged"],
        "authToken": ["propChanged"]
    }]);
function defineCustomElement$1() {
    if (typeof customElements === "undefined") {
        return;
    }
    const components = ["justifi-dispute-management", "custom-popper", "form-control-date", "form-control-file-v2", "form-control-help-text", "form-control-text", "form-control-textarea", "form-control-tooltip", "justifi-additional-statement", "justifi-cancellation-policy", "justifi-customer-details", "justifi-dispute-management-core", "justifi-dispute-notification", "justifi-dispute-response", "justifi-dispute-response-core", "justifi-duplicate-charge", "justifi-electronic-evidence", "justifi-product-or-service", "justifi-refund-policy", "justifi-shipping-details"];
    components.forEach(tagName => { switch (tagName) {
        case "justifi-dispute-management":
            if (!customElements.get(tagName)) {
                customElements.define(tagName, DisputeManagement);
            }
            break;
        case "custom-popper":
            if (!customElements.get(tagName)) {
                defineCustomElement$k();
            }
            break;
        case "form-control-date":
            if (!customElements.get(tagName)) {
                defineCustomElement$j();
            }
            break;
        case "form-control-file-v2":
            if (!customElements.get(tagName)) {
                defineCustomElement$i();
            }
            break;
        case "form-control-help-text":
            if (!customElements.get(tagName)) {
                defineCustomElement$h();
            }
            break;
        case "form-control-text":
            if (!customElements.get(tagName)) {
                defineCustomElement$g();
            }
            break;
        case "form-control-textarea":
            if (!customElements.get(tagName)) {
                defineCustomElement$f();
            }
            break;
        case "form-control-tooltip":
            if (!customElements.get(tagName)) {
                defineCustomElement$e();
            }
            break;
        case "justifi-additional-statement":
            if (!customElements.get(tagName)) {
                defineCustomElement$d();
            }
            break;
        case "justifi-cancellation-policy":
            if (!customElements.get(tagName)) {
                defineCustomElement$c();
            }
            break;
        case "justifi-customer-details":
            if (!customElements.get(tagName)) {
                defineCustomElement$b();
            }
            break;
        case "justifi-dispute-management-core":
            if (!customElements.get(tagName)) {
                defineCustomElement$a();
            }
            break;
        case "justifi-dispute-notification":
            if (!customElements.get(tagName)) {
                defineCustomElement$9();
            }
            break;
        case "justifi-dispute-response":
            if (!customElements.get(tagName)) {
                defineCustomElement$8();
            }
            break;
        case "justifi-dispute-response-core":
            if (!customElements.get(tagName)) {
                defineCustomElement$7();
            }
            break;
        case "justifi-duplicate-charge":
            if (!customElements.get(tagName)) {
                defineCustomElement$6();
            }
            break;
        case "justifi-electronic-evidence":
            if (!customElements.get(tagName)) {
                defineCustomElement$5();
            }
            break;
        case "justifi-product-or-service":
            if (!customElements.get(tagName)) {
                defineCustomElement$4();
            }
            break;
        case "justifi-refund-policy":
            if (!customElements.get(tagName)) {
                defineCustomElement$3();
            }
            break;
        case "justifi-shipping-details":
            if (!customElements.get(tagName)) {
                defineCustomElement$2();
            }
            break;
    } });
}
defineCustomElement$1();

const JustifiDisputeManagement = DisputeManagement;
const defineCustomElement = defineCustomElement$1;

export { JustifiDisputeManagement, defineCustomElement };
