import { proxyCustomElement, HTMLElement, createEvent, h } from '@stencil/core/internal/client';
import { A as Api } from './Api.js';
import { C as ComponentErrorSeverity, a as ComponentErrorCodes } from './Refund.js';
import './Pagination.js';
import './Business.js';
import { g as getErrorCode, a as getErrorMessage } from './utils4.js';
import { E as ErrorState } from './utils.js';
import { c as checkPkgVersion, J as JustifiAnalytics } from './Analytics.js';
import { d as defineCustomElement$2 } from './gross-payment-chart-core2.js';

const api = Api();
class ReportsService {
    async fetchGrossVolumeChartData(accountId, authToken) {
        const endpoint = `account/${accountId}/reports/gross_volume`;
        return api.get({ endpoint, authToken });
    }
}

const makeGetGrossPaymentChartData = ({ id, authToken, service }) => async ({ onSuccess, onError }) => {
    var _a;
    try {
        const response = await service.fetchGrossVolumeChartData(id, authToken);
        if (!response.error) {
            onSuccess(response.data);
        }
        else {
            const errorMessage = getErrorMessage(response.error);
            const code = getErrorCode((_a = response.error) === null || _a === void 0 ? void 0 : _a.code);
            onError({
                error: errorMessage,
                code,
                severity: ComponentErrorSeverity.ERROR,
            });
        }
    }
    catch (error) {
        const code = getErrorCode(error === null || error === void 0 ? void 0 : error.code);
        const errorMessage = getErrorMessage(error);
        onError({
            error: errorMessage,
            code,
            severity: ComponentErrorSeverity.ERROR,
        });
    }
};

const GrossPaymentChart = /*@__PURE__*/ proxyCustomElement(class GrossPaymentChart extends HTMLElement {
    constructor() {
        super();
        this.__registerHost();
        this.__attachShadow();
        this.errorEvent = createEvent(this, "error-event", 7);
        this.errorMessage = null;
        this.handleErrorEvent = (event) => {
            this.errorMessage = event.detail.message;
            this.errorEvent.emit(event.detail);
        };
    }
    componentWillLoad() {
        checkPkgVersion();
        this.analytics = new JustifiAnalytics(this);
        this.initializeGetGrossPayment();
    }
    disconnectedCallback() {
        var _a;
        (_a = this.analytics) === null || _a === void 0 ? void 0 : _a.cleanup();
    }
    ;
    propChanged() {
        this.initializeGetGrossPayment();
    }
    initializeGetGrossPayment() {
        if (this.accountId && this.authToken) {
            this.getGrossPayment = makeGetGrossPaymentChartData({
                id: this.accountId,
                authToken: this.authToken,
                service: new ReportsService(),
            });
        }
        else {
            this.errorMessage = 'Account ID and Auth Token are required';
            this.errorEvent.emit({
                errorCode: ComponentErrorCodes.MISSING_PROPS,
                message: this.errorMessage,
                severity: ComponentErrorSeverity.ERROR,
            });
        }
    }
    render() {
        if (this.errorMessage) {
            return ErrorState(this.errorMessage);
        }
        return (h("gross-payment-chart-core", { getGrossPayment: this.getGrossPayment, "onError-event": this.handleErrorEvent }));
    }
    static get watchers() { return {
        "accountId": ["propChanged"],
        "authToken": ["propChanged"]
    }; }
}, [1, "justifi-gross-payment-chart", {
        "accountId": [1, "account-id"],
        "authToken": [1, "auth-token"],
        "getGrossPayment": [32],
        "errorMessage": [32]
    }, undefined, {
        "accountId": ["propChanged"],
        "authToken": ["propChanged"]
    }]);
function defineCustomElement$1() {
    if (typeof customElements === "undefined") {
        return;
    }
    const components = ["justifi-gross-payment-chart", "gross-payment-chart-core"];
    components.forEach(tagName => { switch (tagName) {
        case "justifi-gross-payment-chart":
            if (!customElements.get(tagName)) {
                customElements.define(tagName, GrossPaymentChart);
            }
            break;
        case "gross-payment-chart-core":
            if (!customElements.get(tagName)) {
                defineCustomElement$2();
            }
            break;
    } });
}
defineCustomElement$1();

const JustifiGrossPaymentChart = GrossPaymentChart;
const defineCustomElement = defineCustomElement$1;

export { JustifiGrossPaymentChart, defineCustomElement };
