import { proxyCustomElement, HTMLElement, createEvent, h } from '@stencil/core/internal/client';
import { P as PaymentService } from './payment.service.js';
import { m as makeGetPaymentDetails } from './get-payment-details.js';
import { E as ErrorState } from './utils.js';
import { C as ComponentErrorSeverity, a as ComponentErrorCodes } from './Refund.js';
import { c as checkPkgVersion, J as JustifiAnalytics } from './Analytics.js';
import { d as defineCustomElement$3 } from './details.js';
import { d as defineCustomElement$2 } from './payment-details-core2.js';

const PaymentDetails = /*@__PURE__*/ proxyCustomElement(class PaymentDetails extends HTMLElement {
    constructor() {
        super();
        this.__registerHost();
        this.__attachShadow();
        this.errorEvent = createEvent(this, "error-event", 7);
        this.errorMessage = null;
        this.paymentService = new PaymentService();
        this.handleErrorEvent = event => {
            this.errorMessage = event.detail.message;
            this.errorEvent.emit(event.detail);
        };
    }
    componentWillLoad() {
        checkPkgVersion();
        this.analytics = new JustifiAnalytics(this);
        this.initializeGetPaymentDetails();
    }
    disconnectedCallback() {
        var _a;
        (_a = this.analytics) === null || _a === void 0 ? void 0 : _a.cleanup();
    }
    ;
    propChanged() {
        this.initializeGetPaymentDetails();
    }
    initializeGetPaymentDetails() {
        if (this.paymentId && this.authToken) {
            this.getPaymentDetails = makeGetPaymentDetails({
                id: this.paymentId,
                authToken: this.authToken,
                service: new PaymentService()
            });
        }
        else {
            this.errorMessage = 'Payment ID and Auth Token are required';
            this.errorEvent.emit({
                message: this.errorMessage,
                errorCode: ComponentErrorCodes.MISSING_PROPS,
                severity: ComponentErrorSeverity.ERROR,
            });
        }
    }
    render() {
        if (this.errorMessage) {
            return ErrorState(this.errorMessage);
        }
        return (h("payment-details-core", { getPaymentDetails: this.getPaymentDetails, "onError-event": this.handleErrorEvent }));
    }
    static get watchers() { return {
        "paymentId": ["propChanged"],
        "authToken": ["propChanged"]
    }; }
}, [1, "justifi-payment-details", {
        "paymentId": [1, "payment-id"],
        "authToken": [1, "auth-token"],
        "getPaymentDetails": [32],
        "errorMessage": [32]
    }, undefined, {
        "paymentId": ["propChanged"],
        "authToken": ["propChanged"]
    }]);
function defineCustomElement$1() {
    if (typeof customElements === "undefined") {
        return;
    }
    const components = ["justifi-payment-details", "justifi-details", "payment-details-core"];
    components.forEach(tagName => { switch (tagName) {
        case "justifi-payment-details":
            if (!customElements.get(tagName)) {
                customElements.define(tagName, PaymentDetails);
            }
            break;
        case "justifi-details":
            if (!customElements.get(tagName)) {
                defineCustomElement$3();
            }
            break;
        case "payment-details-core":
            if (!customElements.get(tagName)) {
                defineCustomElement$2();
            }
            break;
    } });
}
defineCustomElement$1();

const JustifiPaymentDetails = PaymentDetails;
const defineCustomElement = defineCustomElement$1;

export { JustifiPaymentDetails, defineCustomElement };
