import { proxyCustomElement, HTMLElement, h } from '@stencil/core/internal/client';
import { l as lodashExports } from './lodash.js';
import { f as filterParams, p as propsParams, c as clearParams } from './payments-list-params-state.js';
import { a9 as paymentsListFilterMenu, aa as paymentIdPaymentsListFilterParam, ab as terminalIdPaymentsListFilterParam, ac as paymentStatusPaymentsListFilterParam, ad as createdAfterPaymentsListFilterParam, ae as createdBeforePaymentsListFilterParam } from './parts.js';
import { S as StyledHost } from './styled-host.js';
import './details.js';
import './event-types.js';
import './justifi-radio-list-item2.js';
import { h as convertToUTC, e as convertToLocal } from './utils2.js';
import { d as defineCustomElement$7 } from './custom-popper2.js';
import { d as defineCustomElement$6 } from './form-control-date2.js';
import { d as defineCustomElement$5 } from './form-control-select2.js';
import { d as defineCustomElement$4 } from './form-control-text2.js';
import { d as defineCustomElement$3 } from './form-control-tooltip2.js';
import { d as defineCustomElement$2 } from './table-filters-menu2.js';

const PaymentsListFilters = /*@__PURE__*/ proxyCustomElement(class PaymentsListFilters extends HTMLElement {
    constructor() {
        super();
        this.__registerHost();
        this.__attachShadow();
        this.setParamsOnChange = (name, value) => {
            filterParams[name] = value;
        };
        this.handleDateInput = (name, value) => {
            const utcDate = convertToUTC(value, { setExactTime: true });
            this.setParamsOnChange(name, utcDate);
        };
    }
    componentWillLoad() {
        // debounced input handler for text input
        this.debouncedSetParamsOnChange = lodashExports.debounce(this.setParamsOnChange, 300);
        const propsToSet = {
            payment_id: this.paymentId,
            terminal_id: this.terminalId,
            payment_status: this.paymentStatus,
            created_after: this.createdAfter,
            created_before: this.createdBefore
        };
        Object.entries(propsToSet).forEach(([key, value]) => {
            if (value) {
                propsParams[key] = value;
            }
        });
    }
    get paymentStatusOptions() {
        return [
            { label: 'All', value: '' },
            { label: 'Pending', value: 'pending' },
            { label: 'Authorized', value: 'authorized' },
            { label: 'Succeeded', value: 'succeeded' },
            { label: 'Failed', value: 'failed' },
            { label: 'Disputed', value: 'disputed' },
            { label: 'Refunded', value: 'refunded' }
        ];
    }
    render() {
        const filterMenuParams = Object.assign({}, filterParams);
        return (h(StyledHost, { key: 'edb76af8b61fe98b719f5f88418410659789a586' }, h("table-filters-menu", { key: '00281883e331c0f1d1b8a8a8ebd09fff40859c52', params: filterMenuParams, clearParams: clearParams, part: paymentsListFilterMenu }, h("div", { key: '2ba0e2b794aafc6e775ec0699846e35292b687f0', class: "grid-cols-2 gap-3 p-1" }, h("div", { key: '371d156495fcb8495288f1dd4c119ff9bb32a32d', class: "p-2" }, h("form-control-text", { key: '1bf10f06973fe3ee7ab1c2c6871a7c79a12543b9', name: "payment_id", label: "Payment ID", inputHandler: this.debouncedSetParamsOnChange, defaultValue: this.paymentId || filterParams.payment_id, disabled: !!this.paymentId, part: paymentIdPaymentsListFilterParam })), h("div", { key: 'ed1f0667a905aac7ac70c612ae3f1666b8e052f3', class: "p-2" }, h("form-control-text", { key: '841a6cf1cd66f942470f0d6c93f78dfad6865fd7', name: "terminal_id", label: "Terminal ID", inputHandler: this.debouncedSetParamsOnChange, defaultValue: this.terminalId || filterParams.terminal_id, disabled: !!this.terminalId, part: terminalIdPaymentsListFilterParam })), h("div", { key: '67be85f9eeb70c1adf1df71772f19e154c46f598', class: "p-2" }, h("form-control-select", { key: '403dc71eab722d8e4067b9a759e0795ba53bff9f', name: "payment_status", label: "Status", options: this.paymentStatusOptions, inputHandler: this.setParamsOnChange, defaultValue: this.paymentStatus || filterParams.payment_status, disabled: !!this.paymentStatus, part: paymentStatusPaymentsListFilterParam })), h("div", { key: '6d28b998413263d8b88f3fa425a7e30fd669d38e', class: "p-2" }, h("form-control-date", { key: '733b5e5e99a4a8ce670749a56fcd407583dba41b', name: "created_after", label: "Created After", inputHandler: this.handleDateInput, defaultValue: convertToLocal(this.createdAfter, { showInputDateTime: true }) ||
                convertToLocal(filterParams.created_after, { showInputDateTime: true }), showTime: true, disabled: !!this.createdAfter, part: createdAfterPaymentsListFilterParam })), h("div", { key: 'c8390389045dc56592e05d1ae7a2236575569df5', class: "p-2" }, h("form-control-date", { key: '718522151a88e3ffd9d3c1ceb3265767340ab60a', name: "created_before", label: "Created Before", inputHandler: this.handleDateInput, defaultValue: convertToLocal(this.createdBefore, { showInputDateTime: true }) ||
                convertToLocal(filterParams.created_before, { showInputDateTime: true }), showTime: true, disabled: !!this.createdBefore, part: createdBeforePaymentsListFilterParam }))))));
    }
}, [1, "justifi-payments-list-filters", {
        "paymentId": [1, "payment-id"],
        "terminalId": [1, "terminal-id"],
        "paymentStatus": [1, "payment-status"],
        "createdAfter": [1, "created-after"],
        "createdBefore": [1, "created-before"]
    }]);
function defineCustomElement$1() {
    if (typeof customElements === "undefined") {
        return;
    }
    const components = ["justifi-payments-list-filters", "custom-popper", "form-control-date", "form-control-select", "form-control-text", "form-control-tooltip", "table-filters-menu"];
    components.forEach(tagName => { switch (tagName) {
        case "justifi-payments-list-filters":
            if (!customElements.get(tagName)) {
                customElements.define(tagName, PaymentsListFilters);
            }
            break;
        case "custom-popper":
            if (!customElements.get(tagName)) {
                defineCustomElement$7();
            }
            break;
        case "form-control-date":
            if (!customElements.get(tagName)) {
                defineCustomElement$6();
            }
            break;
        case "form-control-select":
            if (!customElements.get(tagName)) {
                defineCustomElement$5();
            }
            break;
        case "form-control-text":
            if (!customElements.get(tagName)) {
                defineCustomElement$4();
            }
            break;
        case "form-control-tooltip":
            if (!customElements.get(tagName)) {
                defineCustomElement$3();
            }
            break;
        case "table-filters-menu":
            if (!customElements.get(tagName)) {
                defineCustomElement$2();
            }
            break;
    } });
}
defineCustomElement$1();

const JustifiPaymentsListFilters = PaymentsListFilters;
const defineCustomElement = defineCustomElement$1;

export { JustifiPaymentsListFilters, defineCustomElement };
