import { proxyCustomElement, HTMLElement, createEvent, h } from '@stencil/core/internal/client';
import { P as PaymentService } from './payment.service.js';
import './config-state.js';
import './dinero.js';
import { P as Payment, C as ComponentErrorSeverity, a as ComponentErrorCodes } from './Refund.js';
import './Pagination.js';
import './Business.js';
import { g as getErrorCode, a as getErrorMessage } from './utils4.js';
import { c as checkPkgVersion, J as JustifiAnalytics } from './Analytics.js';
import { S as StyledHost } from './styled-host.js';
import './details.js';
import './event-types.js';
import './justifi-radio-list-item2.js';
import { d as defineCustomElement$2, a as defaultColumnsKeys } from './payments-list-core2.js';
import { d as defineCustomElement$3 } from './pagination-menu2.js';

const makeGetPayments = ({ id, authToken, service }) => async ({ params, onSuccess, onError, final }) => {
    var _a, _b;
    try {
        const response = await service.fetchPayments(id, authToken, params);
        if (!response.error) {
            const pagingInfo = Object.assign({}, response.page_info);
            const payments = ((_a = response.data) === null || _a === void 0 ? void 0 : _a.map((dataItem) => new Payment(dataItem))) || [];
            onSuccess({ payments, pagingInfo });
        }
        else {
            const responseError = getErrorMessage(response.error);
            const code = getErrorCode((_b = response.error) === null || _b === void 0 ? void 0 : _b.code);
            return onError({
                error: responseError,
                code,
                severity: ComponentErrorSeverity.ERROR,
            });
        }
    }
    catch (error) {
        const code = getErrorCode(error === null || error === void 0 ? void 0 : error.code);
        return onError({
            error: error.message || error,
            code,
            severity: ComponentErrorSeverity.ERROR,
        });
    }
    finally {
        return final();
    }
};

const PaymentsList = /*@__PURE__*/ proxyCustomElement(class PaymentsList extends HTMLElement {
    constructor() {
        super();
        this.__registerHost();
        this.__attachShadow();
        this.errorEvent = createEvent(this, "error-event", 7);
        this.errorMessage = null;
        this.columns = defaultColumnsKeys;
        this.handleErrorEvent = (event) => {
            this.errorMessage = event.detail.message;
            this.errorEvent.emit(event.detail);
        };
    }
    componentWillLoad() {
        checkPkgVersion();
        this.analytics = new JustifiAnalytics(this);
        this.initializeGetPayments();
    }
    disconnectedCallback() {
        var _a;
        (_a = this.analytics) === null || _a === void 0 ? void 0 : _a.cleanup();
    }
    ;
    propChanged() {
        this.initializeGetPayments();
    }
    initializeGetPayments() {
        if (this.accountId && this.authToken) {
            this.getPayments = makeGetPayments({
                id: this.accountId,
                authToken: this.authToken,
                service: new PaymentService()
            });
        }
        else {
            this.errorMessage = 'Account ID and Auth Token are required';
            this.errorEvent.emit({
                errorCode: ComponentErrorCodes.MISSING_PROPS,
                message: this.errorMessage,
                severity: ComponentErrorSeverity.ERROR,
            });
        }
    }
    render() {
        return (h(StyledHost, { key: '9d29383ee2084a5498f6dadc2a710748f5c81c13' }, h("payments-list-core", { key: '1a9255d13b6b1c5b8def24c70eff364ab44957f0', getPayments: this.getPayments, "onError-event": this.handleErrorEvent, columns: this.columns })));
    }
    static get watchers() { return {
        "accountId": ["propChanged"],
        "authToken": ["propChanged"]
    }; }
}, [1, "justifi-payments-list", {
        "accountId": [1, "account-id"],
        "authToken": [1, "auth-token"],
        "columns": [1],
        "getPayments": [32],
        "errorMessage": [32]
    }, undefined, {
        "accountId": ["propChanged"],
        "authToken": ["propChanged"]
    }]);
function defineCustomElement$1() {
    if (typeof customElements === "undefined") {
        return;
    }
    const components = ["justifi-payments-list", "pagination-menu", "payments-list-core"];
    components.forEach(tagName => { switch (tagName) {
        case "justifi-payments-list":
            if (!customElements.get(tagName)) {
                customElements.define(tagName, PaymentsList);
            }
            break;
        case "pagination-menu":
            if (!customElements.get(tagName)) {
                defineCustomElement$3();
            }
            break;
        case "payments-list-core":
            if (!customElements.get(tagName)) {
                defineCustomElement$2();
            }
            break;
    } });
}
defineCustomElement$1();

const JustifiPaymentsList = PaymentsList;
const defineCustomElement = defineCustomElement$1;

export { JustifiPaymentsList, defineCustomElement };
