import { proxyCustomElement, HTMLElement, createEvent, h } from '@stencil/core/internal/client';
import { P as PayoutService } from './payout.service.js';
import './config-state.js';
import './dinero.js';
import { j as Payout, C as ComponentErrorSeverity, a as ComponentErrorCodes } from './Refund.js';
import './Pagination.js';
import './Business.js';
import { g as getErrorCode, a as getErrorMessage } from './utils4.js';
import { E as ErrorState } from './utils.js';
import { c as checkPkgVersion, J as JustifiAnalytics } from './Analytics.js';
import { m as makeGetPayoutCSV } from './get-payout-csv.js';
import { d as defineCustomElement$3 } from './details.js';
import { d as defineCustomElement$2 } from './payout-details-core2.js';

const makeGetPayoutDetails = ({ id, authToken, service }) => async ({ onSuccess, onError }) => {
    var _a;
    try {
        const response = await service.fetchPayout(id, authToken);
        if (!response.error) {
            const payout = new Payout(response.data);
            onSuccess(payout);
        }
        else {
            const errorMessage = getErrorMessage(response.error);
            const code = getErrorCode((_a = response.error) === null || _a === void 0 ? void 0 : _a.code);
            onError({
                error: errorMessage,
                code,
                severity: ComponentErrorSeverity.ERROR,
            });
        }
    }
    catch (error) {
        const errorMessage = getErrorMessage(error);
        const code = getErrorCode(error === null || error === void 0 ? void 0 : error.code);
        onError({
            error: errorMessage,
            code,
            severity: ComponentErrorSeverity.ERROR,
        });
    }
};

const PayoutDetails = /*@__PURE__*/ proxyCustomElement(class PayoutDetails extends HTMLElement {
    constructor() {
        super();
        this.__registerHost();
        this.__attachShadow();
        this.errorEvent = createEvent(this, "error-event", 7);
        this.errorMessage = null;
        this.handleErrorEvent = (event) => {
            this.errorMessage = event.detail.message;
            this.errorEvent.emit(event.detail);
        };
    }
    componentWillLoad() {
        checkPkgVersion();
        this.analytics = new JustifiAnalytics(this);
        this.initializeServices();
    }
    disconnectedCallback() {
        var _a;
        (_a = this.analytics) === null || _a === void 0 ? void 0 : _a.cleanup();
    }
    ;
    propChanged() {
        this.initializeServices();
    }
    initializeServices() {
        if (this.payoutId && this.authToken) {
            this.getPayout = makeGetPayoutDetails({
                id: this.payoutId,
                authToken: this.authToken,
                service: new PayoutService()
            });
            this.getPayoutCSV = makeGetPayoutCSV({
                authToken: this.authToken,
                service: new PayoutService()
            });
        }
        else {
            this.errorMessage = 'Failed to load payout details. payoutId or authToken is not provided.';
            this.errorEvent.emit({
                message: this.errorMessage,
                errorCode: ComponentErrorCodes.MISSING_PROPS,
                severity: ComponentErrorSeverity.ERROR
            });
        }
    }
    render() {
        if (this.errorMessage) {
            return ErrorState(this.errorMessage);
        }
        return (h("payout-details-core", { getPayout: this.getPayout, getPayoutCSV: this.getPayoutCSV, "onError-event": this.handleErrorEvent }));
    }
    static get watchers() { return {
        "payoutId": ["propChanged"],
        "authToken": ["propChanged"]
    }; }
}, [1, "justifi-payout-details", {
        "payoutId": [1, "payout-id"],
        "authToken": [1, "auth-token"],
        "getPayout": [32],
        "getPayoutCSV": [32],
        "errorMessage": [32]
    }, undefined, {
        "payoutId": ["propChanged"],
        "authToken": ["propChanged"]
    }]);
function defineCustomElement$1() {
    if (typeof customElements === "undefined") {
        return;
    }
    const components = ["justifi-payout-details", "justifi-details", "payout-details-core"];
    components.forEach(tagName => { switch (tagName) {
        case "justifi-payout-details":
            if (!customElements.get(tagName)) {
                customElements.define(tagName, PayoutDetails);
            }
            break;
        case "justifi-details":
            if (!customElements.get(tagName)) {
                defineCustomElement$3();
            }
            break;
        case "payout-details-core":
            if (!customElements.get(tagName)) {
                defineCustomElement$2();
            }
            break;
    } });
}
defineCustomElement$1();

const JustifiPayoutDetails = PayoutDetails;
const defineCustomElement = defineCustomElement$1;

export { JustifiPayoutDetails, defineCustomElement };
