import { proxyCustomElement, HTMLElement, h } from '@stencil/core/internal/client';
import { f as filterParams, p as propsParams, c as clearParams } from './terminal-orders-list-params-state.js';
import { ai as terminalOrdersListFilterMenu, aj as orderStatusTerminalOrdersListFilterParam, ak as orderTypeTerminalOrdersListFilterParam, al as createdAfterTerminalOrdersListFilterParam, am as createdBeforeTerminalOrdersListFilterParam } from './parts.js';
import { S as StyledHost } from './styled-host.js';
import './details.js';
import './event-types.js';
import './justifi-radio-list-item2.js';
import './config-state.js';
import { h as convertToUTC, e as convertToLocal } from './utils2.js';
import { T as TerminalOrderStatus, e as TerminalOrderType } from './Refund.js';
import './Pagination.js';
import './Business.js';
import { d as defineCustomElement$6 } from './custom-popper2.js';
import { d as defineCustomElement$5 } from './form-control-date2.js';
import { d as defineCustomElement$4 } from './form-control-select2.js';
import { d as defineCustomElement$3 } from './form-control-tooltip2.js';
import { d as defineCustomElement$2 } from './table-filters-menu2.js';

const TerminalOrdersListFilters = /*@__PURE__*/ proxyCustomElement(class TerminalOrdersListFilters extends HTMLElement {
    constructor() {
        super();
        this.__registerHost();
        this.__attachShadow();
        this.setParamsOnChange = (name, value) => {
            filterParams[name] = value;
        };
        this.handleDateInput = (name, value) => {
            const utcDate = convertToUTC(value, { setExactTime: true });
            this.setParamsOnChange(name, utcDate);
        };
    }
    componentWillLoad() {
        const propsToSet = {
            order_status: this.orderStatus,
            order_type: this.orderType,
            created_after: this.createdAfter,
            created_before: this.createdBefore
        };
        Object.entries(propsToSet).forEach(([key, value]) => {
            if (value) {
                propsParams[key] = value;
            }
        });
    }
    get terminalOrderStatusOptions() {
        return [
            { label: 'All', value: '' },
            { label: 'Created', value: TerminalOrderStatus.created },
            { label: 'Completed', value: TerminalOrderStatus.completed },
            { label: 'Submitted', value: TerminalOrderStatus.submitted },
            { label: 'In Progress', value: TerminalOrderStatus.in_progress },
            { label: 'On Hold', value: TerminalOrderStatus.on_hold },
            { label: 'Canceled', value: TerminalOrderStatus.canceled }
        ];
    }
    get terminalOrderTypeOptions() {
        return [
            { label: 'All', value: '' },
            { label: 'Boarding Only', value: TerminalOrderType.boardingOnly },
            { label: 'Boarding Shipping', value: TerminalOrderType.boardingShipping },
        ];
    }
    render() {
        const filterMenuParams = Object.assign({}, filterParams);
        return (h(StyledHost, { key: '24b9da56d6bef1aa545007f2dba95b1da7fa4f4d' }, h("table-filters-menu", { key: 'ac3c26800fff2176782cf8240916cfd7e9a20333', params: filterMenuParams, clearParams: clearParams, part: terminalOrdersListFilterMenu }, h("div", { key: 'cf11a3bc06453a9970120d0ac05334754a51181b', class: "grid-cols-2 gap-3 p-1" }, h("div", { key: 'e72c2e114463c57e0de6042f2b3c419359f416ab', class: "p-2" }, h("form-control-select", { key: 'b2a3d66f6c0bb9fcf1da45cddc0b9df78ffa5ef8', name: "order_status", label: "Order Status", options: this.terminalOrderStatusOptions, inputHandler: this.setParamsOnChange, defaultValue: this.orderStatus || filterParams.order_status, disabled: !!this.orderStatus, part: orderStatusTerminalOrdersListFilterParam })), h("div", { key: '944a5f0ff5ff2fb87bee60da154b8dd03660e4f3', class: "p-2" }, h("form-control-select", { key: '992921c6f9ecf20587f814f87a44179db3fe49fd', name: "order_type", label: "Order Type", options: this.terminalOrderTypeOptions, inputHandler: this.setParamsOnChange, defaultValue: this.orderType || filterParams.order_type, disabled: !!this.orderType, part: orderTypeTerminalOrdersListFilterParam })), h("div", { key: '5acb3775b09fd508cfc77bf4b309cf43ca71a47a', class: "p-2" }, h("form-control-date", { key: '2b712d2c2903f2d579ada15a0e27eb97cc38c2f9', name: "created_after", label: "Created After", inputHandler: this.handleDateInput, defaultValue: convertToLocal(this.createdAfter, { showInputDateTime: true }) ||
                convertToLocal(filterParams.created_after, { showInputDateTime: true }), showTime: true, disabled: !!this.createdAfter, part: createdAfterTerminalOrdersListFilterParam })), h("div", { key: '66dae53f3fe0a6147570b15e6e85f7a821d7a322', class: "p-2" }, h("form-control-date", { key: '3715aab2b7637c67b1373bd0135a8a35c2b5a34c', name: "created_before", label: "Created Before", inputHandler: this.handleDateInput, defaultValue: convertToLocal(this.createdBefore, { showInputDateTime: true }) ||
                convertToLocal(filterParams.created_before, { showInputDateTime: true }), showTime: true, disabled: !!this.createdBefore, part: createdBeforeTerminalOrdersListFilterParam }))))));
    }
}, [1, "justifi-terminal-orders-list-filters", {
        "orderStatus": [1, "order-status"],
        "orderType": [1, "order-type"],
        "createdAfter": [1, "created-after"],
        "createdBefore": [1, "created-before"]
    }]);
function defineCustomElement$1() {
    if (typeof customElements === "undefined") {
        return;
    }
    const components = ["justifi-terminal-orders-list-filters", "custom-popper", "form-control-date", "form-control-select", "form-control-tooltip", "table-filters-menu"];
    components.forEach(tagName => { switch (tagName) {
        case "justifi-terminal-orders-list-filters":
            if (!customElements.get(tagName)) {
                customElements.define(tagName, TerminalOrdersListFilters);
            }
            break;
        case "custom-popper":
            if (!customElements.get(tagName)) {
                defineCustomElement$6();
            }
            break;
        case "form-control-date":
            if (!customElements.get(tagName)) {
                defineCustomElement$5();
            }
            break;
        case "form-control-select":
            if (!customElements.get(tagName)) {
                defineCustomElement$4();
            }
            break;
        case "form-control-tooltip":
            if (!customElements.get(tagName)) {
                defineCustomElement$3();
            }
            break;
        case "table-filters-menu":
            if (!customElements.get(tagName)) {
                defineCustomElement$2();
            }
            break;
    } });
}
defineCustomElement$1();

const JustifiTerminalOrdersListFilters = TerminalOrdersListFilters;
const defineCustomElement = defineCustomElement$1;

export { JustifiTerminalOrdersListFilters, defineCustomElement };
