import { proxyCustomElement, HTMLElement, createEvent, h } from '@stencil/core/internal/client';
import { S as StyledHost } from './styled-host.js';
import './details.js';
import './event-types.js';
import './justifi-radio-list-item2.js';
import { c as checkPkgVersion, J as JustifiAnalytics } from './Analytics.js';
import { d as defineCustomElement$2, a as defaultColumnsKeys } from './terminal-orders-list-core2.js';
import './config-state.js';
import './dinero.js';
import { n as TerminalOrder, C as ComponentErrorSeverity, a as ComponentErrorCodes } from './Refund.js';
import './Pagination.js';
import './Business.js';
import { g as getErrorCode, a as getErrorMessage } from './utils4.js';
import { A as Api } from './Api.js';
import { d as defineCustomElement$3 } from './pagination-menu2.js';

const makeGetTerminalOrders = ({ id, authToken, service }) => async ({ params, onSuccess, onError, final }) => {
    var _a, _b;
    try {
        const response = await service.fetchTerminalOrders(id, authToken, params);
        if (!response.error) {
            const pagingInfo = Object.assign({}, response.page_info);
            const terminalOrders = ((_a = response.data) === null || _a === void 0 ? void 0 : _a.map((dataItem) => new TerminalOrder(dataItem))) || [];
            onSuccess({ terminalOrders, pagingInfo });
        }
        else {
            const responseError = getErrorMessage(response.error);
            const code = getErrorCode((_b = response.error) === null || _b === void 0 ? void 0 : _b.code);
            return onError({
                error: responseError,
                code,
                severity: ComponentErrorSeverity.ERROR,
            });
        }
    }
    catch (error) {
        const code = getErrorCode(error === null || error === void 0 ? void 0 : error.code);
        return onError({
            error: error.message || error,
            code,
            severity: ComponentErrorSeverity.ERROR,
        });
    }
    finally {
        return final();
    }
};

const api = Api();
class TerminalOrderService {
    async fetchTerminalOrders(accountId, authToken, params) {
        const endpoint = 'terminals/orders';
        const headers = { account: accountId };
        return api.get({ endpoint, params, headers, authToken });
    }
}

const TerminalOrdersList = /*@__PURE__*/ proxyCustomElement(class TerminalOrdersList extends HTMLElement {
    constructor() {
        super();
        this.__registerHost();
        this.__attachShadow();
        this.errorEvent = createEvent(this, "error-event", 7);
        this.errorMessage = null;
        this.columns = defaultColumnsKeys;
        this.handleErrorEvent = (event) => {
            this.errorMessage = event.detail.message;
            this.errorEvent.emit(event.detail);
        };
    }
    componentWillLoad() {
        checkPkgVersion();
        this.analytics = new JustifiAnalytics(this);
        this.initializeGetData();
    }
    disconnectedCallback() {
        var _a;
        (_a = this.analytics) === null || _a === void 0 ? void 0 : _a.cleanup();
    }
    ;
    initializeGetData() {
        if (this.accountId && this.authToken) {
            this.getTerminalOrders = makeGetTerminalOrders({
                id: this.accountId,
                authToken: this.authToken,
                service: new TerminalOrderService()
            });
        }
        else {
            this.errorMessage = 'Account ID and Auth Token are required';
            this.errorEvent.emit({
                errorCode: ComponentErrorCodes.MISSING_PROPS,
                message: this.errorMessage,
                severity: ComponentErrorSeverity.ERROR,
            });
        }
    }
    render() {
        return (h(StyledHost, { key: 'e0fcbc2ccb76acdbcd7a18772d509995c81b1ae1' }, h("terminal-orders-list-core", { key: '21b108f554caa4343ecbd3bffa404c01442ef938', getTerminalOrders: this.getTerminalOrders, "onError-event": this.handleErrorEvent, columns: this.columns })));
    }
}, [1, "justifi-terminal-orders-list", {
        "accountId": [1, "account-id"],
        "authToken": [1, "auth-token"],
        "columns": [1],
        "getTerminalOrders": [32],
        "errorMessage": [32]
    }]);
function defineCustomElement$1() {
    if (typeof customElements === "undefined") {
        return;
    }
    const components = ["justifi-terminal-orders-list", "pagination-menu", "terminal-orders-list-core"];
    components.forEach(tagName => { switch (tagName) {
        case "justifi-terminal-orders-list":
            if (!customElements.get(tagName)) {
                customElements.define(tagName, TerminalOrdersList);
            }
            break;
        case "pagination-menu":
            if (!customElements.get(tagName)) {
                defineCustomElement$3();
            }
            break;
        case "terminal-orders-list-core":
            if (!customElements.get(tagName)) {
                defineCustomElement$2();
            }
            break;
    } });
}
defineCustomElement$1();

const JustifiTerminalOrdersList = TerminalOrdersList;
const defineCustomElement = defineCustomElement$1;

export { JustifiTerminalOrdersList, defineCustomElement };
