import { proxyCustomElement, HTMLElement, h } from '@stencil/core/internal/client';
import { l as lodashExports } from './lodash.js';
import { f as filterParams, p as propsParams, c as clearParams } from './terminals-list-params-state.js';
import { an as terminalsListFilterMenu, ao as terminalIdTerminalsListFilterParam, ap as terminalOrderIdTerminalsListFilterParam, aq as terminalStatusTerminalsListFilterParam } from './parts.js';
import { S as StyledHost } from './styled-host.js';
import './details.js';
import './event-types.js';
import './justifi-radio-list-item2.js';
import './config-state.js';
import './dinero.js';
import { f as ITerminalStatus } from './Refund.js';
import './Pagination.js';
import './Business.js';
import { d as defineCustomElement$6 } from './custom-popper2.js';
import { d as defineCustomElement$5 } from './form-control-select2.js';
import { d as defineCustomElement$4 } from './form-control-text2.js';
import { d as defineCustomElement$3 } from './form-control-tooltip2.js';
import { d as defineCustomElement$2 } from './table-filters-menu2.js';

const TerminalsListFilters = /*@__PURE__*/ proxyCustomElement(class TerminalsListFilters extends HTMLElement {
    constructor() {
        super();
        this.__registerHost();
        this.__attachShadow();
        this.setParamsOnChange = (name, value) => {
            filterParams[name] = value;
        };
    }
    componentWillLoad() {
        // debounced input handler for text input
        this.debouncedSetParamsOnChange = lodashExports.debounce(this.setParamsOnChange, 300);
        const propsToSet = {
            terminal_id: this.terminalId,
            status: this.terminalStatus,
            terminal_order_id: this.terminalOrderId
        };
        Object.entries(propsToSet).forEach(([key, value]) => {
            if (value) {
                propsParams[key] = value;
            }
        });
    }
    get terminalStatusOptions() {
        return [
            { label: 'All', value: '' },
            { label: 'Connected', value: ITerminalStatus.connected },
            { label: 'Disconnected', value: ITerminalStatus.disconnected },
            { label: 'Unknown', value: ITerminalStatus.unknown },
            { label: 'Pending Configuration', value: ITerminalStatus.pending_configuration }
        ];
    }
    render() {
        const filterMenuParams = Object.assign({}, filterParams);
        return (h(StyledHost, { key: 'a5fe1671dd03e1290544f3deaf5aa01b5d937d9d' }, h("table-filters-menu", { key: 'f7a3d95c1b0ad0b52b96f990fd56fdbe64643493', params: filterMenuParams, clearParams: clearParams, part: terminalsListFilterMenu }, h("div", { key: '92b0144a5ab7eee377e053e9b006af846ac43d64', class: "grid-cols-2 gap-3 p-1" }, h("div", { key: '3970a2e11f3be7953af299be4825166a829e9a0a', class: "p-2" }, h("form-control-text", { key: '0653692eaffdb14b092643a9f3c1b8e126c942db', name: "terminal_id", label: "Terminal ID", inputHandler: this.debouncedSetParamsOnChange, defaultValue: this.terminalId || filterParams.terminal_id, disabled: !!this.terminalId, part: terminalIdTerminalsListFilterParam })), h("div", { key: 'c9d152d0a2d7e7b7fd7e72693a2248a020545a24', class: "p-2" }, h("form-control-text", { key: '785e7b382d9cadb72e242a379f2525b2da5140de', name: "terminal_order_id", label: "Terminal Order ID", inputHandler: this.debouncedSetParamsOnChange, defaultValue: this.terminalOrderId || filterParams.terminal_order_id, disabled: !!this.terminalOrderId, part: terminalOrderIdTerminalsListFilterParam })), h("div", { key: 'f4f1e79eb81a72dd25bb4f4c14450ca82657f213', class: "p-2" }, h("form-control-select", { key: '52b390e42309e13e2f09df0681392bbf8e84aed8', name: "status", label: "Status", options: this.terminalStatusOptions, inputHandler: this.setParamsOnChange, defaultValue: this.terminalStatus || filterParams.status, disabled: !!this.terminalStatus, part: terminalStatusTerminalsListFilterParam }))))));
    }
}, [1, "justifi-terminals-list-filters", {
        "terminalId": [1, "terminal-id"],
        "terminalOrderId": [1, "terminal-order-id"],
        "terminalStatus": [1, "terminal-status"]
    }]);
function defineCustomElement$1() {
    if (typeof customElements === "undefined") {
        return;
    }
    const components = ["justifi-terminals-list-filters", "custom-popper", "form-control-select", "form-control-text", "form-control-tooltip", "table-filters-menu"];
    components.forEach(tagName => { switch (tagName) {
        case "justifi-terminals-list-filters":
            if (!customElements.get(tagName)) {
                customElements.define(tagName, TerminalsListFilters);
            }
            break;
        case "custom-popper":
            if (!customElements.get(tagName)) {
                defineCustomElement$6();
            }
            break;
        case "form-control-select":
            if (!customElements.get(tagName)) {
                defineCustomElement$5();
            }
            break;
        case "form-control-text":
            if (!customElements.get(tagName)) {
                defineCustomElement$4();
            }
            break;
        case "form-control-tooltip":
            if (!customElements.get(tagName)) {
                defineCustomElement$3();
            }
            break;
        case "table-filters-menu":
            if (!customElements.get(tagName)) {
                defineCustomElement$2();
            }
            break;
    } });
}
defineCustomElement$1();

const JustifiTerminalsListFilters = TerminalsListFilters;
const defineCustomElement = defineCustomElement$1;

export { JustifiTerminalsListFilters, defineCustomElement };
