import { proxyCustomElement, HTMLElement, createEvent, h } from '@stencil/core/internal/client';
import { k as Terminal, C as ComponentErrorSeverity, a as ComponentErrorCodes } from './Refund.js';
import { c as checkPkgVersion, J as JustifiAnalytics } from './Analytics.js';
import { T as TerminalService } from './terminal.service.js';
import './config-state.js';
import './dinero.js';
import './Pagination.js';
import './Business.js';
import { g as getErrorCode, a as getErrorMessage } from './utils4.js';
import { m as makeGetSubAccounts, S as SubAccountService } from './get-subaccounts.js';
import { S as StyledHost } from './styled-host.js';
import './details.js';
import './event-types.js';
import './justifi-radio-list-item2.js';
import { d as defineCustomElement$2, a as defaultColumnsKeys } from './terminals-list-core2.js';
import { d as defineCustomElement$3 } from './pagination-menu2.js';

const makeGetTerminals = ({ id, authToken, service }) => async ({ params, onSuccess, onError }) => {
    var _a, _b;
    try {
        const response = await service.fetchTerminals(id, authToken, params);
        if (!response.error) {
            const pagingInfo = Object.assign({}, response.page_info);
            const terminals = ((_a = response.data) === null || _a === void 0 ? void 0 : _a.map((dataItem) => new Terminal(dataItem))) || [];
            onSuccess({ terminals, pagingInfo });
        }
        else {
            const responseError = getErrorMessage(response.error);
            const code = getErrorCode((_b = response.error) === null || _b === void 0 ? void 0 : _b.code);
            return onError({
                error: responseError,
                code,
                severity: ComponentErrorSeverity.ERROR,
            });
        }
    }
    catch (error) {
        const code = getErrorCode(error === null || error === void 0 ? void 0 : error.code);
        return onError({
            error: error.message || error,
            code,
            severity: ComponentErrorSeverity.ERROR,
        });
    }
};

const TerminalsList = /*@__PURE__*/ proxyCustomElement(class TerminalsList extends HTMLElement {
    constructor() {
        super();
        this.__registerHost();
        this.__attachShadow();
        this.errorEvent = createEvent(this, "error-event", 7);
        this.errorMessage = null;
        this.columns = defaultColumnsKeys;
        this.handleErrorEvent = (event) => {
            this.errorMessage = event.detail.message;
            this.errorEvent.emit(event.detail);
        };
    }
    componentWillLoad() {
        checkPkgVersion();
        this.analytics = new JustifiAnalytics(this);
        this.initializeGetData();
    }
    disconnectedCallback() {
        var _a;
        (_a = this.analytics) === null || _a === void 0 ? void 0 : _a.cleanup();
    }
    ;
    propChanged() {
        this.initializeGetData();
    }
    initializeGetData() {
        this.initializeGetTerminals();
        this.initializeGetSubAccounts();
    }
    initializeGetTerminals() {
        if (this.accountId && this.authToken) {
            this.getTerminals = makeGetTerminals({
                id: this.accountId,
                authToken: this.authToken,
                service: new TerminalService()
            });
        }
        else {
            this.errorMessage = 'Account ID and Auth Token are required';
            this.errorEvent.emit({
                errorCode: ComponentErrorCodes.MISSING_PROPS,
                message: this.errorMessage,
                severity: ComponentErrorSeverity.ERROR,
            });
        }
    }
    initializeGetSubAccounts() {
        if (this.accountId && this.authToken) {
            this.getSubAccounts = makeGetSubAccounts({
                accountId: this.accountId,
                authToken: this.authToken,
                service: new SubAccountService()
            });
        }
    }
    render() {
        return (h(StyledHost, { key: '57a9be57de845dc3f905260445e245cf30458af8' }, h("terminals-list-core", { key: '00f79218e216fffc12ecfc3b158cd299ad054349', getTerminals: this.getTerminals, getSubAccounts: this.getSubAccounts, "onError-event": this.handleErrorEvent, columns: this.columns })));
    }
    static get watchers() { return {
        "accountId": ["propChanged"],
        "authToken": ["propChanged"]
    }; }
}, [1, "justifi-terminals-list", {
        "accountId": [1, "account-id"],
        "authToken": [1, "auth-token"],
        "columns": [1],
        "getTerminals": [32],
        "getSubAccounts": [32],
        "errorMessage": [32]
    }, undefined, {
        "accountId": ["propChanged"],
        "authToken": ["propChanged"]
    }]);
function defineCustomElement$1() {
    if (typeof customElements === "undefined") {
        return;
    }
    const components = ["justifi-terminals-list", "pagination-menu", "terminals-list-core"];
    components.forEach(tagName => { switch (tagName) {
        case "justifi-terminals-list":
            if (!customElements.get(tagName)) {
                customElements.define(tagName, TerminalsList);
            }
            break;
        case "pagination-menu":
            if (!customElements.get(tagName)) {
                defineCustomElement$3();
            }
            break;
        case "terminals-list-core":
            if (!customElements.get(tagName)) {
                defineCustomElement$2();
            }
            break;
    } });
}
defineCustomElement$1();

const JustifiTerminalsList = TerminalsList;
const defineCustomElement = defineCustomElement$1;

export { JustifiTerminalsList, defineCustomElement };
