import { h, proxyCustomElement, HTMLElement, createEvent } from '@stencil/core/internal/client';
import './config-state.js';
import './dinero.js';
import './Refund.js';
import { p as pagingDefaults } from './Pagination.js';
import './Business.js';
import './details.js';
import { T as Table, a as TableWrapper, b as TableComponent, c as TableHead, d as TableHeadRow, e as TableBody, f as TableLoadingState, g as TableEmptyState, h as TableErrorState, i as TableRow, j as TableFoot, k as TableFootRow, l as TableFootCell } from './table.js';
import { T as TableClickActions } from './event-types.js';
import './justifi-radio-list-item2.js';
import { M as MapPaymentStatusToBadge } from './payments-status.js';
import { e as convertToLocal } from './utils2.js';
import { v as tableHeadCell, a8 as getAlternateTableCellPart } from './parts.js';
import { o as onQueryParamsChange, g as getRequestParams } from './payments-list-params-state.js';
import { d as defineCustomElement$1 } from './pagination-menu2.js';

const defaultColumnsKeys = 'created_at,amount,status,payment_type,description,payers_name,last_four_digits';
const paymentTableColumns = {
    created_at: () => (h("th", { part: tableHeadCell, scope: "col", title: "The date and time each payment was made" }, "Date")),
    amount: () => (h("th", { part: tableHeadCell, scope: "col", title: "The dollar amount of each payment" }, "Amount")),
    status: () => (h("th", { part: tableHeadCell, scope: "col", title: "The current status of each payment" }, "Status")),
    payment_type: () => (h("th", { part: tableHeadCell, scope: "col", title: "The type of each payment" }, "Type")),
    description: () => (h("th", { part: tableHeadCell, scope: "col", title: "The payment description, if you provided one" }, "Description")),
    payers_name: () => (h("th", { part: tableHeadCell, scope: "col", title: "The name associated with the payment method" }, "Account Holder")),
    last_four_digits: () => (h("th", { part: tableHeadCell, scope: "col", title: "The brand and last 4 digits of the payment method" }, "Payment Method")),
};
const paymentTableCells = {
    created_at: (payment, index) => (h("td", { part: getAlternateTableCellPart(index) },
        h("div", { class: "fw-bold" }, convertToLocal(payment.created_at, { showDisplayDate: true })),
        h("div", { class: "fw-bold" }, convertToLocal(payment.created_at, { showTime: true })))),
    amount: (payment, index) => (h("td", { part: getAlternateTableCellPart(index) }, payment.formattedPaymentAmount(payment.amount))),
    status: (payment, index) => (h("td", { part: getAlternateTableCellPart(index) }, MapPaymentStatusToBadge(payment.status))),
    payment_type: (payment, index) => (h("td", { part: getAlternateTableCellPart(index) }, payment.payment_type)),
    description: (payment, index) => (h("td", { part: getAlternateTableCellPart(index) }, payment.description)),
    payers_name: (payment, index) => (h("td", { part: getAlternateTableCellPart(index) }, payment.payers_name)),
    last_four_digits: (payment, index) => (h("td", { part: getAlternateTableCellPart(index) }, payment.last_four_digits)),
};

const PaymentsListCore = /*@__PURE__*/ proxyCustomElement(class PaymentsListCore extends HTMLElement {
    constructor() {
        super();
        this.__registerHost();
        this.clickEvent = createEvent(this, "click-event", 7);
        this.errorEvent = createEvent(this, "error-event", 7);
        this.payments = [];
        this.loading = true;
        this.paging = pagingDefaults;
        this.pagingParams = {};
        this.handleClickPrevious = (beforeCursor) => {
            this.pagingParams = { before_cursor: beforeCursor };
            this.clickEvent.emit({ name: TableClickActions.previous });
        };
        this.handleClickNext = (afterCursor) => {
            this.pagingParams = { after_cursor: afterCursor };
            this.clickEvent.emit({ name: TableClickActions.next });
        };
        this.rowClickHandler = (e) => {
            const clickedPaymentID = e.target.closest('tr').dataset.rowEntityId;
            if (!clickedPaymentID)
                return;
            const paymentData = this.payments.find((payment) => payment.id === clickedPaymentID);
            this.clickEvent.emit({ name: TableClickActions.row, data: paymentData });
        };
    }
    updateOnPropChange() {
        this.fetchData();
    }
    componentWillLoad() {
        this.paymentsTable = new Table(this.payments, this.columns, paymentTableColumns, paymentTableCells);
        if (this.getPayments) {
            this.fetchData();
        }
        onQueryParamsChange('set', () => {
            this.pagingParams = {};
        });
        onQueryParamsChange('reset', () => {
            this.pagingParams = {};
            this.errorMessage = '';
        });
    }
    fetchData() {
        this.loading = true;
        this.getPayments({
            params: this.paymentParams,
            onSuccess: ({ payments, pagingInfo }) => {
                this.payments = payments;
                this.paging = pagingInfo;
                this.paymentsTable.collectionData = this.payments;
            },
            onError: ({ error, code, severity }) => {
                this.errorMessage = error;
                this.errorEvent.emit({
                    errorCode: code,
                    message: error,
                    severity,
                });
            },
            final: () => {
                this.loading = false;
            }
        });
    }
    get paymentParams() {
        const requestParams = getRequestParams();
        const params = Object.assign(Object.assign({}, requestParams), this.pagingParams);
        return params;
    }
    get entityId() {
        return this.payments.map((payment) => payment.id);
    }
    get showEmptyState() {
        return !this.loading && !this.errorMessage && this.paymentsTable.rowData.length < 1;
    }
    get showErrorState() {
        return !this.loading && !!this.errorMessage;
    }
    get showRowData() {
        return !this.showEmptyState && !this.showErrorState && !this.loading;
    }
    render() {
        return (h(TableWrapper, { key: '8717c3554e0d5c8a2cd20b3a5510691c57d9f89a' }, h(TableComponent, { key: 'f23e5222c49c9d2f74c47ee0ded1c79319bd662c' }, h(TableHead, { key: '1cc4cf3bb057247bb0f26efc8414f574685ea134' }, h(TableHeadRow, { key: 'cfb828ecbe828cdd096e1e00710443627c00e72a' }, this.paymentsTable.columnData.map((column) => column))), h(TableBody, { key: 'da5eff4f32f2c47e700665a417f3d71605a287c3' }, h(TableLoadingState, { key: 'f5214c8760d679e47d50d1ac6883176abfd8aa91', columnSpan: this.paymentsTable.columnData.length, isLoading: this.loading }), h(TableEmptyState, { key: 'cbc72d572081b54b42d5adcb4e86937bf6c10fde', isEmpty: this.showEmptyState, columnSpan: this.paymentsTable.columnData.length }), h(TableErrorState, { key: 'ce954f66d360840e0c00d7acc77e8e8d43d93dd6', columnSpan: this.paymentsTable.columnData.length, errorMessage: this.errorMessage }), this.showRowData && this.paymentsTable.rowData.map((data, index) => (h(TableRow, { "data-test-id": "table-row", "data-row-entity-id": this.entityId[index], onClick: this.rowClickHandler }, data)))), this.paging && (h(TableFoot, { key: 'b6794bb85eb48d3ca9fd284a538eecba052b4e41' }, h(TableFootRow, { key: '923942c6cc9e110a93e0ea63dc4a99296ed10d63' }, h(TableFootCell, { key: 'ad259631ffc9d9a567375c7d28f48d449ac40990', colSpan: this.paymentsTable.columnData.length }, h("pagination-menu", { key: 'c06a9e46d23c851a9271bf893889cb3360475070', paging: Object.assign(Object.assign({}, this.paging), { handleClickPrevious: this.handleClickPrevious, handleClickNext: this.handleClickNext }) }))))))));
    }
    static get watchers() { return {
        "pagingParams": ["updateOnPropChange"],
        "getPayments": ["updateOnPropChange"],
        "columns": ["updateOnPropChange"]
    }; }
}, [0, "payments-list-core", {
        "getPayments": [16, "get-payments"],
        "columns": [1],
        "payments": [32],
        "paymentsTable": [32],
        "loading": [32],
        "errorMessage": [32],
        "paging": [32],
        "pagingParams": [32]
    }, undefined, {
        "pagingParams": ["updateOnPropChange"],
        "getPayments": ["updateOnPropChange"],
        "columns": ["updateOnPropChange"]
    }]);
function defineCustomElement() {
    if (typeof customElements === "undefined") {
        return;
    }
    const components = ["payments-list-core", "pagination-menu"];
    components.forEach(tagName => { switch (tagName) {
        case "payments-list-core":
            if (!customElements.get(tagName)) {
                customElements.define(tagName, PaymentsListCore);
            }
            break;
        case "pagination-menu":
            if (!customElements.get(tagName)) {
                defineCustomElement$1();
            }
            break;
    } });
}
defineCustomElement();

export { PaymentsListCore as P, defaultColumnsKeys as a, defineCustomElement as d };
