import { h, proxyCustomElement, HTMLElement, createEvent } from '@stencil/core/internal/client';
import { a as formatDate, d as formatTime } from './utils2.js';
import { E as ErrorState, b as EntityHeadInfo, c as EntityHeadInfoItem, D as DetailSectionTitle, a as DetailItem, C as CodeBlock } from './utils.js';
import { B as Button } from './button.js';
import { S as StyledHost } from './styled-host.js';
import { d as defineCustomElement$1 } from './details.js';
import './event-types.js';
import './justifi-radio-list-item2.js';
import { M as MapPayoutStatusToBadge } from './payouts-status.js';
import { S as Skeleton } from './skeleton.js';
import { B as Badge, a as BadgeVariant } from './badge.js';

const PayoutDetailsLoading = () => (h("div", { class: "row gap-3" },
    h("div", { class: "col-12" },
        h(Skeleton, { width: "35%", height: "30px" })),
    h("div", { class: "col-12" },
        h(Skeleton, { width: "70%" })),
    h("div", { class: "col-12" },
        h(Skeleton, { width: "40%" })),
    h("div", { class: "col-12" },
        h(Skeleton, { width: "40%" })),
    h("div", { class: "col-12" },
        h(Skeleton, { width: "100%" })),
    h("div", { class: "col-12" },
        h(Skeleton, { width: "80%" }))));

const PayoutDetailsCore = /*@__PURE__*/ proxyCustomElement(class PayoutDetailsCore extends HTMLElement {
    constructor() {
        super();
        this.__registerHost();
        this.errorEvent = createEvent(this, "error-event", 7);
        this.loading = true;
        this.errorMessage = null;
        this.downloadCSV = () => {
            this.getPayoutCSV({
                payoutId: this.payout.id,
                onError: ({ error, code, severity }) => {
                    this.errorMessage = error;
                    this.errorEvent.emit({
                        message: error,
                        errorCode: code,
                        severity,
                    });
                },
            });
        };
    }
    componentWillLoad() {
        if (this.getPayout) {
            this.fetchData();
        }
    }
    getPayoutWatcher() {
        this.fetchData();
    }
    fetchData() {
        this.loading = true;
        this.getPayout({
            onSuccess: (payout) => {
                this.errorMessage = null;
                this.payout = payout;
                this.loading = false;
            },
            onError: ({ error, code, severity }) => {
                this.errorMessage = error;
                this.errorEvent.emit({
                    message: error,
                    errorCode: code,
                    severity,
                });
                this.loading = false;
            },
        });
    }
    render() {
        var _a;
        return (h(StyledHost, { key: 'e05c4ce44c4c8f55c654b1bdf1cf6fe683cb9b81' }, this.loading && h(PayoutDetailsLoading, { key: 'e376fe6853e8d7f51c4341eed7b88706bf0f7b8a' }), !this.loading && this.errorMessage && ErrorState(this.errorMessage), !this.loading && this.payout && (h("justifi-details", { key: '2dd14bbe8176fbb2ea33bc10c626295d6dc1e4e1', "error-message": this.errorMessage }, h(EntityHeadInfo, { key: 'dd564d982ac3efb2f095655cf4cb8418811caf02', slot: "head-info", badge: (h("div", { class: "d-flex gap-1" }, MapPayoutStatusToBadge((_a = this.payout) === null || _a === void 0 ? void 0 : _a.status), this.payout.settlement_priority === 'expedited' ? (h(Badge, { variant: BadgeVariant.WARNING, title: "Expedited", text: "Expedited" })) : (h(Badge, { variant: BadgeVariant.SECONDARY, title: "Standard", text: "Standard" })))), title: this.payout.formattedPaymentAmount(this.payout.amount) }, h(EntityHeadInfoItem, { key: 'a1fd083db968de7d1b4f14a40bee168face1d783', classes: "border-1 border-end", title: "Updated At", value: `${formatDate(this.payout.updated_at)} ${formatTime(this.payout.updated_at)}` }), h(EntityHeadInfoItem, { key: '1ab1aa48b5b685e0f6b01bd3199884cc4e7a41a0', classes: "border-1 border-end", title: "Created At", value: `${formatDate(this.payout.created_at)} ${formatTime(this.payout.created_at)}` }), h(EntityHeadInfoItem, { key: '7463594d15588fdb0f81c75d9951d8b15872ddec', title: "ID", value: this.payout.id }), h("div", { key: '8e6db2a97f3fbb3e6249dfaef88dbfdaad2067f1', class: "m-4" }, h(Button, { key: '3bfd46400ea58e57a83fc9872656113d69a77987', variant: "secondary", class: "btn btn-outline-secondary d-flex align-items-center", onClick: this.downloadCSV }, "Export CSV"))), h("div", { key: '427a17dabc56f57f7c91d36916516d78fc3fadf8', slot: 'detail-sections' }, h(DetailSectionTitle, { key: '08b15fa861e7d560df9e6025f79bf4b1c0ca861a', sectionTitle: "Details" }), h("div", { key: '77977c92b829ac50ffb5af03860ae1966116b703', class: "d-table gap-2 w-100" }, h(DetailItem, { key: '32f2044cb92d6870e053eb92de901e040c15ec2e', title: "Date paid", value: formatDate(this.payout.deposits_at) }), h(DetailItem, { key: '52e3acbe2a733e1d6f28a509b9eefaaffd94ee7a', title: "Statement Description", value: this.payout.description }), h(DetailItem, { key: '62ad6df7ed23c6f5f8babacb4bd4b22636f1b42b', title: "Payout Method", value: this.payout.delivery_method }), h(DetailItem, { key: '318d56c8cec9f35070df658bc1bb2aefa2f4fe75', title: "Amount", value: this.payout.formattedPaymentAmount(this.payout.amount) }), h(DetailItem, { key: '49b8c56d9e17c94ea48f693fe296ded03956f62e', title: "Fee", value: this.payout.formattedPaymentAmount(this.payout.fees_total) })), h(DetailSectionTitle, { key: 'a886b2c55ae3759319157ef962d976ca20e9f28c', sectionTitle: "Account" }), h("div", { key: '06f4475021fa8cd81dd42b7de5bf511275872d24', class: "d-table gap-2 w-100" }, h(DetailItem, { key: '614a22ffb02c6b50381cad42b6ac96a08904bab7', title: "ID", value: this.payout.account_id }), h(DetailItem, { key: 'fb5a846b307a56987d0f793a4ed340e2c883bc74', title: "Account Type", value: this.payout.bank_account.account_type }), h(DetailItem, { key: '5cd13f1e3244b4e64dee2f68a1d85f1c4a3503a5', title: "Institution", value: this.payout.bank_account.account_type }), h(DetailItem, { key: '4b09718e6f39c440016e6ddca4d93bc73e10255a', title: "Routing Number", value: this.payout.bank_account.routing_number }), h(DetailItem, { key: '3fd5b3572698f7e84de5d047277389fb521dbe54', title: "Account Number", value: this.payout.bank_account.account_number_last4 })), this.payout.metadata && [
            h(DetailSectionTitle, { key: '556639af0cc42f631033ce58c29c34fe72acbec7', sectionTitle: 'Metadata' }),
            h("div", { key: '5429777122823531e770ed074103385cf587d3ae', class: "d-table gap-2 w-100" }, h(CodeBlock, { key: 'bfef600620b9a041678987fcf5abdb5b8dbc9672', metadata: this.payout.metadata }))
        ])))));
    }
    static get watchers() { return {
        "getPayout": ["getPayoutWatcher"]
    }; }
}, [0, "payout-details-core", {
        "getPayout": [16, "get-payout"],
        "getPayoutCSV": [16, "get-payout-c-s-v"],
        "payout": [32],
        "loading": [32],
        "errorMessage": [32]
    }, undefined, {
        "getPayout": ["getPayoutWatcher"]
    }]);
function defineCustomElement() {
    if (typeof customElements === "undefined") {
        return;
    }
    const components = ["payout-details-core", "justifi-details"];
    components.forEach(tagName => { switch (tagName) {
        case "payout-details-core":
            if (!customElements.get(tagName)) {
                customElements.define(tagName, PayoutDetailsCore);
            }
            break;
        case "justifi-details":
            if (!customElements.get(tagName)) {
                defineCustomElement$1();
            }
            break;
    } });
}
defineCustomElement();

export { PayoutDetailsCore as P, defineCustomElement as d };
