import { proxyCustomElement, HTMLElement, h } from '@stencil/core/internal/client';
import { S as StyledHost } from './styled-host.js';
import './details.js';
import './event-types.js';
import './justifi-radio-list-item2.js';
import { n as numberOnlyHandler } from './utils3.js';
import { F as FormController } from './form.js';
import { b as billingFormSchema } from './billing-form-schema.js';
import { o as onChange } from './checkout.store.js';
import { d as defineCustomElement$3 } from './custom-popper2.js';
import { d as defineCustomElement$2 } from './form-control-text2.js';
import { d as defineCustomElement$1 } from './form-control-tooltip2.js';

const PostalCodeForm = /*@__PURE__*/ proxyCustomElement(class PostalCodeForm extends HTMLElement {
    constructor() {
        super();
        this.__registerHost();
        this.__attachShadow();
        this.errors = {};
        this.inputHandler = (name, value) => {
            this.formController.setValues(Object.assign(Object.assign({}, this.formController.values.getValue()), { [name]: value }));
        };
    }
    connectedCallback() {
        this.unsubscribe = onChange('billingFormFields', (newValue) => {
            this.formController.setInitialValues(newValue);
        });
    }
    disconnectedCallback() {
        var _a;
        (_a = this.unsubscribe) === null || _a === void 0 ? void 0 : _a.call(this);
    }
    componentWillLoad() {
        this.formController = new FormController(billingFormSchema(true));
    }
    componentDidLoad() {
        this.formController.values.subscribe(values => this.billingInfo = Object.assign({}, values));
        this.formController.errors.subscribe(errors => {
            this.errors = Object.assign({}, errors);
        });
    }
    async getValues() {
        return this.formController.values.getValue();
    }
    async fill(fields) {
        this.formController.setInitialValues(fields);
    }
    async validate() {
        let isValid = await this.formController.validate();
        const errors = this.formController.errors.getValue();
        return { isValid, errors };
    }
    render() {
        const billingFormDefaultValue = this.formController.getInitialValues();
        return (h(StyledHost, { key: '881138113d82dd87a364cbadef1947f34d3cdf4f' }, h("form", { key: '647945d6264d0611fcc7970eded8ce22ac2b4db7' }, h("form-control-text", { key: '2308fdcc1634fa8b39ce0735ab3431a406bc7398', name: 'address_postal_code', label: "ZIP", defaultValue: billingFormDefaultValue.address_postal_code, errorText: this.errors.address_postal_code, inputHandler: this.inputHandler, maxLength: 5, keyDownHandler: numberOnlyHandler }))));
    }
}, [1, "justifi-postal-code-form", {
        "formController": [32],
        "billingInfo": [32],
        "errors": [32],
        "getValues": [64],
        "fill": [64],
        "validate": [64]
    }]);
function defineCustomElement() {
    if (typeof customElements === "undefined") {
        return;
    }
    const components = ["justifi-postal-code-form", "custom-popper", "form-control-text", "form-control-tooltip"];
    components.forEach(tagName => { switch (tagName) {
        case "justifi-postal-code-form":
            if (!customElements.get(tagName)) {
                customElements.define(tagName, PostalCodeForm);
            }
            break;
        case "custom-popper":
            if (!customElements.get(tagName)) {
                defineCustomElement$3();
            }
            break;
        case "form-control-text":
            if (!customElements.get(tagName)) {
                defineCustomElement$2();
            }
            break;
        case "form-control-tooltip":
            if (!customElements.get(tagName)) {
                defineCustomElement$1();
            }
            break;
    } });
}
defineCustomElement();

export { PostalCodeForm as P, defineCustomElement as d };
