import { proxyCustomElement, HTMLElement, h } from '@stencil/core/internal/client';
import { c as create$3, a as create$6, F as FormController } from './form.js';
import { D as DisputeResponseFormStep, f as fileInputHandler } from './file-input-handler.js';
import { _ as heading5 } from './parts.js';
import { d as defineCustomElement$5 } from './custom-popper2.js';
import { d as defineCustomElement$4 } from './form-control-file-v22.js';
import { d as defineCustomElement$3 } from './form-control-help-text2.js';
import { d as defineCustomElement$2 } from './form-control-textarea2.js';
import { d as defineCustomElement$1 } from './form-control-tooltip2.js';

const RefundPolicySchema = create$3({
    refund_policy_disclosure: create$6().nullable(),
    refund_refusal_explanation: create$6().nullable(),
});

const RefundPolicy = /*@__PURE__*/ proxyCustomElement(class RefundPolicy extends HTMLElement {
    constructor() {
        super();
        this.__registerHost();
        this.documentErrors = {};
        this.errors = {};
        this.documents = { refund_policy: [], receipt: [] };
        this.inputHandler = (name, value) => {
            this.form.setValues(Object.assign(Object.assign({}, this.form.values.getValue()), { [name]: value }));
        };
    }
    async validateAndSubmit(onSuccess) {
        const documentList = Object.values(this.documents).flat();
        this.form.validateAndSubmit((formData) => onSuccess(formData, documentList, DisputeResponseFormStep.refundPolicy));
    }
    ;
    componentWillLoad() {
        this.form = new FormController(RefundPolicySchema);
    }
    componentDidLoad() {
        this.form.errors.subscribe(errors => {
            this.errors = Object.assign({}, errors);
        });
    }
    render() {
        var _a, _b, _c, _d;
        return (h("div", { key: '75d1e4a99166f8b8f112746fd5a786ed4b41b6ae' }, h("div", { key: 'c4a137ad32f0a0e5580061b1cc2443399d5baf15', class: "row gy-3" }, h("div", { key: '8b864aacd4b1334f9a5e7ffdf116345db20aac58', class: "col-12" }, h("h2", { key: 'e319c7e0d2ebedf204e6845fb977651b96f4a9b8', class: "h5", part: heading5 }, "Refund Policy and Receipt")), h("div", { key: '72cc1aff194c70395f8002b4af6842cd42046d80', class: "col-12" }, h("form-control-textarea", { key: '798219393da9f68198205bb877a5a3aa2ac2d1bb', label: "Refund Policy Disclosure", name: "refund_policy_disclosure", defaultValue: (_a = this.disputeResponse) === null || _a === void 0 ? void 0 : _a.refund_policy_disclosure, inputHandler: this.inputHandler })), h("div", { key: 'bc0d341abb63327da6d97fba120c34aebabd50b3', class: "col-12" }, h("form-control-textarea", { key: '2aa931300951be7897d9ba4adeda6be5e94a00d8', label: "Refund Refusal Explanation", name: "refund_refusal_explanation", defaultValue: (_b = this.disputeResponse) === null || _b === void 0 ? void 0 : _b.refund_refusal_explanation, inputHandler: this.inputHandler })), h("div", { key: 'c3cad588c5b40a6133920a0c43f71d7b172abdab', class: "col-12" }, h("form-control-file-v2", { key: '8f2184a0d95804a85d61de763c14b1a6fb44c566', label: "Upload Refund Policy", name: "refund_policy", onChange: (e) => fileInputHandler(e, this.documents), errorText: (_c = this.documentErrors) === null || _c === void 0 ? void 0 : _c.refund_policy })), h("div", { key: '183f6286e96694e54fd31213b514349a43d0446f', class: "col-12" }, h("form-control-file-v2", { key: 'e3f97404946c8e6a813d397141d10e372df5f520', label: "Upload Receipt", name: "receipt", onChange: (e) => fileInputHandler(e, this.documents), errorText: (_d = this.documentErrors) === null || _d === void 0 ? void 0 : _d.receipt })))));
    }
}, [0, "justifi-refund-policy", {
        "disputeResponse": [8, "dispute-response"],
        "documentErrors": [8, "document-errors"],
        "form": [32],
        "errors": [32],
        "documents": [32],
        "validateAndSubmit": [64]
    }]);
function defineCustomElement() {
    if (typeof customElements === "undefined") {
        return;
    }
    const components = ["justifi-refund-policy", "custom-popper", "form-control-file-v2", "form-control-help-text", "form-control-textarea", "form-control-tooltip"];
    components.forEach(tagName => { switch (tagName) {
        case "justifi-refund-policy":
            if (!customElements.get(tagName)) {
                customElements.define(tagName, RefundPolicy);
            }
            break;
        case "custom-popper":
            if (!customElements.get(tagName)) {
                defineCustomElement$5();
            }
            break;
        case "form-control-file-v2":
            if (!customElements.get(tagName)) {
                defineCustomElement$4();
            }
            break;
        case "form-control-help-text":
            if (!customElements.get(tagName)) {
                defineCustomElement$3();
            }
            break;
        case "form-control-textarea":
            if (!customElements.get(tagName)) {
                defineCustomElement$2();
            }
            break;
        case "form-control-tooltip":
            if (!customElements.get(tagName)) {
                defineCustomElement$1();
            }
            break;
    } });
}
defineCustomElement();

export { RefundPolicy as R, defineCustomElement as d };
