import { proxyCustomElement, HTMLElement, h } from '@stencil/core/internal/client';
import { r as radioListItem } from './parts.js';
import { S as StyledHost } from './styled-host.js';
import './details.js';
import './event-types.js';
import './justifi-radio-list-item2.js';
import { c as checkoutStore } from './checkout.store.js';
import { C as CardBrandLabels } from './payment-method-option-utils.js';
import { d as defineCustomElement$2 } from './form-control-help-text2.js';
import { d as defineCustomElement$1 } from './form-control-radio2.js';

const SavedPaymentMethods = /*@__PURE__*/ proxyCustomElement(class SavedPaymentMethods extends HTMLElement {
    constructor() {
        super();
        this.__registerHost();
        this.__attachShadow();
        this.onPaymentMethodOptionClick = (paymentMethodId) => (e) => {
            e.preventDefault();
            checkoutStore.selectedPaymentMethod = paymentMethodId;
        };
        this.isAllowedPaymentMethod = (paymentMethod) => {
            if (paymentMethod.type === 'card' && checkoutStore.disableCreditCard) {
                return false;
            }
            if (paymentMethod.type === 'bank_account' && checkoutStore.disableBankAccount) {
                return false;
            }
            return true;
        };
    }
    componentWillLoad() {
        if (!checkoutStore.paymentMethods.length) {
            console.warn('No saved payment methods available.');
        }
        if (checkoutStore.disablePaymentMethodGroup) {
            console.warn('Payment method group is disabled.');
        }
    }
    render() {
        if (checkoutStore.disablePaymentMethodGroup) {
            return null;
        }
        return (h(StyledHost, null, h("div", { class: "saved-payment-methods" }, checkoutStore.paymentMethods.length ? checkoutStore.paymentMethods
            .filter(this.isAllowedPaymentMethod)
            .map((paymentMethod) => (h("div", { class: "radio-list-item p-3", part: radioListItem, onClick: this.onPaymentMethodOptionClick(paymentMethod === null || paymentMethod === void 0 ? void 0 : paymentMethod.id) }, h("form-control-radio", { name: "paymentMethodType", value: paymentMethod === null || paymentMethod === void 0 ? void 0 : paymentMethod.id, checked: checkoutStore.selectedPaymentMethod === (paymentMethod === null || paymentMethod === void 0 ? void 0 : paymentMethod.id), label: `${CardBrandLabels[paymentMethod === null || paymentMethod === void 0 ? void 0 : paymentMethod.brand] || ''} *${paymentMethod === null || paymentMethod === void 0 ? void 0 : paymentMethod.acct_last_four}` })))) : null)));
    }
}, [1, "justifi-saved-payment-methods"]);
function defineCustomElement() {
    if (typeof customElements === "undefined") {
        return;
    }
    const components = ["justifi-saved-payment-methods", "form-control-help-text", "form-control-radio"];
    components.forEach(tagName => { switch (tagName) {
        case "justifi-saved-payment-methods":
            if (!customElements.get(tagName)) {
                customElements.define(tagName, SavedPaymentMethods);
            }
            break;
        case "form-control-help-text":
            if (!customElements.get(tagName)) {
                defineCustomElement$2();
            }
            break;
        case "form-control-radio":
            if (!customElements.get(tagName)) {
                defineCustomElement$1();
            }
            break;
    } });
}
defineCustomElement();

export { SavedPaymentMethods as S, defineCustomElement as d };
