import { h, proxyCustomElement, HTMLElement, createEvent } from '@stencil/core/internal/client';
import { p as processHTML, c as formatCurrency, r as removeAttribute, j as addAttribute } from './utils2.js';
import { v as validateInsuranceValues, a as insuranceValues, b as insuranceErrors } from './insurance-state.js';
import { t as text, j as textDanger } from './parts.js';
import { S as StyledHost } from './styled-host.js';
import { H as Header2 } from './header-2.js';
import './details.js';
import './event-types.js';
import './justifi-radio-list-item2.js';
import { S as Skeleton } from './skeleton.js';
import { d as defineCustomElement$2 } from './form-control-help-text2.js';
import { d as defineCustomElement$1 } from './form-control-radio2.js';

const SeasonInterruptionInsuranceLoading = () => (h("div", { class: "row gap-3" },
    h("div", { class: "col-12" },
        h(Skeleton, { width: "35%", height: "30px" })),
    h("div", { class: "col-12" },
        h(Skeleton, { width: "70%" })),
    h("div", { class: "col-12" },
        h(Skeleton, { width: "40%" })),
    h("div", { class: "col-12" },
        h(Skeleton, { width: "40%" })),
    h("div", { class: "col-12" },
        h(Skeleton, { width: "100%" })),
    h("div", { class: "col-12" },
        h(Skeleton, { width: "80%" }))));

const SeasonInterruptionInsuranceCore = /*@__PURE__*/ proxyCustomElement(class SeasonInterruptionInsuranceCore extends HTMLElement {
    constructor() {
        super();
        this.__registerHost();
        this.__attachShadow();
        this.insuranceUpdated = createEvent(this, "insurance-updated", 7);
        this.errorEvent = createEvent(this, "error-event", 7);
        this.isLoading = true;
    }
    async validate() {
        return validateInsuranceValues();
    }
    componentWillLoad() {
        if (this.getQuote) {
            this.fetchData();
        }
    }
    ;
    fetchData() {
        this.isLoading = true;
        this.getQuote({
            payload: {
                checkout_id: this.checkoutId,
                policy_type: "season_interruption",
                primary_identity: {
                    state: this.primaryIdentityState,
                    email: this.primaryIdentityEmailAddress,
                    first_name: this.primaryIdentityFirstName,
                    last_name: this.primaryIdentityLastName,
                    postal_code: this.primaryIdentityPostalCode,
                    country: this.primaryIdentityCountry
                },
                policy_attributes: {
                    insurable_amount: this.policyAttributesInsurableAmount,
                    start_date: this.policyAttributesStartDate,
                    end_date: this.policyAttributesEndDate,
                    covered_identity: {
                        first_name: this.coveredIdentityFirstName,
                        last_name: this.coveredIdentityLastName
                    }
                }
            },
            onSuccess: ({ quote }) => {
                this.quote = quote;
                this.quote.product.description = processHTML(this.quote.product.description, [
                    (html) => removeAttribute(html, 'style'),
                    (html) => addAttribute(html, 'a', 'part', text)
                ]);
                this.quote.product.legal_disclaimer = processHTML(this.quote.product.legal_disclaimer, [
                    (html) => removeAttribute(html, 'style'),
                    (html) => addAttribute(html, 'a', 'part', text)
                ]);
                insuranceValues[quote.policy_type] = quote.accepted;
                this.isLoading = false;
            },
            onError: ({ error, code, severity }) => {
                this.isLoading = false;
                this.errorEvent.emit({
                    errorCode: code,
                    message: error,
                    severity,
                });
            }
        });
    }
    ;
    onChangeHandler(_name, value) {
        this.accepted = value;
        insuranceErrors[this.quote.policy_type] = false;
        this.toggleCoverage({
            quoteId: this.quote.id,
            payload: { accepted: this.accepted },
            onSuccess: () => {
                this.insuranceUpdated.emit();
                insuranceValues[this.quote.policy_type] = this.accepted;
            },
            onError: ({ error, code, severity }) => {
                this.errorEvent.emit({
                    errorCode: code,
                    message: error,
                    severity,
                });
            }
        });
    }
    get error() {
        var _a;
        return insuranceErrors[(_a = this.quote) === null || _a === void 0 ? void 0 : _a.policy_type];
    }
    render() {
        var _a, _b, _c, _d;
        if (this.isLoading)
            return (h(StyledHost, null, h(SeasonInterruptionInsuranceLoading, null)));
        return (h(StyledHost, null, h(Header2, { text: (_a = this.quote) === null || _a === void 0 ? void 0 : _a.product.title, class: "fs-5 fw-bold pb-3" }), h("small", { innerHTML: (_b = this.quote) === null || _b === void 0 ? void 0 : _b.product.description, part: text }), h("form-control-radio", { label: `Accept coverage for ${formatCurrency((_c = this.quote) === null || _c === void 0 ? void 0 : _c.total_cents)}`, name: "opt-in", value: 'true', checked: this.accepted === 'true', inputHandler: this.onChangeHandler.bind(this),
            // don't wanna show error message, but need to show the red border
            errorText: this.error ? ' ' : undefined }), h("form-control-radio", { label: "Decline coverage", name: "opt-in", value: 'false', checked: this.accepted === 'false', inputHandler: this.onChangeHandler.bind(this), errorText: this.error ? ' ' : undefined }), h("div", { class: "invalid-feedback", style: { display: this.error ? 'block' : 'none' }, part: textDanger }, "Please select an option"), h("small", { innerHTML: (_d = this.quote) === null || _d === void 0 ? void 0 : _d.product.legal_disclaimer, part: text })));
    }
}, [1, "justifi-season-interruption-insurance-core", {
        "checkoutId": [1, "checkout-id"],
        "getQuote": [16, "get-quote"],
        "toggleCoverage": [16, "toggle-coverage"],
        "primaryIdentityFirstName": [1, "primary-identity-first-name"],
        "primaryIdentityLastName": [1, "primary-identity-last-name"],
        "primaryIdentityState": [1, "primary-identity-state"],
        "primaryIdentityPostalCode": [1, "primary-identity-postal-code"],
        "primaryIdentityCountry": [1, "primary-identity-country"],
        "primaryIdentityEmailAddress": [1, "primary-identity-email-address"],
        "policyAttributesInsurableAmount": [2, "policy-attributes-insurable-amount"],
        "policyAttributesStartDate": [1, "policy-attributes-start-date"],
        "policyAttributesEndDate": [1, "policy-attributes-end-date"],
        "coveredIdentityFirstName": [1, "covered-identity-first-name"],
        "coveredIdentityLastName": [1, "covered-identity-last-name"],
        "quote": [32],
        "isLoading": [32],
        "accepted": [32],
        "validate": [64]
    }]);
function defineCustomElement() {
    if (typeof customElements === "undefined") {
        return;
    }
    const components = ["justifi-season-interruption-insurance-core", "form-control-help-text", "form-control-radio"];
    components.forEach(tagName => { switch (tagName) {
        case "justifi-season-interruption-insurance-core":
            if (!customElements.get(tagName)) {
                customElements.define(tagName, SeasonInterruptionInsuranceCore);
            }
            break;
        case "form-control-help-text":
            if (!customElements.get(tagName)) {
                defineCustomElement$2();
            }
            break;
        case "form-control-radio":
            if (!customElements.get(tagName)) {
                defineCustomElement$1();
            }
            break;
    } });
}
defineCustomElement();

export { SeasonInterruptionInsuranceCore as S, defineCustomElement as d };
