import { h, proxyCustomElement, HTMLElement, createEvent } from '@stencil/core/internal/client';
import { c as formatCurrency } from './utils2.js';
import { r as radioListItem } from './parts.js';
import { c as checkoutStore } from './checkout.store.js';
import { S as StyledHost } from './styled-host.js';
import './details.js';
import './event-types.js';
import './justifi-radio-list-item2.js';
import { d as defineCustomElement$2 } from './form-control-help-text2.js';
import { d as defineCustomElement$1 } from './form-control-radio2.js';

const sezzleLogo = (h("img", { class: "sezzle-smart-button-logo-img", src: "https://media.sezzle.com/branding/2.0/Sezzle_Logo_FullColor.svg", alt: "Sezzle", style: {
        display: 'inline',
        width: '80px',
        marginLeft: '5px',
        marginTop: '-5px',
    } }));
const SezzlePaymentMethod = /*@__PURE__*/ proxyCustomElement(class SezzlePaymentMethod extends HTMLElement {
    constructor() {
        super();
        this.__registerHost();
        this.__attachShadow();
        this.paymentMethodOptionSelected = createEvent(this, "paymentMethodOptionSelected", 7);
        this.paymentMethodOptionId = 'sezzle';
        this.onPaymentMethodOptionClick = (e) => {
            e.preventDefault();
            checkoutStore.selectedPaymentMethod = this.paymentMethodOptionId;
            this.paymentMethodOptionSelected.emit(this.paymentMethodOptionId);
        };
        this.initializeSezzleCheckout = () => {
            let resolveSezzlePromise;
            this.sezzlePromise = new Promise((resolve) => { resolveSezzlePromise = resolve; });
            const amount = Number(checkoutStore.paymentAmount);
            const Checkout = window.Checkout;
            const checkout = new Checkout({
                mode: 'popup',
                publicKey: checkoutStore.bnplProviderClientId,
                apiMode: checkoutStore.bnplProviderMode,
                apiVersion: checkoutStore.bnplProviderApiVersion,
            });
            checkout.sezzleButtonElement = this.sezzleButtonRef;
            checkout.init({
                onClick: function (event) {
                    event.preventDefault();
                    checkout.startCheckout({
                        checkout_url: checkoutStore.bnplProviderCheckoutUrl,
                    });
                },
                onComplete: (event) => resolveSezzlePromise({ bnpl: event.data }),
                onCancel: (event) => resolveSezzlePromise({ bnpl: event.data }),
                onFailure: (event) => resolveSezzlePromise({ bnpl: event.data }),
            });
            this.sezzleCheckout = checkout;
            this.installmentPlan = this.sezzleCheckout.getInstallmentPlan(amount);
        };
    }
    componentDidRender() {
        if (!this.scriptRef)
            return;
        this.scriptRef.onload = () => {
            this.sezzleButtonRef = document.createElement('button');
            this.initializeSezzleCheckout();
        };
    }
    async resolvePaymentMethod(insuranceValidation) {
        if (!insuranceValidation.isValid) {
            return { validationError: true };
        }
        this.sezzleButtonRef.click();
        return this.sezzlePromise;
    }
    render() {
        var _a, _b;
        if (!checkoutStore.bnplEnabled || checkoutStore.disableBnpl) {
            console.warn('justifi-sezzle-payment-method: BNPL is not enabled for this account.');
            return null;
        }
        return (h(StyledHost, { class: "payment-method" }, h("script", { src: "https://checkout-sdk.sezzle.com/checkout.min.js", async: true, ref: (el) => (this.scriptRef = el) }), h("div", { class: "radio-list-item p-3", part: radioListItem, onClick: this.onPaymentMethodOptionClick }, h("form-control-radio", { name: "paymentMethodType", value: this.paymentMethodOptionId, checked: checkoutStore.selectedPaymentMethod === this.paymentMethodOptionId, label: h("div", null, h("div", null, "Buy now, pay later with ", sezzleLogo), this.installmentPlan && (h("small", null, h("span", null, (_a = this.installmentPlan) === null || _a === void 0 ? void 0 : _a.installments.length), "\u00A0", h("span", null, this.installmentPlan.schedule, " payments of"), "\u00A0", h("span", { class: "fw-bold" }, formatCurrency((_b = this.installmentPlan) === null || _b === void 0 ? void 0 : _b.installments[0].amountInCents))))) }))));
    }
}, [1, "justifi-sezzle-payment-method", {
        "installmentPlan": [32],
        "sezzleCheckout": [32],
        "sezzlePromise": [32],
        "resolvePaymentMethod": [64]
    }]);
function defineCustomElement() {
    if (typeof customElements === "undefined") {
        return;
    }
    const components = ["justifi-sezzle-payment-method", "form-control-help-text", "form-control-radio"];
    components.forEach(tagName => { switch (tagName) {
        case "justifi-sezzle-payment-method":
            if (!customElements.get(tagName)) {
                customElements.define(tagName, SezzlePaymentMethod);
            }
            break;
        case "form-control-help-text":
            if (!customElements.get(tagName)) {
                defineCustomElement$2();
            }
            break;
        case "form-control-radio":
            if (!customElements.get(tagName)) {
                defineCustomElement$1();
            }
            break;
    } });
}
defineCustomElement();

export { SezzlePaymentMethod as S, defineCustomElement as d };
