import { IApiResponse } from './Api';
import { CurrencyTypes } from './Payment';
export interface IBnpl {
    provider: string;
    provider_client_id: string;
    provider_mode: string;
    provider_checkout_url: string;
    provider_order_id: string;
    provider_api_version: string;
}
interface ICompletion {
    payment_mode?: ICheckoutPaymentMode;
    payment_token?: string | null;
    payment_status?: string | null;
    payment_response?: any;
    payment_error_code?: string | null;
    payment_error_description?: string | null;
    checkout_id?: string;
    additional_transactions?: any[];
    payment_id?: string;
    payment_method_id?: string;
    status?: string;
    created_at: string;
    updated_at: string;
}
export declare class Completion implements ICompletion {
    payment_mode?: ICheckoutPaymentMode;
    payment_token?: string | null;
    payment_status?: string | null;
    payment_response?: any;
    payment_error_code?: string | null;
    payment_error_description?: string | null;
    checkout_id?: string;
    additional_transactions?: any[];
    payment_id?: string;
    payment_method_id?: string;
    status?: string;
    created_at: string;
    updated_at: string;
    constructor(data: ICompletion);
}
export interface ICheckout {
    id: string;
    description: string;
    payment_intent_id: string;
    account_id: string;
    platform_account_id: string;
    payment_amount: number;
    payment_client_id: string;
    payment_description: string;
    payment_methods: {
        id: string;
        status: string;
        invalid_reason: null;
        name: string;
        brand: string;
        acct_last_four: string;
        month: string;
        year: string;
        address_line1_check: string;
        address_postal_code_check: string;
        bin_details: null;
    }[];
    payment_method_group_id: string;
    payment_settings: {
        ach_payments: boolean;
        bnpl_payments: boolean;
        credit_card_payments: boolean;
    };
    bnpl?: IBnpl;
    total_amount: number;
    insurance_amount: number;
    status: ICheckoutStatus;
    payment_currency?: CurrencyTypes;
    mode?: string | null;
    statement_descriptor?: string | null;
    application_fees?: any[] | null;
    successful_payment_id?: string | null;
    created_at: string;
    updated_at: string;
    completions?: ICompletion[];
}
export declare class Checkout implements ICheckout {
    id: string;
    description: string;
    payment_intent_id: string;
    account_id: string;
    platform_account_id: string;
    payment_amount: number;
    payment_client_id: string;
    payment_description: string;
    payment_methods: ICheckoutPaymentMethod[];
    payment_method_group_id: string;
    payment_settings: {
        ach_payments: boolean;
        bnpl_payments: boolean;
        credit_card_payments: boolean;
    };
    bnpl?: IBnpl;
    total_amount: number;
    insurance_amount: number;
    status: ICheckoutStatus;
    payment_currency?: CurrencyTypes;
    mode?: string | null;
    statement_descriptor?: string | null;
    application_fees?: any[] | null;
    successful_payment_id?: string | null;
    created_at: string;
    updated_at: string;
    completions?: ICompletion[];
    sub_account_name?: string;
    constructor(data: ICheckout);
    get payment_mode(): ICheckoutPaymentMode;
    formattedPaymentAmount(amount: number): string;
}
export declare enum ICheckoutPaymentMode {
    bnpl = "Buy Now Pay Later",
    ecom = "E-commerce",
    card = "Card",
    bank_account = "Bank Account",
    card_present = "Card Present",
    unknown = ""
}
export declare enum ICheckoutPaymentModeParam {
    bnpl = "bnpl",
    ecom = "ecom"
}
export declare enum ICheckoutStatus {
    created = "created",
    completed = "completed",
    attempted = "attempted",
    expired = "expired"
}
export declare enum CompletionStatuses {
    failed = "failed",
    succeeded = "succeeded"
}
export type ICheckoutCompleteResponse = IApiResponse<{
    payment_mode: ICheckoutPaymentMode;
    payment_token: null;
    payment_status: string;
    payment_response: null;
    checkout_id: string;
    additional_transactions: any[];
    checkout: ICheckout;
}>;
export type ILoadedEventResponse = {
    checkout_status: ICheckoutStatus;
};
export interface CheckoutsQueryParams {
    status?: ICheckoutStatus;
    payment_mode?: ICheckoutPaymentMode;
}
export interface ICheckoutPaymentMethod {
    id: string;
    type?: string;
    status: string;
    invalid_reason: null;
    name: string;
    brand: string;
    acct_last_four: string;
    month: string;
    year: string;
    address_line1_check: string;
    address_postal_code_check: string;
    bin_details: null;
}
export {};
