export interface IDocument {
    business_id: string;
    created_at: string;
    description: string | null;
    document_type: string;
    file_name: string;
    file_type: string;
    id: string;
    identity_id: string;
    metadata: any;
    platform_account_id: string;
    presigned_url: string | null;
    status: EntityDocumentStatus;
    updated_at: string;
}
export declare enum EntityDocumentType {
    voidedCheck = "voided_check",
    balanceSheet = "balance_sheet",
    bankStatement = "bank_statement",
    governmentId = "government_id",
    profitAndLossStatement = "profit_and_loss_statement",
    taxReturn = "tax_return",
    other = "other"
}
export declare enum EntityDocumentStatus {
    pending = "pending",
    uploaded = "uploaded",
    canceled = "canceled",
    needed = "needed"
}
export interface FileSelectEvent {
    fileList: FileList;
    document_type: EntityDocumentType;
}
export interface DocumentRecordData {
    business_id: string;
    document_type: EntityDocumentType;
    file_name: string;
    file_type: string;
}
export declare class EntityDocumentStorage {
    voided_check: EntityDocument[];
    balance_sheet: EntityDocument[];
    bank_statement: EntityDocument[];
    government_id: EntityDocument[];
    profit_and_loss_statement: EntityDocument[];
    tax_return: EntityDocument[];
    other: EntityDocument[];
    constructor();
}
export interface EntityFileData {
    file: File;
    document_type: EntityDocumentType;
}
export declare class EntityDocument {
    file: File;
    fileData: ArrayBuffer | null;
    document_type: EntityDocumentType;
    presigned_url: string | null;
    record_data: DocumentRecordData | null;
    constructor(fileData: EntityFileData, business_id: string);
    getFileData(): Promise<ArrayBuffer>;
    setPresignedUrl(url: string): void;
}
